/*
Copyright (C) 2008-2009  Anders Hedstrom (grymse@alhem.net)

This program is made available under the terms of the GNU GPL.

If you would like to use this program in a closed-source application,
a separate license agreement is available. For information about 
the closed-source license agreement for this program, please
visit http://www.alhem.net/Sockets/license.html and/or
email license@alhem.net.

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#include "FejsBokk.h"
#include <Sockets/XmlNode.h>
#include <Sockets/XmlException.h>
#include <Sockets/Utility.h>

/** http://api.facebook.com/1.0/ */
namespace com_facebook_1_0_ {

// -----------------------------------------------------------------------------
User_status::User_status()
: _element_comment_count(0)
, _element_message_is_set(false)
, _element_time_is_set(false)
, _element_status_id_is_set(false)
, _element_source_is_set(false)
, _element_uid_is_set(false)
, _element_comment_count_is_set(false)
{
}


// -----------------------------------------------------------------------------
User_status::User_status(const Xml::XmlNode& it)
: _element_comment_count(0)
, _element_message_is_set(false)
, _element_time_is_set(false)
, _element_status_id_is_set(false)
, _element_source_is_set(false)
, _element_uid_is_set(false)
, _element_comment_count_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void User_status::clear()
{
	_element_message.clear();
	// simpleType:
	// _element_time.clear();
	// simpleType:
	// _element_status_id.clear();
	_element_source.clear();
	// simpleType:
	// _element_uid.clear();
	_element_comment_count = 0;
	_element_message_is_set = false;
	_element_time_is_set = false;
	_element_status_id_is_set = false;
	_element_source_is_set = false;
	_element_uid_is_set = false;
	_element_comment_count_is_set = false;
}


// -----------------------------------------------------------------------------
void User_status::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("message"))
		throw Xml::XmlException("missing required node in element 'user_status': message");
	SetMessage( it["message"] );
	if (!it.Exists("time"))
		throw Xml::XmlException("missing required node in element 'user_status': time");
	SetTime( atoi(std::string(it["time"]).c_str()) );
	if (!it.Exists("status_id"))
		throw Xml::XmlException("missing required node in element 'user_status': status_id");
	SetStatus_id( atoi(std::string(it["status_id"]).c_str()) );
	if (!it.Exists("source"))
		throw Xml::XmlException("missing required node in element 'user_status': source");
	SetSource( it["source"] );
	if (!it.Exists("uid"))
		throw Xml::XmlException("missing required node in element 'user_status': uid");
	SetUid( atoi(std::string(it["uid"]).c_str()) );
	if (!it.Exists("comment_count"))
		throw Xml::XmlException("missing required node in element 'user_status': comment_count");
	SetComment_count( atoi(std::string(it["comment_count"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string User_status::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<message>" + _element_message + "</message>";
	{
		r = r + "<time>" + Utility::l2string(_element_time) + "</time>";
	}
	{
		r = r + "<status_id>" + Utility::l2string(_element_status_id) + "</status_id>";
	}
	r += "<source>" + _element_source + "</source>";
	{
		r = r + "<uid>" + Utility::l2string(_element_uid) + "</uid>";
	}
	{
		r = r + "<comment_count>" + Utility::l2string(_element_comment_count) + "</comment_count>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool User_status::IsSet() const
{
	return MessageIsSet() || TimeIsSet() || Status_idIsSet() || SourceIsSet() || UidIsSet() || Comment_countIsSet();
}


// -----------------------------------------------------------------------------
const std::string& User_status::GetMessage() const
{
	return _element_message;
}


void User_status::SetMessage(const std::string& message)
{
	_element_message = message;
	_element_message_is_set = true;
}


// -----------------------------------------------------------------------------
long User_status::GetTime() const
{
	return _element_time;
}


void User_status::SetTime(long time)
{
	_element_time = time;
	_element_time_is_set = true;
}


// -----------------------------------------------------------------------------
long User_status::GetStatus_id() const
{
	return _element_status_id;
}


void User_status::SetStatus_id(long status_id)
{
	_element_status_id = status_id;
	_element_status_id_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User_status::GetSource() const
{
	return _element_source;
}


void User_status::SetSource(const std::string& source)
{
	_element_source = source;
	_element_source_is_set = true;
}


// -----------------------------------------------------------------------------
long User_status::GetUid() const
{
	return _element_uid;
}


void User_status::SetUid(long uid)
{
	_element_uid = uid;
	_element_uid_is_set = true;
}


// -----------------------------------------------------------------------------
int User_status::GetComment_count() const
{
	return _element_comment_count;
}


void User_status::SetComment_count(int comment_count)
{
	_element_comment_count = comment_count;
	_element_comment_count_is_set = true;
}


// -----------------------------------------------------------------------------
Comment::Comment()
: _element_xid_is_set(false)
, _element_fromid_is_set(false)
, _element_time_is_set(false)
, _element_text_is_set(false)
, _element_id_is_set(false)
, _element_username_is_set(false)
, _element_reply_xid_is_set(false)
, _element_post_id_is_set(false)
{
}


// -----------------------------------------------------------------------------
Comment::Comment(const Xml::XmlNode& it)
: _element_xid_is_set(false)
, _element_fromid_is_set(false)
, _element_time_is_set(false)
, _element_text_is_set(false)
, _element_id_is_set(false)
, _element_username_is_set(false)
, _element_reply_xid_is_set(false)
, _element_post_id_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Comment::clear()
{
	// simpleType:
	// _element_xid.clear();
	// simpleType:
	// _element_fromid.clear();
	// simpleType:
	// _element_time.clear();
	_element_text.clear();
	// simpleType:
	// _element_id.clear();
	_element_username.clear();
	// simpleType:
	// _element_reply_xid.clear();
	_element_post_id.clear();
	_element_xid_is_set = false;
	_element_fromid_is_set = false;
	_element_time_is_set = false;
	_element_text_is_set = false;
	_element_id_is_set = false;
	_element_username_is_set = false;
	_element_reply_xid_is_set = false;
	_element_post_id_is_set = false;
}


// -----------------------------------------------------------------------------
void Comment::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("xid"))
		throw Xml::XmlException("missing required node in element 'comment': xid");
	SetXid( it["xid"] );
	if (!it.Exists("fromid"))
		throw Xml::XmlException("missing required node in element 'comment': fromid");
	SetFromid( atoi(std::string(it["fromid"]).c_str()) );
	if (!it.Exists("time"))
		throw Xml::XmlException("missing required node in element 'comment': time");
	SetTime( atoi(std::string(it["time"]).c_str()) );
	if (!it.Exists("text"))
		throw Xml::XmlException("missing required node in element 'comment': text");
	SetText( it["text"] );
	if (!it.Exists("id"))
		throw Xml::XmlException("missing required node in element 'comment': id");
	SetId( atoi(std::string(it["id"]).c_str()) );
	if (!it.Exists("username"))
		throw Xml::XmlException("missing required node in element 'comment': username");
	SetUsername( it["username"] );
	if (!it.Exists("reply_xid"))
		throw Xml::XmlException("missing required node in element 'comment': reply_xid");
	SetReply_xid( it["reply_xid"] );
	if (!it.Exists("post_id"))
		throw Xml::XmlException("missing required node in element 'comment': post_id");
	SetPost_id( it["post_id"] );
}


// -----------------------------------------------------------------------------
const std::string Comment::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<xid>" + _element_xid + "</xid>";
	{
		r = r + "<fromid>" + Utility::l2string(_element_fromid) + "</fromid>";
	}
	{
		r = r + "<time>" + Utility::l2string(_element_time) + "</time>";
	}
	r += "<text>" + _element_text + "</text>";
	{
		r = r + "<id>" + Utility::l2string(_element_id) + "</id>";
	}
	r += "<username>" + _element_username + "</username>";
	r += "<reply_xid>" + _element_reply_xid + "</reply_xid>";
	r += "<post_id>" + _element_post_id + "</post_id>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Comment::IsSet() const
{
	return XidIsSet() || FromidIsSet() || TimeIsSet() || TextIsSet() || IdIsSet() || UsernameIsSet() || Reply_xidIsSet() || Post_idIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Comment::GetXid() const
{
	return _element_xid;
}


void Comment::SetXid(const std::string& xid)
{
	_element_xid = xid;
	_element_xid_is_set = true;
}


// -----------------------------------------------------------------------------
long Comment::GetFromid() const
{
	return _element_fromid;
}


void Comment::SetFromid(long fromid)
{
	_element_fromid = fromid;
	_element_fromid_is_set = true;
}


// -----------------------------------------------------------------------------
long Comment::GetTime() const
{
	return _element_time;
}


void Comment::SetTime(long time)
{
	_element_time = time;
	_element_time_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Comment::GetText() const
{
	return _element_text;
}


void Comment::SetText(const std::string& text)
{
	_element_text = text;
	_element_text_is_set = true;
}


// -----------------------------------------------------------------------------
int Comment::GetId() const
{
	return _element_id;
}


void Comment::SetId(int id)
{
	_element_id = id;
	_element_id_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Comment::GetUsername() const
{
	return _element_username;
}


void Comment::SetUsername(const std::string& username)
{
	_element_username = username;
	_element_username_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Comment::GetReply_xid() const
{
	return _element_reply_xid;
}


void Comment::SetReply_xid(const std::string& reply_xid)
{
	_element_reply_xid = reply_xid;
	_element_reply_xid_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Comment::GetPost_id() const
{
	return _element_post_id;
}


void Comment::SetPost_id(const std::string& post_id)
{
	_element_post_id = post_id;
	_element_post_id_is_set = true;
}


// -----------------------------------------------------------------------------
Profile::Profile()
: _element_id(0)
, _element_id_is_set(false)
, _element_url_is_set(false)
, _element_name_is_set(false)
, _element_pic_square_is_set(false)
, _element_type_is_set(false)
{
}


// -----------------------------------------------------------------------------
Profile::Profile(const Xml::XmlNode& it)
: _element_id(0)
, _element_id_is_set(false)
, _element_url_is_set(false)
, _element_name_is_set(false)
, _element_pic_square_is_set(false)
, _element_type_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Profile::clear()
{
	_element_id = 0;
	_element_url.clear();
	_element_name.clear();
	_element_pic_square.clear();
	_element_type.clear();
	_element_id_is_set = false;
	_element_url_is_set = false;
	_element_name_is_set = false;
	_element_pic_square_is_set = false;
	_element_type_is_set = false;
}


// -----------------------------------------------------------------------------
void Profile::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("id"))
		throw Xml::XmlException("missing required node in element 'profile': id");
	SetId( atoi(std::string(it["id"]).c_str()) );
	if (!it.Exists("url"))
		throw Xml::XmlException("missing required node in element 'profile': url");
	SetUrl( it["url"] );
	if (!it.Exists("name"))
		throw Xml::XmlException("missing required node in element 'profile': name");
	SetName( it["name"] );
	if (!it.Exists("pic_square"))
		throw Xml::XmlException("missing required node in element 'profile': pic_square");
	SetPic_square( it["pic_square"] );
	if (!it.Exists("type"))
		throw Xml::XmlException("missing required node in element 'profile': type");
	SetType( it["type"] );
}


// -----------------------------------------------------------------------------
const std::string Profile::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<id>" + Utility::l2string(_element_id) + "</id>";
	}
	r += "<url>" + _element_url + "</url>";
	r += "<name>" + _element_name + "</name>";
	r += "<pic_square>" + _element_pic_square + "</pic_square>";
	r += "<type>" + _element_type + "</type>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Profile::IsSet() const
{
	return IdIsSet() || UrlIsSet() || NameIsSet() || Pic_squareIsSet() || TypeIsSet();
}


// -----------------------------------------------------------------------------
long Profile::GetId() const
{
	return _element_id;
}


void Profile::SetId(long id)
{
	_element_id = id;
	_element_id_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Profile::GetUrl() const
{
	return _element_url;
}


void Profile::SetUrl(const std::string& url)
{
	_element_url = url;
	_element_url_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Profile::GetName() const
{
	return _element_name;
}


void Profile::SetName(const std::string& name)
{
	_element_name = name;
	_element_name_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Profile::GetPic_square() const
{
	return _element_pic_square;
}


void Profile::SetPic_square(const std::string& pic_square)
{
	_element_pic_square = pic_square;
	_element_pic_square_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Profile::GetType() const
{
	return _element_type;
}


void Profile::SetType(const std::string& type)
{
	_element_type = type;
	_element_type_is_set = true;
}


// -----------------------------------------------------------------------------
Id_map::Id_map()
: _element_old_id_is_set(false)
, _element_new_id_is_set(false)
{
}


// -----------------------------------------------------------------------------
Id_map::Id_map(const Xml::XmlNode& it)
: _element_old_id_is_set(false)
, _element_new_id_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Id_map::clear()
{
	// simpleType:
	// _element_old_id.clear();
	// simpleType:
	// _element_new_id.clear();
	_element_old_id_is_set = false;
	_element_new_id_is_set = false;
}


// -----------------------------------------------------------------------------
void Id_map::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("old_id"))
		throw Xml::XmlException("missing required node in element 'id_map': old_id");
	SetOld_id( it["old_id"] );
	if (!it.Exists("new_id"))
		throw Xml::XmlException("missing required node in element 'id_map': new_id");
	SetNew_id( atoi(std::string(it["new_id"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Id_map::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<old_id>" + _element_old_id + "</old_id>";
	{
		r = r + "<new_id>" + Utility::l2string(_element_new_id) + "</new_id>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Id_map::IsSet() const
{
	return Old_idIsSet() || New_idIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Id_map::GetOld_id() const
{
	return _element_old_id;
}


void Id_map::SetOld_id(const std::string& old_id)
{
	_element_old_id = old_id;
	_element_old_id_is_set = true;
}


// -----------------------------------------------------------------------------
long Id_map::GetNew_id() const
{
	return _element_new_id;
}


void Id_map::SetNew_id(long new_id)
{
	_element_new_id = new_id;
	_element_new_id_is_set = true;
}


// -----------------------------------------------------------------------------
Arg::Arg()
: _element_key_is_set(false)
, _element_value_is_set(false)
{
}


// -----------------------------------------------------------------------------
Arg::Arg(const Xml::XmlNode& it)
: _element_key_is_set(false)
, _element_value_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Arg::clear()
{
	_element_key.clear();
	_element_value.clear();
	_element_key_is_set = false;
	_element_value_is_set = false;
}


// -----------------------------------------------------------------------------
void Arg::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("key"))
		throw Xml::XmlException("missing required node in element 'arg': key");
	SetKey( it["key"] );
	if (!it.Exists("value"))
		throw Xml::XmlException("missing required node in element 'arg': value");
	SetValue( it["value"] );
}


// -----------------------------------------------------------------------------
const std::string Arg::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<key>" + _element_key + "</key>";
	r += "<value>" + _element_value + "</value>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Arg::IsSet() const
{
	return KeyIsSet() || ValueIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Arg::GetKey() const
{
	return _element_key;
}


void Arg::SetKey(const std::string& key)
{
	_element_key = key;
	_element_key_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Arg::GetValue() const
{
	return _element_value;
}


void Arg::SetValue(const std::string& value)
{
	_element_value = value;
	_element_value_is_set = true;
}


// -----------------------------------------------------------------------------
FacebookApiException::FacebookApiException()
: _element_error_code(0)
, _element_error_code_is_set(false)
, _element_error_msg_is_set(false)
{
}


// -----------------------------------------------------------------------------
FacebookApiException::FacebookApiException(const Xml::XmlNode& it)
: _element_error_code(0)
, _element_error_code_is_set(false)
, _element_error_msg_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void FacebookApiException::clear()
{
	_element_error_code = 0;
	_element_error_msg.clear();
	_element_request_args.clear();
	_element_error_code_is_set = false;
	_element_error_msg_is_set = false;
}


// -----------------------------------------------------------------------------
void FacebookApiException::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("error_code"))
		throw Xml::XmlException("missing required node in element 'FacebookApiException': error_code");
	SetError_code( atoi(std::string(it["error_code"]).c_str()) );
	if (!it.Exists("error_msg"))
		throw Xml::XmlException("missing required node in element 'FacebookApiException': error_msg");
	SetError_msg( it["error_msg"] );
	if (!it.Exists("request_args"))
		throw Xml::XmlException("missing required node in element 'FacebookApiException': request_args");
	{
		Xml::XmlNode n(it, "request_args");
		if (n)
			_element_request_args.FromXml( n );
	}
}


// -----------------------------------------------------------------------------
const std::string FacebookApiException::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<error_code>" + Utility::l2string(_element_error_code) + "</error_code>";
	}
	r += "<error_msg>" + _element_error_msg + "</error_msg>";
	r += _element_request_args.ToString("request_args");
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool FacebookApiException::IsSet() const
{
	return Error_codeIsSet() || Error_msgIsSet() || Request_argsIsSet();
}


// -----------------------------------------------------------------------------
int FacebookApiException::GetError_code() const
{
	return _element_error_code;
}


void FacebookApiException::SetError_code(int error_code)
{
	_element_error_code = error_code;
	_element_error_code_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& FacebookApiException::GetError_msg() const
{
	return _element_error_msg;
}


void FacebookApiException::SetError_msg(const std::string& error_msg)
{
	_element_error_msg = error_msg;
	_element_error_msg_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::FacebookApiException::Request_args_t& FacebookApiException::GetRequest_args() const
{
	return _element_request_args;
}


com_facebook_1_0_::FacebookApiException::Request_args_t& FacebookApiException::GetRequest_args()
{
	return _element_request_args;
}


void FacebookApiException::SetRequest_args(const com_facebook_1_0_::FacebookApiException::Request_args_t& request_args)
{
	_element_request_args = request_args;
}


// -----------------------------------------------------------------------------
bool FacebookApiException::Request_argsIsSet() const
{
	return _element_request_args.IsSet();
}


// -----------------------------------------------------------------------------
FacebookApiException::Request_args_t::Request_args_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
FacebookApiException::Request_args_t::Request_args_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void FacebookApiException::Request_args_t::clear()
{
	while (!_element_arg.empty())
		_element_arg.erase( _element_arg.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void FacebookApiException::Request_args_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "arg");
		while (n)
		{
			com_facebook_1_0_::Arg tmp(n);
			_element_arg.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string FacebookApiException::Request_args_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Arg>::const_iterator it = _element_arg.begin(); it != _element_arg.end(); it++)
	{
		const com_facebook_1_0_::Arg& ref = *it;
		r += ref.ToString("arg");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool FacebookApiException::Request_args_t::IsSet() const
{
	return ArgIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Arg>& FacebookApiException::Request_args_t::GetArg() const
{
	return _element_arg;
}


std::list<com_facebook_1_0_::Arg>& FacebookApiException::Request_args_t::GetArg()
{
	return _element_arg;
}


void FacebookApiException::Request_args_t::SetArg(const std::list<com_facebook_1_0_::Arg>& arg)
{
	_element_arg = arg;
}


// -----------------------------------------------------------------------------
bool FacebookApiException::Request_args_t::ArgIsSet() const
{
	return !_element_arg.empty();
}


// -----------------------------------------------------------------------------
bool FacebookApiException::Request_args_t::GetList() const
{
	return _attribute_list;
}


void FacebookApiException::Request_args_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Session_info::Session_info()
: _element_expires(0)
, _element_session_key_is_set(false)
, _element_uid_is_set(false)
, _element_expires_is_set(false)
, _element_secret_is_set(false)
, _element_base_domain_is_set(false)
{
}


// -----------------------------------------------------------------------------
Session_info::Session_info(const Xml::XmlNode& it)
: _element_expires(0)
, _element_session_key_is_set(false)
, _element_uid_is_set(false)
, _element_expires_is_set(false)
, _element_secret_is_set(false)
, _element_base_domain_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Session_info::clear()
{
	// simpleType:
	// _element_session_key.clear();
	// simpleType:
	// _element_uid.clear();
	_element_expires = 0;
	_element_secret.clear();
	_element_base_domain.clear();
	_element_session_key_is_set = false;
	_element_uid_is_set = false;
	_element_expires_is_set = false;
	_element_secret_is_set = false;
	_element_base_domain_is_set = false;
}


// -----------------------------------------------------------------------------
void Session_info::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("session_key"))
		throw Xml::XmlException("missing required node in element 'session_info': session_key");
	SetSession_key( it["session_key"] );
	if (!it.Exists("uid"))
		throw Xml::XmlException("missing required node in element 'session_info': uid");
	SetUid( atoi(std::string(it["uid"]).c_str()) );
	if (!it.Exists("expires"))
		throw Xml::XmlException("missing required node in element 'session_info': expires");
	SetExpires( atoi(std::string(it["expires"]).c_str()) );
	if (it.Exists("secret"))
		SetSecret( it["secret"] );
	if (it.Exists("base_domain"))
		SetBase_domain( it["base_domain"] );
}


// -----------------------------------------------------------------------------
const std::string Session_info::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<session_key>" + _element_session_key + "</session_key>";
	{
		r = r + "<uid>" + Utility::l2string(_element_uid) + "</uid>";
	}
	{
		r = r + "<expires>" + Utility::l2string(_element_expires) + "</expires>";
	}
	if (_element_secret_is_set)
		r += "<secret>" + _element_secret + "</secret>";
	if (_element_base_domain_is_set)
		r += "<base_domain>" + _element_base_domain + "</base_domain>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Session_info::IsSet() const
{
	return Session_keyIsSet() || UidIsSet() || ExpiresIsSet() || SecretIsSet() || Base_domainIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Session_info::GetSession_key() const
{
	return _element_session_key;
}


void Session_info::SetSession_key(const std::string& session_key)
{
	_element_session_key = session_key;
	_element_session_key_is_set = true;
}


// -----------------------------------------------------------------------------
long Session_info::GetUid() const
{
	return _element_uid;
}


void Session_info::SetUid(long uid)
{
	_element_uid = uid;
	_element_uid_is_set = true;
}


// -----------------------------------------------------------------------------
int Session_info::GetExpires() const
{
	return _element_expires;
}


void Session_info::SetExpires(int expires)
{
	_element_expires = expires;
	_element_expires_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Session_info::GetSecret() const
{
	return _element_secret;
}


void Session_info::SetSecret(const std::string& secret)
{
	_element_secret = secret;
	_element_secret_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Session_info::GetBase_domain() const
{
	return _element_base_domain;
}


void Session_info::SetBase_domain(const std::string& base_domain)
{
	_element_base_domain = base_domain;
	_element_base_domain_is_set = true;
}


// -----------------------------------------------------------------------------
Public_session_data::Public_session_data()
: _element_expires(0)
, _element_uid_is_set(false)
, _element_api_key_is_set(false)
, _element_expires_is_set(false)
, _element_sig_is_set(false)
{
}


// -----------------------------------------------------------------------------
Public_session_data::Public_session_data(const Xml::XmlNode& it)
: _element_expires(0)
, _element_uid_is_set(false)
, _element_api_key_is_set(false)
, _element_expires_is_set(false)
, _element_sig_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Public_session_data::clear()
{
	// simpleType:
	// _element_uid.clear();
	_element_api_key.clear();
	_element_expires = 0;
	_element_sig.clear();
	_element_uid_is_set = false;
	_element_api_key_is_set = false;
	_element_expires_is_set = false;
	_element_sig_is_set = false;
}


// -----------------------------------------------------------------------------
void Public_session_data::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("uid"))
		throw Xml::XmlException("missing required node in element 'public_session_data': uid");
	SetUid( atoi(std::string(it["uid"]).c_str()) );
	if (!it.Exists("api_key"))
		throw Xml::XmlException("missing required node in element 'public_session_data': api_key");
	SetApi_key( it["api_key"] );
	if (!it.Exists("expires"))
		throw Xml::XmlException("missing required node in element 'public_session_data': expires");
	SetExpires( atoi(std::string(it["expires"]).c_str()) );
	if (!it.Exists("sig"))
		throw Xml::XmlException("missing required node in element 'public_session_data': sig");
	SetSig( it["sig"] );
}


// -----------------------------------------------------------------------------
const std::string Public_session_data::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<uid>" + Utility::l2string(_element_uid) + "</uid>";
	}
	r += "<api_key>" + _element_api_key + "</api_key>";
	{
		r = r + "<expires>" + Utility::l2string(_element_expires) + "</expires>";
	}
	r += "<sig>" + _element_sig + "</sig>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Public_session_data::IsSet() const
{
	return UidIsSet() || Api_keyIsSet() || ExpiresIsSet() || SigIsSet();
}


// -----------------------------------------------------------------------------
long Public_session_data::GetUid() const
{
	return _element_uid;
}


void Public_session_data::SetUid(long uid)
{
	_element_uid = uid;
	_element_uid_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Public_session_data::GetApi_key() const
{
	return _element_api_key;
}


void Public_session_data::SetApi_key(const std::string& api_key)
{
	_element_api_key = api_key;
	_element_api_key_is_set = true;
}


// -----------------------------------------------------------------------------
int Public_session_data::GetExpires() const
{
	return _element_expires;
}


void Public_session_data::SetExpires(int expires)
{
	_element_expires = expires;
	_element_expires_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Public_session_data::GetSig() const
{
	return _element_sig;
}


void Public_session_data::SetSig(const std::string& sig)
{
	_element_sig = sig;
	_element_sig_is_set = true;
}


// -----------------------------------------------------------------------------
Location::Location()
: _element_latitude(0)
, _element_longitude(0)
, _element_street_is_set(false)
, _element_city_is_set(false)
, _element_state_is_set(false)
, _element_country_is_set(false)
, _element_zip_is_set(false)
, _element_latitude_is_set(false)
, _element_longitude_is_set(false)
{
}


// -----------------------------------------------------------------------------
Location::Location(const Xml::XmlNode& it)
: _element_latitude(0)
, _element_longitude(0)
, _element_street_is_set(false)
, _element_city_is_set(false)
, _element_state_is_set(false)
, _element_country_is_set(false)
, _element_zip_is_set(false)
, _element_latitude_is_set(false)
, _element_longitude_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Location::clear()
{
	_element_street.clear();
	_element_city.clear();
	_element_state.clear();
	_element_country.clear();
	_element_zip.clear();
	_element_latitude = 0;
	_element_longitude = 0;
	_element_street_is_set = false;
	_element_city_is_set = false;
	_element_state_is_set = false;
	_element_country_is_set = false;
	_element_zip_is_set = false;
	_element_latitude_is_set = false;
	_element_longitude_is_set = false;
}


// -----------------------------------------------------------------------------
void Location::FromXml(const Xml::XmlNode& it)
{
	if (it.Exists("street"))
		SetStreet( it["street"] );
	if (!it.Exists("city"))
		throw Xml::XmlException("missing required node in element 'location': city");
	SetCity( it["city"] );
	if (!it.Exists("state"))
		throw Xml::XmlException("missing required node in element 'location': state");
	SetState( it["state"] );
	if (!it.Exists("country"))
		throw Xml::XmlException("missing required node in element 'location': country");
	SetCountry( it["country"] );
	if (it.Exists("zip"))
		SetZip( it["zip"] );
	if (it.Exists("latitude"))
		SetLatitude( atoi(std::string(it["latitude"]).c_str()) );
	if (it.Exists("longitude"))
		SetLongitude( atoi(std::string(it["longitude"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Location::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	if (_element_street_is_set)
		r += "<street>" + _element_street + "</street>";
	r += "<city>" + _element_city + "</city>";
	r += "<state>" + _element_state + "</state>";
	r += "<country>" + _element_country + "</country>";
	if (_element_zip_is_set)
		r += "<zip>" + _element_zip + "</zip>";
	if (_element_latitude_is_set)
	{
		r = r + "<latitude>" + Utility::l2string(_element_latitude) + "</latitude>";
	}
	if (_element_longitude_is_set)
	{
		r = r + "<longitude>" + Utility::l2string(_element_longitude) + "</longitude>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Location::IsSet() const
{
	return StreetIsSet() || CityIsSet() || StateIsSet() || CountryIsSet() || ZipIsSet() || LatitudeIsSet() || LongitudeIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Location::GetStreet() const
{
	return _element_street;
}


void Location::SetStreet(const std::string& street)
{
	_element_street = street;
	_element_street_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Location::GetCity() const
{
	return _element_city;
}


void Location::SetCity(const std::string& city)
{
	_element_city = city;
	_element_city_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Location::GetState() const
{
	return _element_state;
}


void Location::SetState(const std::string& state)
{
	_element_state = state;
	_element_state_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Location::GetCountry() const
{
	return _element_country;
}


void Location::SetCountry(const std::string& country)
{
	_element_country = country;
	_element_country_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Location::GetZip() const
{
	return _element_zip;
}


void Location::SetZip(const std::string& zip)
{
	_element_zip = zip;
	_element_zip_is_set = true;
}


// -----------------------------------------------------------------------------
double Location::GetLatitude() const
{
	return _element_latitude;
}


void Location::SetLatitude(double latitude)
{
	_element_latitude = latitude;
	_element_latitude_is_set = true;
}


// -----------------------------------------------------------------------------
double Location::GetLongitude() const
{
	return _element_longitude;
}


void Location::SetLongitude(double longitude)
{
	_element_longitude = longitude;
	_element_longitude_is_set = true;
}


// -----------------------------------------------------------------------------
Connect_account_info::Connect_account_info()
: _element_email_hash_is_set(false)
, _element_account_id_is_set(false)
, _element_account_url_is_set(false)
{
}


// -----------------------------------------------------------------------------
Connect_account_info::Connect_account_info(const Xml::XmlNode& it)
: _element_email_hash_is_set(false)
, _element_account_id_is_set(false)
, _element_account_url_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Connect_account_info::clear()
{
	_element_email_hash.clear();
	_element_account_id.clear();
	_element_account_url.clear();
	_element_email_hash_is_set = false;
	_element_account_id_is_set = false;
	_element_account_url_is_set = false;
}


// -----------------------------------------------------------------------------
void Connect_account_info::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("email_hash"))
		throw Xml::XmlException("missing required node in element 'connect_account_info': email_hash");
	SetEmail_hash( it["email_hash"] );
	if (it.Exists("account_id"))
		SetAccount_id( it["account_id"] );
	if (it.Exists("account_url"))
		SetAccount_url( it["account_url"] );
}


// -----------------------------------------------------------------------------
const std::string Connect_account_info::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<email_hash>" + _element_email_hash + "</email_hash>";
	if (_element_account_id_is_set)
		r += "<account_id>" + _element_account_id + "</account_id>";
	if (_element_account_url_is_set)
		r += "<account_url>" + _element_account_url + "</account_url>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Connect_account_info::IsSet() const
{
	return Email_hashIsSet() || Account_idIsSet() || Account_urlIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Connect_account_info::GetEmail_hash() const
{
	return _element_email_hash;
}


void Connect_account_info::SetEmail_hash(const std::string& email_hash)
{
	_element_email_hash = email_hash;
	_element_email_hash_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Connect_account_info::GetAccount_id() const
{
	return _element_account_id;
}


void Connect_account_info::SetAccount_id(const std::string& account_id)
{
	_element_account_id = account_id;
	_element_account_id_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Connect_account_info::GetAccount_url() const
{
	return _element_account_url;
}


void Connect_account_info::SetAccount_url(const std::string& account_url)
{
	_element_account_url = account_url;
	_element_account_url_is_set = true;
}


// -----------------------------------------------------------------------------
Event::Event()
: _element_eid_is_set(false)
, _element_name_is_set(false)
, _element_tagline_is_set(false)
, _element_nid_is_set(false)
, _element_pic_is_set(false)
, _element_pic_big_is_set(false)
, _element_pic_small_is_set(false)
, _element_host_is_set(false)
, _element_description_is_set(false)
, _element_event_type_is_set(false)
, _element_event_subtype_is_set(false)
, _element_start_time_is_set(false)
, _element_end_time_is_set(false)
, _element_creator_is_set(false)
, _element_update_time_is_set(false)
, _element_location_is_set(false)
, _element_privacy_is_set(false)
, _element_hide_guest_list_is_set(false)
, _element_show_in_search_is_set(false)
{
}


// -----------------------------------------------------------------------------
Event::Event(const Xml::XmlNode& it)
: _element_eid_is_set(false)
, _element_name_is_set(false)
, _element_tagline_is_set(false)
, _element_nid_is_set(false)
, _element_pic_is_set(false)
, _element_pic_big_is_set(false)
, _element_pic_small_is_set(false)
, _element_host_is_set(false)
, _element_description_is_set(false)
, _element_event_type_is_set(false)
, _element_event_subtype_is_set(false)
, _element_start_time_is_set(false)
, _element_end_time_is_set(false)
, _element_creator_is_set(false)
, _element_update_time_is_set(false)
, _element_location_is_set(false)
, _element_privacy_is_set(false)
, _element_hide_guest_list_is_set(false)
, _element_show_in_search_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Event::clear()
{
	// simpleType:
	// _element_eid.clear();
	_element_name.clear();
	_element_tagline.clear();
	// simpleType:
	// _element_nid.clear();
	_element_pic.clear();
	_element_pic_big.clear();
	_element_pic_small.clear();
	_element_host.clear();
	_element_description.clear();
	_element_event_type.clear();
	_element_event_subtype.clear();
	// simpleType:
	// _element_start_time.clear();
	// simpleType:
	// _element_end_time.clear();
	// simpleType:
	// _element_creator.clear();
	// simpleType:
	// _element_update_time.clear();
	_element_location.clear();
	_element_venue.clear();
	_element_privacy.clear();
	_element_hide_guest_list = false;
	_element_show_in_search = false;
	_element_eid_is_set = false;
	_element_name_is_set = false;
	_element_tagline_is_set = false;
	_element_nid_is_set = false;
	_element_pic_is_set = false;
	_element_pic_big_is_set = false;
	_element_pic_small_is_set = false;
	_element_host_is_set = false;
	_element_description_is_set = false;
	_element_event_type_is_set = false;
	_element_event_subtype_is_set = false;
	_element_start_time_is_set = false;
	_element_end_time_is_set = false;
	_element_creator_is_set = false;
	_element_update_time_is_set = false;
	_element_location_is_set = false;
	_element_privacy_is_set = false;
	_element_hide_guest_list_is_set = false;
	_element_show_in_search_is_set = false;
}


// -----------------------------------------------------------------------------
void Event::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("eid"))
		throw Xml::XmlException("missing required node in element 'event': eid");
	SetEid( atoi(std::string(it["eid"]).c_str()) );
	if (!it.Exists("name"))
		throw Xml::XmlException("missing required node in element 'event': name");
	SetName( it["name"] );
	if (!it.Exists("tagline"))
		throw Xml::XmlException("missing required node in element 'event': tagline");
	SetTagline( it["tagline"] );
	if (!it.Exists("nid"))
		throw Xml::XmlException("missing required node in element 'event': nid");
	SetNid( atoi(std::string(it["nid"]).c_str()) );
	if (!it.Exists("pic"))
		throw Xml::XmlException("missing required node in element 'event': pic");
	SetPic( it["pic"] );
	if (!it.Exists("pic_big"))
		throw Xml::XmlException("missing required node in element 'event': pic_big");
	SetPic_big( it["pic_big"] );
	if (!it.Exists("pic_small"))
		throw Xml::XmlException("missing required node in element 'event': pic_small");
	SetPic_small( it["pic_small"] );
	if (!it.Exists("host"))
		throw Xml::XmlException("missing required node in element 'event': host");
	SetHost( it["host"] );
	if (!it.Exists("description"))
		throw Xml::XmlException("missing required node in element 'event': description");
	SetDescription( it["description"] );
	if (!it.Exists("event_type"))
		throw Xml::XmlException("missing required node in element 'event': event_type");
	SetEvent_type( it["event_type"] );
	if (!it.Exists("event_subtype"))
		throw Xml::XmlException("missing required node in element 'event': event_subtype");
	SetEvent_subtype( it["event_subtype"] );
	if (!it.Exists("start_time"))
		throw Xml::XmlException("missing required node in element 'event': start_time");
	SetStart_time( atoi(std::string(it["start_time"]).c_str()) );
	if (!it.Exists("end_time"))
		throw Xml::XmlException("missing required node in element 'event': end_time");
	SetEnd_time( atoi(std::string(it["end_time"]).c_str()) );
	if (!it.Exists("creator"))
		throw Xml::XmlException("missing required node in element 'event': creator");
	SetCreator( atoi(std::string(it["creator"]).c_str()) );
	if (!it.Exists("update_time"))
		throw Xml::XmlException("missing required node in element 'event': update_time");
	SetUpdate_time( atoi(std::string(it["update_time"]).c_str()) );
	if (!it.Exists("location"))
		throw Xml::XmlException("missing required node in element 'event': location");
	SetLocation( it["location"] );
	if (!it.Exists("venue"))
		throw Xml::XmlException("missing required node in element 'event': venue");
	{
		Xml::XmlNode n(it, "venue");
		if (n)
			_element_venue.FromXml( n );
	}
	if (!it.Exists("privacy"))
		throw Xml::XmlException("missing required node in element 'event': privacy");
	SetPrivacy( it["privacy"] );
	if (!it.Exists("hide_guest_list"))
		throw Xml::XmlException("missing required node in element 'event': hide_guest_list");
	SetHide_guest_list( atoi(std::string(it["hide_guest_list"]).c_str()) );
	if (!it.Exists("show_in_search"))
		throw Xml::XmlException("missing required node in element 'event': show_in_search");
	SetShow_in_search( atoi(std::string(it["show_in_search"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Event::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<eid>" + Utility::l2string(_element_eid) + "</eid>";
	}
	r += "<name>" + _element_name + "</name>";
	r += "<tagline>" + _element_tagline + "</tagline>";
	{
		r = r + "<nid>" + Utility::l2string(_element_nid) + "</nid>";
	}
	r += "<pic>" + _element_pic + "</pic>";
	r += "<pic_big>" + _element_pic_big + "</pic_big>";
	r += "<pic_small>" + _element_pic_small + "</pic_small>";
	r += "<host>" + _element_host + "</host>";
	r += "<description>" + _element_description + "</description>";
	r += "<event_type>" + _element_event_type + "</event_type>";
	r += "<event_subtype>" + _element_event_subtype + "</event_subtype>";
	{
		r = r + "<start_time>" + Utility::l2string(_element_start_time) + "</start_time>";
	}
	{
		r = r + "<end_time>" + Utility::l2string(_element_end_time) + "</end_time>";
	}
	{
		r = r + "<creator>" + Utility::l2string(_element_creator) + "</creator>";
	}
	{
		r = r + "<update_time>" + Utility::l2string(_element_update_time) + "</update_time>";
	}
	r += "<location>" + _element_location + "</location>";
	r += _element_venue.ToString("venue");
	r += "<privacy>" + _element_privacy + "</privacy>";
	{
		r = r + "<hide_guest_list>" + Utility::l2string(_element_hide_guest_list) + "</hide_guest_list>";
	}
	{
		r = r + "<show_in_search>" + Utility::l2string(_element_show_in_search) + "</show_in_search>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Event::IsSet() const
{
	return EidIsSet() || NameIsSet() || TaglineIsSet() || NidIsSet() || PicIsSet() || Pic_bigIsSet() || Pic_smallIsSet() || HostIsSet() || DescriptionIsSet() || Event_typeIsSet() || Event_subtypeIsSet() || Start_timeIsSet() || End_timeIsSet() || CreatorIsSet() || Update_timeIsSet() || LocationIsSet() || VenueIsSet() || PrivacyIsSet() || Hide_guest_listIsSet() || Show_in_searchIsSet();
}


// -----------------------------------------------------------------------------
long Event::GetEid() const
{
	return _element_eid;
}


void Event::SetEid(long eid)
{
	_element_eid = eid;
	_element_eid_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Event::GetName() const
{
	return _element_name;
}


void Event::SetName(const std::string& name)
{
	_element_name = name;
	_element_name_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Event::GetTagline() const
{
	return _element_tagline;
}


void Event::SetTagline(const std::string& tagline)
{
	_element_tagline = tagline;
	_element_tagline_is_set = true;
}


// -----------------------------------------------------------------------------
int Event::GetNid() const
{
	return _element_nid;
}


void Event::SetNid(int nid)
{
	_element_nid = nid;
	_element_nid_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Event::GetPic() const
{
	return _element_pic;
}


void Event::SetPic(const std::string& pic)
{
	_element_pic = pic;
	_element_pic_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Event::GetPic_big() const
{
	return _element_pic_big;
}


void Event::SetPic_big(const std::string& pic_big)
{
	_element_pic_big = pic_big;
	_element_pic_big_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Event::GetPic_small() const
{
	return _element_pic_small;
}


void Event::SetPic_small(const std::string& pic_small)
{
	_element_pic_small = pic_small;
	_element_pic_small_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Event::GetHost() const
{
	return _element_host;
}


void Event::SetHost(const std::string& host)
{
	_element_host = host;
	_element_host_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Event::GetDescription() const
{
	return _element_description;
}


void Event::SetDescription(const std::string& description)
{
	_element_description = description;
	_element_description_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Event::GetEvent_type() const
{
	return _element_event_type;
}


void Event::SetEvent_type(const std::string& event_type)
{
	_element_event_type = event_type;
	_element_event_type_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Event::GetEvent_subtype() const
{
	return _element_event_subtype;
}


void Event::SetEvent_subtype(const std::string& event_subtype)
{
	_element_event_subtype = event_subtype;
	_element_event_subtype_is_set = true;
}


// -----------------------------------------------------------------------------
long Event::GetStart_time() const
{
	return _element_start_time;
}


void Event::SetStart_time(long start_time)
{
	_element_start_time = start_time;
	_element_start_time_is_set = true;
}


// -----------------------------------------------------------------------------
long Event::GetEnd_time() const
{
	return _element_end_time;
}


void Event::SetEnd_time(long end_time)
{
	_element_end_time = end_time;
	_element_end_time_is_set = true;
}


// -----------------------------------------------------------------------------
long Event::GetCreator() const
{
	return _element_creator;
}


void Event::SetCreator(long creator)
{
	_element_creator = creator;
	_element_creator_is_set = true;
}


// -----------------------------------------------------------------------------
long Event::GetUpdate_time() const
{
	return _element_update_time;
}


void Event::SetUpdate_time(long update_time)
{
	_element_update_time = update_time;
	_element_update_time_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Event::GetLocation() const
{
	return _element_location;
}


void Event::SetLocation(const std::string& location)
{
	_element_location = location;
	_element_location_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Location& Event::GetVenue() const
{
	return _element_venue;
}


com_facebook_1_0_::Location& Event::GetVenue()
{
	return _element_venue;
}


void Event::SetVenue(const com_facebook_1_0_::Location& venue)
{
	_element_venue = venue;
}


// -----------------------------------------------------------------------------
const std::string& Event::GetPrivacy() const
{
	return _element_privacy;
}


void Event::SetPrivacy(const std::string& privacy)
{
	_element_privacy = privacy;
	_element_privacy_is_set = true;
}


// -----------------------------------------------------------------------------
bool Event::GetHide_guest_list() const
{
	return _element_hide_guest_list;
}


void Event::SetHide_guest_list(bool hide_guest_list)
{
	_element_hide_guest_list = hide_guest_list;
	_element_hide_guest_list_is_set = true;
}


// -----------------------------------------------------------------------------
bool Event::GetShow_in_search() const
{
	return _element_show_in_search;
}


void Event::SetShow_in_search(bool show_in_search)
{
	_element_show_in_search = show_in_search;
	_element_show_in_search_is_set = true;
}


// -----------------------------------------------------------------------------
bool Event::VenueIsSet() const
{
	return _element_venue.IsSet();
}


// -----------------------------------------------------------------------------
Event_member::Event_member()
: _element_uid_is_set(false)
, _element_oid_is_set(false)
, _element_attending_is_set(false)
{
}


// -----------------------------------------------------------------------------
Event_member::Event_member(const Xml::XmlNode& it)
: _element_uid_is_set(false)
, _element_oid_is_set(false)
, _element_attending_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Event_member::clear()
{
	// simpleType:
	// _element_uid.clear();
	// simpleType:
	// _element_oid.clear();
	_element_attending.clear();
	_element_uid_is_set = false;
	_element_oid_is_set = false;
	_element_attending_is_set = false;
}


// -----------------------------------------------------------------------------
void Event_member::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("uid"))
		throw Xml::XmlException("missing required node in element 'event_member': uid");
	SetUid( atoi(std::string(it["uid"]).c_str()) );
	if (!it.Exists("oid"))
		throw Xml::XmlException("missing required node in element 'event_member': oid");
	SetOid( atoi(std::string(it["oid"]).c_str()) );
	if (!it.Exists("attending"))
		throw Xml::XmlException("missing required node in element 'event_member': attending");
	SetAttending( it["attending"] );
}


// -----------------------------------------------------------------------------
const std::string Event_member::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<uid>" + Utility::l2string(_element_uid) + "</uid>";
	}
	{
		r = r + "<oid>" + Utility::l2string(_element_oid) + "</oid>";
	}
	r += "<attending>" + _element_attending + "</attending>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Event_member::IsSet() const
{
	return UidIsSet() || OidIsSet() || AttendingIsSet();
}


// -----------------------------------------------------------------------------
long Event_member::GetUid() const
{
	return _element_uid;
}


void Event_member::SetUid(long uid)
{
	_element_uid = uid;
	_element_uid_is_set = true;
}


// -----------------------------------------------------------------------------
long Event_member::GetOid() const
{
	return _element_oid;
}


void Event_member::SetOid(long oid)
{
	_element_oid = oid;
	_element_oid_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Event_member::GetAttending() const
{
	return _element_attending;
}


void Event_member::SetAttending(const std::string& attending)
{
	_element_attending = attending;
	_element_attending_is_set = true;
}


// -----------------------------------------------------------------------------
Group::Group()
: _element_gid_is_set(false)
, _element_name_is_set(false)
, _element_nid_is_set(false)
, _element_description_is_set(false)
, _element_group_type_is_set(false)
, _element_group_subtype_is_set(false)
, _element_recent_news_is_set(false)
, _element_pic_is_set(false)
, _element_pic_big_is_set(false)
, _element_pic_small_is_set(false)
, _element_creator_is_set(false)
, _element_update_time_is_set(false)
, _element_office_is_set(false)
, _element_website_is_set(false)
, _element_privacy_is_set(false)
{
}


// -----------------------------------------------------------------------------
Group::Group(const Xml::XmlNode& it)
: _element_gid_is_set(false)
, _element_name_is_set(false)
, _element_nid_is_set(false)
, _element_description_is_set(false)
, _element_group_type_is_set(false)
, _element_group_subtype_is_set(false)
, _element_recent_news_is_set(false)
, _element_pic_is_set(false)
, _element_pic_big_is_set(false)
, _element_pic_small_is_set(false)
, _element_creator_is_set(false)
, _element_update_time_is_set(false)
, _element_office_is_set(false)
, _element_website_is_set(false)
, _element_privacy_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Group::clear()
{
	// simpleType:
	// _element_gid.clear();
	_element_name.clear();
	// simpleType:
	// _element_nid.clear();
	_element_description.clear();
	_element_group_type.clear();
	_element_group_subtype.clear();
	_element_recent_news.clear();
	_element_pic.clear();
	_element_pic_big.clear();
	_element_pic_small.clear();
	// simpleType:
	// _element_creator.clear();
	// simpleType:
	// _element_update_time.clear();
	_element_office.clear();
	_element_website.clear();
	_element_venue.clear();
	_element_privacy.clear();
	_element_gid_is_set = false;
	_element_name_is_set = false;
	_element_nid_is_set = false;
	_element_description_is_set = false;
	_element_group_type_is_set = false;
	_element_group_subtype_is_set = false;
	_element_recent_news_is_set = false;
	_element_pic_is_set = false;
	_element_pic_big_is_set = false;
	_element_pic_small_is_set = false;
	_element_creator_is_set = false;
	_element_update_time_is_set = false;
	_element_office_is_set = false;
	_element_website_is_set = false;
	_element_privacy_is_set = false;
}


// -----------------------------------------------------------------------------
void Group::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("gid"))
		throw Xml::XmlException("missing required node in element 'group': gid");
	SetGid( atoi(std::string(it["gid"]).c_str()) );
	if (!it.Exists("name"))
		throw Xml::XmlException("missing required node in element 'group': name");
	SetName( it["name"] );
	if (!it.Exists("nid"))
		throw Xml::XmlException("missing required node in element 'group': nid");
	SetNid( atoi(std::string(it["nid"]).c_str()) );
	if (!it.Exists("description"))
		throw Xml::XmlException("missing required node in element 'group': description");
	SetDescription( it["description"] );
	if (!it.Exists("group_type"))
		throw Xml::XmlException("missing required node in element 'group': group_type");
	SetGroup_type( it["group_type"] );
	if (!it.Exists("group_subtype"))
		throw Xml::XmlException("missing required node in element 'group': group_subtype");
	SetGroup_subtype( it["group_subtype"] );
	if (!it.Exists("recent_news"))
		throw Xml::XmlException("missing required node in element 'group': recent_news");
	SetRecent_news( it["recent_news"] );
	if (!it.Exists("pic"))
		throw Xml::XmlException("missing required node in element 'group': pic");
	SetPic( it["pic"] );
	if (!it.Exists("pic_big"))
		throw Xml::XmlException("missing required node in element 'group': pic_big");
	SetPic_big( it["pic_big"] );
	if (!it.Exists("pic_small"))
		throw Xml::XmlException("missing required node in element 'group': pic_small");
	SetPic_small( it["pic_small"] );
	if (!it.Exists("creator"))
		throw Xml::XmlException("missing required node in element 'group': creator");
	SetCreator( atoi(std::string(it["creator"]).c_str()) );
	if (!it.Exists("update_time"))
		throw Xml::XmlException("missing required node in element 'group': update_time");
	SetUpdate_time( atoi(std::string(it["update_time"]).c_str()) );
	if (!it.Exists("office"))
		throw Xml::XmlException("missing required node in element 'group': office");
	SetOffice( it["office"] );
	if (!it.Exists("website"))
		throw Xml::XmlException("missing required node in element 'group': website");
	SetWebsite( it["website"] );
	if (!it.Exists("venue"))
		throw Xml::XmlException("missing required node in element 'group': venue");
	{
		Xml::XmlNode n(it, "venue");
		if (n)
			_element_venue.FromXml( n );
	}
	if (!it.Exists("privacy"))
		throw Xml::XmlException("missing required node in element 'group': privacy");
	SetPrivacy( it["privacy"] );
}


// -----------------------------------------------------------------------------
const std::string Group::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<gid>" + Utility::l2string(_element_gid) + "</gid>";
	}
	r += "<name>" + _element_name + "</name>";
	{
		r = r + "<nid>" + Utility::l2string(_element_nid) + "</nid>";
	}
	r += "<description>" + _element_description + "</description>";
	r += "<group_type>" + _element_group_type + "</group_type>";
	r += "<group_subtype>" + _element_group_subtype + "</group_subtype>";
	r += "<recent_news>" + _element_recent_news + "</recent_news>";
	r += "<pic>" + _element_pic + "</pic>";
	r += "<pic_big>" + _element_pic_big + "</pic_big>";
	r += "<pic_small>" + _element_pic_small + "</pic_small>";
	{
		r = r + "<creator>" + Utility::l2string(_element_creator) + "</creator>";
	}
	{
		r = r + "<update_time>" + Utility::l2string(_element_update_time) + "</update_time>";
	}
	r += "<office>" + _element_office + "</office>";
	r += "<website>" + _element_website + "</website>";
	r += _element_venue.ToString("venue");
	r += "<privacy>" + _element_privacy + "</privacy>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Group::IsSet() const
{
	return GidIsSet() || NameIsSet() || NidIsSet() || DescriptionIsSet() || Group_typeIsSet() || Group_subtypeIsSet() || Recent_newsIsSet() || PicIsSet() || Pic_bigIsSet() || Pic_smallIsSet() || CreatorIsSet() || Update_timeIsSet() || OfficeIsSet() || WebsiteIsSet() || VenueIsSet() || PrivacyIsSet();
}


// -----------------------------------------------------------------------------
long Group::GetGid() const
{
	return _element_gid;
}


void Group::SetGid(long gid)
{
	_element_gid = gid;
	_element_gid_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Group::GetName() const
{
	return _element_name;
}


void Group::SetName(const std::string& name)
{
	_element_name = name;
	_element_name_is_set = true;
}


// -----------------------------------------------------------------------------
int Group::GetNid() const
{
	return _element_nid;
}


void Group::SetNid(int nid)
{
	_element_nid = nid;
	_element_nid_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Group::GetDescription() const
{
	return _element_description;
}


void Group::SetDescription(const std::string& description)
{
	_element_description = description;
	_element_description_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Group::GetGroup_type() const
{
	return _element_group_type;
}


void Group::SetGroup_type(const std::string& group_type)
{
	_element_group_type = group_type;
	_element_group_type_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Group::GetGroup_subtype() const
{
	return _element_group_subtype;
}


void Group::SetGroup_subtype(const std::string& group_subtype)
{
	_element_group_subtype = group_subtype;
	_element_group_subtype_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Group::GetRecent_news() const
{
	return _element_recent_news;
}


void Group::SetRecent_news(const std::string& recent_news)
{
	_element_recent_news = recent_news;
	_element_recent_news_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Group::GetPic() const
{
	return _element_pic;
}


void Group::SetPic(const std::string& pic)
{
	_element_pic = pic;
	_element_pic_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Group::GetPic_big() const
{
	return _element_pic_big;
}


void Group::SetPic_big(const std::string& pic_big)
{
	_element_pic_big = pic_big;
	_element_pic_big_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Group::GetPic_small() const
{
	return _element_pic_small;
}


void Group::SetPic_small(const std::string& pic_small)
{
	_element_pic_small = pic_small;
	_element_pic_small_is_set = true;
}


// -----------------------------------------------------------------------------
long Group::GetCreator() const
{
	return _element_creator;
}


void Group::SetCreator(long creator)
{
	_element_creator = creator;
	_element_creator_is_set = true;
}


// -----------------------------------------------------------------------------
long Group::GetUpdate_time() const
{
	return _element_update_time;
}


void Group::SetUpdate_time(long update_time)
{
	_element_update_time = update_time;
	_element_update_time_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Group::GetOffice() const
{
	return _element_office;
}


void Group::SetOffice(const std::string& office)
{
	_element_office = office;
	_element_office_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Group::GetWebsite() const
{
	return _element_website;
}


void Group::SetWebsite(const std::string& website)
{
	_element_website = website;
	_element_website_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Location& Group::GetVenue() const
{
	return _element_venue;
}


com_facebook_1_0_::Location& Group::GetVenue()
{
	return _element_venue;
}


void Group::SetVenue(const com_facebook_1_0_::Location& venue)
{
	_element_venue = venue;
}


// -----------------------------------------------------------------------------
const std::string& Group::GetPrivacy() const
{
	return _element_privacy;
}


void Group::SetPrivacy(const std::string& privacy)
{
	_element_privacy = privacy;
	_element_privacy_is_set = true;
}


// -----------------------------------------------------------------------------
bool Group::VenueIsSet() const
{
	return _element_venue.IsSet();
}


// -----------------------------------------------------------------------------
Group_member::Group_member()
: _element_uid_is_set(false)
, _element_gid_is_set(false)
{
}


// -----------------------------------------------------------------------------
Group_member::Group_member(const Xml::XmlNode& it)
: _element_uid_is_set(false)
, _element_gid_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Group_member::clear()
{
	// simpleType:
	// _element_uid.clear();
	// simpleType:
	// _element_gid.clear();
	_element_positions.clear();
	_element_uid_is_set = false;
	_element_gid_is_set = false;
}


// -----------------------------------------------------------------------------
void Group_member::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("uid"))
		throw Xml::XmlException("missing required node in element 'group_member': uid");
	SetUid( atoi(std::string(it["uid"]).c_str()) );
	if (!it.Exists("gid"))
		throw Xml::XmlException("missing required node in element 'group_member': gid");
	SetGid( atoi(std::string(it["gid"]).c_str()) );
	if (!it.Exists("positions"))
		throw Xml::XmlException("missing required node in element 'group_member': positions");
	{
		Xml::XmlNode n(it, "positions");
		if (n)
			_element_positions.FromXml( n );
	}
}


// -----------------------------------------------------------------------------
const std::string Group_member::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<uid>" + Utility::l2string(_element_uid) + "</uid>";
	}
	{
		r = r + "<gid>" + Utility::l2string(_element_gid) + "</gid>";
	}
	r += _element_positions.ToString("positions");
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Group_member::IsSet() const
{
	return UidIsSet() || GidIsSet() || PositionsIsSet();
}


// -----------------------------------------------------------------------------
long Group_member::GetUid() const
{
	return _element_uid;
}


void Group_member::SetUid(long uid)
{
	_element_uid = uid;
	_element_uid_is_set = true;
}


// -----------------------------------------------------------------------------
long Group_member::GetGid() const
{
	return _element_gid;
}


void Group_member::SetGid(long gid)
{
	_element_gid = gid;
	_element_gid_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Group_member::Positions_t& Group_member::GetPositions() const
{
	return _element_positions;
}


com_facebook_1_0_::Group_member::Positions_t& Group_member::GetPositions()
{
	return _element_positions;
}


void Group_member::SetPositions(const com_facebook_1_0_::Group_member::Positions_t& positions)
{
	_element_positions = positions;
}


// -----------------------------------------------------------------------------
bool Group_member::PositionsIsSet() const
{
	return _element_positions.IsSet();
}


// -----------------------------------------------------------------------------
Group_member::Positions_t::Positions_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Group_member::Positions_t::Positions_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Group_member::Positions_t::clear()
{
	while (!_element_member_type.empty())
		_element_member_type.erase( _element_member_type.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Group_member::Positions_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "member_type");
		while (n)
		{
			_element_member_type.push_back( n.GetContent() );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Group_member::Positions_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<std::string>::const_iterator it = _element_member_type.begin(); it != _element_member_type.end(); it++)
	{
		r += "<member_type>" + *it + "</member_type>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Group_member::Positions_t::IsSet() const
{
	return Member_typeIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<std::string>& Group_member::Positions_t::GetMember_type() const
{
	return _element_member_type;
}


std::list<std::string>& Group_member::Positions_t::GetMember_type()
{
	return _element_member_type;
}


void Group_member::Positions_t::SetMember_type(const std::list<std::string>& member_type)
{
	_element_member_type = member_type;
}


// -----------------------------------------------------------------------------
bool Group_member::Positions_t::Member_typeIsSet() const
{
	return !_element_member_type.empty();
}


// -----------------------------------------------------------------------------
bool Group_member::Positions_t::GetList() const
{
	return _attribute_list;
}


void Group_member::Positions_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
UidListType::UidListType()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
UidListType::UidListType(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void UidListType::clear()
{
	while (!_element_uid.empty())
		_element_uid.erase( _element_uid.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void UidListType::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "uid");
		while (n)
		{
			_element_uid.push_back( atoi(n.GetContent().c_str()) );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string UidListType::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<long>::const_iterator it = _element_uid.begin(); it != _element_uid.end(); it++)
	{
			r = r + "<uid>" + Utility::l2string(*it) + "</uid>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool UidListType::IsSet() const
{
	return UidIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<long>& UidListType::GetUid() const
{
	return _element_uid;
}


std::list<long>& UidListType::GetUid()
{
	return _element_uid;
}


void UidListType::SetUid(const std::list<long>& uid)
{
	_element_uid = uid;
}


// -----------------------------------------------------------------------------
bool UidListType::UidIsSet() const
{
	return !_element_uid.empty();
}


// -----------------------------------------------------------------------------
bool UidListType::GetList() const
{
	return _attribute_list;
}


void UidListType::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Group_members::Group_members()
{
}


// -----------------------------------------------------------------------------
Group_members::Group_members(const Xml::XmlNode& it)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Group_members::clear()
{
	_element_members.clear();
	_element_admins.clear();
	_element_officers.clear();
	_element_not_replied.clear();
}


// -----------------------------------------------------------------------------
void Group_members::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("members"))
		throw Xml::XmlException("missing required node in element 'group_members': members");
	{
		Xml::XmlNode n(it, "members");
		if (n)
			_element_members.FromXml( n );
	}
	if (!it.Exists("admins"))
		throw Xml::XmlException("missing required node in element 'group_members': admins");
	{
		Xml::XmlNode n(it, "admins");
		if (n)
			_element_admins.FromXml( n );
	}
	if (!it.Exists("officers"))
		throw Xml::XmlException("missing required node in element 'group_members': officers");
	{
		Xml::XmlNode n(it, "officers");
		if (n)
			_element_officers.FromXml( n );
	}
	if (!it.Exists("not_replied"))
		throw Xml::XmlException("missing required node in element 'group_members': not_replied");
	{
		Xml::XmlNode n(it, "not_replied");
		if (n)
			_element_not_replied.FromXml( n );
	}
}


// -----------------------------------------------------------------------------
const std::string Group_members::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += _element_members.ToString("members");
	r += _element_admins.ToString("admins");
	r += _element_officers.ToString("officers");
	r += _element_not_replied.ToString("not_replied");
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Group_members::IsSet() const
{
	return MembersIsSet() || AdminsIsSet() || OfficersIsSet() || Not_repliedIsSet();
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Group_members::Members_t& Group_members::GetMembers() const
{
	return _element_members;
}


com_facebook_1_0_::Group_members::Members_t& Group_members::GetMembers()
{
	return _element_members;
}


void Group_members::SetMembers(const com_facebook_1_0_::Group_members::Members_t& members)
{
	_element_members = members;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Group_members::Admins_t& Group_members::GetAdmins() const
{
	return _element_admins;
}


com_facebook_1_0_::Group_members::Admins_t& Group_members::GetAdmins()
{
	return _element_admins;
}


void Group_members::SetAdmins(const com_facebook_1_0_::Group_members::Admins_t& admins)
{
	_element_admins = admins;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Group_members::Officers_t& Group_members::GetOfficers() const
{
	return _element_officers;
}


com_facebook_1_0_::Group_members::Officers_t& Group_members::GetOfficers()
{
	return _element_officers;
}


void Group_members::SetOfficers(const com_facebook_1_0_::Group_members::Officers_t& officers)
{
	_element_officers = officers;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::UidListType& Group_members::GetNot_replied() const
{
	return _element_not_replied;
}


com_facebook_1_0_::UidListType& Group_members::GetNot_replied()
{
	return _element_not_replied;
}


void Group_members::SetNot_replied(const com_facebook_1_0_::UidListType& not_replied)
{
	_element_not_replied = not_replied;
}


// -----------------------------------------------------------------------------
bool Group_members::MembersIsSet() const
{
	return _element_members.IsSet();
}


// -----------------------------------------------------------------------------
bool Group_members::AdminsIsSet() const
{
	return _element_admins.IsSet();
}


// -----------------------------------------------------------------------------
bool Group_members::OfficersIsSet() const
{
	return _element_officers.IsSet();
}


// -----------------------------------------------------------------------------
bool Group_members::Not_repliedIsSet() const
{
	return _element_not_replied.IsSet();
}


// -----------------------------------------------------------------------------
Group_members::Members_t::Members_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Group_members::Members_t::Members_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Group_members::Members_t::clear()
{
	while (!_element_uid.empty())
		_element_uid.erase( _element_uid.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Group_members::Members_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "uid");
		while (n)
		{
			_element_uid.push_back( atoi(n.GetContent().c_str()) );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Group_members::Members_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<long>::const_iterator it = _element_uid.begin(); it != _element_uid.end(); it++)
	{
			r = r + "<uid>" + Utility::l2string(*it) + "</uid>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Group_members::Members_t::IsSet() const
{
	return UidIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<long>& Group_members::Members_t::GetUid() const
{
	return _element_uid;
}


std::list<long>& Group_members::Members_t::GetUid()
{
	return _element_uid;
}


void Group_members::Members_t::SetUid(const std::list<long>& uid)
{
	_element_uid = uid;
}


// -----------------------------------------------------------------------------
bool Group_members::Members_t::UidIsSet() const
{
	return !_element_uid.empty();
}


// -----------------------------------------------------------------------------
bool Group_members::Members_t::GetList() const
{
	return _attribute_list;
}


void Group_members::Members_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Group_members::Admins_t::Admins_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Group_members::Admins_t::Admins_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Group_members::Admins_t::clear()
{
	while (!_element_uid.empty())
		_element_uid.erase( _element_uid.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Group_members::Admins_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "uid");
		while (n)
		{
			_element_uid.push_back( atoi(n.GetContent().c_str()) );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Group_members::Admins_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<long>::const_iterator it = _element_uid.begin(); it != _element_uid.end(); it++)
	{
			r = r + "<uid>" + Utility::l2string(*it) + "</uid>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Group_members::Admins_t::IsSet() const
{
	return UidIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<long>& Group_members::Admins_t::GetUid() const
{
	return _element_uid;
}


std::list<long>& Group_members::Admins_t::GetUid()
{
	return _element_uid;
}


void Group_members::Admins_t::SetUid(const std::list<long>& uid)
{
	_element_uid = uid;
}


// -----------------------------------------------------------------------------
bool Group_members::Admins_t::UidIsSet() const
{
	return !_element_uid.empty();
}


// -----------------------------------------------------------------------------
bool Group_members::Admins_t::GetList() const
{
	return _attribute_list;
}


void Group_members::Admins_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Group_members::Officers_t::Officers_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Group_members::Officers_t::Officers_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Group_members::Officers_t::clear()
{
	while (!_element_uid.empty())
		_element_uid.erase( _element_uid.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Group_members::Officers_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "uid");
		while (n)
		{
			_element_uid.push_back( atoi(n.GetContent().c_str()) );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Group_members::Officers_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<long>::const_iterator it = _element_uid.begin(); it != _element_uid.end(); it++)
	{
			r = r + "<uid>" + Utility::l2string(*it) + "</uid>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Group_members::Officers_t::IsSet() const
{
	return UidIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<long>& Group_members::Officers_t::GetUid() const
{
	return _element_uid;
}


std::list<long>& Group_members::Officers_t::GetUid()
{
	return _element_uid;
}


void Group_members::Officers_t::SetUid(const std::list<long>& uid)
{
	_element_uid = uid;
}


// -----------------------------------------------------------------------------
bool Group_members::Officers_t::UidIsSet() const
{
	return !_element_uid.empty();
}


// -----------------------------------------------------------------------------
bool Group_members::Officers_t::GetList() const
{
	return _attribute_list;
}


void Group_members::Officers_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Event_members::Event_members()
{
}


// -----------------------------------------------------------------------------
Event_members::Event_members(const Xml::XmlNode& it)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Event_members::clear()
{
	_element_attending.clear();
	_element_unsure.clear();
	_element_declined.clear();
	_element_not_replied.clear();
}


// -----------------------------------------------------------------------------
void Event_members::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("attending"))
		throw Xml::XmlException("missing required node in element 'event_members': attending");
	{
		Xml::XmlNode n(it, "attending");
		if (n)
			_element_attending.FromXml( n );
	}
	if (!it.Exists("unsure"))
		throw Xml::XmlException("missing required node in element 'event_members': unsure");
	{
		Xml::XmlNode n(it, "unsure");
		if (n)
			_element_unsure.FromXml( n );
	}
	if (!it.Exists("declined"))
		throw Xml::XmlException("missing required node in element 'event_members': declined");
	{
		Xml::XmlNode n(it, "declined");
		if (n)
			_element_declined.FromXml( n );
	}
	if (!it.Exists("not_replied"))
		throw Xml::XmlException("missing required node in element 'event_members': not_replied");
	{
		Xml::XmlNode n(it, "not_replied");
		if (n)
			_element_not_replied.FromXml( n );
	}
}


// -----------------------------------------------------------------------------
const std::string Event_members::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += _element_attending.ToString("attending");
	r += _element_unsure.ToString("unsure");
	r += _element_declined.ToString("declined");
	r += _element_not_replied.ToString("not_replied");
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Event_members::IsSet() const
{
	return AttendingIsSet() || UnsureIsSet() || DeclinedIsSet() || Not_repliedIsSet();
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Event_members::Attending_t& Event_members::GetAttending() const
{
	return _element_attending;
}


com_facebook_1_0_::Event_members::Attending_t& Event_members::GetAttending()
{
	return _element_attending;
}


void Event_members::SetAttending(const com_facebook_1_0_::Event_members::Attending_t& attending)
{
	_element_attending = attending;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Event_members::Unsure_t& Event_members::GetUnsure() const
{
	return _element_unsure;
}


com_facebook_1_0_::Event_members::Unsure_t& Event_members::GetUnsure()
{
	return _element_unsure;
}


void Event_members::SetUnsure(const com_facebook_1_0_::Event_members::Unsure_t& unsure)
{
	_element_unsure = unsure;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Event_members::Declined_t& Event_members::GetDeclined() const
{
	return _element_declined;
}


com_facebook_1_0_::Event_members::Declined_t& Event_members::GetDeclined()
{
	return _element_declined;
}


void Event_members::SetDeclined(const com_facebook_1_0_::Event_members::Declined_t& declined)
{
	_element_declined = declined;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::UidListType& Event_members::GetNot_replied() const
{
	return _element_not_replied;
}


com_facebook_1_0_::UidListType& Event_members::GetNot_replied()
{
	return _element_not_replied;
}


void Event_members::SetNot_replied(const com_facebook_1_0_::UidListType& not_replied)
{
	_element_not_replied = not_replied;
}


// -----------------------------------------------------------------------------
bool Event_members::AttendingIsSet() const
{
	return _element_attending.IsSet();
}


// -----------------------------------------------------------------------------
bool Event_members::UnsureIsSet() const
{
	return _element_unsure.IsSet();
}


// -----------------------------------------------------------------------------
bool Event_members::DeclinedIsSet() const
{
	return _element_declined.IsSet();
}


// -----------------------------------------------------------------------------
bool Event_members::Not_repliedIsSet() const
{
	return _element_not_replied.IsSet();
}


// -----------------------------------------------------------------------------
Event_members::Attending_t::Attending_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Event_members::Attending_t::Attending_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Event_members::Attending_t::clear()
{
	while (!_element_uid.empty())
		_element_uid.erase( _element_uid.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Event_members::Attending_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "uid");
		while (n)
		{
			_element_uid.push_back( atoi(n.GetContent().c_str()) );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Event_members::Attending_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<long>::const_iterator it = _element_uid.begin(); it != _element_uid.end(); it++)
	{
			r = r + "<uid>" + Utility::l2string(*it) + "</uid>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Event_members::Attending_t::IsSet() const
{
	return UidIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<long>& Event_members::Attending_t::GetUid() const
{
	return _element_uid;
}


std::list<long>& Event_members::Attending_t::GetUid()
{
	return _element_uid;
}


void Event_members::Attending_t::SetUid(const std::list<long>& uid)
{
	_element_uid = uid;
}


// -----------------------------------------------------------------------------
bool Event_members::Attending_t::UidIsSet() const
{
	return !_element_uid.empty();
}


// -----------------------------------------------------------------------------
bool Event_members::Attending_t::GetList() const
{
	return _attribute_list;
}


void Event_members::Attending_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Event_members::Unsure_t::Unsure_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Event_members::Unsure_t::Unsure_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Event_members::Unsure_t::clear()
{
	while (!_element_uid.empty())
		_element_uid.erase( _element_uid.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Event_members::Unsure_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "uid");
		while (n)
		{
			_element_uid.push_back( atoi(n.GetContent().c_str()) );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Event_members::Unsure_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<long>::const_iterator it = _element_uid.begin(); it != _element_uid.end(); it++)
	{
			r = r + "<uid>" + Utility::l2string(*it) + "</uid>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Event_members::Unsure_t::IsSet() const
{
	return UidIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<long>& Event_members::Unsure_t::GetUid() const
{
	return _element_uid;
}


std::list<long>& Event_members::Unsure_t::GetUid()
{
	return _element_uid;
}


void Event_members::Unsure_t::SetUid(const std::list<long>& uid)
{
	_element_uid = uid;
}


// -----------------------------------------------------------------------------
bool Event_members::Unsure_t::UidIsSet() const
{
	return !_element_uid.empty();
}


// -----------------------------------------------------------------------------
bool Event_members::Unsure_t::GetList() const
{
	return _attribute_list;
}


void Event_members::Unsure_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Event_members::Declined_t::Declined_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Event_members::Declined_t::Declined_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Event_members::Declined_t::clear()
{
	while (!_element_uid.empty())
		_element_uid.erase( _element_uid.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Event_members::Declined_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "uid");
		while (n)
		{
			_element_uid.push_back( atoi(n.GetContent().c_str()) );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Event_members::Declined_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<long>::const_iterator it = _element_uid.begin(); it != _element_uid.end(); it++)
	{
			r = r + "<uid>" + Utility::l2string(*it) + "</uid>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Event_members::Declined_t::IsSet() const
{
	return UidIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<long>& Event_members::Declined_t::GetUid() const
{
	return _element_uid;
}


std::list<long>& Event_members::Declined_t::GetUid()
{
	return _element_uid;
}


void Event_members::Declined_t::SetUid(const std::list<long>& uid)
{
	_element_uid = uid;
}


// -----------------------------------------------------------------------------
bool Event_members::Declined_t::UidIsSet() const
{
	return !_element_uid.empty();
}


// -----------------------------------------------------------------------------
bool Event_members::Declined_t::GetList() const
{
	return _attribute_list;
}


void Event_members::Declined_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Notification_count::Notification_count()
: _element_unread(0)
, _element_unread_is_set(false)
, _element_most_recent_is_set(false)
{
}


// -----------------------------------------------------------------------------
Notification_count::Notification_count(const Xml::XmlNode& it)
: _element_unread(0)
, _element_unread_is_set(false)
, _element_most_recent_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Notification_count::clear()
{
	_element_unread = 0;
	// simpleType:
	// _element_most_recent.clear();
	_element_unread_is_set = false;
	_element_most_recent_is_set = false;
}


// -----------------------------------------------------------------------------
void Notification_count::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("unread"))
		throw Xml::XmlException("missing required node in element 'notification_count': unread");
	SetUnread( atoi(std::string(it["unread"]).c_str()) );
	if (!it.Exists("most_recent"))
		throw Xml::XmlException("missing required node in element 'notification_count': most_recent");
	SetMost_recent( atoi(std::string(it["most_recent"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Notification_count::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<unread>" + Utility::l2string(_element_unread) + "</unread>";
	}
	{
		r = r + "<most_recent>" + Utility::l2string(_element_most_recent) + "</most_recent>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Notification_count::IsSet() const
{
	return UnreadIsSet() || Most_recentIsSet();
}


// -----------------------------------------------------------------------------
int Notification_count::GetUnread() const
{
	return _element_unread;
}


void Notification_count::SetUnread(int unread)
{
	_element_unread = unread;
	_element_unread_is_set = true;
}


// -----------------------------------------------------------------------------
long Notification_count::GetMost_recent() const
{
	return _element_most_recent;
}


void Notification_count::SetMost_recent(long most_recent)
{
	_element_most_recent = most_recent;
	_element_most_recent_is_set = true;
}


// -----------------------------------------------------------------------------
Notifications::Notifications()
{
}


// -----------------------------------------------------------------------------
Notifications::Notifications(const Xml::XmlNode& it)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Notifications::clear()
{
	_element_messages.clear();
	_element_pokes.clear();
	_element_shares.clear();
	_element_friend_requests.clear();
	_element_group_invites.clear();
	_element_event_invites.clear();
}


// -----------------------------------------------------------------------------
void Notifications::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("messages"))
		throw Xml::XmlException("missing required node in element 'notifications': messages");
	{
		Xml::XmlNode n(it, "messages");
		if (n)
			_element_messages.FromXml( n );
	}
	if (!it.Exists("pokes"))
		throw Xml::XmlException("missing required node in element 'notifications': pokes");
	{
		Xml::XmlNode n(it, "pokes");
		if (n)
			_element_pokes.FromXml( n );
	}
	if (!it.Exists("shares"))
		throw Xml::XmlException("missing required node in element 'notifications': shares");
	{
		Xml::XmlNode n(it, "shares");
		if (n)
			_element_shares.FromXml( n );
	}
	if (!it.Exists("friend_requests"))
		throw Xml::XmlException("missing required node in element 'notifications': friend_requests");
	{
		Xml::XmlNode n(it, "friend_requests");
		if (n)
			_element_friend_requests.FromXml( n );
	}
	if (!it.Exists("group_invites"))
		throw Xml::XmlException("missing required node in element 'notifications': group_invites");
	{
		Xml::XmlNode n(it, "group_invites");
		if (n)
			_element_group_invites.FromXml( n );
	}
	if (!it.Exists("event_invites"))
		throw Xml::XmlException("missing required node in element 'notifications': event_invites");
	{
		Xml::XmlNode n(it, "event_invites");
		if (n)
			_element_event_invites.FromXml( n );
	}
}


// -----------------------------------------------------------------------------
const std::string Notifications::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += _element_messages.ToString("messages");
	r += _element_pokes.ToString("pokes");
	r += _element_shares.ToString("shares");
	r += _element_friend_requests.ToString("friend_requests");
	r += _element_group_invites.ToString("group_invites");
	r += _element_event_invites.ToString("event_invites");
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Notifications::IsSet() const
{
	return MessagesIsSet() || PokesIsSet() || SharesIsSet() || Friend_requestsIsSet() || Group_invitesIsSet() || Event_invitesIsSet();
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Notification_count& Notifications::GetMessages() const
{
	return _element_messages;
}


com_facebook_1_0_::Notification_count& Notifications::GetMessages()
{
	return _element_messages;
}


void Notifications::SetMessages(const com_facebook_1_0_::Notification_count& messages)
{
	_element_messages = messages;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Notification_count& Notifications::GetPokes() const
{
	return _element_pokes;
}


com_facebook_1_0_::Notification_count& Notifications::GetPokes()
{
	return _element_pokes;
}


void Notifications::SetPokes(const com_facebook_1_0_::Notification_count& pokes)
{
	_element_pokes = pokes;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Notification_count& Notifications::GetShares() const
{
	return _element_shares;
}


com_facebook_1_0_::Notification_count& Notifications::GetShares()
{
	return _element_shares;
}


void Notifications::SetShares(const com_facebook_1_0_::Notification_count& shares)
{
	_element_shares = shares;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Notifications::Friend_requests_t& Notifications::GetFriend_requests() const
{
	return _element_friend_requests;
}


com_facebook_1_0_::Notifications::Friend_requests_t& Notifications::GetFriend_requests()
{
	return _element_friend_requests;
}


void Notifications::SetFriend_requests(const com_facebook_1_0_::Notifications::Friend_requests_t& friend_requests)
{
	_element_friend_requests = friend_requests;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Notifications::Group_invites_t& Notifications::GetGroup_invites() const
{
	return _element_group_invites;
}


com_facebook_1_0_::Notifications::Group_invites_t& Notifications::GetGroup_invites()
{
	return _element_group_invites;
}


void Notifications::SetGroup_invites(const com_facebook_1_0_::Notifications::Group_invites_t& group_invites)
{
	_element_group_invites = group_invites;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Notifications::Event_invites_t& Notifications::GetEvent_invites() const
{
	return _element_event_invites;
}


com_facebook_1_0_::Notifications::Event_invites_t& Notifications::GetEvent_invites()
{
	return _element_event_invites;
}


void Notifications::SetEvent_invites(const com_facebook_1_0_::Notifications::Event_invites_t& event_invites)
{
	_element_event_invites = event_invites;
}


// -----------------------------------------------------------------------------
bool Notifications::MessagesIsSet() const
{
	return _element_messages.IsSet();
}


// -----------------------------------------------------------------------------
bool Notifications::PokesIsSet() const
{
	return _element_pokes.IsSet();
}


// -----------------------------------------------------------------------------
bool Notifications::SharesIsSet() const
{
	return _element_shares.IsSet();
}


// -----------------------------------------------------------------------------
bool Notifications::Friend_requestsIsSet() const
{
	return _element_friend_requests.IsSet();
}


// -----------------------------------------------------------------------------
bool Notifications::Group_invitesIsSet() const
{
	return _element_group_invites.IsSet();
}


// -----------------------------------------------------------------------------
bool Notifications::Event_invitesIsSet() const
{
	return _element_event_invites.IsSet();
}


// -----------------------------------------------------------------------------
Notifications::Friend_requests_t::Friend_requests_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Notifications::Friend_requests_t::Friend_requests_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Notifications::Friend_requests_t::clear()
{
	while (!_element_uid.empty())
		_element_uid.erase( _element_uid.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Notifications::Friend_requests_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "uid");
		while (n)
		{
			_element_uid.push_back( atoi(n.GetContent().c_str()) );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Notifications::Friend_requests_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<long>::const_iterator it = _element_uid.begin(); it != _element_uid.end(); it++)
	{
			r = r + "<uid>" + Utility::l2string(*it) + "</uid>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Notifications::Friend_requests_t::IsSet() const
{
	return UidIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<long>& Notifications::Friend_requests_t::GetUid() const
{
	return _element_uid;
}


std::list<long>& Notifications::Friend_requests_t::GetUid()
{
	return _element_uid;
}


void Notifications::Friend_requests_t::SetUid(const std::list<long>& uid)
{
	_element_uid = uid;
}


// -----------------------------------------------------------------------------
bool Notifications::Friend_requests_t::UidIsSet() const
{
	return !_element_uid.empty();
}


// -----------------------------------------------------------------------------
bool Notifications::Friend_requests_t::GetList() const
{
	return _attribute_list;
}


void Notifications::Friend_requests_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Notifications::Group_invites_t::Group_invites_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Notifications::Group_invites_t::Group_invites_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Notifications::Group_invites_t::clear()
{
	while (!_element_gid.empty())
		_element_gid.erase( _element_gid.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Notifications::Group_invites_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "gid");
		while (n)
		{
			_element_gid.push_back( atoi(n.GetContent().c_str()) );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Notifications::Group_invites_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<long>::const_iterator it = _element_gid.begin(); it != _element_gid.end(); it++)
	{
			r = r + "<gid>" + Utility::l2string(*it) + "</gid>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Notifications::Group_invites_t::IsSet() const
{
	return GidIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<long>& Notifications::Group_invites_t::GetGid() const
{
	return _element_gid;
}


std::list<long>& Notifications::Group_invites_t::GetGid()
{
	return _element_gid;
}


void Notifications::Group_invites_t::SetGid(const std::list<long>& gid)
{
	_element_gid = gid;
}


// -----------------------------------------------------------------------------
bool Notifications::Group_invites_t::GidIsSet() const
{
	return !_element_gid.empty();
}


// -----------------------------------------------------------------------------
bool Notifications::Group_invites_t::GetList() const
{
	return _attribute_list;
}


void Notifications::Group_invites_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Notifications::Event_invites_t::Event_invites_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Notifications::Event_invites_t::Event_invites_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Notifications::Event_invites_t::clear()
{
	while (!_element_eid.empty())
		_element_eid.erase( _element_eid.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Notifications::Event_invites_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "eid");
		while (n)
		{
			_element_eid.push_back( atoi(n.GetContent().c_str()) );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Notifications::Event_invites_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<long>::const_iterator it = _element_eid.begin(); it != _element_eid.end(); it++)
	{
			r = r + "<eid>" + Utility::l2string(*it) + "</eid>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Notifications::Event_invites_t::IsSet() const
{
	return EidIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<long>& Notifications::Event_invites_t::GetEid() const
{
	return _element_eid;
}


std::list<long>& Notifications::Event_invites_t::GetEid()
{
	return _element_eid;
}


void Notifications::Event_invites_t::SetEid(const std::list<long>& eid)
{
	_element_eid = eid;
}


// -----------------------------------------------------------------------------
bool Notifications::Event_invites_t::EidIsSet() const
{
	return !_element_eid.empty();
}


// -----------------------------------------------------------------------------
bool Notifications::Event_invites_t::GetList() const
{
	return _attribute_list;
}


void Notifications::Event_invites_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Notification::Notification()
: _element_is_unread(0)
, _element_is_hidden(0)
, _element_notification_id_is_set(false)
, _element_sender_id_is_set(false)
, _element_recipient_id_is_set(false)
, _element_created_time_is_set(false)
, _element_updated_time_is_set(false)
, _element_title_html_is_set(false)
, _element_title_text_is_set(false)
, _element_body_html_is_set(false)
, _element_body_text_is_set(false)
, _element_href_is_set(false)
, _element_app_id_is_set(false)
, _element_is_unread_is_set(false)
, _element_is_hidden_is_set(false)
{
}


// -----------------------------------------------------------------------------
Notification::Notification(const Xml::XmlNode& it)
: _element_is_unread(0)
, _element_is_hidden(0)
, _element_notification_id_is_set(false)
, _element_sender_id_is_set(false)
, _element_recipient_id_is_set(false)
, _element_created_time_is_set(false)
, _element_updated_time_is_set(false)
, _element_title_html_is_set(false)
, _element_title_text_is_set(false)
, _element_body_html_is_set(false)
, _element_body_text_is_set(false)
, _element_href_is_set(false)
, _element_app_id_is_set(false)
, _element_is_unread_is_set(false)
, _element_is_hidden_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Notification::clear()
{
	// simpleType:
	// _element_notification_id.clear();
	// simpleType:
	// _element_sender_id.clear();
	// simpleType:
	// _element_recipient_id.clear();
	// simpleType:
	// _element_created_time.clear();
	// simpleType:
	// _element_updated_time.clear();
	_element_title_html.clear();
	_element_title_text.clear();
	_element_body_html.clear();
	_element_body_text.clear();
	_element_href.clear();
	// simpleType:
	// _element_app_id.clear();
	_element_is_unread = 0;
	_element_is_hidden = 0;
	_element_notification_id_is_set = false;
	_element_sender_id_is_set = false;
	_element_recipient_id_is_set = false;
	_element_created_time_is_set = false;
	_element_updated_time_is_set = false;
	_element_title_html_is_set = false;
	_element_title_text_is_set = false;
	_element_body_html_is_set = false;
	_element_body_text_is_set = false;
	_element_href_is_set = false;
	_element_app_id_is_set = false;
	_element_is_unread_is_set = false;
	_element_is_hidden_is_set = false;
}


// -----------------------------------------------------------------------------
void Notification::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("notification_id"))
		throw Xml::XmlException("missing required node in element 'notification': notification_id");
	SetNotification_id( atoi(std::string(it["notification_id"]).c_str()) );
	if (!it.Exists("sender_id"))
		throw Xml::XmlException("missing required node in element 'notification': sender_id");
	SetSender_id( atoi(std::string(it["sender_id"]).c_str()) );
	if (!it.Exists("recipient_id"))
		throw Xml::XmlException("missing required node in element 'notification': recipient_id");
	SetRecipient_id( atoi(std::string(it["recipient_id"]).c_str()) );
	if (!it.Exists("created_time"))
		throw Xml::XmlException("missing required node in element 'notification': created_time");
	SetCreated_time( atoi(std::string(it["created_time"]).c_str()) );
	if (!it.Exists("updated_time"))
		throw Xml::XmlException("missing required node in element 'notification': updated_time");
	SetUpdated_time( atoi(std::string(it["updated_time"]).c_str()) );
	if (!it.Exists("title_html"))
		throw Xml::XmlException("missing required node in element 'notification': title_html");
	SetTitle_html( it["title_html"] );
	if (!it.Exists("title_text"))
		throw Xml::XmlException("missing required node in element 'notification': title_text");
	SetTitle_text( it["title_text"] );
	if (!it.Exists("body_html"))
		throw Xml::XmlException("missing required node in element 'notification': body_html");
	SetBody_html( it["body_html"] );
	if (!it.Exists("body_text"))
		throw Xml::XmlException("missing required node in element 'notification': body_text");
	SetBody_text( it["body_text"] );
	if (!it.Exists("href"))
		throw Xml::XmlException("missing required node in element 'notification': href");
	SetHref( it["href"] );
	if (!it.Exists("app_id"))
		throw Xml::XmlException("missing required node in element 'notification': app_id");
	SetApp_id( atoi(std::string(it["app_id"]).c_str()) );
	if (!it.Exists("is_unread"))
		throw Xml::XmlException("missing required node in element 'notification': is_unread");
	SetIs_unread( atoi(std::string(it["is_unread"]).c_str()) );
	if (!it.Exists("is_hidden"))
		throw Xml::XmlException("missing required node in element 'notification': is_hidden");
	SetIs_hidden( atoi(std::string(it["is_hidden"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Notification::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<notification_id>" + Utility::l2string(_element_notification_id) + "</notification_id>";
	}
	{
		r = r + "<sender_id>" + Utility::l2string(_element_sender_id) + "</sender_id>";
	}
	{
		r = r + "<recipient_id>" + Utility::l2string(_element_recipient_id) + "</recipient_id>";
	}
	{
		r = r + "<created_time>" + Utility::l2string(_element_created_time) + "</created_time>";
	}
	{
		r = r + "<updated_time>" + Utility::l2string(_element_updated_time) + "</updated_time>";
	}
	r += "<title_html>" + _element_title_html + "</title_html>";
	r += "<title_text>" + _element_title_text + "</title_text>";
	r += "<body_html>" + _element_body_html + "</body_html>";
	r += "<body_text>" + _element_body_text + "</body_text>";
	r += "<href>" + _element_href + "</href>";
	{
		r = r + "<app_id>" + Utility::l2string(_element_app_id) + "</app_id>";
	}
	{
		r = r + "<is_unread>" + Utility::l2string(_element_is_unread) + "</is_unread>";
	}
	{
		r = r + "<is_hidden>" + Utility::l2string(_element_is_hidden) + "</is_hidden>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Notification::IsSet() const
{
	return Notification_idIsSet() || Sender_idIsSet() || Recipient_idIsSet() || Created_timeIsSet() || Updated_timeIsSet() || Title_htmlIsSet() || Title_textIsSet() || Body_htmlIsSet() || Body_textIsSet() || HrefIsSet() || App_idIsSet() || Is_unreadIsSet() || Is_hiddenIsSet();
}


// -----------------------------------------------------------------------------
long Notification::GetNotification_id() const
{
	return _element_notification_id;
}


void Notification::SetNotification_id(long notification_id)
{
	_element_notification_id = notification_id;
	_element_notification_id_is_set = true;
}


// -----------------------------------------------------------------------------
long Notification::GetSender_id() const
{
	return _element_sender_id;
}


void Notification::SetSender_id(long sender_id)
{
	_element_sender_id = sender_id;
	_element_sender_id_is_set = true;
}


// -----------------------------------------------------------------------------
long Notification::GetRecipient_id() const
{
	return _element_recipient_id;
}


void Notification::SetRecipient_id(long recipient_id)
{
	_element_recipient_id = recipient_id;
	_element_recipient_id_is_set = true;
}


// -----------------------------------------------------------------------------
long Notification::GetCreated_time() const
{
	return _element_created_time;
}


void Notification::SetCreated_time(long created_time)
{
	_element_created_time = created_time;
	_element_created_time_is_set = true;
}


// -----------------------------------------------------------------------------
long Notification::GetUpdated_time() const
{
	return _element_updated_time;
}


void Notification::SetUpdated_time(long updated_time)
{
	_element_updated_time = updated_time;
	_element_updated_time_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Notification::GetTitle_html() const
{
	return _element_title_html;
}


void Notification::SetTitle_html(const std::string& title_html)
{
	_element_title_html = title_html;
	_element_title_html_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Notification::GetTitle_text() const
{
	return _element_title_text;
}


void Notification::SetTitle_text(const std::string& title_text)
{
	_element_title_text = title_text;
	_element_title_text_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Notification::GetBody_html() const
{
	return _element_body_html;
}


void Notification::SetBody_html(const std::string& body_html)
{
	_element_body_html = body_html;
	_element_body_html_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Notification::GetBody_text() const
{
	return _element_body_text;
}


void Notification::SetBody_text(const std::string& body_text)
{
	_element_body_text = body_text;
	_element_body_text_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Notification::GetHref() const
{
	return _element_href;
}


void Notification::SetHref(const std::string& href)
{
	_element_href = href;
	_element_href_is_set = true;
}


// -----------------------------------------------------------------------------
long Notification::GetApp_id() const
{
	return _element_app_id;
}


void Notification::SetApp_id(long app_id)
{
	_element_app_id = app_id;
	_element_app_id_is_set = true;
}


// -----------------------------------------------------------------------------
int Notification::GetIs_unread() const
{
	return _element_is_unread;
}


void Notification::SetIs_unread(int is_unread)
{
	_element_is_unread = is_unread;
	_element_is_unread_is_set = true;
}


// -----------------------------------------------------------------------------
int Notification::GetIs_hidden() const
{
	return _element_is_hidden;
}


void Notification::SetIs_hidden(int is_hidden)
{
	_element_is_hidden = is_hidden;
	_element_is_hidden_is_set = true;
}


// -----------------------------------------------------------------------------
Photo::Photo()
: _element_object_id(0)
, _element_pid_is_set(false)
, _element_aid_is_set(false)
, _element_owner_is_set(false)
, _element_src_is_set(false)
, _element_src_big_is_set(false)
, _element_src_small_is_set(false)
, _element_link_is_set(false)
, _element_caption_is_set(false)
, _element_created_is_set(false)
, _element_story_fbid_is_set(false)
, _element_modified_is_set(false)
, _element_object_id_is_set(false)
{
}


// -----------------------------------------------------------------------------
Photo::Photo(const Xml::XmlNode& it)
: _element_object_id(0)
, _element_pid_is_set(false)
, _element_aid_is_set(false)
, _element_owner_is_set(false)
, _element_src_is_set(false)
, _element_src_big_is_set(false)
, _element_src_small_is_set(false)
, _element_link_is_set(false)
, _element_caption_is_set(false)
, _element_created_is_set(false)
, _element_story_fbid_is_set(false)
, _element_modified_is_set(false)
, _element_object_id_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Photo::clear()
{
	// simpleType:
	// _element_pid.clear();
	// simpleType:
	// _element_aid.clear();
	// simpleType:
	// _element_owner.clear();
	_element_src.clear();
	_element_src_big.clear();
	_element_src_small.clear();
	_element_link.clear();
	_element_caption.clear();
	// simpleType:
	// _element_created.clear();
	// simpleType:
	// _element_story_fbid.clear();
	// simpleType:
	// _element_modified.clear();
	_element_object_id = 0;
	_element_pid_is_set = false;
	_element_aid_is_set = false;
	_element_owner_is_set = false;
	_element_src_is_set = false;
	_element_src_big_is_set = false;
	_element_src_small_is_set = false;
	_element_link_is_set = false;
	_element_caption_is_set = false;
	_element_created_is_set = false;
	_element_story_fbid_is_set = false;
	_element_modified_is_set = false;
	_element_object_id_is_set = false;
}


// -----------------------------------------------------------------------------
void Photo::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("pid"))
		throw Xml::XmlException("missing required node in element 'photo': pid");
	SetPid( it["pid"] );
	if (!it.Exists("aid"))
		throw Xml::XmlException("missing required node in element 'photo': aid");
	SetAid( it["aid"] );
	if (!it.Exists("owner"))
		throw Xml::XmlException("missing required node in element 'photo': owner");
	SetOwner( atoi(std::string(it["owner"]).c_str()) );
	if (!it.Exists("src"))
		throw Xml::XmlException("missing required node in element 'photo': src");
	SetSrc( it["src"] );
	if (!it.Exists("src_big"))
		throw Xml::XmlException("missing required node in element 'photo': src_big");
	SetSrc_big( it["src_big"] );
	if (!it.Exists("src_small"))
		throw Xml::XmlException("missing required node in element 'photo': src_small");
	SetSrc_small( it["src_small"] );
	if (!it.Exists("link"))
		throw Xml::XmlException("missing required node in element 'photo': link");
	SetLink( it["link"] );
	if (!it.Exists("caption"))
		throw Xml::XmlException("missing required node in element 'photo': caption");
	SetCaption( it["caption"] );
	if (!it.Exists("created"))
		throw Xml::XmlException("missing required node in element 'photo': created");
	SetCreated( atoi(std::string(it["created"]).c_str()) );
	if (!it.Exists("story_fbid"))
		throw Xml::XmlException("missing required node in element 'photo': story_fbid");
	SetStory_fbid( atoi(std::string(it["story_fbid"]).c_str()) );
	if (!it.Exists("modified"))
		throw Xml::XmlException("missing required node in element 'photo': modified");
	SetModified( atoi(std::string(it["modified"]).c_str()) );
	if (!it.Exists("object_id"))
		throw Xml::XmlException("missing required node in element 'photo': object_id");
	SetObject_id( atoi(std::string(it["object_id"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Photo::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<pid>" + _element_pid + "</pid>";
	r += "<aid>" + _element_aid + "</aid>";
	{
		r = r + "<owner>" + Utility::l2string(_element_owner) + "</owner>";
	}
	r += "<src>" + _element_src + "</src>";
	r += "<src_big>" + _element_src_big + "</src_big>";
	r += "<src_small>" + _element_src_small + "</src_small>";
	r += "<link>" + _element_link + "</link>";
	r += "<caption>" + _element_caption + "</caption>";
	{
		r = r + "<created>" + Utility::l2string(_element_created) + "</created>";
	}
	{
		r = r + "<story_fbid>" + Utility::l2string(_element_story_fbid) + "</story_fbid>";
	}
	{
		r = r + "<modified>" + Utility::l2string(_element_modified) + "</modified>";
	}
	{
		r = r + "<object_id>" + Utility::l2string(_element_object_id) + "</object_id>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Photo::IsSet() const
{
	return PidIsSet() || AidIsSet() || OwnerIsSet() || SrcIsSet() || Src_bigIsSet() || Src_smallIsSet() || LinkIsSet() || CaptionIsSet() || CreatedIsSet() || Story_fbidIsSet() || ModifiedIsSet() || Object_idIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Photo::GetPid() const
{
	return _element_pid;
}


void Photo::SetPid(const std::string& pid)
{
	_element_pid = pid;
	_element_pid_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Photo::GetAid() const
{
	return _element_aid;
}


void Photo::SetAid(const std::string& aid)
{
	_element_aid = aid;
	_element_aid_is_set = true;
}


// -----------------------------------------------------------------------------
long Photo::GetOwner() const
{
	return _element_owner;
}


void Photo::SetOwner(long owner)
{
	_element_owner = owner;
	_element_owner_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Photo::GetSrc() const
{
	return _element_src;
}


void Photo::SetSrc(const std::string& src)
{
	_element_src = src;
	_element_src_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Photo::GetSrc_big() const
{
	return _element_src_big;
}


void Photo::SetSrc_big(const std::string& src_big)
{
	_element_src_big = src_big;
	_element_src_big_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Photo::GetSrc_small() const
{
	return _element_src_small;
}


void Photo::SetSrc_small(const std::string& src_small)
{
	_element_src_small = src_small;
	_element_src_small_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Photo::GetLink() const
{
	return _element_link;
}


void Photo::SetLink(const std::string& link)
{
	_element_link = link;
	_element_link_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Photo::GetCaption() const
{
	return _element_caption;
}


void Photo::SetCaption(const std::string& caption)
{
	_element_caption = caption;
	_element_caption_is_set = true;
}


// -----------------------------------------------------------------------------
long Photo::GetCreated() const
{
	return _element_created;
}


void Photo::SetCreated(long created)
{
	_element_created = created;
	_element_created_is_set = true;
}


// -----------------------------------------------------------------------------
long Photo::GetStory_fbid() const
{
	return _element_story_fbid;
}


void Photo::SetStory_fbid(long story_fbid)
{
	_element_story_fbid = story_fbid;
	_element_story_fbid_is_set = true;
}


// -----------------------------------------------------------------------------
long Photo::GetModified() const
{
	return _element_modified;
}


void Photo::SetModified(long modified)
{
	_element_modified = modified;
	_element_modified_is_set = true;
}


// -----------------------------------------------------------------------------
long Photo::GetObject_id() const
{
	return _element_object_id;
}


void Photo::SetObject_id(long object_id)
{
	_element_object_id = object_id;
	_element_object_id_is_set = true;
}


// -----------------------------------------------------------------------------
Photo_tag::Photo_tag()
: _element_xcoord(0)
, _element_ycoord(0)
, _element_pid_is_set(false)
, _element_subject_is_set(false)
, _element_text_is_set(false)
, _element_xcoord_is_set(false)
, _element_ycoord_is_set(false)
, _element_created_is_set(false)
{
}


// -----------------------------------------------------------------------------
Photo_tag::Photo_tag(const Xml::XmlNode& it)
: _element_xcoord(0)
, _element_ycoord(0)
, _element_pid_is_set(false)
, _element_subject_is_set(false)
, _element_text_is_set(false)
, _element_xcoord_is_set(false)
, _element_ycoord_is_set(false)
, _element_created_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Photo_tag::clear()
{
	// simpleType:
	// _element_pid.clear();
	// simpleType:
	// _element_subject.clear();
	_element_text.clear();
	_element_xcoord = 0;
	_element_ycoord = 0;
	// simpleType:
	// _element_created.clear();
	_element_pid_is_set = false;
	_element_subject_is_set = false;
	_element_text_is_set = false;
	_element_xcoord_is_set = false;
	_element_ycoord_is_set = false;
	_element_created_is_set = false;
}


// -----------------------------------------------------------------------------
void Photo_tag::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("pid"))
		throw Xml::XmlException("missing required node in element 'photo_tag': pid");
	SetPid( it["pid"] );
	if (it.Exists("subject"))
		SetSubject( atoi(std::string(it["subject"]).c_str()) );
	if (it.Exists("text"))
		SetText( it["text"] );
	if (!it.Exists("xcoord"))
		throw Xml::XmlException("missing required node in element 'photo_tag': xcoord");
	SetXcoord( atoi(std::string(it["xcoord"]).c_str()) );
	if (!it.Exists("ycoord"))
		throw Xml::XmlException("missing required node in element 'photo_tag': ycoord");
	SetYcoord( atoi(std::string(it["ycoord"]).c_str()) );
	if (!it.Exists("created"))
		throw Xml::XmlException("missing required node in element 'photo_tag': created");
	SetCreated( atoi(std::string(it["created"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Photo_tag::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<pid>" + _element_pid + "</pid>";
	if (_element_subject_is_set)
	{
		r = r + "<subject>" + Utility::l2string(_element_subject) + "</subject>";
	}
	if (_element_text_is_set)
		r += "<text>" + _element_text + "</text>";
	{
		r = r + "<xcoord>" + Utility::l2string(_element_xcoord) + "</xcoord>";
	}
	{
		r = r + "<ycoord>" + Utility::l2string(_element_ycoord) + "</ycoord>";
	}
	{
		r = r + "<created>" + Utility::l2string(_element_created) + "</created>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Photo_tag::IsSet() const
{
	return PidIsSet() || SubjectIsSet() || TextIsSet() || XcoordIsSet() || YcoordIsSet() || CreatedIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Photo_tag::GetPid() const
{
	return _element_pid;
}


void Photo_tag::SetPid(const std::string& pid)
{
	_element_pid = pid;
	_element_pid_is_set = true;
}


// -----------------------------------------------------------------------------
long Photo_tag::GetSubject() const
{
	return _element_subject;
}


void Photo_tag::SetSubject(long subject)
{
	_element_subject = subject;
	_element_subject_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Photo_tag::GetText() const
{
	return _element_text;
}


void Photo_tag::SetText(const std::string& text)
{
	_element_text = text;
	_element_text_is_set = true;
}


// -----------------------------------------------------------------------------
double Photo_tag::GetXcoord() const
{
	return _element_xcoord;
}


void Photo_tag::SetXcoord(double xcoord)
{
	_element_xcoord = xcoord;
	_element_xcoord_is_set = true;
}


// -----------------------------------------------------------------------------
double Photo_tag::GetYcoord() const
{
	return _element_ycoord;
}


void Photo_tag::SetYcoord(double ycoord)
{
	_element_ycoord = ycoord;
	_element_ycoord_is_set = true;
}


// -----------------------------------------------------------------------------
long Photo_tag::GetCreated() const
{
	return _element_created;
}


void Photo_tag::SetCreated(long created)
{
	_element_created = created;
	_element_created_is_set = true;
}


// -----------------------------------------------------------------------------
Album::Album()
: _element_size(0)
, _element_object_id(0)
, _element_aid_is_set(false)
, _element_cover_pid_is_set(false)
, _element_owner_is_set(false)
, _element_name_is_set(false)
, _element_created_is_set(false)
, _element_modified_is_set(false)
, _element_description_is_set(false)
, _element_location_is_set(false)
, _element_link_is_set(false)
, _element_size_is_set(false)
, _element_visible_is_set(false)
, _element_modified_major_is_set(false)
, _element_type_is_set(false)
, _element_object_id_is_set(false)
{
}


// -----------------------------------------------------------------------------
Album::Album(const Xml::XmlNode& it)
: _element_size(0)
, _element_object_id(0)
, _element_aid_is_set(false)
, _element_cover_pid_is_set(false)
, _element_owner_is_set(false)
, _element_name_is_set(false)
, _element_created_is_set(false)
, _element_modified_is_set(false)
, _element_description_is_set(false)
, _element_location_is_set(false)
, _element_link_is_set(false)
, _element_size_is_set(false)
, _element_visible_is_set(false)
, _element_modified_major_is_set(false)
, _element_type_is_set(false)
, _element_object_id_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Album::clear()
{
	// simpleType:
	// _element_aid.clear();
	// simpleType:
	// _element_cover_pid.clear();
	// simpleType:
	// _element_owner.clear();
	_element_name.clear();
	// simpleType:
	// _element_created.clear();
	// simpleType:
	// _element_modified.clear();
	_element_description.clear();
	_element_location.clear();
	_element_link.clear();
	_element_size = 0;
	_element_visible.clear();
	// simpleType:
	// _element_modified_major.clear();
	_element_type.clear();
	_element_object_id = 0;
	_element_aid_is_set = false;
	_element_cover_pid_is_set = false;
	_element_owner_is_set = false;
	_element_name_is_set = false;
	_element_created_is_set = false;
	_element_modified_is_set = false;
	_element_description_is_set = false;
	_element_location_is_set = false;
	_element_link_is_set = false;
	_element_size_is_set = false;
	_element_visible_is_set = false;
	_element_modified_major_is_set = false;
	_element_type_is_set = false;
	_element_object_id_is_set = false;
}


// -----------------------------------------------------------------------------
void Album::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("aid"))
		throw Xml::XmlException("missing required node in element 'album': aid");
	SetAid( it["aid"] );
	if (!it.Exists("cover_pid"))
		throw Xml::XmlException("missing required node in element 'album': cover_pid");
	SetCover_pid( it["cover_pid"] );
	if (!it.Exists("owner"))
		throw Xml::XmlException("missing required node in element 'album': owner");
	SetOwner( atoi(std::string(it["owner"]).c_str()) );
	if (!it.Exists("name"))
		throw Xml::XmlException("missing required node in element 'album': name");
	SetName( it["name"] );
	if (!it.Exists("created"))
		throw Xml::XmlException("missing required node in element 'album': created");
	SetCreated( atoi(std::string(it["created"]).c_str()) );
	if (!it.Exists("modified"))
		throw Xml::XmlException("missing required node in element 'album': modified");
	SetModified( atoi(std::string(it["modified"]).c_str()) );
	if (!it.Exists("description"))
		throw Xml::XmlException("missing required node in element 'album': description");
	SetDescription( it["description"] );
	if (!it.Exists("location"))
		throw Xml::XmlException("missing required node in element 'album': location");
	SetLocation( it["location"] );
	if (!it.Exists("link"))
		throw Xml::XmlException("missing required node in element 'album': link");
	SetLink( it["link"] );
	if (!it.Exists("size"))
		throw Xml::XmlException("missing required node in element 'album': size");
	SetSize( atoi(std::string(it["size"]).c_str()) );
	if (!it.Exists("visible"))
		throw Xml::XmlException("missing required node in element 'album': visible");
	SetVisible( it["visible"] );
	if (!it.Exists("modified_major"))
		throw Xml::XmlException("missing required node in element 'album': modified_major");
	SetModified_major( atoi(std::string(it["modified_major"]).c_str()) );
	if (!it.Exists("type"))
		throw Xml::XmlException("missing required node in element 'album': type");
	SetType( it["type"] );
	if (!it.Exists("object_id"))
		throw Xml::XmlException("missing required node in element 'album': object_id");
	SetObject_id( atoi(std::string(it["object_id"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Album::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<aid>" + _element_aid + "</aid>";
	r += "<cover_pid>" + _element_cover_pid + "</cover_pid>";
	{
		r = r + "<owner>" + Utility::l2string(_element_owner) + "</owner>";
	}
	r += "<name>" + _element_name + "</name>";
	{
		r = r + "<created>" + Utility::l2string(_element_created) + "</created>";
	}
	{
		r = r + "<modified>" + Utility::l2string(_element_modified) + "</modified>";
	}
	r += "<description>" + _element_description + "</description>";
	r += "<location>" + _element_location + "</location>";
	r += "<link>" + _element_link + "</link>";
	{
		r = r + "<size>" + Utility::l2string(_element_size) + "</size>";
	}
	r += "<visible>" + _element_visible + "</visible>";
	{
		r = r + "<modified_major>" + Utility::l2string(_element_modified_major) + "</modified_major>";
	}
	r += "<type>" + _element_type + "</type>";
	{
		r = r + "<object_id>" + Utility::l2string(_element_object_id) + "</object_id>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Album::IsSet() const
{
	return AidIsSet() || Cover_pidIsSet() || OwnerIsSet() || NameIsSet() || CreatedIsSet() || ModifiedIsSet() || DescriptionIsSet() || LocationIsSet() || LinkIsSet() || SizeIsSet() || VisibleIsSet() || Modified_majorIsSet() || TypeIsSet() || Object_idIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Album::GetAid() const
{
	return _element_aid;
}


void Album::SetAid(const std::string& aid)
{
	_element_aid = aid;
	_element_aid_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Album::GetCover_pid() const
{
	return _element_cover_pid;
}


void Album::SetCover_pid(const std::string& cover_pid)
{
	_element_cover_pid = cover_pid;
	_element_cover_pid_is_set = true;
}


// -----------------------------------------------------------------------------
long Album::GetOwner() const
{
	return _element_owner;
}


void Album::SetOwner(long owner)
{
	_element_owner = owner;
	_element_owner_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Album::GetName() const
{
	return _element_name;
}


void Album::SetName(const std::string& name)
{
	_element_name = name;
	_element_name_is_set = true;
}


// -----------------------------------------------------------------------------
long Album::GetCreated() const
{
	return _element_created;
}


void Album::SetCreated(long created)
{
	_element_created = created;
	_element_created_is_set = true;
}


// -----------------------------------------------------------------------------
long Album::GetModified() const
{
	return _element_modified;
}


void Album::SetModified(long modified)
{
	_element_modified = modified;
	_element_modified_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Album::GetDescription() const
{
	return _element_description;
}


void Album::SetDescription(const std::string& description)
{
	_element_description = description;
	_element_description_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Album::GetLocation() const
{
	return _element_location;
}


void Album::SetLocation(const std::string& location)
{
	_element_location = location;
	_element_location_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Album::GetLink() const
{
	return _element_link;
}


void Album::SetLink(const std::string& link)
{
	_element_link = link;
	_element_link_is_set = true;
}


// -----------------------------------------------------------------------------
int Album::GetSize() const
{
	return _element_size;
}


void Album::SetSize(int size)
{
	_element_size = size;
	_element_size_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Album::GetVisible() const
{
	return _element_visible;
}


void Album::SetVisible(const std::string& visible)
{
	_element_visible = visible;
	_element_visible_is_set = true;
}


// -----------------------------------------------------------------------------
long Album::GetModified_major() const
{
	return _element_modified_major;
}


void Album::SetModified_major(long modified_major)
{
	_element_modified_major = modified_major;
	_element_modified_major_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Album::GetType() const
{
	return _element_type;
}


void Album::SetType(const std::string& type)
{
	_element_type = type;
	_element_type_is_set = true;
}


// -----------------------------------------------------------------------------
long Album::GetObject_id() const
{
	return _element_object_id;
}


void Album::SetObject_id(long object_id)
{
	_element_object_id = object_id;
	_element_object_id_is_set = true;
}


// -----------------------------------------------------------------------------
Video::Video()
: _element_length(0)
, _element_vid_is_set(false)
, _element_title_is_set(false)
, _element_description_is_set(false)
, _element_link_is_set(false)
, _element_owner_is_set(false)
, _element_thumbnail_link_is_set(false)
, _element_embed_html_is_set(false)
, _element_created_time_is_set(false)
, _element_updated_time_is_set(false)
, _element_length_is_set(false)
{
}


// -----------------------------------------------------------------------------
Video::Video(const Xml::XmlNode& it)
: _element_length(0)
, _element_vid_is_set(false)
, _element_title_is_set(false)
, _element_description_is_set(false)
, _element_link_is_set(false)
, _element_owner_is_set(false)
, _element_thumbnail_link_is_set(false)
, _element_embed_html_is_set(false)
, _element_created_time_is_set(false)
, _element_updated_time_is_set(false)
, _element_length_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Video::clear()
{
	// simpleType:
	// _element_vid.clear();
	_element_title.clear();
	_element_description.clear();
	_element_link.clear();
	// simpleType:
	// _element_owner.clear();
	_element_thumbnail_link.clear();
	_element_embed_html.clear();
	// simpleType:
	// _element_created_time.clear();
	// simpleType:
	// _element_updated_time.clear();
	_element_length = 0;
	_element_vid_is_set = false;
	_element_title_is_set = false;
	_element_description_is_set = false;
	_element_link_is_set = false;
	_element_owner_is_set = false;
	_element_thumbnail_link_is_set = false;
	_element_embed_html_is_set = false;
	_element_created_time_is_set = false;
	_element_updated_time_is_set = false;
	_element_length_is_set = false;
}


// -----------------------------------------------------------------------------
void Video::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("vid"))
		throw Xml::XmlException("missing required node in element 'video': vid");
	SetVid( atoi(std::string(it["vid"]).c_str()) );
	if (!it.Exists("title"))
		throw Xml::XmlException("missing required node in element 'video': title");
	SetTitle( it["title"] );
	if (!it.Exists("description"))
		throw Xml::XmlException("missing required node in element 'video': description");
	SetDescription( it["description"] );
	if (!it.Exists("link"))
		throw Xml::XmlException("missing required node in element 'video': link");
	SetLink( it["link"] );
	if (!it.Exists("owner"))
		throw Xml::XmlException("missing required node in element 'video': owner");
	SetOwner( atoi(std::string(it["owner"]).c_str()) );
	if (!it.Exists("thumbnail_link"))
		throw Xml::XmlException("missing required node in element 'video': thumbnail_link");
	SetThumbnail_link( it["thumbnail_link"] );
	if (!it.Exists("embed_html"))
		throw Xml::XmlException("missing required node in element 'video': embed_html");
	SetEmbed_html( it["embed_html"] );
	if (!it.Exists("created_time"))
		throw Xml::XmlException("missing required node in element 'video': created_time");
	SetCreated_time( atoi(std::string(it["created_time"]).c_str()) );
	if (!it.Exists("updated_time"))
		throw Xml::XmlException("missing required node in element 'video': updated_time");
	SetUpdated_time( atoi(std::string(it["updated_time"]).c_str()) );
	if (!it.Exists("length"))
		throw Xml::XmlException("missing required node in element 'video': length");
	SetLength( atoi(std::string(it["length"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Video::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<vid>" + Utility::l2string(_element_vid) + "</vid>";
	}
	r += "<title>" + _element_title + "</title>";
	r += "<description>" + _element_description + "</description>";
	r += "<link>" + _element_link + "</link>";
	{
		r = r + "<owner>" + Utility::l2string(_element_owner) + "</owner>";
	}
	r += "<thumbnail_link>" + _element_thumbnail_link + "</thumbnail_link>";
	r += "<embed_html>" + _element_embed_html + "</embed_html>";
	{
		r = r + "<created_time>" + Utility::l2string(_element_created_time) + "</created_time>";
	}
	{
		r = r + "<updated_time>" + Utility::l2string(_element_updated_time) + "</updated_time>";
	}
	{
		r = r + "<length>" + Utility::l2string(_element_length) + "</length>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Video::IsSet() const
{
	return VidIsSet() || TitleIsSet() || DescriptionIsSet() || LinkIsSet() || OwnerIsSet() || Thumbnail_linkIsSet() || Embed_htmlIsSet() || Created_timeIsSet() || Updated_timeIsSet() || LengthIsSet();
}


// -----------------------------------------------------------------------------
long Video::GetVid() const
{
	return _element_vid;
}


void Video::SetVid(long vid)
{
	_element_vid = vid;
	_element_vid_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Video::GetTitle() const
{
	return _element_title;
}


void Video::SetTitle(const std::string& title)
{
	_element_title = title;
	_element_title_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Video::GetDescription() const
{
	return _element_description;
}


void Video::SetDescription(const std::string& description)
{
	_element_description = description;
	_element_description_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Video::GetLink() const
{
	return _element_link;
}


void Video::SetLink(const std::string& link)
{
	_element_link = link;
	_element_link_is_set = true;
}


// -----------------------------------------------------------------------------
long Video::GetOwner() const
{
	return _element_owner;
}


void Video::SetOwner(long owner)
{
	_element_owner = owner;
	_element_owner_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Video::GetThumbnail_link() const
{
	return _element_thumbnail_link;
}


void Video::SetThumbnail_link(const std::string& thumbnail_link)
{
	_element_thumbnail_link = thumbnail_link;
	_element_thumbnail_link_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Video::GetEmbed_html() const
{
	return _element_embed_html;
}


void Video::SetEmbed_html(const std::string& embed_html)
{
	_element_embed_html = embed_html;
	_element_embed_html_is_set = true;
}


// -----------------------------------------------------------------------------
long Video::GetCreated_time() const
{
	return _element_created_time;
}


void Video::SetCreated_time(long created_time)
{
	_element_created_time = created_time;
	_element_created_time_is_set = true;
}


// -----------------------------------------------------------------------------
long Video::GetUpdated_time() const
{
	return _element_updated_time;
}


void Video::SetUpdated_time(long updated_time)
{
	_element_updated_time = updated_time;
	_element_updated_time_is_set = true;
}


// -----------------------------------------------------------------------------
int Video::GetLength() const
{
	return _element_length;
}


void Video::SetLength(int length)
{
	_element_length = length;
	_element_length_is_set = true;
}


// -----------------------------------------------------------------------------
Video_tag::Video_tag()
: _element_vid_is_set(false)
, _element_subject_is_set(false)
, _element_created_time_is_set(false)
, _element_updated_time_is_set(false)
{
}


// -----------------------------------------------------------------------------
Video_tag::Video_tag(const Xml::XmlNode& it)
: _element_vid_is_set(false)
, _element_subject_is_set(false)
, _element_created_time_is_set(false)
, _element_updated_time_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Video_tag::clear()
{
	// simpleType:
	// _element_vid.clear();
	// simpleType:
	// _element_subject.clear();
	// simpleType:
	// _element_created_time.clear();
	// simpleType:
	// _element_updated_time.clear();
	_element_vid_is_set = false;
	_element_subject_is_set = false;
	_element_created_time_is_set = false;
	_element_updated_time_is_set = false;
}


// -----------------------------------------------------------------------------
void Video_tag::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("vid"))
		throw Xml::XmlException("missing required node in element 'video_tag': vid");
	SetVid( atoi(std::string(it["vid"]).c_str()) );
	if (!it.Exists("subject"))
		throw Xml::XmlException("missing required node in element 'video_tag': subject");
	SetSubject( atoi(std::string(it["subject"]).c_str()) );
	if (!it.Exists("created_time"))
		throw Xml::XmlException("missing required node in element 'video_tag': created_time");
	SetCreated_time( atoi(std::string(it["created_time"]).c_str()) );
	if (!it.Exists("updated_time"))
		throw Xml::XmlException("missing required node in element 'video_tag': updated_time");
	SetUpdated_time( atoi(std::string(it["updated_time"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Video_tag::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<vid>" + Utility::l2string(_element_vid) + "</vid>";
	}
	{
		r = r + "<subject>" + Utility::l2string(_element_subject) + "</subject>";
	}
	{
		r = r + "<created_time>" + Utility::l2string(_element_created_time) + "</created_time>";
	}
	{
		r = r + "<updated_time>" + Utility::l2string(_element_updated_time) + "</updated_time>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Video_tag::IsSet() const
{
	return VidIsSet() || SubjectIsSet() || Created_timeIsSet() || Updated_timeIsSet();
}


// -----------------------------------------------------------------------------
long Video_tag::GetVid() const
{
	return _element_vid;
}


void Video_tag::SetVid(long vid)
{
	_element_vid = vid;
	_element_vid_is_set = true;
}


// -----------------------------------------------------------------------------
long Video_tag::GetSubject() const
{
	return _element_subject;
}


void Video_tag::SetSubject(long subject)
{
	_element_subject = subject;
	_element_subject_is_set = true;
}


// -----------------------------------------------------------------------------
long Video_tag::GetCreated_time() const
{
	return _element_created_time;
}


void Video_tag::SetCreated_time(long created_time)
{
	_element_created_time = created_time;
	_element_created_time_is_set = true;
}


// -----------------------------------------------------------------------------
long Video_tag::GetUpdated_time() const
{
	return _element_updated_time;
}


void Video_tag::SetUpdated_time(long updated_time)
{
	_element_updated_time = updated_time;
	_element_updated_time_is_set = true;
}


// -----------------------------------------------------------------------------
Video_limits::Video_limits()
: _element_length(0)
, _element_size(0)
, _element_length_is_set(false)
, _element_size_is_set(false)
{
}


// -----------------------------------------------------------------------------
Video_limits::Video_limits(const Xml::XmlNode& it)
: _element_length(0)
, _element_size(0)
, _element_length_is_set(false)
, _element_size_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Video_limits::clear()
{
	_element_length = 0;
	_element_size = 0;
	_element_length_is_set = false;
	_element_size_is_set = false;
}


// -----------------------------------------------------------------------------
void Video_limits::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("length"))
		throw Xml::XmlException("missing required node in element 'video_limits': length");
	SetLength( atoi(std::string(it["length"]).c_str()) );
	if (!it.Exists("size"))
		throw Xml::XmlException("missing required node in element 'video_limits': size");
	SetSize( atoi(std::string(it["size"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Video_limits::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<length>" + Utility::l2string(_element_length) + "</length>";
	}
	{
		r = r + "<size>" + Utility::l2string(_element_size) + "</size>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Video_limits::IsSet() const
{
	return LengthIsSet() || SizeIsSet();
}


// -----------------------------------------------------------------------------
int Video_limits::GetLength() const
{
	return _element_length;
}


void Video_limits::SetLength(int length)
{
	_element_length = length;
	_element_length_is_set = true;
}


// -----------------------------------------------------------------------------
long Video_limits::GetSize() const
{
	return _element_size;
}


void Video_limits::SetSize(long size)
{
	_element_size = size;
	_element_size_is_set = true;
}


// -----------------------------------------------------------------------------
Affiliation::Affiliation()
: _element_nid_is_set(false)
, _element_name_is_set(false)
, _element_type_is_set(false)
, _element_status_is_set(false)
, _element_year_is_set(false)
{
}


// -----------------------------------------------------------------------------
Affiliation::Affiliation(const Xml::XmlNode& it)
: _element_nid_is_set(false)
, _element_name_is_set(false)
, _element_type_is_set(false)
, _element_status_is_set(false)
, _element_year_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Affiliation::clear()
{
	// simpleType:
	// _element_nid.clear();
	_element_name.clear();
	_element_type.clear();
	_element_status.clear();
	// simpleType:
	// _element_year.clear();
	_element_nid_is_set = false;
	_element_name_is_set = false;
	_element_type_is_set = false;
	_element_status_is_set = false;
	_element_year_is_set = false;
}


// -----------------------------------------------------------------------------
void Affiliation::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("nid"))
		throw Xml::XmlException("missing required node in element 'affiliation': nid");
	SetNid( atoi(std::string(it["nid"]).c_str()) );
	if (!it.Exists("name"))
		throw Xml::XmlException("missing required node in element 'affiliation': name");
	SetName( it["name"] );
	if (!it.Exists("type"))
		throw Xml::XmlException("missing required node in element 'affiliation': type");
	SetType( it["type"] );
	if (!it.Exists("status"))
		throw Xml::XmlException("missing required node in element 'affiliation': status");
	SetStatus( it["status"] );
	if (!it.Exists("year"))
		throw Xml::XmlException("missing required node in element 'affiliation': year");
	SetYear( atoi(std::string(it["year"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Affiliation::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<nid>" + Utility::l2string(_element_nid) + "</nid>";
	}
	r += "<name>" + _element_name + "</name>";
	r += "<type>" + _element_type + "</type>";
	r += "<status>" + _element_status + "</status>";
	{
		r = r + "<year>" + Utility::l2string(_element_year) + "</year>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Affiliation::IsSet() const
{
	return NidIsSet() || NameIsSet() || TypeIsSet() || StatusIsSet() || YearIsSet();
}


// -----------------------------------------------------------------------------
int Affiliation::GetNid() const
{
	return _element_nid;
}


void Affiliation::SetNid(int nid)
{
	_element_nid = nid;
	_element_nid_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Affiliation::GetName() const
{
	return _element_name;
}


void Affiliation::SetName(const std::string& name)
{
	_element_name = name;
	_element_name_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Affiliation::GetType() const
{
	return _element_type;
}


void Affiliation::SetType(const std::string& type)
{
	_element_type = type;
	_element_type_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Affiliation::GetStatus() const
{
	return _element_status;
}


void Affiliation::SetStatus(const std::string& status)
{
	_element_status = status;
	_element_status_is_set = true;
}


// -----------------------------------------------------------------------------
int Affiliation::GetYear() const
{
	return _element_year;
}


void Affiliation::SetYear(int year)
{
	_element_year = year;
	_element_year_is_set = true;
}


// -----------------------------------------------------------------------------
Hs_info::Hs_info()
: _element_hs1_name_is_set(false)
, _element_hs2_name_is_set(false)
, _element_grad_year_is_set(false)
, _element_hs1_id_is_set(false)
, _element_hs2_id_is_set(false)
{
}


// -----------------------------------------------------------------------------
Hs_info::Hs_info(const Xml::XmlNode& it)
: _element_hs1_name_is_set(false)
, _element_hs2_name_is_set(false)
, _element_grad_year_is_set(false)
, _element_hs1_id_is_set(false)
, _element_hs2_id_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Hs_info::clear()
{
	_element_hs1_name.clear();
	_element_hs2_name.clear();
	// simpleType:
	// _element_grad_year.clear();
	// simpleType:
	// _element_hs1_id.clear();
	// simpleType:
	// _element_hs2_id.clear();
	_element_hs1_name_is_set = false;
	_element_hs2_name_is_set = false;
	_element_grad_year_is_set = false;
	_element_hs1_id_is_set = false;
	_element_hs2_id_is_set = false;
}


// -----------------------------------------------------------------------------
void Hs_info::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("hs1_name"))
		throw Xml::XmlException("missing required node in element 'hs_info': hs1_name");
	SetHs1_name( it["hs1_name"] );
	if (!it.Exists("hs2_name"))
		throw Xml::XmlException("missing required node in element 'hs_info': hs2_name");
	SetHs2_name( it["hs2_name"] );
	if (!it.Exists("grad_year"))
		throw Xml::XmlException("missing required node in element 'hs_info': grad_year");
	SetGrad_year( atoi(std::string(it["grad_year"]).c_str()) );
	if (!it.Exists("hs1_id"))
		throw Xml::XmlException("missing required node in element 'hs_info': hs1_id");
	SetHs1_id( atoi(std::string(it["hs1_id"]).c_str()) );
	if (!it.Exists("hs2_id"))
		throw Xml::XmlException("missing required node in element 'hs_info': hs2_id");
	SetHs2_id( atoi(std::string(it["hs2_id"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Hs_info::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<hs1_name>" + _element_hs1_name + "</hs1_name>";
	r += "<hs2_name>" + _element_hs2_name + "</hs2_name>";
	{
		r = r + "<grad_year>" + Utility::l2string(_element_grad_year) + "</grad_year>";
	}
	{
		r = r + "<hs1_id>" + Utility::l2string(_element_hs1_id) + "</hs1_id>";
	}
	{
		r = r + "<hs2_id>" + Utility::l2string(_element_hs2_id) + "</hs2_id>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Hs_info::IsSet() const
{
	return Hs1_nameIsSet() || Hs2_nameIsSet() || Grad_yearIsSet() || Hs1_idIsSet() || Hs2_idIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Hs_info::GetHs1_name() const
{
	return _element_hs1_name;
}


void Hs_info::SetHs1_name(const std::string& hs1_name)
{
	_element_hs1_name = hs1_name;
	_element_hs1_name_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Hs_info::GetHs2_name() const
{
	return _element_hs2_name;
}


void Hs_info::SetHs2_name(const std::string& hs2_name)
{
	_element_hs2_name = hs2_name;
	_element_hs2_name_is_set = true;
}


// -----------------------------------------------------------------------------
int Hs_info::GetGrad_year() const
{
	return _element_grad_year;
}


void Hs_info::SetGrad_year(int grad_year)
{
	_element_grad_year = grad_year;
	_element_grad_year_is_set = true;
}


// -----------------------------------------------------------------------------
int Hs_info::GetHs1_id() const
{
	return _element_hs1_id;
}


void Hs_info::SetHs1_id(int hs1_id)
{
	_element_hs1_id = hs1_id;
	_element_hs1_id_is_set = true;
}


// -----------------------------------------------------------------------------
int Hs_info::GetHs2_id() const
{
	return _element_hs2_id;
}


void Hs_info::SetHs2_id(int hs2_id)
{
	_element_hs2_id = hs2_id;
	_element_hs2_id_is_set = true;
}


// -----------------------------------------------------------------------------
Education_info::Education_info()
: _element_name_is_set(false)
, _element_year_is_set(false)
, _element_degree_is_set(false)
, _element_school_type_is_set(false)
{
}


// -----------------------------------------------------------------------------
Education_info::Education_info(const Xml::XmlNode& it)
: _element_name_is_set(false)
, _element_year_is_set(false)
, _element_degree_is_set(false)
, _element_school_type_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Education_info::clear()
{
	_element_name.clear();
	// simpleType:
	// _element_year.clear();
	_element_concentrations.clear();
	_element_degree.clear();
	_element_school_type.clear();
	_element_name_is_set = false;
	_element_year_is_set = false;
	_element_degree_is_set = false;
	_element_school_type_is_set = false;
}


// -----------------------------------------------------------------------------
void Education_info::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("name"))
		throw Xml::XmlException("missing required node in element 'education_info': name");
	SetName( it["name"] );
	if (!it.Exists("year"))
		throw Xml::XmlException("missing required node in element 'education_info': year");
	SetYear( atoi(std::string(it["year"]).c_str()) );
	if (!it.Exists("concentrations"))
		throw Xml::XmlException("missing required node in element 'education_info': concentrations");
	{
		Xml::XmlNode n(it, "concentrations");
		if (n)
			_element_concentrations.FromXml( n );
	}
	if (!it.Exists("degree"))
		throw Xml::XmlException("missing required node in element 'education_info': degree");
	SetDegree( it["degree"] );
	if (!it.Exists("school_type"))
		throw Xml::XmlException("missing required node in element 'education_info': school_type");
	SetSchool_type( it["school_type"] );
}


// -----------------------------------------------------------------------------
const std::string Education_info::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<name>" + _element_name + "</name>";
	{
		r = r + "<year>" + Utility::l2string(_element_year) + "</year>";
	}
	r += _element_concentrations.ToString("concentrations");
	r += "<degree>" + _element_degree + "</degree>";
	r += "<school_type>" + _element_school_type + "</school_type>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Education_info::IsSet() const
{
	return NameIsSet() || YearIsSet() || ConcentrationsIsSet() || DegreeIsSet() || School_typeIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Education_info::GetName() const
{
	return _element_name;
}


void Education_info::SetName(const std::string& name)
{
	_element_name = name;
	_element_name_is_set = true;
}


// -----------------------------------------------------------------------------
int Education_info::GetYear() const
{
	return _element_year;
}


void Education_info::SetYear(int year)
{
	_element_year = year;
	_element_year_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Education_info::Concentrations_t& Education_info::GetConcentrations() const
{
	return _element_concentrations;
}


com_facebook_1_0_::Education_info::Concentrations_t& Education_info::GetConcentrations()
{
	return _element_concentrations;
}


void Education_info::SetConcentrations(const com_facebook_1_0_::Education_info::Concentrations_t& concentrations)
{
	_element_concentrations = concentrations;
}


// -----------------------------------------------------------------------------
const std::string& Education_info::GetDegree() const
{
	return _element_degree;
}


void Education_info::SetDegree(const std::string& degree)
{
	_element_degree = degree;
	_element_degree_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Education_info::GetSchool_type() const
{
	return _element_school_type;
}


void Education_info::SetSchool_type(const std::string& school_type)
{
	_element_school_type = school_type;
	_element_school_type_is_set = true;
}


// -----------------------------------------------------------------------------
bool Education_info::ConcentrationsIsSet() const
{
	return _element_concentrations.IsSet();
}


// -----------------------------------------------------------------------------
Education_info::Concentrations_t::Concentrations_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Education_info::Concentrations_t::Concentrations_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Education_info::Concentrations_t::clear()
{
	while (!_element_concentration.empty())
		_element_concentration.erase( _element_concentration.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Education_info::Concentrations_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "concentration");
		while (n)
		{
			_element_concentration.push_back( n.GetContent() );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Education_info::Concentrations_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<std::string>::const_iterator it = _element_concentration.begin(); it != _element_concentration.end(); it++)
	{
		r += "<concentration>" + *it + "</concentration>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Education_info::Concentrations_t::IsSet() const
{
	return ConcentrationIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<std::string>& Education_info::Concentrations_t::GetConcentration() const
{
	return _element_concentration;
}


std::list<std::string>& Education_info::Concentrations_t::GetConcentration()
{
	return _element_concentration;
}


void Education_info::Concentrations_t::SetConcentration(const std::list<std::string>& concentration)
{
	_element_concentration = concentration;
}


// -----------------------------------------------------------------------------
bool Education_info::Concentrations_t::ConcentrationIsSet() const
{
	return !_element_concentration.empty();
}


// -----------------------------------------------------------------------------
bool Education_info::Concentrations_t::GetList() const
{
	return _attribute_list;
}


void Education_info::Concentrations_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Work_info::Work_info()
: _element_company_name_is_set(false)
, _element_position_is_set(false)
, _element_description_is_set(false)
, _element_start_date_is_set(false)
, _element_end_date_is_set(false)
{
}


// -----------------------------------------------------------------------------
Work_info::Work_info(const Xml::XmlNode& it)
: _element_company_name_is_set(false)
, _element_position_is_set(false)
, _element_description_is_set(false)
, _element_start_date_is_set(false)
, _element_end_date_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Work_info::clear()
{
	_element_location.clear();
	_element_company_name.clear();
	_element_position.clear();
	_element_description.clear();
	// simpleType:
	// _element_start_date.clear();
	// simpleType:
	// _element_end_date.clear();
	_element_company_name_is_set = false;
	_element_position_is_set = false;
	_element_description_is_set = false;
	_element_start_date_is_set = false;
	_element_end_date_is_set = false;
}


// -----------------------------------------------------------------------------
void Work_info::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("location"))
		throw Xml::XmlException("missing required node in element 'work_info': location");
	{
		Xml::XmlNode n(it, "location");
		if (n)
			_element_location.FromXml( n );
	}
	if (!it.Exists("company_name"))
		throw Xml::XmlException("missing required node in element 'work_info': company_name");
	SetCompany_name( it["company_name"] );
	if (!it.Exists("position"))
		throw Xml::XmlException("missing required node in element 'work_info': position");
	SetPosition( it["position"] );
	if (!it.Exists("description"))
		throw Xml::XmlException("missing required node in element 'work_info': description");
	SetDescription( it["description"] );
	if (!it.Exists("start_date"))
		throw Xml::XmlException("missing required node in element 'work_info': start_date");
	SetStart_date( it["start_date"] );
	if (!it.Exists("end_date"))
		throw Xml::XmlException("missing required node in element 'work_info': end_date");
	SetEnd_date( it["end_date"] );
}


// -----------------------------------------------------------------------------
const std::string Work_info::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += _element_location.ToString("location");
	r += "<company_name>" + _element_company_name + "</company_name>";
	r += "<position>" + _element_position + "</position>";
	r += "<description>" + _element_description + "</description>";
	r += "<start_date>" + _element_start_date + "</start_date>";
	r += "<end_date>" + _element_end_date + "</end_date>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Work_info::IsSet() const
{
	return LocationIsSet() || Company_nameIsSet() || PositionIsSet() || DescriptionIsSet() || Start_dateIsSet() || End_dateIsSet();
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Location& Work_info::GetLocation() const
{
	return _element_location;
}


com_facebook_1_0_::Location& Work_info::GetLocation()
{
	return _element_location;
}


void Work_info::SetLocation(const com_facebook_1_0_::Location& location)
{
	_element_location = location;
}


// -----------------------------------------------------------------------------
const std::string& Work_info::GetCompany_name() const
{
	return _element_company_name;
}


void Work_info::SetCompany_name(const std::string& company_name)
{
	_element_company_name = company_name;
	_element_company_name_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Work_info::GetPosition() const
{
	return _element_position;
}


void Work_info::SetPosition(const std::string& position)
{
	_element_position = position;
	_element_position_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Work_info::GetDescription() const
{
	return _element_description;
}


void Work_info::SetDescription(const std::string& description)
{
	_element_description = description;
	_element_description_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Work_info::GetStart_date() const
{
	return _element_start_date;
}


void Work_info::SetStart_date(const std::string& start_date)
{
	_element_start_date = start_date;
	_element_start_date_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Work_info::GetEnd_date() const
{
	return _element_end_date;
}


void Work_info::SetEnd_date(const std::string& end_date)
{
	_element_end_date = end_date;
	_element_end_date_is_set = true;
}


// -----------------------------------------------------------------------------
bool Work_info::LocationIsSet() const
{
	return _element_location.IsSet();
}


// -----------------------------------------------------------------------------
Family_info::Family_info()
: _element_relationship_is_set(false)
, _element_uid_is_set(false)
, _element_name_is_set(false)
, _element_birthday_is_set(false)
, _element_profile_id_is_set(false)
{
}


// -----------------------------------------------------------------------------
Family_info::Family_info(const Xml::XmlNode& it)
: _element_relationship_is_set(false)
, _element_uid_is_set(false)
, _element_name_is_set(false)
, _element_birthday_is_set(false)
, _element_profile_id_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Family_info::clear()
{
	_element_relationship.clear();
	// simpleType:
	// _element_uid.clear();
	_element_name.clear();
	_element_birthday.clear();
	// simpleType:
	// _element_profile_id.clear();
	_element_relationship_is_set = false;
	_element_uid_is_set = false;
	_element_name_is_set = false;
	_element_birthday_is_set = false;
	_element_profile_id_is_set = false;
}


// -----------------------------------------------------------------------------
void Family_info::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("relationship"))
		throw Xml::XmlException("missing required node in element 'family_info': relationship");
	SetRelationship( it["relationship"] );
	if (!it.Exists("uid"))
		throw Xml::XmlException("missing required node in element 'family_info': uid");
	SetUid( atoi(std::string(it["uid"]).c_str()) );
	if (!it.Exists("name"))
		throw Xml::XmlException("missing required node in element 'family_info': name");
	SetName( it["name"] );
	if (!it.Exists("birthday"))
		throw Xml::XmlException("missing required node in element 'family_info': birthday");
	SetBirthday( it["birthday"] );
	if (!it.Exists("profile_id"))
		throw Xml::XmlException("missing required node in element 'family_info': profile_id");
	SetProfile_id( atoi(std::string(it["profile_id"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Family_info::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<relationship>" + _element_relationship + "</relationship>";
	{
		r = r + "<uid>" + Utility::l2string(_element_uid) + "</uid>";
	}
	r += "<name>" + _element_name + "</name>";
	r += "<birthday>" + _element_birthday + "</birthday>";
	{
		r = r + "<profile_id>" + Utility::l2string(_element_profile_id) + "</profile_id>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Family_info::IsSet() const
{
	return RelationshipIsSet() || UidIsSet() || NameIsSet() || BirthdayIsSet() || Profile_idIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Family_info::GetRelationship() const
{
	return _element_relationship;
}


void Family_info::SetRelationship(const std::string& relationship)
{
	_element_relationship = relationship;
	_element_relationship_is_set = true;
}


// -----------------------------------------------------------------------------
long Family_info::GetUid() const
{
	return _element_uid;
}


void Family_info::SetUid(long uid)
{
	_element_uid = uid;
	_element_uid_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Family_info::GetName() const
{
	return _element_name;
}


void Family_info::SetName(const std::string& name)
{
	_element_name = name;
	_element_name_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Family_info::GetBirthday() const
{
	return _element_birthday;
}


void Family_info::SetBirthday(const std::string& birthday)
{
	_element_birthday = birthday;
	_element_birthday_is_set = true;
}


// -----------------------------------------------------------------------------
long Family_info::GetProfile_id() const
{
	return _element_profile_id;
}


void Family_info::SetProfile_id(long profile_id)
{
	_element_profile_id = profile_id;
	_element_profile_id_is_set = true;
}


// -----------------------------------------------------------------------------
User::User()
: _element_notes_count(0)
, _element_timezone(0)
, _element_wall_count(0)
, _element_about_me_is_set(false)
, _element_activities_is_set(false)
, _element_birthday_is_set(false)
, _element_books_is_set(false)
, _element_first_name_is_set(false)
, _element_interests_is_set(false)
, _element_is_app_user_is_set(false)
, _element_last_name_is_set(false)
, _element_movies_is_set(false)
, _element_music_is_set(false)
, _element_name_is_set(false)
, _element_notes_count_is_set(false)
, _element_pic_is_set(false)
, _element_pic_big_is_set(false)
, _element_pic_small_is_set(false)
, _element_political_is_set(false)
, _element_profile_update_time_is_set(false)
, _element_quotes_is_set(false)
, _element_relationship_status_is_set(false)
, _element_religion_is_set(false)
, _element_sex_is_set(false)
, _element_significant_other_id_is_set(false)
, _element_timezone_is_set(false)
, _element_tv_is_set(false)
, _element_uid_is_set(false)
, _element_wall_count_is_set(false)
, _element_pic_square_is_set(false)
, _element_has_added_app_is_set(false)
, _element_locale_is_set(false)
, _element_are_friends_is_set(false)
, _element_can_see_profile_is_set(false)
, _element_profile_url_is_set(false)
, _element_username_is_set(false)
, _element_proxied_email_is_set(false)
, _element_pic_large_is_set(false)
, _element_pic_big_with_logo_is_set(false)
, _element_pic_small_with_logo_is_set(false)
, _element_pic_square_with_logo_is_set(false)
, _element_pic_with_logo_is_set(false)
, _element_birthday_date_is_set(false)
, _element_online_presence_is_set(false)
, _element_website_is_set(false)
, _element_is_blocked_is_set(false)
{
}


// -----------------------------------------------------------------------------
User::User(const Xml::XmlNode& it)
: _element_notes_count(0)
, _element_timezone(0)
, _element_wall_count(0)
, _element_about_me_is_set(false)
, _element_activities_is_set(false)
, _element_birthday_is_set(false)
, _element_books_is_set(false)
, _element_first_name_is_set(false)
, _element_interests_is_set(false)
, _element_is_app_user_is_set(false)
, _element_last_name_is_set(false)
, _element_movies_is_set(false)
, _element_music_is_set(false)
, _element_name_is_set(false)
, _element_notes_count_is_set(false)
, _element_pic_is_set(false)
, _element_pic_big_is_set(false)
, _element_pic_small_is_set(false)
, _element_political_is_set(false)
, _element_profile_update_time_is_set(false)
, _element_quotes_is_set(false)
, _element_relationship_status_is_set(false)
, _element_religion_is_set(false)
, _element_sex_is_set(false)
, _element_significant_other_id_is_set(false)
, _element_timezone_is_set(false)
, _element_tv_is_set(false)
, _element_uid_is_set(false)
, _element_wall_count_is_set(false)
, _element_pic_square_is_set(false)
, _element_has_added_app_is_set(false)
, _element_locale_is_set(false)
, _element_are_friends_is_set(false)
, _element_can_see_profile_is_set(false)
, _element_profile_url_is_set(false)
, _element_username_is_set(false)
, _element_proxied_email_is_set(false)
, _element_pic_large_is_set(false)
, _element_pic_big_with_logo_is_set(false)
, _element_pic_small_with_logo_is_set(false)
, _element_pic_square_with_logo_is_set(false)
, _element_pic_with_logo_is_set(false)
, _element_birthday_date_is_set(false)
, _element_online_presence_is_set(false)
, _element_website_is_set(false)
, _element_is_blocked_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void User::clear()
{
	_element_about_me.clear();
	_element_activities.clear();
	_element_affiliations.clear();
	_element_birthday.clear();
	_element_books.clear();
	_element_current_location.clear();
	_element_education_history.clear();
	_element_first_name.clear();
	_element_hometown_location.clear();
	_element_hs_info.clear();
	_element_interests.clear();
	_element_is_app_user = false;
	_element_last_name.clear();
	_element_meeting_for.clear();
	_element_meeting_sex.clear();
	_element_movies.clear();
	_element_music.clear();
	_element_name.clear();
	_element_notes_count = 0;
	_element_pic.clear();
	_element_pic_big.clear();
	_element_pic_small.clear();
	_element_political.clear();
	// simpleType:
	// _element_profile_update_time.clear();
	_element_quotes.clear();
	_element_relationship_status.clear();
	_element_religion.clear();
	// simpleType:
	// _element_sex.clear();
	// simpleType:
	// _element_significant_other_id.clear();
	_element_status.clear();
	_element_timezone = 0;
	_element_tv.clear();
	// simpleType:
	// _element_uid.clear();
	_element_wall_count = 0;
	_element_work_history.clear();
	_element_pic_square.clear();
	_element_has_added_app = false;
	_element_email_hashes.clear();
	_element_locale.clear();
	_element_family.clear();
	_element_are_friends = false;
	_element_can_see_profile = false;
	_element_profile_url.clear();
	_element_username.clear();
	_element_proxied_email.clear();
	_element_pic_large.clear();
	_element_pic_big_with_logo.clear();
	_element_pic_small_with_logo.clear();
	_element_pic_square_with_logo.clear();
	_element_pic_with_logo.clear();
	_element_birthday_date.clear();
	_element_online_presence.clear();
	_element_website.clear();
	_element_is_blocked = false;
	_element_about_me_is_set = false;
	_element_activities_is_set = false;
	_element_birthday_is_set = false;
	_element_books_is_set = false;
	_element_first_name_is_set = false;
	_element_interests_is_set = false;
	_element_is_app_user_is_set = false;
	_element_last_name_is_set = false;
	_element_movies_is_set = false;
	_element_music_is_set = false;
	_element_name_is_set = false;
	_element_notes_count_is_set = false;
	_element_pic_is_set = false;
	_element_pic_big_is_set = false;
	_element_pic_small_is_set = false;
	_element_political_is_set = false;
	_element_profile_update_time_is_set = false;
	_element_quotes_is_set = false;
	_element_relationship_status_is_set = false;
	_element_religion_is_set = false;
	_element_sex_is_set = false;
	_element_significant_other_id_is_set = false;
	_element_timezone_is_set = false;
	_element_tv_is_set = false;
	_element_uid_is_set = false;
	_element_wall_count_is_set = false;
	_element_pic_square_is_set = false;
	_element_has_added_app_is_set = false;
	_element_locale_is_set = false;
	_element_are_friends_is_set = false;
	_element_can_see_profile_is_set = false;
	_element_profile_url_is_set = false;
	_element_username_is_set = false;
	_element_proxied_email_is_set = false;
	_element_pic_large_is_set = false;
	_element_pic_big_with_logo_is_set = false;
	_element_pic_small_with_logo_is_set = false;
	_element_pic_square_with_logo_is_set = false;
	_element_pic_with_logo_is_set = false;
	_element_birthday_date_is_set = false;
	_element_online_presence_is_set = false;
	_element_website_is_set = false;
	_element_is_blocked_is_set = false;
}


// -----------------------------------------------------------------------------
void User::FromXml(const Xml::XmlNode& it)
{
	if (it.Exists("about_me"))
		SetAbout_me( it["about_me"] );
	if (it.Exists("activities"))
		SetActivities( it["activities"] );
	{
		Xml::XmlNode n(it, "affiliations");
		if (n)
			_element_affiliations.FromXml( n );
	}
	if (it.Exists("birthday"))
		SetBirthday( it["birthday"] );
	if (it.Exists("books"))
		SetBooks( it["books"] );
	{
		Xml::XmlNode n(it, "current_location");
		if (n)
			_element_current_location.FromXml( n );
	}
	{
		Xml::XmlNode n(it, "education_history");
		if (n)
			_element_education_history.FromXml( n );
	}
	if (it.Exists("first_name"))
		SetFirst_name( it["first_name"] );
	{
		Xml::XmlNode n(it, "hometown_location");
		if (n)
			_element_hometown_location.FromXml( n );
	}
	{
		Xml::XmlNode n(it, "hs_info");
		if (n)
			_element_hs_info.FromXml( n );
	}
	if (it.Exists("interests"))
		SetInterests( it["interests"] );
	if (it.Exists("is_app_user"))
		SetIs_app_user( atoi(std::string(it["is_app_user"]).c_str()) );
	if (it.Exists("last_name"))
		SetLast_name( it["last_name"] );
	{
		Xml::XmlNode n(it, "meeting_for");
		if (n)
			_element_meeting_for.FromXml( n );
	}
	{
		Xml::XmlNode n(it, "meeting_sex");
		if (n)
			_element_meeting_sex.FromXml( n );
	}
	if (it.Exists("movies"))
		SetMovies( it["movies"] );
	if (it.Exists("music"))
		SetMusic( it["music"] );
	if (it.Exists("name"))
		SetName( it["name"] );
	if (it.Exists("notes_count"))
		SetNotes_count( atoi(std::string(it["notes_count"]).c_str()) );
	if (it.Exists("pic"))
		SetPic( it["pic"] );
	if (it.Exists("pic_big"))
		SetPic_big( it["pic_big"] );
	if (it.Exists("pic_small"))
		SetPic_small( it["pic_small"] );
	if (it.Exists("political"))
		SetPolitical( it["political"] );
	if (it.Exists("profile_update_time"))
		SetProfile_update_time( atoi(std::string(it["profile_update_time"]).c_str()) );
	if (it.Exists("quotes"))
		SetQuotes( it["quotes"] );
	if (it.Exists("relationship_status"))
		SetRelationship_status( it["relationship_status"] );
	if (it.Exists("religion"))
		SetReligion( it["religion"] );
	if (it.Exists("sex"))
		SetSex( it["sex"] );
	if (it.Exists("significant_other_id"))
		SetSignificant_other_id( atoi(std::string(it["significant_other_id"]).c_str()) );
	{
		Xml::XmlNode n(it, "status");
		if (n)
			_element_status.FromXml( n );
	}
	if (it.Exists("timezone"))
		SetTimezone( atoi(std::string(it["timezone"]).c_str()) );
	if (it.Exists("tv"))
		SetTv( it["tv"] );
	if (it.Exists("uid"))
		SetUid( atoi(std::string(it["uid"]).c_str()) );
	if (it.Exists("wall_count"))
		SetWall_count( atoi(std::string(it["wall_count"]).c_str()) );
	{
		Xml::XmlNode n(it, "work_history");
		if (n)
			_element_work_history.FromXml( n );
	}
	if (it.Exists("pic_square"))
		SetPic_square( it["pic_square"] );
	if (it.Exists("has_added_app"))
		SetHas_added_app( atoi(std::string(it["has_added_app"]).c_str()) );
	{
		Xml::XmlNode n(it, "email_hashes");
		if (n)
			_element_email_hashes.FromXml( n );
	}
	if (it.Exists("locale"))
		SetLocale( it["locale"] );
	{
		Xml::XmlNode n(it, "family");
		if (n)
			_element_family.FromXml( n );
	}
	if (it.Exists("are_friends"))
		SetAre_friends( atoi(std::string(it["are_friends"]).c_str()) );
	if (it.Exists("can_see_profile"))
		SetCan_see_profile( atoi(std::string(it["can_see_profile"]).c_str()) );
	if (it.Exists("profile_url"))
		SetProfile_url( it["profile_url"] );
	if (it.Exists("username"))
		SetUsername( it["username"] );
	if (it.Exists("proxied_email"))
		SetProxied_email( it["proxied_email"] );
	if (it.Exists("pic_large"))
		SetPic_large( it["pic_large"] );
	if (it.Exists("pic_big_with_logo"))
		SetPic_big_with_logo( it["pic_big_with_logo"] );
	if (it.Exists("pic_small_with_logo"))
		SetPic_small_with_logo( it["pic_small_with_logo"] );
	if (it.Exists("pic_square_with_logo"))
		SetPic_square_with_logo( it["pic_square_with_logo"] );
	if (it.Exists("pic_with_logo"))
		SetPic_with_logo( it["pic_with_logo"] );
	if (it.Exists("birthday_date"))
		SetBirthday_date( it["birthday_date"] );
	if (it.Exists("online_presence"))
		SetOnline_presence( it["online_presence"] );
	if (it.Exists("website"))
		SetWebsite( it["website"] );
	if (it.Exists("is_blocked"))
		SetIs_blocked( atoi(std::string(it["is_blocked"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string User::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	if (_element_about_me_is_set)
		r += "<about_me>" + _element_about_me + "</about_me>";
	if (_element_activities_is_set)
		r += "<activities>" + _element_activities + "</activities>";
	r += _element_affiliations.ToString("affiliations");
	if (_element_birthday_is_set)
		r += "<birthday>" + _element_birthday + "</birthday>";
	if (_element_books_is_set)
		r += "<books>" + _element_books + "</books>";
	r += _element_current_location.ToString("current_location");
	r += _element_education_history.ToString("education_history");
	if (_element_first_name_is_set)
		r += "<first_name>" + _element_first_name + "</first_name>";
	r += _element_hometown_location.ToString("hometown_location");
	r += _element_hs_info.ToString("hs_info");
	if (_element_interests_is_set)
		r += "<interests>" + _element_interests + "</interests>";
	if (_element_is_app_user_is_set)
	{
		r = r + "<is_app_user>" + Utility::l2string(_element_is_app_user) + "</is_app_user>";
	}
	if (_element_last_name_is_set)
		r += "<last_name>" + _element_last_name + "</last_name>";
	r += _element_meeting_for.ToString("meeting_for");
	r += _element_meeting_sex.ToString("meeting_sex");
	if (_element_movies_is_set)
		r += "<movies>" + _element_movies + "</movies>";
	if (_element_music_is_set)
		r += "<music>" + _element_music + "</music>";
	if (_element_name_is_set)
		r += "<name>" + _element_name + "</name>";
	if (_element_notes_count_is_set)
	{
		r = r + "<notes_count>" + Utility::l2string(_element_notes_count) + "</notes_count>";
	}
	if (_element_pic_is_set)
		r += "<pic>" + _element_pic + "</pic>";
	if (_element_pic_big_is_set)
		r += "<pic_big>" + _element_pic_big + "</pic_big>";
	if (_element_pic_small_is_set)
		r += "<pic_small>" + _element_pic_small + "</pic_small>";
	if (_element_political_is_set)
		r += "<political>" + _element_political + "</political>";
	if (_element_profile_update_time_is_set)
	{
		r = r + "<profile_update_time>" + Utility::l2string(_element_profile_update_time) + "</profile_update_time>";
	}
	if (_element_quotes_is_set)
		r += "<quotes>" + _element_quotes + "</quotes>";
	if (_element_relationship_status_is_set)
		r += "<relationship_status>" + _element_relationship_status + "</relationship_status>";
	if (_element_religion_is_set)
		r += "<religion>" + _element_religion + "</religion>";
	if (_element_sex_is_set)
		r += "<sex>" + _element_sex + "</sex>";
	if (_element_significant_other_id_is_set)
	{
		r = r + "<significant_other_id>" + Utility::l2string(_element_significant_other_id) + "</significant_other_id>";
	}
	r += _element_status.ToString("status");
	if (_element_timezone_is_set)
	{
		r = r + "<timezone>" + Utility::l2string(_element_timezone) + "</timezone>";
	}
	if (_element_tv_is_set)
		r += "<tv>" + _element_tv + "</tv>";
	if (_element_uid_is_set)
	{
		r = r + "<uid>" + Utility::l2string(_element_uid) + "</uid>";
	}
	if (_element_wall_count_is_set)
	{
		r = r + "<wall_count>" + Utility::l2string(_element_wall_count) + "</wall_count>";
	}
	r += _element_work_history.ToString("work_history");
	if (_element_pic_square_is_set)
		r += "<pic_square>" + _element_pic_square + "</pic_square>";
	if (_element_has_added_app_is_set)
	{
		r = r + "<has_added_app>" + Utility::l2string(_element_has_added_app) + "</has_added_app>";
	}
	r += _element_email_hashes.ToString("email_hashes");
	if (_element_locale_is_set)
		r += "<locale>" + _element_locale + "</locale>";
	r += _element_family.ToString("family");
	if (_element_are_friends_is_set)
	{
		r = r + "<are_friends>" + Utility::l2string(_element_are_friends) + "</are_friends>";
	}
	if (_element_can_see_profile_is_set)
	{
		r = r + "<can_see_profile>" + Utility::l2string(_element_can_see_profile) + "</can_see_profile>";
	}
	if (_element_profile_url_is_set)
		r += "<profile_url>" + _element_profile_url + "</profile_url>";
	if (_element_username_is_set)
		r += "<username>" + _element_username + "</username>";
	if (_element_proxied_email_is_set)
		r += "<proxied_email>" + _element_proxied_email + "</proxied_email>";
	if (_element_pic_large_is_set)
		r += "<pic_large>" + _element_pic_large + "</pic_large>";
	if (_element_pic_big_with_logo_is_set)
		r += "<pic_big_with_logo>" + _element_pic_big_with_logo + "</pic_big_with_logo>";
	if (_element_pic_small_with_logo_is_set)
		r += "<pic_small_with_logo>" + _element_pic_small_with_logo + "</pic_small_with_logo>";
	if (_element_pic_square_with_logo_is_set)
		r += "<pic_square_with_logo>" + _element_pic_square_with_logo + "</pic_square_with_logo>";
	if (_element_pic_with_logo_is_set)
		r += "<pic_with_logo>" + _element_pic_with_logo + "</pic_with_logo>";
	if (_element_birthday_date_is_set)
		r += "<birthday_date>" + _element_birthday_date + "</birthday_date>";
	if (_element_online_presence_is_set)
		r += "<online_presence>" + _element_online_presence + "</online_presence>";
	if (_element_website_is_set)
		r += "<website>" + _element_website + "</website>";
	if (_element_is_blocked_is_set)
	{
		r = r + "<is_blocked>" + Utility::l2string(_element_is_blocked) + "</is_blocked>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool User::IsSet() const
{
	return About_meIsSet() || ActivitiesIsSet() || AffiliationsIsSet() || BirthdayIsSet() || BooksIsSet() || Current_locationIsSet() || Education_historyIsSet() || First_nameIsSet() || Hometown_locationIsSet() || Hs_infoIsSet() || InterestsIsSet() || Is_app_userIsSet() || Last_nameIsSet() || Meeting_forIsSet() || Meeting_sexIsSet() || MoviesIsSet() || MusicIsSet() || NameIsSet() || Notes_countIsSet() || PicIsSet() || Pic_bigIsSet() || Pic_smallIsSet() || PoliticalIsSet() || Profile_update_timeIsSet() || QuotesIsSet() || Relationship_statusIsSet() || ReligionIsSet() || SexIsSet() || Significant_other_idIsSet() || StatusIsSet() || TimezoneIsSet() || TvIsSet() || UidIsSet() || Wall_countIsSet() || Work_historyIsSet() || Pic_squareIsSet() || Has_added_appIsSet() || Email_hashesIsSet() || LocaleIsSet() || FamilyIsSet() || Are_friendsIsSet() || Can_see_profileIsSet() || Profile_urlIsSet() || UsernameIsSet() || Proxied_emailIsSet() || Pic_largeIsSet() || Pic_big_with_logoIsSet() || Pic_small_with_logoIsSet() || Pic_square_with_logoIsSet() || Pic_with_logoIsSet() || Birthday_dateIsSet() || Online_presenceIsSet() || WebsiteIsSet() || Is_blockedIsSet();
}


// -----------------------------------------------------------------------------
const std::string& User::GetAbout_me() const
{
	return _element_about_me;
}


void User::SetAbout_me(const std::string& about_me)
{
	_element_about_me = about_me;
	_element_about_me_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetActivities() const
{
	return _element_activities;
}


void User::SetActivities(const std::string& activities)
{
	_element_activities = activities;
	_element_activities_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::User::Affiliations_t& User::GetAffiliations() const
{
	return _element_affiliations;
}


com_facebook_1_0_::User::Affiliations_t& User::GetAffiliations()
{
	return _element_affiliations;
}


void User::SetAffiliations(const com_facebook_1_0_::User::Affiliations_t& affiliations)
{
	_element_affiliations = affiliations;
}


// -----------------------------------------------------------------------------
const std::string& User::GetBirthday() const
{
	return _element_birthday;
}


void User::SetBirthday(const std::string& birthday)
{
	_element_birthday = birthday;
	_element_birthday_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetBooks() const
{
	return _element_books;
}


void User::SetBooks(const std::string& books)
{
	_element_books = books;
	_element_books_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Location& User::GetCurrent_location() const
{
	return _element_current_location;
}


com_facebook_1_0_::Location& User::GetCurrent_location()
{
	return _element_current_location;
}


void User::SetCurrent_location(const com_facebook_1_0_::Location& current_location)
{
	_element_current_location = current_location;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::User::Education_history_t& User::GetEducation_history() const
{
	return _element_education_history;
}


com_facebook_1_0_::User::Education_history_t& User::GetEducation_history()
{
	return _element_education_history;
}


void User::SetEducation_history(const com_facebook_1_0_::User::Education_history_t& education_history)
{
	_element_education_history = education_history;
}


// -----------------------------------------------------------------------------
const std::string& User::GetFirst_name() const
{
	return _element_first_name;
}


void User::SetFirst_name(const std::string& first_name)
{
	_element_first_name = first_name;
	_element_first_name_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Location& User::GetHometown_location() const
{
	return _element_hometown_location;
}


com_facebook_1_0_::Location& User::GetHometown_location()
{
	return _element_hometown_location;
}


void User::SetHometown_location(const com_facebook_1_0_::Location& hometown_location)
{
	_element_hometown_location = hometown_location;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Hs_info& User::GetHs_info() const
{
	return _element_hs_info;
}


com_facebook_1_0_::Hs_info& User::GetHs_info()
{
	return _element_hs_info;
}


void User::SetHs_info(const com_facebook_1_0_::Hs_info& hs_info)
{
	_element_hs_info = hs_info;
}


// -----------------------------------------------------------------------------
const std::string& User::GetInterests() const
{
	return _element_interests;
}


void User::SetInterests(const std::string& interests)
{
	_element_interests = interests;
	_element_interests_is_set = true;
}


// -----------------------------------------------------------------------------
bool User::GetIs_app_user() const
{
	return _element_is_app_user;
}


void User::SetIs_app_user(bool is_app_user)
{
	_element_is_app_user = is_app_user;
	_element_is_app_user_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetLast_name() const
{
	return _element_last_name;
}


void User::SetLast_name(const std::string& last_name)
{
	_element_last_name = last_name;
	_element_last_name_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::User::Meeting_for_t& User::GetMeeting_for() const
{
	return _element_meeting_for;
}


com_facebook_1_0_::User::Meeting_for_t& User::GetMeeting_for()
{
	return _element_meeting_for;
}


void User::SetMeeting_for(const com_facebook_1_0_::User::Meeting_for_t& meeting_for)
{
	_element_meeting_for = meeting_for;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::User::Meeting_sex_t& User::GetMeeting_sex() const
{
	return _element_meeting_sex;
}


com_facebook_1_0_::User::Meeting_sex_t& User::GetMeeting_sex()
{
	return _element_meeting_sex;
}


void User::SetMeeting_sex(const com_facebook_1_0_::User::Meeting_sex_t& meeting_sex)
{
	_element_meeting_sex = meeting_sex;
}


// -----------------------------------------------------------------------------
const std::string& User::GetMovies() const
{
	return _element_movies;
}


void User::SetMovies(const std::string& movies)
{
	_element_movies = movies;
	_element_movies_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetMusic() const
{
	return _element_music;
}


void User::SetMusic(const std::string& music)
{
	_element_music = music;
	_element_music_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetName() const
{
	return _element_name;
}


void User::SetName(const std::string& name)
{
	_element_name = name;
	_element_name_is_set = true;
}


// -----------------------------------------------------------------------------
int User::GetNotes_count() const
{
	return _element_notes_count;
}


void User::SetNotes_count(int notes_count)
{
	_element_notes_count = notes_count;
	_element_notes_count_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetPic() const
{
	return _element_pic;
}


void User::SetPic(const std::string& pic)
{
	_element_pic = pic;
	_element_pic_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetPic_big() const
{
	return _element_pic_big;
}


void User::SetPic_big(const std::string& pic_big)
{
	_element_pic_big = pic_big;
	_element_pic_big_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetPic_small() const
{
	return _element_pic_small;
}


void User::SetPic_small(const std::string& pic_small)
{
	_element_pic_small = pic_small;
	_element_pic_small_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetPolitical() const
{
	return _element_political;
}


void User::SetPolitical(const std::string& political)
{
	_element_political = political;
	_element_political_is_set = true;
}


// -----------------------------------------------------------------------------
long User::GetProfile_update_time() const
{
	return _element_profile_update_time;
}


void User::SetProfile_update_time(long profile_update_time)
{
	_element_profile_update_time = profile_update_time;
	_element_profile_update_time_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetQuotes() const
{
	return _element_quotes;
}


void User::SetQuotes(const std::string& quotes)
{
	_element_quotes = quotes;
	_element_quotes_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetRelationship_status() const
{
	return _element_relationship_status;
}


void User::SetRelationship_status(const std::string& relationship_status)
{
	_element_relationship_status = relationship_status;
	_element_relationship_status_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetReligion() const
{
	return _element_religion;
}


void User::SetReligion(const std::string& religion)
{
	_element_religion = religion;
	_element_religion_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetSex() const
{
	return _element_sex;
}


void User::SetSex(const std::string& sex)
{
	_element_sex = sex;
	_element_sex_is_set = true;
}


// -----------------------------------------------------------------------------
long User::GetSignificant_other_id() const
{
	return _element_significant_other_id;
}


void User::SetSignificant_other_id(long significant_other_id)
{
	_element_significant_other_id = significant_other_id;
	_element_significant_other_id_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::User_status& User::GetStatus() const
{
	return _element_status;
}


com_facebook_1_0_::User_status& User::GetStatus()
{
	return _element_status;
}


void User::SetStatus(const com_facebook_1_0_::User_status& status)
{
	_element_status = status;
}


// -----------------------------------------------------------------------------
double User::GetTimezone() const
{
	return _element_timezone;
}


void User::SetTimezone(double timezone)
{
	_element_timezone = timezone;
	_element_timezone_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetTv() const
{
	return _element_tv;
}


void User::SetTv(const std::string& tv)
{
	_element_tv = tv;
	_element_tv_is_set = true;
}


// -----------------------------------------------------------------------------
long User::GetUid() const
{
	return _element_uid;
}


void User::SetUid(long uid)
{
	_element_uid = uid;
	_element_uid_is_set = true;
}


// -----------------------------------------------------------------------------
int User::GetWall_count() const
{
	return _element_wall_count;
}


void User::SetWall_count(int wall_count)
{
	_element_wall_count = wall_count;
	_element_wall_count_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::User::Work_history_t& User::GetWork_history() const
{
	return _element_work_history;
}


com_facebook_1_0_::User::Work_history_t& User::GetWork_history()
{
	return _element_work_history;
}


void User::SetWork_history(const com_facebook_1_0_::User::Work_history_t& work_history)
{
	_element_work_history = work_history;
}


// -----------------------------------------------------------------------------
const std::string& User::GetPic_square() const
{
	return _element_pic_square;
}


void User::SetPic_square(const std::string& pic_square)
{
	_element_pic_square = pic_square;
	_element_pic_square_is_set = true;
}


// -----------------------------------------------------------------------------
bool User::GetHas_added_app() const
{
	return _element_has_added_app;
}


void User::SetHas_added_app(bool has_added_app)
{
	_element_has_added_app = has_added_app;
	_element_has_added_app_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::User::Email_hashes_t& User::GetEmail_hashes() const
{
	return _element_email_hashes;
}


com_facebook_1_0_::User::Email_hashes_t& User::GetEmail_hashes()
{
	return _element_email_hashes;
}


void User::SetEmail_hashes(const com_facebook_1_0_::User::Email_hashes_t& email_hashes)
{
	_element_email_hashes = email_hashes;
}


// -----------------------------------------------------------------------------
const std::string& User::GetLocale() const
{
	return _element_locale;
}


void User::SetLocale(const std::string& locale)
{
	_element_locale = locale;
	_element_locale_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::User::Family_t& User::GetFamily() const
{
	return _element_family;
}


com_facebook_1_0_::User::Family_t& User::GetFamily()
{
	return _element_family;
}


void User::SetFamily(const com_facebook_1_0_::User::Family_t& family)
{
	_element_family = family;
}


// -----------------------------------------------------------------------------
bool User::GetAre_friends() const
{
	return _element_are_friends;
}


void User::SetAre_friends(bool are_friends)
{
	_element_are_friends = are_friends;
	_element_are_friends_is_set = true;
}


// -----------------------------------------------------------------------------
bool User::GetCan_see_profile() const
{
	return _element_can_see_profile;
}


void User::SetCan_see_profile(bool can_see_profile)
{
	_element_can_see_profile = can_see_profile;
	_element_can_see_profile_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetProfile_url() const
{
	return _element_profile_url;
}


void User::SetProfile_url(const std::string& profile_url)
{
	_element_profile_url = profile_url;
	_element_profile_url_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetUsername() const
{
	return _element_username;
}


void User::SetUsername(const std::string& username)
{
	_element_username = username;
	_element_username_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetProxied_email() const
{
	return _element_proxied_email;
}


void User::SetProxied_email(const std::string& proxied_email)
{
	_element_proxied_email = proxied_email;
	_element_proxied_email_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetPic_large() const
{
	return _element_pic_large;
}


void User::SetPic_large(const std::string& pic_large)
{
	_element_pic_large = pic_large;
	_element_pic_large_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetPic_big_with_logo() const
{
	return _element_pic_big_with_logo;
}


void User::SetPic_big_with_logo(const std::string& pic_big_with_logo)
{
	_element_pic_big_with_logo = pic_big_with_logo;
	_element_pic_big_with_logo_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetPic_small_with_logo() const
{
	return _element_pic_small_with_logo;
}


void User::SetPic_small_with_logo(const std::string& pic_small_with_logo)
{
	_element_pic_small_with_logo = pic_small_with_logo;
	_element_pic_small_with_logo_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetPic_square_with_logo() const
{
	return _element_pic_square_with_logo;
}


void User::SetPic_square_with_logo(const std::string& pic_square_with_logo)
{
	_element_pic_square_with_logo = pic_square_with_logo;
	_element_pic_square_with_logo_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetPic_with_logo() const
{
	return _element_pic_with_logo;
}


void User::SetPic_with_logo(const std::string& pic_with_logo)
{
	_element_pic_with_logo = pic_with_logo;
	_element_pic_with_logo_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetBirthday_date() const
{
	return _element_birthday_date;
}


void User::SetBirthday_date(const std::string& birthday_date)
{
	_element_birthday_date = birthday_date;
	_element_birthday_date_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetOnline_presence() const
{
	return _element_online_presence;
}


void User::SetOnline_presence(const std::string& online_presence)
{
	_element_online_presence = online_presence;
	_element_online_presence_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& User::GetWebsite() const
{
	return _element_website;
}


void User::SetWebsite(const std::string& website)
{
	_element_website = website;
	_element_website_is_set = true;
}


// -----------------------------------------------------------------------------
bool User::GetIs_blocked() const
{
	return _element_is_blocked;
}


void User::SetIs_blocked(bool is_blocked)
{
	_element_is_blocked = is_blocked;
	_element_is_blocked_is_set = true;
}


// -----------------------------------------------------------------------------
bool User::AffiliationsIsSet() const
{
	return _element_affiliations.IsSet();
}


// -----------------------------------------------------------------------------
bool User::Current_locationIsSet() const
{
	return _element_current_location.IsSet();
}


// -----------------------------------------------------------------------------
bool User::Education_historyIsSet() const
{
	return _element_education_history.IsSet();
}


// -----------------------------------------------------------------------------
bool User::Hometown_locationIsSet() const
{
	return _element_hometown_location.IsSet();
}


// -----------------------------------------------------------------------------
bool User::Hs_infoIsSet() const
{
	return _element_hs_info.IsSet();
}


// -----------------------------------------------------------------------------
bool User::Meeting_forIsSet() const
{
	return _element_meeting_for.IsSet();
}


// -----------------------------------------------------------------------------
bool User::Meeting_sexIsSet() const
{
	return _element_meeting_sex.IsSet();
}


// -----------------------------------------------------------------------------
bool User::StatusIsSet() const
{
	return _element_status.IsSet();
}


// -----------------------------------------------------------------------------
bool User::Work_historyIsSet() const
{
	return _element_work_history.IsSet();
}


// -----------------------------------------------------------------------------
bool User::Email_hashesIsSet() const
{
	return _element_email_hashes.IsSet();
}


// -----------------------------------------------------------------------------
bool User::FamilyIsSet() const
{
	return _element_family.IsSet();
}


// -----------------------------------------------------------------------------
User::Affiliations_t::Affiliations_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
User::Affiliations_t::Affiliations_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void User::Affiliations_t::clear()
{
	while (!_element_affiliation.empty())
		_element_affiliation.erase( _element_affiliation.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void User::Affiliations_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "affiliation");
		while (n)
		{
			com_facebook_1_0_::Affiliation tmp(n);
			_element_affiliation.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string User::Affiliations_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Affiliation>::const_iterator it = _element_affiliation.begin(); it != _element_affiliation.end(); it++)
	{
		const com_facebook_1_0_::Affiliation& ref = *it;
		r += ref.ToString("affiliation");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool User::Affiliations_t::IsSet() const
{
	return AffiliationIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Affiliation>& User::Affiliations_t::GetAffiliation() const
{
	return _element_affiliation;
}


std::list<com_facebook_1_0_::Affiliation>& User::Affiliations_t::GetAffiliation()
{
	return _element_affiliation;
}


void User::Affiliations_t::SetAffiliation(const std::list<com_facebook_1_0_::Affiliation>& affiliation)
{
	_element_affiliation = affiliation;
}


// -----------------------------------------------------------------------------
bool User::Affiliations_t::AffiliationIsSet() const
{
	return !_element_affiliation.empty();
}


// -----------------------------------------------------------------------------
bool User::Affiliations_t::GetList() const
{
	return _attribute_list;
}


void User::Affiliations_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
User::Education_history_t::Education_history_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
User::Education_history_t::Education_history_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void User::Education_history_t::clear()
{
	while (!_element_education_info.empty())
		_element_education_info.erase( _element_education_info.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void User::Education_history_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "education_info");
		while (n)
		{
			com_facebook_1_0_::Education_info tmp(n);
			_element_education_info.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string User::Education_history_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Education_info>::const_iterator it = _element_education_info.begin(); it != _element_education_info.end(); it++)
	{
		const com_facebook_1_0_::Education_info& ref = *it;
		r += ref.ToString("education_info");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool User::Education_history_t::IsSet() const
{
	return Education_infoIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Education_info>& User::Education_history_t::GetEducation_info() const
{
	return _element_education_info;
}


std::list<com_facebook_1_0_::Education_info>& User::Education_history_t::GetEducation_info()
{
	return _element_education_info;
}


void User::Education_history_t::SetEducation_info(const std::list<com_facebook_1_0_::Education_info>& education_info)
{
	_element_education_info = education_info;
}


// -----------------------------------------------------------------------------
bool User::Education_history_t::Education_infoIsSet() const
{
	return !_element_education_info.empty();
}


// -----------------------------------------------------------------------------
bool User::Education_history_t::GetList() const
{
	return _attribute_list;
}


void User::Education_history_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
User::Meeting_for_t::Meeting_for_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
User::Meeting_for_t::Meeting_for_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void User::Meeting_for_t::clear()
{
	while (!_element_seeking.empty())
		_element_seeking.erase( _element_seeking.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void User::Meeting_for_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "seeking");
		while (n)
		{
			_element_seeking.push_back( n.GetContent() );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string User::Meeting_for_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<std::string>::const_iterator it = _element_seeking.begin(); it != _element_seeking.end(); it++)
	{
		r += "<seeking>" + *it + "</seeking>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool User::Meeting_for_t::IsSet() const
{
	return SeekingIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<std::string>& User::Meeting_for_t::GetSeeking() const
{
	return _element_seeking;
}


std::list<std::string>& User::Meeting_for_t::GetSeeking()
{
	return _element_seeking;
}


void User::Meeting_for_t::SetSeeking(const std::list<std::string>& seeking)
{
	_element_seeking = seeking;
}


// -----------------------------------------------------------------------------
bool User::Meeting_for_t::SeekingIsSet() const
{
	return !_element_seeking.empty();
}


// -----------------------------------------------------------------------------
bool User::Meeting_for_t::GetList() const
{
	return _attribute_list;
}


void User::Meeting_for_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
User::Meeting_sex_t::Meeting_sex_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
User::Meeting_sex_t::Meeting_sex_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void User::Meeting_sex_t::clear()
{
	while (!_element_sex.empty())
		_element_sex.erase( _element_sex.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void User::Meeting_sex_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "sex");
		while (n)
		{
			_element_sex.push_back( n.GetContent() );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string User::Meeting_sex_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<std::string>::const_iterator it = _element_sex.begin(); it != _element_sex.end(); it++)
	{
		r += "<sex>" + *it + "</sex>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool User::Meeting_sex_t::IsSet() const
{
	return SexIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<std::string>& User::Meeting_sex_t::GetSex() const
{
	return _element_sex;
}


std::list<std::string>& User::Meeting_sex_t::GetSex()
{
	return _element_sex;
}


void User::Meeting_sex_t::SetSex(const std::list<std::string>& sex)
{
	_element_sex = sex;
}


// -----------------------------------------------------------------------------
bool User::Meeting_sex_t::SexIsSet() const
{
	return !_element_sex.empty();
}


// -----------------------------------------------------------------------------
bool User::Meeting_sex_t::GetList() const
{
	return _attribute_list;
}


void User::Meeting_sex_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
User::Work_history_t::Work_history_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
User::Work_history_t::Work_history_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void User::Work_history_t::clear()
{
	while (!_element_work_info.empty())
		_element_work_info.erase( _element_work_info.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void User::Work_history_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "work_info");
		while (n)
		{
			com_facebook_1_0_::Work_info tmp(n);
			_element_work_info.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string User::Work_history_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Work_info>::const_iterator it = _element_work_info.begin(); it != _element_work_info.end(); it++)
	{
		const com_facebook_1_0_::Work_info& ref = *it;
		r += ref.ToString("work_info");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool User::Work_history_t::IsSet() const
{
	return Work_infoIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Work_info>& User::Work_history_t::GetWork_info() const
{
	return _element_work_info;
}


std::list<com_facebook_1_0_::Work_info>& User::Work_history_t::GetWork_info()
{
	return _element_work_info;
}


void User::Work_history_t::SetWork_info(const std::list<com_facebook_1_0_::Work_info>& work_info)
{
	_element_work_info = work_info;
}


// -----------------------------------------------------------------------------
bool User::Work_history_t::Work_infoIsSet() const
{
	return !_element_work_info.empty();
}


// -----------------------------------------------------------------------------
bool User::Work_history_t::GetList() const
{
	return _attribute_list;
}


void User::Work_history_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
User::Email_hashes_t::Email_hashes_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
User::Email_hashes_t::Email_hashes_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void User::Email_hashes_t::clear()
{
	while (!_element_email_hashes_elt.empty())
		_element_email_hashes_elt.erase( _element_email_hashes_elt.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void User::Email_hashes_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "email_hashes_elt");
		while (n)
		{
			_element_email_hashes_elt.push_back( n.GetContent() );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string User::Email_hashes_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<std::string>::const_iterator it = _element_email_hashes_elt.begin(); it != _element_email_hashes_elt.end(); it++)
	{
		r += "<email_hashes_elt>" + *it + "</email_hashes_elt>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool User::Email_hashes_t::IsSet() const
{
	return Email_hashes_eltIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<std::string>& User::Email_hashes_t::GetEmail_hashes_elt() const
{
	return _element_email_hashes_elt;
}


std::list<std::string>& User::Email_hashes_t::GetEmail_hashes_elt()
{
	return _element_email_hashes_elt;
}


void User::Email_hashes_t::SetEmail_hashes_elt(const std::list<std::string>& email_hashes_elt)
{
	_element_email_hashes_elt = email_hashes_elt;
}


// -----------------------------------------------------------------------------
bool User::Email_hashes_t::Email_hashes_eltIsSet() const
{
	return !_element_email_hashes_elt.empty();
}


// -----------------------------------------------------------------------------
bool User::Email_hashes_t::GetList() const
{
	return _attribute_list;
}


void User::Email_hashes_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
User::Family_t::Family_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
User::Family_t::Family_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void User::Family_t::clear()
{
	while (!_element_family_info.empty())
		_element_family_info.erase( _element_family_info.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void User::Family_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "family_info");
		while (n)
		{
			com_facebook_1_0_::Family_info tmp(n);
			_element_family_info.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string User::Family_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Family_info>::const_iterator it = _element_family_info.begin(); it != _element_family_info.end(); it++)
	{
		const com_facebook_1_0_::Family_info& ref = *it;
		r += ref.ToString("family_info");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool User::Family_t::IsSet() const
{
	return Family_infoIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Family_info>& User::Family_t::GetFamily_info() const
{
	return _element_family_info;
}


std::list<com_facebook_1_0_::Family_info>& User::Family_t::GetFamily_info()
{
	return _element_family_info;
}


void User::Family_t::SetFamily_info(const std::list<com_facebook_1_0_::Family_info>& family_info)
{
	_element_family_info = family_info;
}


// -----------------------------------------------------------------------------
bool User::Family_t::Family_infoIsSet() const
{
	return !_element_family_info.empty();
}


// -----------------------------------------------------------------------------
bool User::Family_t::GetList() const
{
	return _attribute_list;
}


void User::Family_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Friend_info::Friend_info()
: _element_uid1_is_set(false)
, _element_uid2_is_set(false)
, _element_are_friends_is_set(false)
{
}


// -----------------------------------------------------------------------------
Friend_info::Friend_info(const Xml::XmlNode& it)
: _element_uid1_is_set(false)
, _element_uid2_is_set(false)
, _element_are_friends_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Friend_info::clear()
{
	// simpleType:
	// _element_uid1.clear();
	// simpleType:
	// _element_uid2.clear();
	_element_are_friends = false;
	_element_uid1_is_set = false;
	_element_uid2_is_set = false;
	_element_are_friends_is_set = false;
}


// -----------------------------------------------------------------------------
void Friend_info::FromXml(const Xml::XmlNode& it)
{
	if (it.Exists("uid1"))
		SetUid1( atoi(std::string(it["uid1"]).c_str()) );
	if (it.Exists("uid2"))
		SetUid2( atoi(std::string(it["uid2"]).c_str()) );
	if (it.Exists("are_friends"))
		SetAre_friends( atoi(std::string(it["are_friends"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Friend_info::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	if (_element_uid1_is_set)
	{
		r = r + "<uid1>" + Utility::l2string(_element_uid1) + "</uid1>";
	}
	if (_element_uid2_is_set)
	{
		r = r + "<uid2>" + Utility::l2string(_element_uid2) + "</uid2>";
	}
	if (_element_are_friends_is_set)
	{
		r = r + "<are_friends>" + Utility::l2string(_element_are_friends) + "</are_friends>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Friend_info::IsSet() const
{
	return Uid1IsSet() || Uid2IsSet() || Are_friendsIsSet();
}


// -----------------------------------------------------------------------------
long Friend_info::GetUid1() const
{
	return _element_uid1;
}


void Friend_info::SetUid1(long uid1)
{
	_element_uid1 = uid1;
	_element_uid1_is_set = true;
}


// -----------------------------------------------------------------------------
long Friend_info::GetUid2() const
{
	return _element_uid2;
}


void Friend_info::SetUid2(long uid2)
{
	_element_uid2 = uid2;
	_element_uid2_is_set = true;
}


// -----------------------------------------------------------------------------
bool Friend_info::GetAre_friends() const
{
	return _element_are_friends;
}


void Friend_info::SetAre_friends(bool are_friends)
{
	_element_are_friends = are_friends;
	_element_are_friends_is_set = true;
}


// -----------------------------------------------------------------------------
Friendlist::Friendlist()
: _element_flid_is_set(false)
, _element_name_is_set(false)
, _element_owner_is_set(false)
{
}


// -----------------------------------------------------------------------------
Friendlist::Friendlist(const Xml::XmlNode& it)
: _element_flid_is_set(false)
, _element_name_is_set(false)
, _element_owner_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Friendlist::clear()
{
	// simpleType:
	// _element_flid.clear();
	_element_name.clear();
	// simpleType:
	// _element_owner.clear();
	_element_flid_is_set = false;
	_element_name_is_set = false;
	_element_owner_is_set = false;
}


// -----------------------------------------------------------------------------
void Friendlist::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("flid"))
		throw Xml::XmlException("missing required node in element 'friendlist': flid");
	SetFlid( atoi(std::string(it["flid"]).c_str()) );
	if (!it.Exists("name"))
		throw Xml::XmlException("missing required node in element 'friendlist': name");
	SetName( it["name"] );
	if (it.Exists("owner"))
		SetOwner( atoi(std::string(it["owner"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Friendlist::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<flid>" + Utility::l2string(_element_flid) + "</flid>";
	}
	r += "<name>" + _element_name + "</name>";
	if (_element_owner_is_set)
	{
		r = r + "<owner>" + Utility::l2string(_element_owner) + "</owner>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Friendlist::IsSet() const
{
	return FlidIsSet() || NameIsSet() || OwnerIsSet();
}


// -----------------------------------------------------------------------------
long Friendlist::GetFlid() const
{
	return _element_flid;
}


void Friendlist::SetFlid(long flid)
{
	_element_flid = flid;
	_element_flid_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Friendlist::GetName() const
{
	return _element_name;
}


void Friendlist::SetName(const std::string& name)
{
	_element_name = name;
	_element_name_is_set = true;
}


// -----------------------------------------------------------------------------
long Friendlist::GetOwner() const
{
	return _element_owner;
}


void Friendlist::SetOwner(long owner)
{
	_element_owner = owner;
	_element_owner_is_set = true;
}


// -----------------------------------------------------------------------------
Friendlist_member::Friendlist_member()
: _element_flid_is_set(false)
, _element_uid_is_set(false)
{
}


// -----------------------------------------------------------------------------
Friendlist_member::Friendlist_member(const Xml::XmlNode& it)
: _element_flid_is_set(false)
, _element_uid_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Friendlist_member::clear()
{
	// simpleType:
	// _element_flid.clear();
	// simpleType:
	// _element_uid.clear();
	_element_flid_is_set = false;
	_element_uid_is_set = false;
}


// -----------------------------------------------------------------------------
void Friendlist_member::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("flid"))
		throw Xml::XmlException("missing required node in element 'friendlist_member': flid");
	SetFlid( atoi(std::string(it["flid"]).c_str()) );
	if (!it.Exists("uid"))
		throw Xml::XmlException("missing required node in element 'friendlist_member': uid");
	SetUid( atoi(std::string(it["uid"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Friendlist_member::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<flid>" + Utility::l2string(_element_flid) + "</flid>";
	}
	{
		r = r + "<uid>" + Utility::l2string(_element_uid) + "</uid>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Friendlist_member::IsSet() const
{
	return FlidIsSet() || UidIsSet();
}


// -----------------------------------------------------------------------------
long Friendlist_member::GetFlid() const
{
	return _element_flid;
}


void Friendlist_member::SetFlid(long flid)
{
	_element_flid = flid;
	_element_flid_is_set = true;
}


// -----------------------------------------------------------------------------
long Friendlist_member::GetUid() const
{
	return _element_uid;
}


void Friendlist_member::SetUid(long uid)
{
	_element_uid = uid;
	_element_uid_is_set = true;
}


// -----------------------------------------------------------------------------
Object_type_info::Object_type_info()
: _element_object_class(0)
, _element_name_is_set(false)
, _element_object_class_is_set(false)
{
}


// -----------------------------------------------------------------------------
Object_type_info::Object_type_info(const Xml::XmlNode& it)
: _element_object_class(0)
, _element_name_is_set(false)
, _element_object_class_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Object_type_info::clear()
{
	_element_name.clear();
	_element_object_class = 0;
	_element_name_is_set = false;
	_element_object_class_is_set = false;
}


// -----------------------------------------------------------------------------
void Object_type_info::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("name"))
		throw Xml::XmlException("missing required node in element 'object_type_info': name");
	SetName( it["name"] );
	if (!it.Exists("object_class"))
		throw Xml::XmlException("missing required node in element 'object_type_info': object_class");
	SetObject_class( atoi(std::string(it["object_class"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Object_type_info::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<name>" + _element_name + "</name>";
	{
		r = r + "<object_class>" + Utility::l2string(_element_object_class) + "</object_class>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Object_type_info::IsSet() const
{
	return NameIsSet() || Object_classIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Object_type_info::GetName() const
{
	return _element_name;
}


void Object_type_info::SetName(const std::string& name)
{
	_element_name = name;
	_element_name_is_set = true;
}


// -----------------------------------------------------------------------------
int Object_type_info::GetObject_class() const
{
	return _element_object_class;
}


void Object_type_info::SetObject_class(int object_class)
{
	_element_object_class = object_class;
	_element_object_class_is_set = true;
}


// -----------------------------------------------------------------------------
Object_property_info::Object_property_info()
: _element_data_type(0)
, _element_index_type(0)
, _element_name_is_set(false)
, _element_data_type_is_set(false)
, _element_index_type_is_set(false)
{
}


// -----------------------------------------------------------------------------
Object_property_info::Object_property_info(const Xml::XmlNode& it)
: _element_data_type(0)
, _element_index_type(0)
, _element_name_is_set(false)
, _element_data_type_is_set(false)
, _element_index_type_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Object_property_info::clear()
{
	_element_name.clear();
	_element_data_type = 0;
	_element_index_type = 0;
	_element_name_is_set = false;
	_element_data_type_is_set = false;
	_element_index_type_is_set = false;
}


// -----------------------------------------------------------------------------
void Object_property_info::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("name"))
		throw Xml::XmlException("missing required node in element 'object_property_info': name");
	SetName( it["name"] );
	if (!it.Exists("data_type"))
		throw Xml::XmlException("missing required node in element 'object_property_info': data_type");
	SetData_type( atoi(std::string(it["data_type"]).c_str()) );
	if (!it.Exists("index_type"))
		throw Xml::XmlException("missing required node in element 'object_property_info': index_type");
	SetIndex_type( atoi(std::string(it["index_type"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Object_property_info::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<name>" + _element_name + "</name>";
	{
		r = r + "<data_type>" + Utility::l2string(_element_data_type) + "</data_type>";
	}
	{
		r = r + "<index_type>" + Utility::l2string(_element_index_type) + "</index_type>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Object_property_info::IsSet() const
{
	return NameIsSet() || Data_typeIsSet() || Index_typeIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Object_property_info::GetName() const
{
	return _element_name;
}


void Object_property_info::SetName(const std::string& name)
{
	_element_name = name;
	_element_name_is_set = true;
}


// -----------------------------------------------------------------------------
int Object_property_info::GetData_type() const
{
	return _element_data_type;
}


void Object_property_info::SetData_type(int data_type)
{
	_element_data_type = data_type;
	_element_data_type_is_set = true;
}


// -----------------------------------------------------------------------------
int Object_property_info::GetIndex_type() const
{
	return _element_index_type;
}


void Object_property_info::SetIndex_type(int index_type)
{
	_element_index_type = index_type;
	_element_index_type_is_set = true;
}


// -----------------------------------------------------------------------------
Assoc_object_type::Assoc_object_type()
: _element_alias_is_set(false)
, _element_object_type_is_set(false)
, _element_unique_is_set(false)
{
}


// -----------------------------------------------------------------------------
Assoc_object_type::Assoc_object_type(const Xml::XmlNode& it)
: _element_alias_is_set(false)
, _element_object_type_is_set(false)
, _element_unique_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Assoc_object_type::clear()
{
	_element_alias.clear();
	_element_object_type.clear();
	_element_unique = false;
	_element_alias_is_set = false;
	_element_object_type_is_set = false;
	_element_unique_is_set = false;
}


// -----------------------------------------------------------------------------
void Assoc_object_type::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("alias"))
		throw Xml::XmlException("missing required node in element 'assoc_object_type': alias");
	SetAlias( it["alias"] );
	if (!it.Exists("object_type"))
		throw Xml::XmlException("missing required node in element 'assoc_object_type': object_type");
	SetObject_type( it["object_type"] );
	if (!it.Exists("unique"))
		throw Xml::XmlException("missing required node in element 'assoc_object_type': unique");
	SetUnique( atoi(std::string(it["unique"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Assoc_object_type::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<alias>" + _element_alias + "</alias>";
	r += "<object_type>" + _element_object_type + "</object_type>";
	{
		r = r + "<unique>" + Utility::l2string(_element_unique) + "</unique>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Assoc_object_type::IsSet() const
{
	return AliasIsSet() || Object_typeIsSet() || UniqueIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Assoc_object_type::GetAlias() const
{
	return _element_alias;
}


void Assoc_object_type::SetAlias(const std::string& alias)
{
	_element_alias = alias;
	_element_alias_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Assoc_object_type::GetObject_type() const
{
	return _element_object_type;
}


void Assoc_object_type::SetObject_type(const std::string& object_type)
{
	_element_object_type = object_type;
	_element_object_type_is_set = true;
}


// -----------------------------------------------------------------------------
bool Assoc_object_type::GetUnique() const
{
	return _element_unique;
}


void Assoc_object_type::SetUnique(bool unique)
{
	_element_unique = unique;
	_element_unique_is_set = true;
}


// -----------------------------------------------------------------------------
Object_assoc_info::Object_assoc_info()
: _element_assoc_type(0)
, _element_name_is_set(false)
, _element_assoc_type_is_set(false)
{
}


// -----------------------------------------------------------------------------
Object_assoc_info::Object_assoc_info(const Xml::XmlNode& it)
: _element_assoc_type(0)
, _element_name_is_set(false)
, _element_assoc_type_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Object_assoc_info::clear()
{
	_element_name.clear();
	_element_assoc_type = 0;
	_element_assoc_info1.clear();
	_element_assoc_info2.clear();
	_element_name_is_set = false;
	_element_assoc_type_is_set = false;
}


// -----------------------------------------------------------------------------
void Object_assoc_info::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("name"))
		throw Xml::XmlException("missing required node in element 'object_assoc_info': name");
	SetName( it["name"] );
	if (!it.Exists("assoc_type"))
		throw Xml::XmlException("missing required node in element 'object_assoc_info': assoc_type");
	SetAssoc_type( atoi(std::string(it["assoc_type"]).c_str()) );
	if (!it.Exists("assoc_info1"))
		throw Xml::XmlException("missing required node in element 'object_assoc_info': assoc_info1");
	{
		Xml::XmlNode n(it, "assoc_info1");
		if (n)
			_element_assoc_info1.FromXml( n );
	}
	if (!it.Exists("assoc_info2"))
		throw Xml::XmlException("missing required node in element 'object_assoc_info': assoc_info2");
	{
		Xml::XmlNode n(it, "assoc_info2");
		if (n)
			_element_assoc_info2.FromXml( n );
	}
}


// -----------------------------------------------------------------------------
const std::string Object_assoc_info::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<name>" + _element_name + "</name>";
	{
		r = r + "<assoc_type>" + Utility::l2string(_element_assoc_type) + "</assoc_type>";
	}
	r += _element_assoc_info1.ToString("assoc_info1");
	r += _element_assoc_info2.ToString("assoc_info2");
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Object_assoc_info::IsSet() const
{
	return NameIsSet() || Assoc_typeIsSet() || Assoc_info1IsSet() || Assoc_info2IsSet();
}


// -----------------------------------------------------------------------------
const std::string& Object_assoc_info::GetName() const
{
	return _element_name;
}


void Object_assoc_info::SetName(const std::string& name)
{
	_element_name = name;
	_element_name_is_set = true;
}


// -----------------------------------------------------------------------------
int Object_assoc_info::GetAssoc_type() const
{
	return _element_assoc_type;
}


void Object_assoc_info::SetAssoc_type(int assoc_type)
{
	_element_assoc_type = assoc_type;
	_element_assoc_type_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Assoc_object_type& Object_assoc_info::GetAssoc_info1() const
{
	return _element_assoc_info1;
}


com_facebook_1_0_::Assoc_object_type& Object_assoc_info::GetAssoc_info1()
{
	return _element_assoc_info1;
}


void Object_assoc_info::SetAssoc_info1(const com_facebook_1_0_::Assoc_object_type& assoc_info1)
{
	_element_assoc_info1 = assoc_info1;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Assoc_object_type& Object_assoc_info::GetAssoc_info2() const
{
	return _element_assoc_info2;
}


com_facebook_1_0_::Assoc_object_type& Object_assoc_info::GetAssoc_info2()
{
	return _element_assoc_info2;
}


void Object_assoc_info::SetAssoc_info2(const com_facebook_1_0_::Assoc_object_type& assoc_info2)
{
	_element_assoc_info2 = assoc_info2;
}


// -----------------------------------------------------------------------------
bool Object_assoc_info::Assoc_info1IsSet() const
{
	return _element_assoc_info1.IsSet();
}


// -----------------------------------------------------------------------------
bool Object_assoc_info::Assoc_info2IsSet() const
{
	return _element_assoc_info2.IsSet();
}


// -----------------------------------------------------------------------------
Object_association::Object_association()
: _element_id1(0)
, _element_id2(0)
, _element_name_is_set(false)
, _element_id1_is_set(false)
, _element_id2_is_set(false)
, _element_data_is_set(false)
, _element_time_is_set(false)
{
}


// -----------------------------------------------------------------------------
Object_association::Object_association(const Xml::XmlNode& it)
: _element_id1(0)
, _element_id2(0)
, _element_name_is_set(false)
, _element_id1_is_set(false)
, _element_id2_is_set(false)
, _element_data_is_set(false)
, _element_time_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Object_association::clear()
{
	_element_name.clear();
	_element_id1 = 0;
	_element_id2 = 0;
	_element_data.clear();
	// simpleType:
	// _element_time.clear();
	_element_name_is_set = false;
	_element_id1_is_set = false;
	_element_id2_is_set = false;
	_element_data_is_set = false;
	_element_time_is_set = false;
}


// -----------------------------------------------------------------------------
void Object_association::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("name"))
		throw Xml::XmlException("missing required node in element 'object_association': name");
	SetName( it["name"] );
	if (!it.Exists("id1"))
		throw Xml::XmlException("missing required node in element 'object_association': id1");
	SetId1( atoi(std::string(it["id1"]).c_str()) );
	if (!it.Exists("id2"))
		throw Xml::XmlException("missing required node in element 'object_association': id2");
	SetId2( atoi(std::string(it["id2"]).c_str()) );
	if (!it.Exists("data"))
		throw Xml::XmlException("missing required node in element 'object_association': data");
	SetData( it["data"] );
	if (!it.Exists("time"))
		throw Xml::XmlException("missing required node in element 'object_association': time");
	SetTime( atoi(std::string(it["time"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Object_association::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<name>" + _element_name + "</name>";
	{
		r = r + "<id1>" + Utility::l2string(_element_id1) + "</id1>";
	}
	{
		r = r + "<id2>" + Utility::l2string(_element_id2) + "</id2>";
	}
	r += "<data>" + _element_data + "</data>";
	{
		r = r + "<time>" + Utility::l2string(_element_time) + "</time>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Object_association::IsSet() const
{
	return NameIsSet() || Id1IsSet() || Id2IsSet() || DataIsSet() || TimeIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Object_association::GetName() const
{
	return _element_name;
}


void Object_association::SetName(const std::string& name)
{
	_element_name = name;
	_element_name_is_set = true;
}


// -----------------------------------------------------------------------------
long Object_association::GetId1() const
{
	return _element_id1;
}


void Object_association::SetId1(long id1)
{
	_element_id1 = id1;
	_element_id1_is_set = true;
}


// -----------------------------------------------------------------------------
long Object_association::GetId2() const
{
	return _element_id2;
}


void Object_association::SetId2(long id2)
{
	_element_id2 = id2;
	_element_id2_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Object_association::GetData() const
{
	return _element_data;
}


void Object_association::SetData(const std::string& data)
{
	_element_data = data;
	_element_data_is_set = true;
}


// -----------------------------------------------------------------------------
long Object_association::GetTime() const
{
	return _element_time;
}


void Object_association::SetTime(long time)
{
	_element_time = time;
	_element_time_is_set = true;
}


// -----------------------------------------------------------------------------
Container::Container()
{
}


// -----------------------------------------------------------------------------
Container::Container(const Xml::XmlNode& it)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Container::clear()
{
}


// -----------------------------------------------------------------------------
void Container::FromXml(const Xml::XmlNode& it)
{
}


// -----------------------------------------------------------------------------
const std::string Container::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Container::IsSet() const
{
;
}


// -----------------------------------------------------------------------------
Preference::Preference()
: _element_pref_id(0)
, _element_pref_id_is_set(false)
, _element_value_is_set(false)
{
}


// -----------------------------------------------------------------------------
Preference::Preference(const Xml::XmlNode& it)
: _element_pref_id(0)
, _element_pref_id_is_set(false)
, _element_value_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Preference::clear()
{
	_element_pref_id = 0;
	_element_value.clear();
	_element_pref_id_is_set = false;
	_element_value_is_set = false;
}


// -----------------------------------------------------------------------------
void Preference::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("pref_id"))
		throw Xml::XmlException("missing required node in element 'preference': pref_id");
	SetPref_id( atoi(std::string(it["pref_id"]).c_str()) );
	if (!it.Exists("value"))
		throw Xml::XmlException("missing required node in element 'preference': value");
	SetValue( it["value"] );
}


// -----------------------------------------------------------------------------
const std::string Preference::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<pref_id>" + Utility::l2string(_element_pref_id) + "</pref_id>";
	}
	r += "<value>" + _element_value + "</value>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Preference::IsSet() const
{
	return Pref_idIsSet() || ValueIsSet();
}


// -----------------------------------------------------------------------------
int Preference::GetPref_id() const
{
	return _element_pref_id;
}


void Preference::SetPref_id(int pref_id)
{
	_element_pref_id = pref_id;
	_element_pref_id_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Preference::GetValue() const
{
	return _element_value;
}


void Preference::SetValue(const std::string& value)
{
	_element_value = value;
	_element_value_is_set = true;
}


// -----------------------------------------------------------------------------
Page_hours::Page_hours()
: _element_mon_1_open_is_set(false)
, _element_mon_1_close_is_set(false)
, _element_tue_1_open_is_set(false)
, _element_tue_1_close_is_set(false)
, _element_wed_1_open_is_set(false)
, _element_thu_1_open_is_set(false)
, _element_thu_1_close_is_set(false)
, _element_fri_1_open_is_set(false)
, _element_fri_1_close_is_set(false)
, _element_sat_1_open_is_set(false)
, _element_sat_1_close_is_set(false)
, _element_sun_1_open_is_set(false)
, _element_sun_1_close_is_set(false)
, _element_mon_2_open_is_set(false)
, _element_mon_2_close_is_set(false)
, _element_tue_2_open_is_set(false)
, _element_tue_2_close_is_set(false)
, _element_wed_2_open_is_set(false)
, _element_wed_2_close_is_set(false)
, _element_thu_2_open_is_set(false)
, _element_thu_2_close_is_set(false)
, _element_fri_2_open_is_set(false)
, _element_fri_2_close_is_set(false)
, _element_sat_2_open_is_set(false)
, _element_sat_2_close_is_set(false)
, _element_sun_2_open_is_set(false)
, _element_sun_2_close_is_set(false)
{
}


// -----------------------------------------------------------------------------
Page_hours::Page_hours(const Xml::XmlNode& it)
: _element_mon_1_open_is_set(false)
, _element_mon_1_close_is_set(false)
, _element_tue_1_open_is_set(false)
, _element_tue_1_close_is_set(false)
, _element_wed_1_open_is_set(false)
, _element_thu_1_open_is_set(false)
, _element_thu_1_close_is_set(false)
, _element_fri_1_open_is_set(false)
, _element_fri_1_close_is_set(false)
, _element_sat_1_open_is_set(false)
, _element_sat_1_close_is_set(false)
, _element_sun_1_open_is_set(false)
, _element_sun_1_close_is_set(false)
, _element_mon_2_open_is_set(false)
, _element_mon_2_close_is_set(false)
, _element_tue_2_open_is_set(false)
, _element_tue_2_close_is_set(false)
, _element_wed_2_open_is_set(false)
, _element_wed_2_close_is_set(false)
, _element_thu_2_open_is_set(false)
, _element_thu_2_close_is_set(false)
, _element_fri_2_open_is_set(false)
, _element_fri_2_close_is_set(false)
, _element_sat_2_open_is_set(false)
, _element_sat_2_close_is_set(false)
, _element_sun_2_open_is_set(false)
, _element_sun_2_close_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Page_hours::clear()
{
	// simpleType:
	// _element_mon_1_open.clear();
	// simpleType:
	// _element_mon_1_close.clear();
	// simpleType:
	// _element_tue_1_open.clear();
	// simpleType:
	// _element_tue_1_close.clear();
	// simpleType:
	// _element_wed_1_open.clear();
	// simpleType:
	// _element_thu_1_open.clear();
	// simpleType:
	// _element_thu_1_close.clear();
	// simpleType:
	// _element_fri_1_open.clear();
	// simpleType:
	// _element_fri_1_close.clear();
	// simpleType:
	// _element_sat_1_open.clear();
	// simpleType:
	// _element_sat_1_close.clear();
	// simpleType:
	// _element_sun_1_open.clear();
	// simpleType:
	// _element_sun_1_close.clear();
	// simpleType:
	// _element_mon_2_open.clear();
	// simpleType:
	// _element_mon_2_close.clear();
	// simpleType:
	// _element_tue_2_open.clear();
	// simpleType:
	// _element_tue_2_close.clear();
	// simpleType:
	// _element_wed_2_open.clear();
	// simpleType:
	// _element_wed_2_close.clear();
	// simpleType:
	// _element_thu_2_open.clear();
	// simpleType:
	// _element_thu_2_close.clear();
	// simpleType:
	// _element_fri_2_open.clear();
	// simpleType:
	// _element_fri_2_close.clear();
	// simpleType:
	// _element_sat_2_open.clear();
	// simpleType:
	// _element_sat_2_close.clear();
	// simpleType:
	// _element_sun_2_open.clear();
	// simpleType:
	// _element_sun_2_close.clear();
	_element_mon_1_open_is_set = false;
	_element_mon_1_close_is_set = false;
	_element_tue_1_open_is_set = false;
	_element_tue_1_close_is_set = false;
	_element_wed_1_open_is_set = false;
	_element_thu_1_open_is_set = false;
	_element_thu_1_close_is_set = false;
	_element_fri_1_open_is_set = false;
	_element_fri_1_close_is_set = false;
	_element_sat_1_open_is_set = false;
	_element_sat_1_close_is_set = false;
	_element_sun_1_open_is_set = false;
	_element_sun_1_close_is_set = false;
	_element_mon_2_open_is_set = false;
	_element_mon_2_close_is_set = false;
	_element_tue_2_open_is_set = false;
	_element_tue_2_close_is_set = false;
	_element_wed_2_open_is_set = false;
	_element_wed_2_close_is_set = false;
	_element_thu_2_open_is_set = false;
	_element_thu_2_close_is_set = false;
	_element_fri_2_open_is_set = false;
	_element_fri_2_close_is_set = false;
	_element_sat_2_open_is_set = false;
	_element_sat_2_close_is_set = false;
	_element_sun_2_open_is_set = false;
	_element_sun_2_close_is_set = false;
}


// -----------------------------------------------------------------------------
void Page_hours::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("mon_1_open"))
		throw Xml::XmlException("missing required node in element 'page_hours': mon_1_open");
	SetMon_1_open( atoi(std::string(it["mon_1_open"]).c_str()) );
	if (!it.Exists("mon_1_close"))
		throw Xml::XmlException("missing required node in element 'page_hours': mon_1_close");
	SetMon_1_close( atoi(std::string(it["mon_1_close"]).c_str()) );
	if (!it.Exists("tue_1_open"))
		throw Xml::XmlException("missing required node in element 'page_hours': tue_1_open");
	SetTue_1_open( atoi(std::string(it["tue_1_open"]).c_str()) );
	if (!it.Exists("tue_1_close"))
		throw Xml::XmlException("missing required node in element 'page_hours': tue_1_close");
	SetTue_1_close( atoi(std::string(it["tue_1_close"]).c_str()) );
	if (!it.Exists("wed_1_open"))
		throw Xml::XmlException("missing required node in element 'page_hours': wed_1_open");
	SetWed_1_open( atoi(std::string(it["wed_1_open"]).c_str()) );
	if (!it.Exists("thu_1_open"))
		throw Xml::XmlException("missing required node in element 'page_hours': thu_1_open");
	SetThu_1_open( atoi(std::string(it["thu_1_open"]).c_str()) );
	if (!it.Exists("thu_1_close"))
		throw Xml::XmlException("missing required node in element 'page_hours': thu_1_close");
	SetThu_1_close( atoi(std::string(it["thu_1_close"]).c_str()) );
	if (!it.Exists("fri_1_open"))
		throw Xml::XmlException("missing required node in element 'page_hours': fri_1_open");
	SetFri_1_open( atoi(std::string(it["fri_1_open"]).c_str()) );
	if (!it.Exists("fri_1_close"))
		throw Xml::XmlException("missing required node in element 'page_hours': fri_1_close");
	SetFri_1_close( atoi(std::string(it["fri_1_close"]).c_str()) );
	if (!it.Exists("sat_1_open"))
		throw Xml::XmlException("missing required node in element 'page_hours': sat_1_open");
	SetSat_1_open( atoi(std::string(it["sat_1_open"]).c_str()) );
	if (!it.Exists("sat_1_close"))
		throw Xml::XmlException("missing required node in element 'page_hours': sat_1_close");
	SetSat_1_close( atoi(std::string(it["sat_1_close"]).c_str()) );
	if (!it.Exists("sun_1_open"))
		throw Xml::XmlException("missing required node in element 'page_hours': sun_1_open");
	SetSun_1_open( atoi(std::string(it["sun_1_open"]).c_str()) );
	if (!it.Exists("sun_1_close"))
		throw Xml::XmlException("missing required node in element 'page_hours': sun_1_close");
	SetSun_1_close( atoi(std::string(it["sun_1_close"]).c_str()) );
	if (!it.Exists("mon_2_open"))
		throw Xml::XmlException("missing required node in element 'page_hours': mon_2_open");
	SetMon_2_open( atoi(std::string(it["mon_2_open"]).c_str()) );
	if (!it.Exists("mon_2_close"))
		throw Xml::XmlException("missing required node in element 'page_hours': mon_2_close");
	SetMon_2_close( atoi(std::string(it["mon_2_close"]).c_str()) );
	if (!it.Exists("tue_2_open"))
		throw Xml::XmlException("missing required node in element 'page_hours': tue_2_open");
	SetTue_2_open( atoi(std::string(it["tue_2_open"]).c_str()) );
	if (!it.Exists("tue_2_close"))
		throw Xml::XmlException("missing required node in element 'page_hours': tue_2_close");
	SetTue_2_close( atoi(std::string(it["tue_2_close"]).c_str()) );
	if (!it.Exists("wed_2_open"))
		throw Xml::XmlException("missing required node in element 'page_hours': wed_2_open");
	SetWed_2_open( atoi(std::string(it["wed_2_open"]).c_str()) );
	if (!it.Exists("wed_2_close"))
		throw Xml::XmlException("missing required node in element 'page_hours': wed_2_close");
	SetWed_2_close( atoi(std::string(it["wed_2_close"]).c_str()) );
	if (!it.Exists("thu_2_open"))
		throw Xml::XmlException("missing required node in element 'page_hours': thu_2_open");
	SetThu_2_open( atoi(std::string(it["thu_2_open"]).c_str()) );
	if (!it.Exists("thu_2_close"))
		throw Xml::XmlException("missing required node in element 'page_hours': thu_2_close");
	SetThu_2_close( atoi(std::string(it["thu_2_close"]).c_str()) );
	if (!it.Exists("fri_2_open"))
		throw Xml::XmlException("missing required node in element 'page_hours': fri_2_open");
	SetFri_2_open( atoi(std::string(it["fri_2_open"]).c_str()) );
	if (!it.Exists("fri_2_close"))
		throw Xml::XmlException("missing required node in element 'page_hours': fri_2_close");
	SetFri_2_close( atoi(std::string(it["fri_2_close"]).c_str()) );
	if (!it.Exists("sat_2_open"))
		throw Xml::XmlException("missing required node in element 'page_hours': sat_2_open");
	SetSat_2_open( atoi(std::string(it["sat_2_open"]).c_str()) );
	if (!it.Exists("sat_2_close"))
		throw Xml::XmlException("missing required node in element 'page_hours': sat_2_close");
	SetSat_2_close( atoi(std::string(it["sat_2_close"]).c_str()) );
	if (!it.Exists("sun_2_open"))
		throw Xml::XmlException("missing required node in element 'page_hours': sun_2_open");
	SetSun_2_open( atoi(std::string(it["sun_2_open"]).c_str()) );
	if (!it.Exists("sun_2_close"))
		throw Xml::XmlException("missing required node in element 'page_hours': sun_2_close");
	SetSun_2_close( atoi(std::string(it["sun_2_close"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Page_hours::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<mon_1_open>" + Utility::l2string(_element_mon_1_open) + "</mon_1_open>";
	}
	{
		r = r + "<mon_1_close>" + Utility::l2string(_element_mon_1_close) + "</mon_1_close>";
	}
	{
		r = r + "<tue_1_open>" + Utility::l2string(_element_tue_1_open) + "</tue_1_open>";
	}
	{
		r = r + "<tue_1_close>" + Utility::l2string(_element_tue_1_close) + "</tue_1_close>";
	}
	{
		r = r + "<wed_1_open>" + Utility::l2string(_element_wed_1_open) + "</wed_1_open>";
	}
	{
		r = r + "<thu_1_open>" + Utility::l2string(_element_thu_1_open) + "</thu_1_open>";
	}
	{
		r = r + "<thu_1_close>" + Utility::l2string(_element_thu_1_close) + "</thu_1_close>";
	}
	{
		r = r + "<fri_1_open>" + Utility::l2string(_element_fri_1_open) + "</fri_1_open>";
	}
	{
		r = r + "<fri_1_close>" + Utility::l2string(_element_fri_1_close) + "</fri_1_close>";
	}
	{
		r = r + "<sat_1_open>" + Utility::l2string(_element_sat_1_open) + "</sat_1_open>";
	}
	{
		r = r + "<sat_1_close>" + Utility::l2string(_element_sat_1_close) + "</sat_1_close>";
	}
	{
		r = r + "<sun_1_open>" + Utility::l2string(_element_sun_1_open) + "</sun_1_open>";
	}
	{
		r = r + "<sun_1_close>" + Utility::l2string(_element_sun_1_close) + "</sun_1_close>";
	}
	{
		r = r + "<mon_2_open>" + Utility::l2string(_element_mon_2_open) + "</mon_2_open>";
	}
	{
		r = r + "<mon_2_close>" + Utility::l2string(_element_mon_2_close) + "</mon_2_close>";
	}
	{
		r = r + "<tue_2_open>" + Utility::l2string(_element_tue_2_open) + "</tue_2_open>";
	}
	{
		r = r + "<tue_2_close>" + Utility::l2string(_element_tue_2_close) + "</tue_2_close>";
	}
	{
		r = r + "<wed_2_open>" + Utility::l2string(_element_wed_2_open) + "</wed_2_open>";
	}
	{
		r = r + "<wed_2_close>" + Utility::l2string(_element_wed_2_close) + "</wed_2_close>";
	}
	{
		r = r + "<thu_2_open>" + Utility::l2string(_element_thu_2_open) + "</thu_2_open>";
	}
	{
		r = r + "<thu_2_close>" + Utility::l2string(_element_thu_2_close) + "</thu_2_close>";
	}
	{
		r = r + "<fri_2_open>" + Utility::l2string(_element_fri_2_open) + "</fri_2_open>";
	}
	{
		r = r + "<fri_2_close>" + Utility::l2string(_element_fri_2_close) + "</fri_2_close>";
	}
	{
		r = r + "<sat_2_open>" + Utility::l2string(_element_sat_2_open) + "</sat_2_open>";
	}
	{
		r = r + "<sat_2_close>" + Utility::l2string(_element_sat_2_close) + "</sat_2_close>";
	}
	{
		r = r + "<sun_2_open>" + Utility::l2string(_element_sun_2_open) + "</sun_2_open>";
	}
	{
		r = r + "<sun_2_close>" + Utility::l2string(_element_sun_2_close) + "</sun_2_close>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Page_hours::IsSet() const
{
	return Mon_1_openIsSet() || Mon_1_closeIsSet() || Tue_1_openIsSet() || Tue_1_closeIsSet() || Wed_1_openIsSet() || Thu_1_openIsSet() || Thu_1_closeIsSet() || Fri_1_openIsSet() || Fri_1_closeIsSet() || Sat_1_openIsSet() || Sat_1_closeIsSet() || Sun_1_openIsSet() || Sun_1_closeIsSet() || Mon_2_openIsSet() || Mon_2_closeIsSet() || Tue_2_openIsSet() || Tue_2_closeIsSet() || Wed_2_openIsSet() || Wed_2_closeIsSet() || Thu_2_openIsSet() || Thu_2_closeIsSet() || Fri_2_openIsSet() || Fri_2_closeIsSet() || Sat_2_openIsSet() || Sat_2_closeIsSet() || Sun_2_openIsSet() || Sun_2_closeIsSet();
}


// -----------------------------------------------------------------------------
long Page_hours::GetMon_1_open() const
{
	return _element_mon_1_open;
}


void Page_hours::SetMon_1_open(long mon_1_open)
{
	_element_mon_1_open = mon_1_open;
	_element_mon_1_open_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetMon_1_close() const
{
	return _element_mon_1_close;
}


void Page_hours::SetMon_1_close(long mon_1_close)
{
	_element_mon_1_close = mon_1_close;
	_element_mon_1_close_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetTue_1_open() const
{
	return _element_tue_1_open;
}


void Page_hours::SetTue_1_open(long tue_1_open)
{
	_element_tue_1_open = tue_1_open;
	_element_tue_1_open_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetTue_1_close() const
{
	return _element_tue_1_close;
}


void Page_hours::SetTue_1_close(long tue_1_close)
{
	_element_tue_1_close = tue_1_close;
	_element_tue_1_close_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetWed_1_open() const
{
	return _element_wed_1_open;
}


void Page_hours::SetWed_1_open(long wed_1_open)
{
	_element_wed_1_open = wed_1_open;
	_element_wed_1_open_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetThu_1_open() const
{
	return _element_thu_1_open;
}


void Page_hours::SetThu_1_open(long thu_1_open)
{
	_element_thu_1_open = thu_1_open;
	_element_thu_1_open_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetThu_1_close() const
{
	return _element_thu_1_close;
}


void Page_hours::SetThu_1_close(long thu_1_close)
{
	_element_thu_1_close = thu_1_close;
	_element_thu_1_close_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetFri_1_open() const
{
	return _element_fri_1_open;
}


void Page_hours::SetFri_1_open(long fri_1_open)
{
	_element_fri_1_open = fri_1_open;
	_element_fri_1_open_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetFri_1_close() const
{
	return _element_fri_1_close;
}


void Page_hours::SetFri_1_close(long fri_1_close)
{
	_element_fri_1_close = fri_1_close;
	_element_fri_1_close_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetSat_1_open() const
{
	return _element_sat_1_open;
}


void Page_hours::SetSat_1_open(long sat_1_open)
{
	_element_sat_1_open = sat_1_open;
	_element_sat_1_open_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetSat_1_close() const
{
	return _element_sat_1_close;
}


void Page_hours::SetSat_1_close(long sat_1_close)
{
	_element_sat_1_close = sat_1_close;
	_element_sat_1_close_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetSun_1_open() const
{
	return _element_sun_1_open;
}


void Page_hours::SetSun_1_open(long sun_1_open)
{
	_element_sun_1_open = sun_1_open;
	_element_sun_1_open_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetSun_1_close() const
{
	return _element_sun_1_close;
}


void Page_hours::SetSun_1_close(long sun_1_close)
{
	_element_sun_1_close = sun_1_close;
	_element_sun_1_close_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetMon_2_open() const
{
	return _element_mon_2_open;
}


void Page_hours::SetMon_2_open(long mon_2_open)
{
	_element_mon_2_open = mon_2_open;
	_element_mon_2_open_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetMon_2_close() const
{
	return _element_mon_2_close;
}


void Page_hours::SetMon_2_close(long mon_2_close)
{
	_element_mon_2_close = mon_2_close;
	_element_mon_2_close_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetTue_2_open() const
{
	return _element_tue_2_open;
}


void Page_hours::SetTue_2_open(long tue_2_open)
{
	_element_tue_2_open = tue_2_open;
	_element_tue_2_open_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetTue_2_close() const
{
	return _element_tue_2_close;
}


void Page_hours::SetTue_2_close(long tue_2_close)
{
	_element_tue_2_close = tue_2_close;
	_element_tue_2_close_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetWed_2_open() const
{
	return _element_wed_2_open;
}


void Page_hours::SetWed_2_open(long wed_2_open)
{
	_element_wed_2_open = wed_2_open;
	_element_wed_2_open_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetWed_2_close() const
{
	return _element_wed_2_close;
}


void Page_hours::SetWed_2_close(long wed_2_close)
{
	_element_wed_2_close = wed_2_close;
	_element_wed_2_close_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetThu_2_open() const
{
	return _element_thu_2_open;
}


void Page_hours::SetThu_2_open(long thu_2_open)
{
	_element_thu_2_open = thu_2_open;
	_element_thu_2_open_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetThu_2_close() const
{
	return _element_thu_2_close;
}


void Page_hours::SetThu_2_close(long thu_2_close)
{
	_element_thu_2_close = thu_2_close;
	_element_thu_2_close_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetFri_2_open() const
{
	return _element_fri_2_open;
}


void Page_hours::SetFri_2_open(long fri_2_open)
{
	_element_fri_2_open = fri_2_open;
	_element_fri_2_open_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetFri_2_close() const
{
	return _element_fri_2_close;
}


void Page_hours::SetFri_2_close(long fri_2_close)
{
	_element_fri_2_close = fri_2_close;
	_element_fri_2_close_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetSat_2_open() const
{
	return _element_sat_2_open;
}


void Page_hours::SetSat_2_open(long sat_2_open)
{
	_element_sat_2_open = sat_2_open;
	_element_sat_2_open_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetSat_2_close() const
{
	return _element_sat_2_close;
}


void Page_hours::SetSat_2_close(long sat_2_close)
{
	_element_sat_2_close = sat_2_close;
	_element_sat_2_close_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetSun_2_open() const
{
	return _element_sun_2_open;
}


void Page_hours::SetSun_2_open(long sun_2_open)
{
	_element_sun_2_open = sun_2_open;
	_element_sun_2_open_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_hours::GetSun_2_close() const
{
	return _element_sun_2_close;
}


void Page_hours::SetSun_2_close(long sun_2_close)
{
	_element_sun_2_close = sun_2_close;
	_element_sun_2_close_is_set = true;
}


// -----------------------------------------------------------------------------
Page_parking::Page_parking()
: _element_street_is_set(false)
, _element_lot_is_set(false)
, _element_valet_is_set(false)
{
}


// -----------------------------------------------------------------------------
Page_parking::Page_parking(const Xml::XmlNode& it)
: _element_street_is_set(false)
, _element_lot_is_set(false)
, _element_valet_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Page_parking::clear()
{
	_element_street = false;
	_element_lot = false;
	_element_valet = false;
	_element_street_is_set = false;
	_element_lot_is_set = false;
	_element_valet_is_set = false;
}


// -----------------------------------------------------------------------------
void Page_parking::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("street"))
		throw Xml::XmlException("missing required node in element 'page_parking': street");
	SetStreet( atoi(std::string(it["street"]).c_str()) );
	if (!it.Exists("lot"))
		throw Xml::XmlException("missing required node in element 'page_parking': lot");
	SetLot( atoi(std::string(it["lot"]).c_str()) );
	if (!it.Exists("valet"))
		throw Xml::XmlException("missing required node in element 'page_parking': valet");
	SetValet( atoi(std::string(it["valet"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Page_parking::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<street>" + Utility::l2string(_element_street) + "</street>";
	}
	{
		r = r + "<lot>" + Utility::l2string(_element_lot) + "</lot>";
	}
	{
		r = r + "<valet>" + Utility::l2string(_element_valet) + "</valet>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Page_parking::IsSet() const
{
	return StreetIsSet() || LotIsSet() || ValetIsSet();
}


// -----------------------------------------------------------------------------
bool Page_parking::GetStreet() const
{
	return _element_street;
}


void Page_parking::SetStreet(bool street)
{
	_element_street = street;
	_element_street_is_set = true;
}


// -----------------------------------------------------------------------------
bool Page_parking::GetLot() const
{
	return _element_lot;
}


void Page_parking::SetLot(bool lot)
{
	_element_lot = lot;
	_element_lot_is_set = true;
}


// -----------------------------------------------------------------------------
bool Page_parking::GetValet() const
{
	return _element_valet;
}


void Page_parking::SetValet(bool valet)
{
	_element_valet = valet;
	_element_valet_is_set = true;
}


// -----------------------------------------------------------------------------
Page_fan::Page_fan()
: _element_page_id_is_set(false)
, _element_uid_is_set(false)
, _element_type_is_set(false)
{
}


// -----------------------------------------------------------------------------
Page_fan::Page_fan(const Xml::XmlNode& it)
: _element_page_id_is_set(false)
, _element_uid_is_set(false)
, _element_type_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Page_fan::clear()
{
	// simpleType:
	// _element_page_id.clear();
	// simpleType:
	// _element_uid.clear();
	_element_type.clear();
	_element_page_id_is_set = false;
	_element_uid_is_set = false;
	_element_type_is_set = false;
}


// -----------------------------------------------------------------------------
void Page_fan::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("page_id"))
		throw Xml::XmlException("missing required node in element 'page_fan': page_id");
	SetPage_id( atoi(std::string(it["page_id"]).c_str()) );
	if (!it.Exists("uid"))
		throw Xml::XmlException("missing required node in element 'page_fan': uid");
	SetUid( atoi(std::string(it["uid"]).c_str()) );
	if (!it.Exists("type"))
		throw Xml::XmlException("missing required node in element 'page_fan': type");
	SetType( it["type"] );
}


// -----------------------------------------------------------------------------
const std::string Page_fan::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<page_id>" + Utility::l2string(_element_page_id) + "</page_id>";
	}
	{
		r = r + "<uid>" + Utility::l2string(_element_uid) + "</uid>";
	}
	r += "<type>" + _element_type + "</type>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Page_fan::IsSet() const
{
	return Page_idIsSet() || UidIsSet() || TypeIsSet();
}


// -----------------------------------------------------------------------------
long Page_fan::GetPage_id() const
{
	return _element_page_id;
}


void Page_fan::SetPage_id(long page_id)
{
	_element_page_id = page_id;
	_element_page_id_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_fan::GetUid() const
{
	return _element_uid;
}


void Page_fan::SetUid(long uid)
{
	_element_uid = uid;
	_element_uid_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page_fan::GetType() const
{
	return _element_type;
}


void Page_fan::SetType(const std::string& type)
{
	_element_type = type;
	_element_type_is_set = true;
}


// -----------------------------------------------------------------------------
Page_admin::Page_admin()
: _element_page_id_is_set(false)
, _element_uid_is_set(false)
, _element_type_is_set(false)
{
}


// -----------------------------------------------------------------------------
Page_admin::Page_admin(const Xml::XmlNode& it)
: _element_page_id_is_set(false)
, _element_uid_is_set(false)
, _element_type_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Page_admin::clear()
{
	// simpleType:
	// _element_page_id.clear();
	// simpleType:
	// _element_uid.clear();
	_element_type.clear();
	_element_page_id_is_set = false;
	_element_uid_is_set = false;
	_element_type_is_set = false;
}


// -----------------------------------------------------------------------------
void Page_admin::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("page_id"))
		throw Xml::XmlException("missing required node in element 'page_admin': page_id");
	SetPage_id( atoi(std::string(it["page_id"]).c_str()) );
	if (!it.Exists("uid"))
		throw Xml::XmlException("missing required node in element 'page_admin': uid");
	SetUid( atoi(std::string(it["uid"]).c_str()) );
	if (!it.Exists("type"))
		throw Xml::XmlException("missing required node in element 'page_admin': type");
	SetType( it["type"] );
}


// -----------------------------------------------------------------------------
const std::string Page_admin::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<page_id>" + Utility::l2string(_element_page_id) + "</page_id>";
	}
	{
		r = r + "<uid>" + Utility::l2string(_element_uid) + "</uid>";
	}
	r += "<type>" + _element_type + "</type>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Page_admin::IsSet() const
{
	return Page_idIsSet() || UidIsSet() || TypeIsSet();
}


// -----------------------------------------------------------------------------
long Page_admin::GetPage_id() const
{
	return _element_page_id;
}


void Page_admin::SetPage_id(long page_id)
{
	_element_page_id = page_id;
	_element_page_id_is_set = true;
}


// -----------------------------------------------------------------------------
long Page_admin::GetUid() const
{
	return _element_uid;
}


void Page_admin::SetUid(long uid)
{
	_element_uid = uid;
	_element_uid_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page_admin::GetType() const
{
	return _element_type;
}


void Page_admin::SetType(const std::string& type)
{
	_element_type = type;
	_element_type_is_set = true;
}


// -----------------------------------------------------------------------------
Page_restaurant_services::Page_restaurant_services()
: _element_reserve_is_set(false)
, _element_walkins_is_set(false)
, _element_groups_is_set(false)
, _element_kids_is_set(false)
, _element_takeout_is_set(false)
, _element_delivery_is_set(false)
, _element_catering_is_set(false)
, _element_waiter_is_set(false)
, _element_outdoor_is_set(false)
{
}


// -----------------------------------------------------------------------------
Page_restaurant_services::Page_restaurant_services(const Xml::XmlNode& it)
: _element_reserve_is_set(false)
, _element_walkins_is_set(false)
, _element_groups_is_set(false)
, _element_kids_is_set(false)
, _element_takeout_is_set(false)
, _element_delivery_is_set(false)
, _element_catering_is_set(false)
, _element_waiter_is_set(false)
, _element_outdoor_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Page_restaurant_services::clear()
{
	_element_reserve = false;
	_element_walkins = false;
	_element_groups = false;
	_element_kids = false;
	_element_takeout = false;
	_element_delivery = false;
	_element_catering = false;
	_element_waiter = false;
	_element_outdoor = false;
	_element_reserve_is_set = false;
	_element_walkins_is_set = false;
	_element_groups_is_set = false;
	_element_kids_is_set = false;
	_element_takeout_is_set = false;
	_element_delivery_is_set = false;
	_element_catering_is_set = false;
	_element_waiter_is_set = false;
	_element_outdoor_is_set = false;
}


// -----------------------------------------------------------------------------
void Page_restaurant_services::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("reserve"))
		throw Xml::XmlException("missing required node in element 'page_restaurant_services': reserve");
	SetReserve( atoi(std::string(it["reserve"]).c_str()) );
	if (!it.Exists("walkins"))
		throw Xml::XmlException("missing required node in element 'page_restaurant_services': walkins");
	SetWalkins( atoi(std::string(it["walkins"]).c_str()) );
	if (!it.Exists("groups"))
		throw Xml::XmlException("missing required node in element 'page_restaurant_services': groups");
	SetGroups( atoi(std::string(it["groups"]).c_str()) );
	if (!it.Exists("kids"))
		throw Xml::XmlException("missing required node in element 'page_restaurant_services': kids");
	SetKids( atoi(std::string(it["kids"]).c_str()) );
	if (!it.Exists("takeout"))
		throw Xml::XmlException("missing required node in element 'page_restaurant_services': takeout");
	SetTakeout( atoi(std::string(it["takeout"]).c_str()) );
	if (!it.Exists("delivery"))
		throw Xml::XmlException("missing required node in element 'page_restaurant_services': delivery");
	SetDelivery( atoi(std::string(it["delivery"]).c_str()) );
	if (!it.Exists("catering"))
		throw Xml::XmlException("missing required node in element 'page_restaurant_services': catering");
	SetCatering( atoi(std::string(it["catering"]).c_str()) );
	if (!it.Exists("waiter"))
		throw Xml::XmlException("missing required node in element 'page_restaurant_services': waiter");
	SetWaiter( atoi(std::string(it["waiter"]).c_str()) );
	if (!it.Exists("outdoor"))
		throw Xml::XmlException("missing required node in element 'page_restaurant_services': outdoor");
	SetOutdoor( atoi(std::string(it["outdoor"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Page_restaurant_services::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<reserve>" + Utility::l2string(_element_reserve) + "</reserve>";
	}
	{
		r = r + "<walkins>" + Utility::l2string(_element_walkins) + "</walkins>";
	}
	{
		r = r + "<groups>" + Utility::l2string(_element_groups) + "</groups>";
	}
	{
		r = r + "<kids>" + Utility::l2string(_element_kids) + "</kids>";
	}
	{
		r = r + "<takeout>" + Utility::l2string(_element_takeout) + "</takeout>";
	}
	{
		r = r + "<delivery>" + Utility::l2string(_element_delivery) + "</delivery>";
	}
	{
		r = r + "<catering>" + Utility::l2string(_element_catering) + "</catering>";
	}
	{
		r = r + "<waiter>" + Utility::l2string(_element_waiter) + "</waiter>";
	}
	{
		r = r + "<outdoor>" + Utility::l2string(_element_outdoor) + "</outdoor>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Page_restaurant_services::IsSet() const
{
	return ReserveIsSet() || WalkinsIsSet() || GroupsIsSet() || KidsIsSet() || TakeoutIsSet() || DeliveryIsSet() || CateringIsSet() || WaiterIsSet() || OutdoorIsSet();
}


// -----------------------------------------------------------------------------
bool Page_restaurant_services::GetReserve() const
{
	return _element_reserve;
}


void Page_restaurant_services::SetReserve(bool reserve)
{
	_element_reserve = reserve;
	_element_reserve_is_set = true;
}


// -----------------------------------------------------------------------------
bool Page_restaurant_services::GetWalkins() const
{
	return _element_walkins;
}


void Page_restaurant_services::SetWalkins(bool walkins)
{
	_element_walkins = walkins;
	_element_walkins_is_set = true;
}


// -----------------------------------------------------------------------------
bool Page_restaurant_services::GetGroups() const
{
	return _element_groups;
}


void Page_restaurant_services::SetGroups(bool groups)
{
	_element_groups = groups;
	_element_groups_is_set = true;
}


// -----------------------------------------------------------------------------
bool Page_restaurant_services::GetKids() const
{
	return _element_kids;
}


void Page_restaurant_services::SetKids(bool kids)
{
	_element_kids = kids;
	_element_kids_is_set = true;
}


// -----------------------------------------------------------------------------
bool Page_restaurant_services::GetTakeout() const
{
	return _element_takeout;
}


void Page_restaurant_services::SetTakeout(bool takeout)
{
	_element_takeout = takeout;
	_element_takeout_is_set = true;
}


// -----------------------------------------------------------------------------
bool Page_restaurant_services::GetDelivery() const
{
	return _element_delivery;
}


void Page_restaurant_services::SetDelivery(bool delivery)
{
	_element_delivery = delivery;
	_element_delivery_is_set = true;
}


// -----------------------------------------------------------------------------
bool Page_restaurant_services::GetCatering() const
{
	return _element_catering;
}


void Page_restaurant_services::SetCatering(bool catering)
{
	_element_catering = catering;
	_element_catering_is_set = true;
}


// -----------------------------------------------------------------------------
bool Page_restaurant_services::GetWaiter() const
{
	return _element_waiter;
}


void Page_restaurant_services::SetWaiter(bool waiter)
{
	_element_waiter = waiter;
	_element_waiter_is_set = true;
}


// -----------------------------------------------------------------------------
bool Page_restaurant_services::GetOutdoor() const
{
	return _element_outdoor;
}


void Page_restaurant_services::SetOutdoor(bool outdoor)
{
	_element_outdoor = outdoor;
	_element_outdoor_is_set = true;
}


// -----------------------------------------------------------------------------
Page_restaurant_specialties::Page_restaurant_specialties()
: _element_breakfast_is_set(false)
, _element_lunch_is_set(false)
, _element_dinner_is_set(false)
, _element_coffee_is_set(false)
, _element_drinks_is_set(false)
{
}


// -----------------------------------------------------------------------------
Page_restaurant_specialties::Page_restaurant_specialties(const Xml::XmlNode& it)
: _element_breakfast_is_set(false)
, _element_lunch_is_set(false)
, _element_dinner_is_set(false)
, _element_coffee_is_set(false)
, _element_drinks_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Page_restaurant_specialties::clear()
{
	_element_breakfast = false;
	_element_lunch = false;
	_element_dinner = false;
	_element_coffee = false;
	_element_drinks = false;
	_element_breakfast_is_set = false;
	_element_lunch_is_set = false;
	_element_dinner_is_set = false;
	_element_coffee_is_set = false;
	_element_drinks_is_set = false;
}


// -----------------------------------------------------------------------------
void Page_restaurant_specialties::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("breakfast"))
		throw Xml::XmlException("missing required node in element 'page_restaurant_specialties': breakfast");
	SetBreakfast( atoi(std::string(it["breakfast"]).c_str()) );
	if (!it.Exists("lunch"))
		throw Xml::XmlException("missing required node in element 'page_restaurant_specialties': lunch");
	SetLunch( atoi(std::string(it["lunch"]).c_str()) );
	if (!it.Exists("dinner"))
		throw Xml::XmlException("missing required node in element 'page_restaurant_specialties': dinner");
	SetDinner( atoi(std::string(it["dinner"]).c_str()) );
	if (!it.Exists("coffee"))
		throw Xml::XmlException("missing required node in element 'page_restaurant_specialties': coffee");
	SetCoffee( atoi(std::string(it["coffee"]).c_str()) );
	if (!it.Exists("drinks"))
		throw Xml::XmlException("missing required node in element 'page_restaurant_specialties': drinks");
	SetDrinks( atoi(std::string(it["drinks"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Page_restaurant_specialties::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<breakfast>" + Utility::l2string(_element_breakfast) + "</breakfast>";
	}
	{
		r = r + "<lunch>" + Utility::l2string(_element_lunch) + "</lunch>";
	}
	{
		r = r + "<dinner>" + Utility::l2string(_element_dinner) + "</dinner>";
	}
	{
		r = r + "<coffee>" + Utility::l2string(_element_coffee) + "</coffee>";
	}
	{
		r = r + "<drinks>" + Utility::l2string(_element_drinks) + "</drinks>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Page_restaurant_specialties::IsSet() const
{
	return BreakfastIsSet() || LunchIsSet() || DinnerIsSet() || CoffeeIsSet() || DrinksIsSet();
}


// -----------------------------------------------------------------------------
bool Page_restaurant_specialties::GetBreakfast() const
{
	return _element_breakfast;
}


void Page_restaurant_specialties::SetBreakfast(bool breakfast)
{
	_element_breakfast = breakfast;
	_element_breakfast_is_set = true;
}


// -----------------------------------------------------------------------------
bool Page_restaurant_specialties::GetLunch() const
{
	return _element_lunch;
}


void Page_restaurant_specialties::SetLunch(bool lunch)
{
	_element_lunch = lunch;
	_element_lunch_is_set = true;
}


// -----------------------------------------------------------------------------
bool Page_restaurant_specialties::GetDinner() const
{
	return _element_dinner;
}


void Page_restaurant_specialties::SetDinner(bool dinner)
{
	_element_dinner = dinner;
	_element_dinner_is_set = true;
}


// -----------------------------------------------------------------------------
bool Page_restaurant_specialties::GetCoffee() const
{
	return _element_coffee;
}


void Page_restaurant_specialties::SetCoffee(bool coffee)
{
	_element_coffee = coffee;
	_element_coffee_is_set = true;
}


// -----------------------------------------------------------------------------
bool Page_restaurant_specialties::GetDrinks() const
{
	return _element_drinks;
}


void Page_restaurant_specialties::SetDrinks(bool drinks)
{
	_element_drinks = drinks;
	_element_drinks_is_set = true;
}


// -----------------------------------------------------------------------------
Page_payment_options::Page_payment_options()
: _element_cash_only_is_set(false)
, _element_visa_is_set(false)
, _element_amex_is_set(false)
, _element_mastercard_is_set(false)
, _element_discover_is_set(false)
{
}


// -----------------------------------------------------------------------------
Page_payment_options::Page_payment_options(const Xml::XmlNode& it)
: _element_cash_only_is_set(false)
, _element_visa_is_set(false)
, _element_amex_is_set(false)
, _element_mastercard_is_set(false)
, _element_discover_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Page_payment_options::clear()
{
	_element_cash_only = false;
	_element_visa = false;
	_element_amex = false;
	_element_mastercard = false;
	_element_discover = false;
	_element_cash_only_is_set = false;
	_element_visa_is_set = false;
	_element_amex_is_set = false;
	_element_mastercard_is_set = false;
	_element_discover_is_set = false;
}


// -----------------------------------------------------------------------------
void Page_payment_options::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("cash_only"))
		throw Xml::XmlException("missing required node in element 'page_payment_options': cash_only");
	SetCash_only( atoi(std::string(it["cash_only"]).c_str()) );
	if (!it.Exists("visa"))
		throw Xml::XmlException("missing required node in element 'page_payment_options': visa");
	SetVisa( atoi(std::string(it["visa"]).c_str()) );
	if (!it.Exists("amex"))
		throw Xml::XmlException("missing required node in element 'page_payment_options': amex");
	SetAmex( atoi(std::string(it["amex"]).c_str()) );
	if (!it.Exists("mastercard"))
		throw Xml::XmlException("missing required node in element 'page_payment_options': mastercard");
	SetMastercard( atoi(std::string(it["mastercard"]).c_str()) );
	if (!it.Exists("discover"))
		throw Xml::XmlException("missing required node in element 'page_payment_options': discover");
	SetDiscover( atoi(std::string(it["discover"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Page_payment_options::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<cash_only>" + Utility::l2string(_element_cash_only) + "</cash_only>";
	}
	{
		r = r + "<visa>" + Utility::l2string(_element_visa) + "</visa>";
	}
	{
		r = r + "<amex>" + Utility::l2string(_element_amex) + "</amex>";
	}
	{
		r = r + "<mastercard>" + Utility::l2string(_element_mastercard) + "</mastercard>";
	}
	{
		r = r + "<discover>" + Utility::l2string(_element_discover) + "</discover>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Page_payment_options::IsSet() const
{
	return Cash_onlyIsSet() || VisaIsSet() || AmexIsSet() || MastercardIsSet() || DiscoverIsSet();
}


// -----------------------------------------------------------------------------
bool Page_payment_options::GetCash_only() const
{
	return _element_cash_only;
}


void Page_payment_options::SetCash_only(bool cash_only)
{
	_element_cash_only = cash_only;
	_element_cash_only_is_set = true;
}


// -----------------------------------------------------------------------------
bool Page_payment_options::GetVisa() const
{
	return _element_visa;
}


void Page_payment_options::SetVisa(bool visa)
{
	_element_visa = visa;
	_element_visa_is_set = true;
}


// -----------------------------------------------------------------------------
bool Page_payment_options::GetAmex() const
{
	return _element_amex;
}


void Page_payment_options::SetAmex(bool amex)
{
	_element_amex = amex;
	_element_amex_is_set = true;
}


// -----------------------------------------------------------------------------
bool Page_payment_options::GetMastercard() const
{
	return _element_mastercard;
}


void Page_payment_options::SetMastercard(bool mastercard)
{
	_element_mastercard = mastercard;
	_element_mastercard_is_set = true;
}


// -----------------------------------------------------------------------------
bool Page_payment_options::GetDiscover() const
{
	return _element_discover;
}


void Page_payment_options::SetDiscover(bool discover)
{
	_element_discover = discover;
	_element_discover_is_set = true;
}


// -----------------------------------------------------------------------------
Page::Page()
: _element_page_id_is_set(false)
, _element_name_is_set(false)
, _element_pic_small_is_set(false)
, _element_pic_big_is_set(false)
, _element_pic_square_is_set(false)
, _element_pic_is_set(false)
, _element_pic_large_is_set(false)
, _element_page_url_is_set(false)
, _element_type_is_set(false)
, _element_website_is_set(false)
, _element_has_added_app_is_set(false)
, _element_founded_is_set(false)
, _element_company_overview_is_set(false)
, _element_mission_is_set(false)
, _element_products_is_set(false)
, _element_public_transit_is_set(false)
, _element_attire_is_set(false)
, _element_payment_options_is_set(false)
, _element_culinary_team_is_set(false)
, _element_general_manager_is_set(false)
, _element_price_range_is_set(false)
, _element_release_date_is_set(false)
, _element_genre_is_set(false)
, _element_starring_is_set(false)
, _element_screenplay_by_is_set(false)
, _element_directed_by_is_set(false)
, _element_produced_by_is_set(false)
, _element_studio_is_set(false)
, _element_awards_is_set(false)
, _element_plot_outline_is_set(false)
, _element_network_is_set(false)
, _element_season_is_set(false)
, _element_schedule_is_set(false)
, _element_written_by_is_set(false)
, _element_band_members_is_set(false)
, _element_hometown_is_set(false)
, _element_current_location_is_set(false)
, _element_record_label_is_set(false)
, _element_booking_agent_is_set(false)
, _element_artists_we_like_is_set(false)
, _element_influences_is_set(false)
, _element_band_interests_is_set(false)
, _element_bio_is_set(false)
, _element_affiliation_is_set(false)
, _element_birthday_is_set(false)
, _element_personal_info_is_set(false)
, _element_personal_interests_is_set(false)
, _element_members_is_set(false)
, _element_built_is_set(false)
, _element_features_is_set(false)
, _element_mpg_is_set(false)
, _element_general_info_is_set(false)
, _element_username_is_set(false)
{
}


// -----------------------------------------------------------------------------
Page::Page(const Xml::XmlNode& it)
: _element_page_id_is_set(false)
, _element_name_is_set(false)
, _element_pic_small_is_set(false)
, _element_pic_big_is_set(false)
, _element_pic_square_is_set(false)
, _element_pic_is_set(false)
, _element_pic_large_is_set(false)
, _element_page_url_is_set(false)
, _element_type_is_set(false)
, _element_website_is_set(false)
, _element_has_added_app_is_set(false)
, _element_founded_is_set(false)
, _element_company_overview_is_set(false)
, _element_mission_is_set(false)
, _element_products_is_set(false)
, _element_public_transit_is_set(false)
, _element_attire_is_set(false)
, _element_payment_options_is_set(false)
, _element_culinary_team_is_set(false)
, _element_general_manager_is_set(false)
, _element_price_range_is_set(false)
, _element_release_date_is_set(false)
, _element_genre_is_set(false)
, _element_starring_is_set(false)
, _element_screenplay_by_is_set(false)
, _element_directed_by_is_set(false)
, _element_produced_by_is_set(false)
, _element_studio_is_set(false)
, _element_awards_is_set(false)
, _element_plot_outline_is_set(false)
, _element_network_is_set(false)
, _element_season_is_set(false)
, _element_schedule_is_set(false)
, _element_written_by_is_set(false)
, _element_band_members_is_set(false)
, _element_hometown_is_set(false)
, _element_current_location_is_set(false)
, _element_record_label_is_set(false)
, _element_booking_agent_is_set(false)
, _element_artists_we_like_is_set(false)
, _element_influences_is_set(false)
, _element_band_interests_is_set(false)
, _element_bio_is_set(false)
, _element_affiliation_is_set(false)
, _element_birthday_is_set(false)
, _element_personal_info_is_set(false)
, _element_personal_interests_is_set(false)
, _element_members_is_set(false)
, _element_built_is_set(false)
, _element_features_is_set(false)
, _element_mpg_is_set(false)
, _element_general_info_is_set(false)
, _element_username_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Page::clear()
{
	// simpleType:
	// _element_page_id.clear();
	_element_name.clear();
	_element_pic_small.clear();
	_element_pic_big.clear();
	_element_pic_square.clear();
	_element_pic.clear();
	_element_pic_large.clear();
	_element_page_url.clear();
	_element_status.clear();
	_element_type.clear();
	_element_website.clear();
	_element_has_added_app = false;
	_element_founded.clear();
	_element_company_overview.clear();
	_element_mission.clear();
	_element_products.clear();
	_element_location.clear();
	_element_parking.clear();
	_element_public_transit.clear();
	_element_hours.clear();
	_element_attire.clear();
	_element_payment_options.clear();
	_element_culinary_team.clear();
	_element_general_manager.clear();
	_element_price_range.clear();
	_element_restaurant_services.clear();
	_element_restaurant_specialties.clear();
	_element_release_date.clear();
	_element_genre.clear();
	_element_starring.clear();
	_element_screenplay_by.clear();
	_element_directed_by.clear();
	_element_produced_by.clear();
	_element_studio.clear();
	_element_awards.clear();
	_element_plot_outline.clear();
	_element_network.clear();
	_element_season.clear();
	_element_schedule.clear();
	_element_written_by.clear();
	_element_band_members.clear();
	_element_hometown.clear();
	_element_current_location.clear();
	_element_record_label.clear();
	_element_booking_agent.clear();
	_element_artists_we_like.clear();
	_element_influences.clear();
	_element_band_interests.clear();
	_element_bio.clear();
	_element_affiliation.clear();
	_element_birthday.clear();
	_element_personal_info.clear();
	_element_personal_interests.clear();
	_element_members.clear();
	_element_built.clear();
	_element_features.clear();
	_element_mpg.clear();
	_element_general_info.clear();
	_element_username.clear();
	_element_page_id_is_set = false;
	_element_name_is_set = false;
	_element_pic_small_is_set = false;
	_element_pic_big_is_set = false;
	_element_pic_square_is_set = false;
	_element_pic_is_set = false;
	_element_pic_large_is_set = false;
	_element_page_url_is_set = false;
	_element_type_is_set = false;
	_element_website_is_set = false;
	_element_has_added_app_is_set = false;
	_element_founded_is_set = false;
	_element_company_overview_is_set = false;
	_element_mission_is_set = false;
	_element_products_is_set = false;
	_element_public_transit_is_set = false;
	_element_attire_is_set = false;
	_element_payment_options_is_set = false;
	_element_culinary_team_is_set = false;
	_element_general_manager_is_set = false;
	_element_price_range_is_set = false;
	_element_release_date_is_set = false;
	_element_genre_is_set = false;
	_element_starring_is_set = false;
	_element_screenplay_by_is_set = false;
	_element_directed_by_is_set = false;
	_element_produced_by_is_set = false;
	_element_studio_is_set = false;
	_element_awards_is_set = false;
	_element_plot_outline_is_set = false;
	_element_network_is_set = false;
	_element_season_is_set = false;
	_element_schedule_is_set = false;
	_element_written_by_is_set = false;
	_element_band_members_is_set = false;
	_element_hometown_is_set = false;
	_element_current_location_is_set = false;
	_element_record_label_is_set = false;
	_element_booking_agent_is_set = false;
	_element_artists_we_like_is_set = false;
	_element_influences_is_set = false;
	_element_band_interests_is_set = false;
	_element_bio_is_set = false;
	_element_affiliation_is_set = false;
	_element_birthday_is_set = false;
	_element_personal_info_is_set = false;
	_element_personal_interests_is_set = false;
	_element_members_is_set = false;
	_element_built_is_set = false;
	_element_features_is_set = false;
	_element_mpg_is_set = false;
	_element_general_info_is_set = false;
	_element_username_is_set = false;
}


// -----------------------------------------------------------------------------
void Page::FromXml(const Xml::XmlNode& it)
{
	if (it.Exists("page_id"))
		SetPage_id( atoi(std::string(it["page_id"]).c_str()) );
	if (it.Exists("name"))
		SetName( it["name"] );
	if (it.Exists("pic_small"))
		SetPic_small( it["pic_small"] );
	if (it.Exists("pic_big"))
		SetPic_big( it["pic_big"] );
	if (it.Exists("pic_square"))
		SetPic_square( it["pic_square"] );
	if (it.Exists("pic"))
		SetPic( it["pic"] );
	if (it.Exists("pic_large"))
		SetPic_large( it["pic_large"] );
	if (it.Exists("page_url"))
		SetPage_url( it["page_url"] );
	{
		Xml::XmlNode n(it, "status");
		if (n)
			_element_status.FromXml( n );
	}
	if (it.Exists("type"))
		SetType( it["type"] );
	if (it.Exists("website"))
		SetWebsite( it["website"] );
	if (it.Exists("has_added_app"))
		SetHas_added_app( atoi(std::string(it["has_added_app"]).c_str()) );
	if (it.Exists("founded"))
		SetFounded( it["founded"] );
	if (it.Exists("company_overview"))
		SetCompany_overview( it["company_overview"] );
	if (it.Exists("mission"))
		SetMission( it["mission"] );
	if (it.Exists("products"))
		SetProducts( it["products"] );
	{
		Xml::XmlNode n(it, "location");
		if (n)
			_element_location.FromXml( n );
	}
	{
		Xml::XmlNode n(it, "parking");
		if (n)
			_element_parking.FromXml( n );
	}
	if (it.Exists("public_transit"))
		SetPublic_transit( it["public_transit"] );
	{
		Xml::XmlNode n(it, "hours");
		if (n)
			_element_hours.FromXml( n );
	}
	if (it.Exists("attire"))
		SetAttire( it["attire"] );
	if (it.Exists("payment_options"))
		SetPayment_options( it["payment_options"] );
	if (it.Exists("culinary_team"))
		SetCulinary_team( it["culinary_team"] );
	if (it.Exists("general_manager"))
		SetGeneral_manager( it["general_manager"] );
	if (it.Exists("price_range"))
		SetPrice_range( it["price_range"] );
	{
		Xml::XmlNode n(it, "restaurant_services");
		if (n)
			_element_restaurant_services.FromXml( n );
	}
	{
		Xml::XmlNode n(it, "restaurant_specialties");
		if (n)
			_element_restaurant_specialties.FromXml( n );
	}
	if (it.Exists("release_date"))
		SetRelease_date( it["release_date"] );
	if (it.Exists("genre"))
		SetGenre( it["genre"] );
	if (it.Exists("starring"))
		SetStarring( it["starring"] );
	if (it.Exists("screenplay_by"))
		SetScreenplay_by( it["screenplay_by"] );
	if (it.Exists("directed_by"))
		SetDirected_by( it["directed_by"] );
	if (it.Exists("produced_by"))
		SetProduced_by( it["produced_by"] );
	if (it.Exists("studio"))
		SetStudio( it["studio"] );
	if (it.Exists("awards"))
		SetAwards( it["awards"] );
	if (it.Exists("plot_outline"))
		SetPlot_outline( it["plot_outline"] );
	if (it.Exists("network"))
		SetNetwork( it["network"] );
	if (it.Exists("season"))
		SetSeason( it["season"] );
	if (it.Exists("schedule"))
		SetSchedule( it["schedule"] );
	if (it.Exists("written_by"))
		SetWritten_by( it["written_by"] );
	if (it.Exists("band_members"))
		SetBand_members( it["band_members"] );
	if (it.Exists("hometown"))
		SetHometown( it["hometown"] );
	if (it.Exists("current_location"))
		SetCurrent_location( it["current_location"] );
	if (it.Exists("record_label"))
		SetRecord_label( it["record_label"] );
	if (it.Exists("booking_agent"))
		SetBooking_agent( it["booking_agent"] );
	if (it.Exists("artists_we_like"))
		SetArtists_we_like( it["artists_we_like"] );
	if (it.Exists("influences"))
		SetInfluences( it["influences"] );
	if (it.Exists("band_interests"))
		SetBand_interests( it["band_interests"] );
	if (it.Exists("bio"))
		SetBio( it["bio"] );
	if (it.Exists("affiliation"))
		SetAffiliation( it["affiliation"] );
	if (it.Exists("birthday"))
		SetBirthday( it["birthday"] );
	if (it.Exists("personal_info"))
		SetPersonal_info( it["personal_info"] );
	if (it.Exists("personal_interests"))
		SetPersonal_interests( it["personal_interests"] );
	if (it.Exists("members"))
		SetMembers( it["members"] );
	if (it.Exists("built"))
		SetBuilt( it["built"] );
	if (it.Exists("features"))
		SetFeatures( it["features"] );
	if (it.Exists("mpg"))
		SetMpg( it["mpg"] );
	if (it.Exists("general_info"))
		SetGeneral_info( it["general_info"] );
	if (it.Exists("username"))
		SetUsername( it["username"] );
}


// -----------------------------------------------------------------------------
const std::string Page::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	if (_element_page_id_is_set)
	{
		r = r + "<page_id>" + Utility::l2string(_element_page_id) + "</page_id>";
	}
	if (_element_name_is_set)
		r += "<name>" + _element_name + "</name>";
	if (_element_pic_small_is_set)
		r += "<pic_small>" + _element_pic_small + "</pic_small>";
	if (_element_pic_big_is_set)
		r += "<pic_big>" + _element_pic_big + "</pic_big>";
	if (_element_pic_square_is_set)
		r += "<pic_square>" + _element_pic_square + "</pic_square>";
	if (_element_pic_is_set)
		r += "<pic>" + _element_pic + "</pic>";
	if (_element_pic_large_is_set)
		r += "<pic_large>" + _element_pic_large + "</pic_large>";
	if (_element_page_url_is_set)
		r += "<page_url>" + _element_page_url + "</page_url>";
	r += _element_status.ToString("status");
	if (_element_type_is_set)
		r += "<type>" + _element_type + "</type>";
	if (_element_website_is_set)
		r += "<website>" + _element_website + "</website>";
	if (_element_has_added_app_is_set)
	{
		r = r + "<has_added_app>" + Utility::l2string(_element_has_added_app) + "</has_added_app>";
	}
	if (_element_founded_is_set)
		r += "<founded>" + _element_founded + "</founded>";
	if (_element_company_overview_is_set)
		r += "<company_overview>" + _element_company_overview + "</company_overview>";
	if (_element_mission_is_set)
		r += "<mission>" + _element_mission + "</mission>";
	if (_element_products_is_set)
		r += "<products>" + _element_products + "</products>";
	r += _element_location.ToString("location");
	r += _element_parking.ToString("parking");
	if (_element_public_transit_is_set)
		r += "<public_transit>" + _element_public_transit + "</public_transit>";
	r += _element_hours.ToString("hours");
	if (_element_attire_is_set)
		r += "<attire>" + _element_attire + "</attire>";
	if (_element_payment_options_is_set)
		r += "<payment_options>" + _element_payment_options + "</payment_options>";
	if (_element_culinary_team_is_set)
		r += "<culinary_team>" + _element_culinary_team + "</culinary_team>";
	if (_element_general_manager_is_set)
		r += "<general_manager>" + _element_general_manager + "</general_manager>";
	if (_element_price_range_is_set)
		r += "<price_range>" + _element_price_range + "</price_range>";
	r += _element_restaurant_services.ToString("restaurant_services");
	r += _element_restaurant_specialties.ToString("restaurant_specialties");
	if (_element_release_date_is_set)
		r += "<release_date>" + _element_release_date + "</release_date>";
	if (_element_genre_is_set)
		r += "<genre>" + _element_genre + "</genre>";
	if (_element_starring_is_set)
		r += "<starring>" + _element_starring + "</starring>";
	if (_element_screenplay_by_is_set)
		r += "<screenplay_by>" + _element_screenplay_by + "</screenplay_by>";
	if (_element_directed_by_is_set)
		r += "<directed_by>" + _element_directed_by + "</directed_by>";
	if (_element_produced_by_is_set)
		r += "<produced_by>" + _element_produced_by + "</produced_by>";
	if (_element_studio_is_set)
		r += "<studio>" + _element_studio + "</studio>";
	if (_element_awards_is_set)
		r += "<awards>" + _element_awards + "</awards>";
	if (_element_plot_outline_is_set)
		r += "<plot_outline>" + _element_plot_outline + "</plot_outline>";
	if (_element_network_is_set)
		r += "<network>" + _element_network + "</network>";
	if (_element_season_is_set)
		r += "<season>" + _element_season + "</season>";
	if (_element_schedule_is_set)
		r += "<schedule>" + _element_schedule + "</schedule>";
	if (_element_written_by_is_set)
		r += "<written_by>" + _element_written_by + "</written_by>";
	if (_element_band_members_is_set)
		r += "<band_members>" + _element_band_members + "</band_members>";
	if (_element_hometown_is_set)
		r += "<hometown>" + _element_hometown + "</hometown>";
	if (_element_current_location_is_set)
		r += "<current_location>" + _element_current_location + "</current_location>";
	if (_element_record_label_is_set)
		r += "<record_label>" + _element_record_label + "</record_label>";
	if (_element_booking_agent_is_set)
		r += "<booking_agent>" + _element_booking_agent + "</booking_agent>";
	if (_element_artists_we_like_is_set)
		r += "<artists_we_like>" + _element_artists_we_like + "</artists_we_like>";
	if (_element_influences_is_set)
		r += "<influences>" + _element_influences + "</influences>";
	if (_element_band_interests_is_set)
		r += "<band_interests>" + _element_band_interests + "</band_interests>";
	if (_element_bio_is_set)
		r += "<bio>" + _element_bio + "</bio>";
	if (_element_affiliation_is_set)
		r += "<affiliation>" + _element_affiliation + "</affiliation>";
	if (_element_birthday_is_set)
		r += "<birthday>" + _element_birthday + "</birthday>";
	if (_element_personal_info_is_set)
		r += "<personal_info>" + _element_personal_info + "</personal_info>";
	if (_element_personal_interests_is_set)
		r += "<personal_interests>" + _element_personal_interests + "</personal_interests>";
	if (_element_members_is_set)
		r += "<members>" + _element_members + "</members>";
	if (_element_built_is_set)
		r += "<built>" + _element_built + "</built>";
	if (_element_features_is_set)
		r += "<features>" + _element_features + "</features>";
	if (_element_mpg_is_set)
		r += "<mpg>" + _element_mpg + "</mpg>";
	if (_element_general_info_is_set)
		r += "<general_info>" + _element_general_info + "</general_info>";
	if (_element_username_is_set)
		r += "<username>" + _element_username + "</username>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Page::IsSet() const
{
	return Page_idIsSet() || NameIsSet() || Pic_smallIsSet() || Pic_bigIsSet() || Pic_squareIsSet() || PicIsSet() || Pic_largeIsSet() || Page_urlIsSet() || StatusIsSet() || TypeIsSet() || WebsiteIsSet() || Has_added_appIsSet() || FoundedIsSet() || Company_overviewIsSet() || MissionIsSet() || ProductsIsSet() || LocationIsSet() || ParkingIsSet() || Public_transitIsSet() || HoursIsSet() || AttireIsSet() || Payment_optionsIsSet() || Culinary_teamIsSet() || General_managerIsSet() || Price_rangeIsSet() || Restaurant_servicesIsSet() || Restaurant_specialtiesIsSet() || Release_dateIsSet() || GenreIsSet() || StarringIsSet() || Screenplay_byIsSet() || Directed_byIsSet() || Produced_byIsSet() || StudioIsSet() || AwardsIsSet() || Plot_outlineIsSet() || NetworkIsSet() || SeasonIsSet() || ScheduleIsSet() || Written_byIsSet() || Band_membersIsSet() || HometownIsSet() || Current_locationIsSet() || Record_labelIsSet() || Booking_agentIsSet() || Artists_we_likeIsSet() || InfluencesIsSet() || Band_interestsIsSet() || BioIsSet() || AffiliationIsSet() || BirthdayIsSet() || Personal_infoIsSet() || Personal_interestsIsSet() || MembersIsSet() || BuiltIsSet() || FeaturesIsSet() || MpgIsSet() || General_infoIsSet() || UsernameIsSet();
}


// -----------------------------------------------------------------------------
long Page::GetPage_id() const
{
	return _element_page_id;
}


void Page::SetPage_id(long page_id)
{
	_element_page_id = page_id;
	_element_page_id_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetName() const
{
	return _element_name;
}


void Page::SetName(const std::string& name)
{
	_element_name = name;
	_element_name_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetPic_small() const
{
	return _element_pic_small;
}


void Page::SetPic_small(const std::string& pic_small)
{
	_element_pic_small = pic_small;
	_element_pic_small_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetPic_big() const
{
	return _element_pic_big;
}


void Page::SetPic_big(const std::string& pic_big)
{
	_element_pic_big = pic_big;
	_element_pic_big_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetPic_square() const
{
	return _element_pic_square;
}


void Page::SetPic_square(const std::string& pic_square)
{
	_element_pic_square = pic_square;
	_element_pic_square_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetPic() const
{
	return _element_pic;
}


void Page::SetPic(const std::string& pic)
{
	_element_pic = pic;
	_element_pic_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetPic_large() const
{
	return _element_pic_large;
}


void Page::SetPic_large(const std::string& pic_large)
{
	_element_pic_large = pic_large;
	_element_pic_large_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetPage_url() const
{
	return _element_page_url;
}


void Page::SetPage_url(const std::string& page_url)
{
	_element_page_url = page_url;
	_element_page_url_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::User_status& Page::GetStatus() const
{
	return _element_status;
}


com_facebook_1_0_::User_status& Page::GetStatus()
{
	return _element_status;
}


void Page::SetStatus(const com_facebook_1_0_::User_status& status)
{
	_element_status = status;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetType() const
{
	return _element_type;
}


void Page::SetType(const std::string& type)
{
	_element_type = type;
	_element_type_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetWebsite() const
{
	return _element_website;
}


void Page::SetWebsite(const std::string& website)
{
	_element_website = website;
	_element_website_is_set = true;
}


// -----------------------------------------------------------------------------
bool Page::GetHas_added_app() const
{
	return _element_has_added_app;
}


void Page::SetHas_added_app(bool has_added_app)
{
	_element_has_added_app = has_added_app;
	_element_has_added_app_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetFounded() const
{
	return _element_founded;
}


void Page::SetFounded(const std::string& founded)
{
	_element_founded = founded;
	_element_founded_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetCompany_overview() const
{
	return _element_company_overview;
}


void Page::SetCompany_overview(const std::string& company_overview)
{
	_element_company_overview = company_overview;
	_element_company_overview_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetMission() const
{
	return _element_mission;
}


void Page::SetMission(const std::string& mission)
{
	_element_mission = mission;
	_element_mission_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetProducts() const
{
	return _element_products;
}


void Page::SetProducts(const std::string& products)
{
	_element_products = products;
	_element_products_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Location& Page::GetLocation() const
{
	return _element_location;
}


com_facebook_1_0_::Location& Page::GetLocation()
{
	return _element_location;
}


void Page::SetLocation(const com_facebook_1_0_::Location& location)
{
	_element_location = location;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Page_parking& Page::GetParking() const
{
	return _element_parking;
}


com_facebook_1_0_::Page_parking& Page::GetParking()
{
	return _element_parking;
}


void Page::SetParking(const com_facebook_1_0_::Page_parking& parking)
{
	_element_parking = parking;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetPublic_transit() const
{
	return _element_public_transit;
}


void Page::SetPublic_transit(const std::string& public_transit)
{
	_element_public_transit = public_transit;
	_element_public_transit_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Page_hours& Page::GetHours() const
{
	return _element_hours;
}


com_facebook_1_0_::Page_hours& Page::GetHours()
{
	return _element_hours;
}


void Page::SetHours(const com_facebook_1_0_::Page_hours& hours)
{
	_element_hours = hours;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetAttire() const
{
	return _element_attire;
}


void Page::SetAttire(const std::string& attire)
{
	_element_attire = attire;
	_element_attire_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetPayment_options() const
{
	return _element_payment_options;
}


void Page::SetPayment_options(const std::string& payment_options)
{
	_element_payment_options = payment_options;
	_element_payment_options_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetCulinary_team() const
{
	return _element_culinary_team;
}


void Page::SetCulinary_team(const std::string& culinary_team)
{
	_element_culinary_team = culinary_team;
	_element_culinary_team_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetGeneral_manager() const
{
	return _element_general_manager;
}


void Page::SetGeneral_manager(const std::string& general_manager)
{
	_element_general_manager = general_manager;
	_element_general_manager_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetPrice_range() const
{
	return _element_price_range;
}


void Page::SetPrice_range(const std::string& price_range)
{
	_element_price_range = price_range;
	_element_price_range_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Page_restaurant_services& Page::GetRestaurant_services() const
{
	return _element_restaurant_services;
}


com_facebook_1_0_::Page_restaurant_services& Page::GetRestaurant_services()
{
	return _element_restaurant_services;
}


void Page::SetRestaurant_services(const com_facebook_1_0_::Page_restaurant_services& restaurant_services)
{
	_element_restaurant_services = restaurant_services;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Page_restaurant_specialties& Page::GetRestaurant_specialties() const
{
	return _element_restaurant_specialties;
}


com_facebook_1_0_::Page_restaurant_specialties& Page::GetRestaurant_specialties()
{
	return _element_restaurant_specialties;
}


void Page::SetRestaurant_specialties(const com_facebook_1_0_::Page_restaurant_specialties& restaurant_specialties)
{
	_element_restaurant_specialties = restaurant_specialties;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetRelease_date() const
{
	return _element_release_date;
}


void Page::SetRelease_date(const std::string& release_date)
{
	_element_release_date = release_date;
	_element_release_date_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetGenre() const
{
	return _element_genre;
}


void Page::SetGenre(const std::string& genre)
{
	_element_genre = genre;
	_element_genre_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetStarring() const
{
	return _element_starring;
}


void Page::SetStarring(const std::string& starring)
{
	_element_starring = starring;
	_element_starring_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetScreenplay_by() const
{
	return _element_screenplay_by;
}


void Page::SetScreenplay_by(const std::string& screenplay_by)
{
	_element_screenplay_by = screenplay_by;
	_element_screenplay_by_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetDirected_by() const
{
	return _element_directed_by;
}


void Page::SetDirected_by(const std::string& directed_by)
{
	_element_directed_by = directed_by;
	_element_directed_by_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetProduced_by() const
{
	return _element_produced_by;
}


void Page::SetProduced_by(const std::string& produced_by)
{
	_element_produced_by = produced_by;
	_element_produced_by_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetStudio() const
{
	return _element_studio;
}


void Page::SetStudio(const std::string& studio)
{
	_element_studio = studio;
	_element_studio_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetAwards() const
{
	return _element_awards;
}


void Page::SetAwards(const std::string& awards)
{
	_element_awards = awards;
	_element_awards_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetPlot_outline() const
{
	return _element_plot_outline;
}


void Page::SetPlot_outline(const std::string& plot_outline)
{
	_element_plot_outline = plot_outline;
	_element_plot_outline_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetNetwork() const
{
	return _element_network;
}


void Page::SetNetwork(const std::string& network)
{
	_element_network = network;
	_element_network_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetSeason() const
{
	return _element_season;
}


void Page::SetSeason(const std::string& season)
{
	_element_season = season;
	_element_season_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetSchedule() const
{
	return _element_schedule;
}


void Page::SetSchedule(const std::string& schedule)
{
	_element_schedule = schedule;
	_element_schedule_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetWritten_by() const
{
	return _element_written_by;
}


void Page::SetWritten_by(const std::string& written_by)
{
	_element_written_by = written_by;
	_element_written_by_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetBand_members() const
{
	return _element_band_members;
}


void Page::SetBand_members(const std::string& band_members)
{
	_element_band_members = band_members;
	_element_band_members_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetHometown() const
{
	return _element_hometown;
}


void Page::SetHometown(const std::string& hometown)
{
	_element_hometown = hometown;
	_element_hometown_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetCurrent_location() const
{
	return _element_current_location;
}


void Page::SetCurrent_location(const std::string& current_location)
{
	_element_current_location = current_location;
	_element_current_location_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetRecord_label() const
{
	return _element_record_label;
}


void Page::SetRecord_label(const std::string& record_label)
{
	_element_record_label = record_label;
	_element_record_label_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetBooking_agent() const
{
	return _element_booking_agent;
}


void Page::SetBooking_agent(const std::string& booking_agent)
{
	_element_booking_agent = booking_agent;
	_element_booking_agent_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetArtists_we_like() const
{
	return _element_artists_we_like;
}


void Page::SetArtists_we_like(const std::string& artists_we_like)
{
	_element_artists_we_like = artists_we_like;
	_element_artists_we_like_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetInfluences() const
{
	return _element_influences;
}


void Page::SetInfluences(const std::string& influences)
{
	_element_influences = influences;
	_element_influences_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetBand_interests() const
{
	return _element_band_interests;
}


void Page::SetBand_interests(const std::string& band_interests)
{
	_element_band_interests = band_interests;
	_element_band_interests_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetBio() const
{
	return _element_bio;
}


void Page::SetBio(const std::string& bio)
{
	_element_bio = bio;
	_element_bio_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetAffiliation() const
{
	return _element_affiliation;
}


void Page::SetAffiliation(const std::string& affiliation)
{
	_element_affiliation = affiliation;
	_element_affiliation_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetBirthday() const
{
	return _element_birthday;
}


void Page::SetBirthday(const std::string& birthday)
{
	_element_birthday = birthday;
	_element_birthday_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetPersonal_info() const
{
	return _element_personal_info;
}


void Page::SetPersonal_info(const std::string& personal_info)
{
	_element_personal_info = personal_info;
	_element_personal_info_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetPersonal_interests() const
{
	return _element_personal_interests;
}


void Page::SetPersonal_interests(const std::string& personal_interests)
{
	_element_personal_interests = personal_interests;
	_element_personal_interests_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetMembers() const
{
	return _element_members;
}


void Page::SetMembers(const std::string& members)
{
	_element_members = members;
	_element_members_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetBuilt() const
{
	return _element_built;
}


void Page::SetBuilt(const std::string& built)
{
	_element_built = built;
	_element_built_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetFeatures() const
{
	return _element_features;
}


void Page::SetFeatures(const std::string& features)
{
	_element_features = features;
	_element_features_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetMpg() const
{
	return _element_mpg;
}


void Page::SetMpg(const std::string& mpg)
{
	_element_mpg = mpg;
	_element_mpg_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetGeneral_info() const
{
	return _element_general_info;
}


void Page::SetGeneral_info(const std::string& general_info)
{
	_element_general_info = general_info;
	_element_general_info_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Page::GetUsername() const
{
	return _element_username;
}


void Page::SetUsername(const std::string& username)
{
	_element_username = username;
	_element_username_is_set = true;
}


// -----------------------------------------------------------------------------
bool Page::StatusIsSet() const
{
	return _element_status.IsSet();
}


// -----------------------------------------------------------------------------
bool Page::LocationIsSet() const
{
	return _element_location.IsSet();
}


// -----------------------------------------------------------------------------
bool Page::ParkingIsSet() const
{
	return _element_parking.IsSet();
}


// -----------------------------------------------------------------------------
bool Page::HoursIsSet() const
{
	return _element_hours.IsSet();
}


// -----------------------------------------------------------------------------
bool Page::Restaurant_servicesIsSet() const
{
	return _element_restaurant_services.IsSet();
}


// -----------------------------------------------------------------------------
bool Page::Restaurant_specialtiesIsSet() const
{
	return _element_restaurant_specialties.IsSet();
}


// -----------------------------------------------------------------------------
Cookie::Cookie()
: _element_expires(0)
, _element_uid_is_set(false)
, _element_name_is_set(false)
, _element_value_is_set(false)
, _element_expires_is_set(false)
, _element_path_is_set(false)
{
}


// -----------------------------------------------------------------------------
Cookie::Cookie(const Xml::XmlNode& it)
: _element_expires(0)
, _element_uid_is_set(false)
, _element_name_is_set(false)
, _element_value_is_set(false)
, _element_expires_is_set(false)
, _element_path_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Cookie::clear()
{
	// simpleType:
	// _element_uid.clear();
	_element_name.clear();
	_element_value.clear();
	_element_expires = 0;
	_element_path.clear();
	_element_uid_is_set = false;
	_element_name_is_set = false;
	_element_value_is_set = false;
	_element_expires_is_set = false;
	_element_path_is_set = false;
}


// -----------------------------------------------------------------------------
void Cookie::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("uid"))
		throw Xml::XmlException("missing required node in element 'cookie': uid");
	SetUid( atoi(std::string(it["uid"]).c_str()) );
	if (!it.Exists("name"))
		throw Xml::XmlException("missing required node in element 'cookie': name");
	SetName( it["name"] );
	if (!it.Exists("value"))
		throw Xml::XmlException("missing required node in element 'cookie': value");
	SetValue( it["value"] );
	if (!it.Exists("expires"))
		throw Xml::XmlException("missing required node in element 'cookie': expires");
	SetExpires( atoi(std::string(it["expires"]).c_str()) );
	if (!it.Exists("path"))
		throw Xml::XmlException("missing required node in element 'cookie': path");
	SetPath( it["path"] );
}


// -----------------------------------------------------------------------------
const std::string Cookie::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<uid>" + Utility::l2string(_element_uid) + "</uid>";
	}
	r += "<name>" + _element_name + "</name>";
	r += "<value>" + _element_value + "</value>";
	{
		r = r + "<expires>" + Utility::l2string(_element_expires) + "</expires>";
	}
	r += "<path>" + _element_path + "</path>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Cookie::IsSet() const
{
	return UidIsSet() || NameIsSet() || ValueIsSet() || ExpiresIsSet() || PathIsSet();
}


// -----------------------------------------------------------------------------
long Cookie::GetUid() const
{
	return _element_uid;
}


void Cookie::SetUid(long uid)
{
	_element_uid = uid;
	_element_uid_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Cookie::GetName() const
{
	return _element_name;
}


void Cookie::SetName(const std::string& name)
{
	_element_name = name;
	_element_name_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Cookie::GetValue() const
{
	return _element_value;
}


void Cookie::SetValue(const std::string& value)
{
	_element_value = value;
	_element_value_is_set = true;
}


// -----------------------------------------------------------------------------
int Cookie::GetExpires() const
{
	return _element_expires;
}


void Cookie::SetExpires(int expires)
{
	_element_expires = expires;
	_element_expires_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Cookie::GetPath() const
{
	return _element_path;
}


void Cookie::SetPath(const std::string& path)
{
	_element_path = path;
	_element_path_is_set = true;
}


// -----------------------------------------------------------------------------
Phrase::Phrase()
: _element_description_is_set(false)
, _element_text_is_set(false)
{
}


// -----------------------------------------------------------------------------
Phrase::Phrase(const Xml::XmlNode& it)
: _element_description_is_set(false)
, _element_text_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Phrase::clear()
{
	_element_description.clear();
	_element_text.clear();
	_element_description_is_set = false;
	_element_text_is_set = false;
}


// -----------------------------------------------------------------------------
void Phrase::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("description"))
		throw Xml::XmlException("missing required node in element 'phrase': description");
	SetDescription( it["description"] );
	if (!it.Exists("text"))
		throw Xml::XmlException("missing required node in element 'phrase': text");
	SetText( it["text"] );
}


// -----------------------------------------------------------------------------
const std::string Phrase::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<description>" + _element_description + "</description>";
	r += "<text>" + _element_text + "</text>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Phrase::IsSet() const
{
	return DescriptionIsSet() || TextIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Phrase::GetDescription() const
{
	return _element_description;
}


void Phrase::SetDescription(const std::string& description)
{
	_element_description = description;
	_element_description_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Phrase::GetText() const
{
	return _element_text;
}


void Phrase::SetText(const std::string& text)
{
	_element_text = text;
	_element_text_is_set = true;
}


// -----------------------------------------------------------------------------
Developer_info::Developer_info()
: _element_uid(0)
, _element_uid_is_set(false)
, _element_name_is_set(false)
{
}


// -----------------------------------------------------------------------------
Developer_info::Developer_info(const Xml::XmlNode& it)
: _element_uid(0)
, _element_uid_is_set(false)
, _element_name_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Developer_info::clear()
{
	_element_uid = 0;
	_element_name.clear();
	_element_uid_is_set = false;
	_element_name_is_set = false;
}


// -----------------------------------------------------------------------------
void Developer_info::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("uid"))
		throw Xml::XmlException("missing required node in element 'developer_info': uid");
	SetUid( atoi(std::string(it["uid"]).c_str()) );
	if (!it.Exists("name"))
		throw Xml::XmlException("missing required node in element 'developer_info': name");
	SetName( it["name"] );
}


// -----------------------------------------------------------------------------
const std::string Developer_info::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<uid>" + Utility::l2string(_element_uid) + "</uid>";
	}
	r += "<name>" + _element_name + "</name>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Developer_info::IsSet() const
{
	return UidIsSet() || NameIsSet();
}


// -----------------------------------------------------------------------------
int Developer_info::GetUid() const
{
	return _element_uid;
}


void Developer_info::SetUid(int uid)
{
	_element_uid = uid;
	_element_uid_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Developer_info::GetName() const
{
	return _element_name;
}


void Developer_info::SetName(const std::string& name)
{
	_element_name = name;
	_element_name_is_set = true;
}


// -----------------------------------------------------------------------------
App_info::App_info()
: _element_app_id(0)
, _element_daily_active_users(0)
, _element_weekly_active_users(0)
, _element_monthly_active_users(0)
, _element_app_id_is_set(false)
, _element_api_key_is_set(false)
, _element_canvas_name_is_set(false)
, _element_display_name_is_set(false)
, _element_icon_url_is_set(false)
, _element_logo_url_is_set(false)
, _element_company_name_is_set(false)
, _element_description_is_set(false)
, _element_daily_active_users_is_set(false)
, _element_weekly_active_users_is_set(false)
, _element_monthly_active_users_is_set(false)
, _element_category_is_set(false)
, _element_subcategory_is_set(false)
{
}


// -----------------------------------------------------------------------------
App_info::App_info(const Xml::XmlNode& it)
: _element_app_id(0)
, _element_daily_active_users(0)
, _element_weekly_active_users(0)
, _element_monthly_active_users(0)
, _element_app_id_is_set(false)
, _element_api_key_is_set(false)
, _element_canvas_name_is_set(false)
, _element_display_name_is_set(false)
, _element_icon_url_is_set(false)
, _element_logo_url_is_set(false)
, _element_company_name_is_set(false)
, _element_description_is_set(false)
, _element_daily_active_users_is_set(false)
, _element_weekly_active_users_is_set(false)
, _element_monthly_active_users_is_set(false)
, _element_category_is_set(false)
, _element_subcategory_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void App_info::clear()
{
	_element_app_id = 0;
	_element_api_key.clear();
	_element_canvas_name.clear();
	_element_display_name.clear();
	_element_icon_url.clear();
	_element_logo_url.clear();
	_element_developers.clear();
	_element_company_name.clear();
	_element_description.clear();
	_element_daily_active_users = 0;
	_element_weekly_active_users = 0;
	_element_monthly_active_users = 0;
	_element_category.clear();
	_element_subcategory.clear();
	_element_app_id_is_set = false;
	_element_api_key_is_set = false;
	_element_canvas_name_is_set = false;
	_element_display_name_is_set = false;
	_element_icon_url_is_set = false;
	_element_logo_url_is_set = false;
	_element_company_name_is_set = false;
	_element_description_is_set = false;
	_element_daily_active_users_is_set = false;
	_element_weekly_active_users_is_set = false;
	_element_monthly_active_users_is_set = false;
	_element_category_is_set = false;
	_element_subcategory_is_set = false;
}


// -----------------------------------------------------------------------------
void App_info::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("app_id"))
		throw Xml::XmlException("missing required node in element 'app_info': app_id");
	SetApp_id( atoi(std::string(it["app_id"]).c_str()) );
	if (!it.Exists("api_key"))
		throw Xml::XmlException("missing required node in element 'app_info': api_key");
	SetApi_key( it["api_key"] );
	if (!it.Exists("canvas_name"))
		throw Xml::XmlException("missing required node in element 'app_info': canvas_name");
	SetCanvas_name( it["canvas_name"] );
	if (!it.Exists("display_name"))
		throw Xml::XmlException("missing required node in element 'app_info': display_name");
	SetDisplay_name( it["display_name"] );
	if (!it.Exists("icon_url"))
		throw Xml::XmlException("missing required node in element 'app_info': icon_url");
	SetIcon_url( it["icon_url"] );
	if (!it.Exists("logo_url"))
		throw Xml::XmlException("missing required node in element 'app_info': logo_url");
	SetLogo_url( it["logo_url"] );
	if (!it.Exists("developers"))
		throw Xml::XmlException("missing required node in element 'app_info': developers");
	{
		Xml::XmlNode n(it, "developers");
		if (n)
			_element_developers.FromXml( n );
	}
	if (!it.Exists("company_name"))
		throw Xml::XmlException("missing required node in element 'app_info': company_name");
	SetCompany_name( it["company_name"] );
	if (!it.Exists("description"))
		throw Xml::XmlException("missing required node in element 'app_info': description");
	SetDescription( it["description"] );
	if (!it.Exists("daily_active_users"))
		throw Xml::XmlException("missing required node in element 'app_info': daily_active_users");
	SetDaily_active_users( atoi(std::string(it["daily_active_users"]).c_str()) );
	if (!it.Exists("weekly_active_users"))
		throw Xml::XmlException("missing required node in element 'app_info': weekly_active_users");
	SetWeekly_active_users( atoi(std::string(it["weekly_active_users"]).c_str()) );
	if (!it.Exists("monthly_active_users"))
		throw Xml::XmlException("missing required node in element 'app_info': monthly_active_users");
	SetMonthly_active_users( atoi(std::string(it["monthly_active_users"]).c_str()) );
	if (!it.Exists("category"))
		throw Xml::XmlException("missing required node in element 'app_info': category");
	SetCategory( it["category"] );
	if (!it.Exists("subcategory"))
		throw Xml::XmlException("missing required node in element 'app_info': subcategory");
	SetSubcategory( it["subcategory"] );
}


// -----------------------------------------------------------------------------
const std::string App_info::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<app_id>" + Utility::l2string(_element_app_id) + "</app_id>";
	}
	r += "<api_key>" + _element_api_key + "</api_key>";
	r += "<canvas_name>" + _element_canvas_name + "</canvas_name>";
	r += "<display_name>" + _element_display_name + "</display_name>";
	r += "<icon_url>" + _element_icon_url + "</icon_url>";
	r += "<logo_url>" + _element_logo_url + "</logo_url>";
	r += _element_developers.ToString("developers");
	r += "<company_name>" + _element_company_name + "</company_name>";
	r += "<description>" + _element_description + "</description>";
	{
		r = r + "<daily_active_users>" + Utility::l2string(_element_daily_active_users) + "</daily_active_users>";
	}
	{
		r = r + "<weekly_active_users>" + Utility::l2string(_element_weekly_active_users) + "</weekly_active_users>";
	}
	{
		r = r + "<monthly_active_users>" + Utility::l2string(_element_monthly_active_users) + "</monthly_active_users>";
	}
	r += "<category>" + _element_category + "</category>";
	r += "<subcategory>" + _element_subcategory + "</subcategory>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool App_info::IsSet() const
{
	return App_idIsSet() || Api_keyIsSet() || Canvas_nameIsSet() || Display_nameIsSet() || Icon_urlIsSet() || Logo_urlIsSet() || DevelopersIsSet() || Company_nameIsSet() || DescriptionIsSet() || Daily_active_usersIsSet() || Weekly_active_usersIsSet() || Monthly_active_usersIsSet() || CategoryIsSet() || SubcategoryIsSet();
}


// -----------------------------------------------------------------------------
long App_info::GetApp_id() const
{
	return _element_app_id;
}


void App_info::SetApp_id(long app_id)
{
	_element_app_id = app_id;
	_element_app_id_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& App_info::GetApi_key() const
{
	return _element_api_key;
}


void App_info::SetApi_key(const std::string& api_key)
{
	_element_api_key = api_key;
	_element_api_key_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& App_info::GetCanvas_name() const
{
	return _element_canvas_name;
}


void App_info::SetCanvas_name(const std::string& canvas_name)
{
	_element_canvas_name = canvas_name;
	_element_canvas_name_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& App_info::GetDisplay_name() const
{
	return _element_display_name;
}


void App_info::SetDisplay_name(const std::string& display_name)
{
	_element_display_name = display_name;
	_element_display_name_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& App_info::GetIcon_url() const
{
	return _element_icon_url;
}


void App_info::SetIcon_url(const std::string& icon_url)
{
	_element_icon_url = icon_url;
	_element_icon_url_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& App_info::GetLogo_url() const
{
	return _element_logo_url;
}


void App_info::SetLogo_url(const std::string& logo_url)
{
	_element_logo_url = logo_url;
	_element_logo_url_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::App_info::Developers_t& App_info::GetDevelopers() const
{
	return _element_developers;
}


com_facebook_1_0_::App_info::Developers_t& App_info::GetDevelopers()
{
	return _element_developers;
}


void App_info::SetDevelopers(const com_facebook_1_0_::App_info::Developers_t& developers)
{
	_element_developers = developers;
}


// -----------------------------------------------------------------------------
const std::string& App_info::GetCompany_name() const
{
	return _element_company_name;
}


void App_info::SetCompany_name(const std::string& company_name)
{
	_element_company_name = company_name;
	_element_company_name_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& App_info::GetDescription() const
{
	return _element_description;
}


void App_info::SetDescription(const std::string& description)
{
	_element_description = description;
	_element_description_is_set = true;
}


// -----------------------------------------------------------------------------
int App_info::GetDaily_active_users() const
{
	return _element_daily_active_users;
}


void App_info::SetDaily_active_users(int daily_active_users)
{
	_element_daily_active_users = daily_active_users;
	_element_daily_active_users_is_set = true;
}


// -----------------------------------------------------------------------------
int App_info::GetWeekly_active_users() const
{
	return _element_weekly_active_users;
}


void App_info::SetWeekly_active_users(int weekly_active_users)
{
	_element_weekly_active_users = weekly_active_users;
	_element_weekly_active_users_is_set = true;
}


// -----------------------------------------------------------------------------
int App_info::GetMonthly_active_users() const
{
	return _element_monthly_active_users;
}


void App_info::SetMonthly_active_users(int monthly_active_users)
{
	_element_monthly_active_users = monthly_active_users;
	_element_monthly_active_users_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& App_info::GetCategory() const
{
	return _element_category;
}


void App_info::SetCategory(const std::string& category)
{
	_element_category = category;
	_element_category_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& App_info::GetSubcategory() const
{
	return _element_subcategory;
}


void App_info::SetSubcategory(const std::string& subcategory)
{
	_element_subcategory = subcategory;
	_element_subcategory_is_set = true;
}


// -----------------------------------------------------------------------------
bool App_info::DevelopersIsSet() const
{
	return _element_developers.IsSet();
}


// -----------------------------------------------------------------------------
App_info::Developers_t::Developers_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
App_info::Developers_t::Developers_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void App_info::Developers_t::clear()
{
	while (!_element_developer_info.empty())
		_element_developer_info.erase( _element_developer_info.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void App_info::Developers_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "developer_info");
		while (n)
		{
			com_facebook_1_0_::Developer_info tmp(n);
			_element_developer_info.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string App_info::Developers_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Developer_info>::const_iterator it = _element_developer_info.begin(); it != _element_developer_info.end(); it++)
	{
		const com_facebook_1_0_::Developer_info& ref = *it;
		r += ref.ToString("developer_info");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool App_info::Developers_t::IsSet() const
{
	return Developer_infoIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Developer_info>& App_info::Developers_t::GetDeveloper_info() const
{
	return _element_developer_info;
}


std::list<com_facebook_1_0_::Developer_info>& App_info::Developers_t::GetDeveloper_info()
{
	return _element_developer_info;
}


void App_info::Developers_t::SetDeveloper_info(const std::list<com_facebook_1_0_::Developer_info>& developer_info)
{
	_element_developer_info = developer_info;
}


// -----------------------------------------------------------------------------
bool App_info::Developers_t::Developer_infoIsSet() const
{
	return !_element_developer_info.empty();
}


// -----------------------------------------------------------------------------
bool App_info::Developers_t::GetList() const
{
	return _attribute_list;
}


void App_info::Developers_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Notification_data::Notification_data()
{
}


// -----------------------------------------------------------------------------
Notification_data::Notification_data(const Xml::XmlNode& it)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Notification_data::clear()
{
	_element_notifications.clear();
	_element_apps.clear();
}


// -----------------------------------------------------------------------------
void Notification_data::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("notifications"))
		throw Xml::XmlException("missing required node in element 'notification_data': notifications");
	{
		Xml::XmlNode n(it, "notifications");
		if (n)
			_element_notifications.FromXml( n );
	}
	if (!it.Exists("apps"))
		throw Xml::XmlException("missing required node in element 'notification_data': apps");
	{
		Xml::XmlNode n(it, "apps");
		if (n)
			_element_apps.FromXml( n );
	}
}


// -----------------------------------------------------------------------------
const std::string Notification_data::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += _element_notifications.ToString("notifications");
	r += _element_apps.ToString("apps");
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Notification_data::IsSet() const
{
	return NotificationsIsSet() || AppsIsSet();
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Notification_data::Notifications_t& Notification_data::GetNotifications() const
{
	return _element_notifications;
}


com_facebook_1_0_::Notification_data::Notifications_t& Notification_data::GetNotifications()
{
	return _element_notifications;
}


void Notification_data::SetNotifications(const com_facebook_1_0_::Notification_data::Notifications_t& notifications)
{
	_element_notifications = notifications;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Notification_data::Apps_t& Notification_data::GetApps() const
{
	return _element_apps;
}


com_facebook_1_0_::Notification_data::Apps_t& Notification_data::GetApps()
{
	return _element_apps;
}


void Notification_data::SetApps(const com_facebook_1_0_::Notification_data::Apps_t& apps)
{
	_element_apps = apps;
}


// -----------------------------------------------------------------------------
bool Notification_data::NotificationsIsSet() const
{
	return _element_notifications.IsSet();
}


// -----------------------------------------------------------------------------
bool Notification_data::AppsIsSet() const
{
	return _element_apps.IsSet();
}


// -----------------------------------------------------------------------------
Notification_data::Notifications_t::Notifications_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Notification_data::Notifications_t::Notifications_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Notification_data::Notifications_t::clear()
{
	while (!_element_notification.empty())
		_element_notification.erase( _element_notification.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Notification_data::Notifications_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "notification");
		while (n)
		{
			com_facebook_1_0_::Notification tmp(n);
			_element_notification.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Notification_data::Notifications_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Notification>::const_iterator it = _element_notification.begin(); it != _element_notification.end(); it++)
	{
		const com_facebook_1_0_::Notification& ref = *it;
		r += ref.ToString("notification");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Notification_data::Notifications_t::IsSet() const
{
	return NotificationIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Notification>& Notification_data::Notifications_t::GetNotification() const
{
	return _element_notification;
}


std::list<com_facebook_1_0_::Notification>& Notification_data::Notifications_t::GetNotification()
{
	return _element_notification;
}


void Notification_data::Notifications_t::SetNotification(const std::list<com_facebook_1_0_::Notification>& notification)
{
	_element_notification = notification;
}


// -----------------------------------------------------------------------------
bool Notification_data::Notifications_t::NotificationIsSet() const
{
	return !_element_notification.empty();
}


// -----------------------------------------------------------------------------
bool Notification_data::Notifications_t::GetList() const
{
	return _attribute_list;
}


void Notification_data::Notifications_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Notification_data::Apps_t::Apps_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Notification_data::Apps_t::Apps_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Notification_data::Apps_t::clear()
{
	while (!_element_app_info.empty())
		_element_app_info.erase( _element_app_info.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Notification_data::Apps_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "app_info");
		while (n)
		{
			com_facebook_1_0_::App_info tmp(n);
			_element_app_info.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Notification_data::Apps_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::App_info>::const_iterator it = _element_app_info.begin(); it != _element_app_info.end(); it++)
	{
		const com_facebook_1_0_::App_info& ref = *it;
		r += ref.ToString("app_info");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Notification_data::Apps_t::IsSet() const
{
	return App_infoIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::App_info>& Notification_data::Apps_t::GetApp_info() const
{
	return _element_app_info;
}


std::list<com_facebook_1_0_::App_info>& Notification_data::Apps_t::GetApp_info()
{
	return _element_app_info;
}


void Notification_data::Apps_t::SetApp_info(const std::list<com_facebook_1_0_::App_info>& app_info)
{
	_element_app_info = app_info;
}


// -----------------------------------------------------------------------------
bool Notification_data::Apps_t::App_infoIsSet() const
{
	return !_element_app_info.empty();
}


// -----------------------------------------------------------------------------
bool Notification_data::Apps_t::GetList() const
{
	return _attribute_list;
}


void Notification_data::Apps_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Note::Note()
: _element_note_id_is_set(false)
, _element_title_is_set(false)
, _element_content_is_set(false)
, _element_created_time_is_set(false)
, _element_updated_time_is_set(false)
{
}


// -----------------------------------------------------------------------------
Note::Note(const Xml::XmlNode& it)
: _element_note_id_is_set(false)
, _element_title_is_set(false)
, _element_content_is_set(false)
, _element_created_time_is_set(false)
, _element_updated_time_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Note::clear()
{
	// simpleType:
	// _element_note_id.clear();
	_element_title.clear();
	_element_content.clear();
	// simpleType:
	// _element_created_time.clear();
	// simpleType:
	// _element_updated_time.clear();
	_element_note_id_is_set = false;
	_element_title_is_set = false;
	_element_content_is_set = false;
	_element_created_time_is_set = false;
	_element_updated_time_is_set = false;
}


// -----------------------------------------------------------------------------
void Note::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("note_id"))
		throw Xml::XmlException("missing required node in element 'note': note_id");
	SetNote_id( atoi(std::string(it["note_id"]).c_str()) );
	if (!it.Exists("title"))
		throw Xml::XmlException("missing required node in element 'note': title");
	SetTitle( it["title"] );
	if (!it.Exists("content"))
		throw Xml::XmlException("missing required node in element 'note': content");
	SetContent( it["content"] );
	if (!it.Exists("created_time"))
		throw Xml::XmlException("missing required node in element 'note': created_time");
	SetCreated_time( atoi(std::string(it["created_time"]).c_str()) );
	if (!it.Exists("updated_time"))
		throw Xml::XmlException("missing required node in element 'note': updated_time");
	SetUpdated_time( atoi(std::string(it["updated_time"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Note::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<note_id>" + Utility::l2string(_element_note_id) + "</note_id>";
	}
	r += "<title>" + _element_title + "</title>";
	r += "<content>" + _element_content + "</content>";
	{
		r = r + "<created_time>" + Utility::l2string(_element_created_time) + "</created_time>";
	}
	{
		r = r + "<updated_time>" + Utility::l2string(_element_updated_time) + "</updated_time>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Note::IsSet() const
{
	return Note_idIsSet() || TitleIsSet() || ContentIsSet() || Created_timeIsSet() || Updated_timeIsSet();
}


// -----------------------------------------------------------------------------
long Note::GetNote_id() const
{
	return _element_note_id;
}


void Note::SetNote_id(long note_id)
{
	_element_note_id = note_id;
	_element_note_id_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Note::GetTitle() const
{
	return _element_title;
}


void Note::SetTitle(const std::string& title)
{
	_element_title = title;
	_element_title_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Note::GetContent() const
{
	return _element_content;
}


void Note::SetContent(const std::string& content)
{
	_element_content = content;
	_element_content_is_set = true;
}


// -----------------------------------------------------------------------------
long Note::GetCreated_time() const
{
	return _element_created_time;
}


void Note::SetCreated_time(long created_time)
{
	_element_created_time = created_time;
	_element_created_time_is_set = true;
}


// -----------------------------------------------------------------------------
long Note::GetUpdated_time() const
{
	return _element_updated_time;
}


void Note::SetUpdated_time(long updated_time)
{
	_element_updated_time = updated_time;
	_element_updated_time_is_set = true;
}


// -----------------------------------------------------------------------------
Link::Link()
: _element_link_id_is_set(false)
, _element_owner_is_set(false)
, _element_owner_comment_is_set(false)
, _element_created_time_is_set(false)
, _element_title_is_set(false)
, _element_summary_is_set(false)
, _element_url_is_set(false)
{
}


// -----------------------------------------------------------------------------
Link::Link(const Xml::XmlNode& it)
: _element_link_id_is_set(false)
, _element_owner_is_set(false)
, _element_owner_comment_is_set(false)
, _element_created_time_is_set(false)
, _element_title_is_set(false)
, _element_summary_is_set(false)
, _element_url_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Link::clear()
{
	// simpleType:
	// _element_link_id.clear();
	// simpleType:
	// _element_owner.clear();
	_element_owner_comment.clear();
	// simpleType:
	// _element_created_time.clear();
	_element_title.clear();
	_element_summary.clear();
	_element_url.clear();
	_element_image_urls.clear();
	_element_link_id_is_set = false;
	_element_owner_is_set = false;
	_element_owner_comment_is_set = false;
	_element_created_time_is_set = false;
	_element_title_is_set = false;
	_element_summary_is_set = false;
	_element_url_is_set = false;
}


// -----------------------------------------------------------------------------
void Link::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("link_id"))
		throw Xml::XmlException("missing required node in element 'link': link_id");
	SetLink_id( atoi(std::string(it["link_id"]).c_str()) );
	if (!it.Exists("owner"))
		throw Xml::XmlException("missing required node in element 'link': owner");
	SetOwner( atoi(std::string(it["owner"]).c_str()) );
	if (!it.Exists("owner_comment"))
		throw Xml::XmlException("missing required node in element 'link': owner_comment");
	SetOwner_comment( it["owner_comment"] );
	if (!it.Exists("created_time"))
		throw Xml::XmlException("missing required node in element 'link': created_time");
	SetCreated_time( atoi(std::string(it["created_time"]).c_str()) );
	if (!it.Exists("title"))
		throw Xml::XmlException("missing required node in element 'link': title");
	SetTitle( it["title"] );
	if (!it.Exists("summary"))
		throw Xml::XmlException("missing required node in element 'link': summary");
	SetSummary( it["summary"] );
	if (!it.Exists("url"))
		throw Xml::XmlException("missing required node in element 'link': url");
	SetUrl( it["url"] );
	if (!it.Exists("image_urls"))
		throw Xml::XmlException("missing required node in element 'link': image_urls");
	{
		Xml::XmlNode n(it, "image_urls");
		if (n)
			_element_image_urls.FromXml( n );
	}
}


// -----------------------------------------------------------------------------
const std::string Link::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<link_id>" + Utility::l2string(_element_link_id) + "</link_id>";
	}
	{
		r = r + "<owner>" + Utility::l2string(_element_owner) + "</owner>";
	}
	r += "<owner_comment>" + _element_owner_comment + "</owner_comment>";
	{
		r = r + "<created_time>" + Utility::l2string(_element_created_time) + "</created_time>";
	}
	r += "<title>" + _element_title + "</title>";
	r += "<summary>" + _element_summary + "</summary>";
	r += "<url>" + _element_url + "</url>";
	r += _element_image_urls.ToString("image_urls");
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Link::IsSet() const
{
	return Link_idIsSet() || OwnerIsSet() || Owner_commentIsSet() || Created_timeIsSet() || TitleIsSet() || SummaryIsSet() || UrlIsSet() || Image_urlsIsSet();
}


// -----------------------------------------------------------------------------
long Link::GetLink_id() const
{
	return _element_link_id;
}


void Link::SetLink_id(long link_id)
{
	_element_link_id = link_id;
	_element_link_id_is_set = true;
}


// -----------------------------------------------------------------------------
long Link::GetOwner() const
{
	return _element_owner;
}


void Link::SetOwner(long owner)
{
	_element_owner = owner;
	_element_owner_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Link::GetOwner_comment() const
{
	return _element_owner_comment;
}


void Link::SetOwner_comment(const std::string& owner_comment)
{
	_element_owner_comment = owner_comment;
	_element_owner_comment_is_set = true;
}


// -----------------------------------------------------------------------------
long Link::GetCreated_time() const
{
	return _element_created_time;
}


void Link::SetCreated_time(long created_time)
{
	_element_created_time = created_time;
	_element_created_time_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Link::GetTitle() const
{
	return _element_title;
}


void Link::SetTitle(const std::string& title)
{
	_element_title = title;
	_element_title_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Link::GetSummary() const
{
	return _element_summary;
}


void Link::SetSummary(const std::string& summary)
{
	_element_summary = summary;
	_element_summary_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Link::GetUrl() const
{
	return _element_url;
}


void Link::SetUrl(const std::string& url)
{
	_element_url = url;
	_element_url_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Link::Image_urls_t& Link::GetImage_urls() const
{
	return _element_image_urls;
}


com_facebook_1_0_::Link::Image_urls_t& Link::GetImage_urls()
{
	return _element_image_urls;
}


void Link::SetImage_urls(const com_facebook_1_0_::Link::Image_urls_t& image_urls)
{
	_element_image_urls = image_urls;
}


// -----------------------------------------------------------------------------
bool Link::Image_urlsIsSet() const
{
	return _element_image_urls.IsSet();
}


// -----------------------------------------------------------------------------
Link::Image_urls_t::Image_urls_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Link::Image_urls_t::Image_urls_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Link::Image_urls_t::clear()
{
	while (!_element_image_urls_elt.empty())
		_element_image_urls_elt.erase( _element_image_urls_elt.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Link::Image_urls_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "image_urls_elt");
		while (n)
		{
			_element_image_urls_elt.push_back( n.GetContent() );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Link::Image_urls_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<std::string>::const_iterator it = _element_image_urls_elt.begin(); it != _element_image_urls_elt.end(); it++)
	{
		r += "<image_urls_elt>" + *it + "</image_urls_elt>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Link::Image_urls_t::IsSet() const
{
	return Image_urls_eltIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<std::string>& Link::Image_urls_t::GetImage_urls_elt() const
{
	return _element_image_urls_elt;
}


std::list<std::string>& Link::Image_urls_t::GetImage_urls_elt()
{
	return _element_image_urls_elt;
}


void Link::Image_urls_t::SetImage_urls_elt(const std::list<std::string>& image_urls_elt)
{
	_element_image_urls_elt = image_urls_elt;
}


// -----------------------------------------------------------------------------
bool Link::Image_urls_t::Image_urls_eltIsSet() const
{
	return !_element_image_urls_elt.empty();
}


// -----------------------------------------------------------------------------
bool Link::Image_urls_t::GetList() const
{
	return _attribute_list;
}


void Link::Image_urls_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Metrics::Metrics()
: _element_active_users(0)
, _element_api_calls(0)
, _element_unique_api_calls(0)
, _element_canvas_page_views(0)
, _element_unique_canvas_page_views(0)
, _element_canvas_http_request_time_avg(0)
, _element_canvas_fbml_render_time_avg(0)
, _element_unique_adds(0)
, _element_unique_removes(0)
, _element_unique_blocks(0)
, _element_unique_unblocks(0)
, _element_canvas_page_views_http_code_0(0)
, _element_canvas_page_views_http_code_100(0)
, _element_canvas_page_views_http_code_200(0)
, _element_canvas_page_views_http_code_200ND(0)
, _element_canvas_page_views_http_code_301(0)
, _element_canvas_page_views_http_code_302(0)
, _element_canvas_page_views_http_code_303(0)
, _element_canvas_page_views_http_code_400(0)
, _element_canvas_page_views_http_code_401(0)
, _element_canvas_page_views_http_code_402(0)
, _element_canvas_page_views_http_code_403(0)
, _element_canvas_page_views_http_code_404(0)
, _element_canvas_page_views_http_code_405(0)
, _element_canvas_page_views_http_code_413(0)
, _element_canvas_page_views_http_code_422(0)
, _element_canvas_page_views_http_code_500(0)
, _element_canvas_page_views_http_code_502(0)
, _element_canvas_page_views_http_code_503(0)
, _element_canvas_page_views_http_code_505(0)
, _element_feedform_impression(0)
, _element_feedform_publish(0)
, _element_end_time_is_set(false)
, _element_active_users_is_set(false)
, _element_api_calls_is_set(false)
, _element_unique_api_calls_is_set(false)
, _element_canvas_page_views_is_set(false)
, _element_unique_canvas_page_views_is_set(false)
, _element_canvas_http_request_time_avg_is_set(false)
, _element_canvas_fbml_render_time_avg_is_set(false)
, _element_unique_adds_is_set(false)
, _element_unique_removes_is_set(false)
, _element_unique_blocks_is_set(false)
, _element_unique_unblocks_is_set(false)
, _element_canvas_page_views_http_code_0_is_set(false)
, _element_canvas_page_views_http_code_100_is_set(false)
, _element_canvas_page_views_http_code_200_is_set(false)
, _element_canvas_page_views_http_code_200ND_is_set(false)
, _element_canvas_page_views_http_code_301_is_set(false)
, _element_canvas_page_views_http_code_302_is_set(false)
, _element_canvas_page_views_http_code_303_is_set(false)
, _element_canvas_page_views_http_code_400_is_set(false)
, _element_canvas_page_views_http_code_401_is_set(false)
, _element_canvas_page_views_http_code_402_is_set(false)
, _element_canvas_page_views_http_code_403_is_set(false)
, _element_canvas_page_views_http_code_404_is_set(false)
, _element_canvas_page_views_http_code_405_is_set(false)
, _element_canvas_page_views_http_code_413_is_set(false)
, _element_canvas_page_views_http_code_422_is_set(false)
, _element_canvas_page_views_http_code_500_is_set(false)
, _element_canvas_page_views_http_code_502_is_set(false)
, _element_canvas_page_views_http_code_503_is_set(false)
, _element_canvas_page_views_http_code_505_is_set(false)
, _element_feedform_impression_is_set(false)
, _element_feedform_publish_is_set(false)
{
}


// -----------------------------------------------------------------------------
Metrics::Metrics(const Xml::XmlNode& it)
: _element_active_users(0)
, _element_api_calls(0)
, _element_unique_api_calls(0)
, _element_canvas_page_views(0)
, _element_unique_canvas_page_views(0)
, _element_canvas_http_request_time_avg(0)
, _element_canvas_fbml_render_time_avg(0)
, _element_unique_adds(0)
, _element_unique_removes(0)
, _element_unique_blocks(0)
, _element_unique_unblocks(0)
, _element_canvas_page_views_http_code_0(0)
, _element_canvas_page_views_http_code_100(0)
, _element_canvas_page_views_http_code_200(0)
, _element_canvas_page_views_http_code_200ND(0)
, _element_canvas_page_views_http_code_301(0)
, _element_canvas_page_views_http_code_302(0)
, _element_canvas_page_views_http_code_303(0)
, _element_canvas_page_views_http_code_400(0)
, _element_canvas_page_views_http_code_401(0)
, _element_canvas_page_views_http_code_402(0)
, _element_canvas_page_views_http_code_403(0)
, _element_canvas_page_views_http_code_404(0)
, _element_canvas_page_views_http_code_405(0)
, _element_canvas_page_views_http_code_413(0)
, _element_canvas_page_views_http_code_422(0)
, _element_canvas_page_views_http_code_500(0)
, _element_canvas_page_views_http_code_502(0)
, _element_canvas_page_views_http_code_503(0)
, _element_canvas_page_views_http_code_505(0)
, _element_feedform_impression(0)
, _element_feedform_publish(0)
, _element_end_time_is_set(false)
, _element_active_users_is_set(false)
, _element_api_calls_is_set(false)
, _element_unique_api_calls_is_set(false)
, _element_canvas_page_views_is_set(false)
, _element_unique_canvas_page_views_is_set(false)
, _element_canvas_http_request_time_avg_is_set(false)
, _element_canvas_fbml_render_time_avg_is_set(false)
, _element_unique_adds_is_set(false)
, _element_unique_removes_is_set(false)
, _element_unique_blocks_is_set(false)
, _element_unique_unblocks_is_set(false)
, _element_canvas_page_views_http_code_0_is_set(false)
, _element_canvas_page_views_http_code_100_is_set(false)
, _element_canvas_page_views_http_code_200_is_set(false)
, _element_canvas_page_views_http_code_200ND_is_set(false)
, _element_canvas_page_views_http_code_301_is_set(false)
, _element_canvas_page_views_http_code_302_is_set(false)
, _element_canvas_page_views_http_code_303_is_set(false)
, _element_canvas_page_views_http_code_400_is_set(false)
, _element_canvas_page_views_http_code_401_is_set(false)
, _element_canvas_page_views_http_code_402_is_set(false)
, _element_canvas_page_views_http_code_403_is_set(false)
, _element_canvas_page_views_http_code_404_is_set(false)
, _element_canvas_page_views_http_code_405_is_set(false)
, _element_canvas_page_views_http_code_413_is_set(false)
, _element_canvas_page_views_http_code_422_is_set(false)
, _element_canvas_page_views_http_code_500_is_set(false)
, _element_canvas_page_views_http_code_502_is_set(false)
, _element_canvas_page_views_http_code_503_is_set(false)
, _element_canvas_page_views_http_code_505_is_set(false)
, _element_feedform_impression_is_set(false)
, _element_feedform_publish_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Metrics::clear()
{
	// simpleType:
	// _element_end_time.clear();
	_element_active_users = 0;
	_element_api_calls = 0;
	_element_unique_api_calls = 0;
	_element_canvas_page_views = 0;
	_element_unique_canvas_page_views = 0;
	_element_canvas_http_request_time_avg = 0;
	_element_canvas_fbml_render_time_avg = 0;
	_element_unique_adds = 0;
	_element_unique_removes = 0;
	_element_unique_blocks = 0;
	_element_unique_unblocks = 0;
	_element_canvas_page_views_http_code_0 = 0;
	_element_canvas_page_views_http_code_100 = 0;
	_element_canvas_page_views_http_code_200 = 0;
	_element_canvas_page_views_http_code_200ND = 0;
	_element_canvas_page_views_http_code_301 = 0;
	_element_canvas_page_views_http_code_302 = 0;
	_element_canvas_page_views_http_code_303 = 0;
	_element_canvas_page_views_http_code_400 = 0;
	_element_canvas_page_views_http_code_401 = 0;
	_element_canvas_page_views_http_code_402 = 0;
	_element_canvas_page_views_http_code_403 = 0;
	_element_canvas_page_views_http_code_404 = 0;
	_element_canvas_page_views_http_code_405 = 0;
	_element_canvas_page_views_http_code_413 = 0;
	_element_canvas_page_views_http_code_422 = 0;
	_element_canvas_page_views_http_code_500 = 0;
	_element_canvas_page_views_http_code_502 = 0;
	_element_canvas_page_views_http_code_503 = 0;
	_element_canvas_page_views_http_code_505 = 0;
	_element_feedform_impression = 0;
	_element_feedform_publish = 0;
	_element_end_time_is_set = false;
	_element_active_users_is_set = false;
	_element_api_calls_is_set = false;
	_element_unique_api_calls_is_set = false;
	_element_canvas_page_views_is_set = false;
	_element_unique_canvas_page_views_is_set = false;
	_element_canvas_http_request_time_avg_is_set = false;
	_element_canvas_fbml_render_time_avg_is_set = false;
	_element_unique_adds_is_set = false;
	_element_unique_removes_is_set = false;
	_element_unique_blocks_is_set = false;
	_element_unique_unblocks_is_set = false;
	_element_canvas_page_views_http_code_0_is_set = false;
	_element_canvas_page_views_http_code_100_is_set = false;
	_element_canvas_page_views_http_code_200_is_set = false;
	_element_canvas_page_views_http_code_200ND_is_set = false;
	_element_canvas_page_views_http_code_301_is_set = false;
	_element_canvas_page_views_http_code_302_is_set = false;
	_element_canvas_page_views_http_code_303_is_set = false;
	_element_canvas_page_views_http_code_400_is_set = false;
	_element_canvas_page_views_http_code_401_is_set = false;
	_element_canvas_page_views_http_code_402_is_set = false;
	_element_canvas_page_views_http_code_403_is_set = false;
	_element_canvas_page_views_http_code_404_is_set = false;
	_element_canvas_page_views_http_code_405_is_set = false;
	_element_canvas_page_views_http_code_413_is_set = false;
	_element_canvas_page_views_http_code_422_is_set = false;
	_element_canvas_page_views_http_code_500_is_set = false;
	_element_canvas_page_views_http_code_502_is_set = false;
	_element_canvas_page_views_http_code_503_is_set = false;
	_element_canvas_page_views_http_code_505_is_set = false;
	_element_feedform_impression_is_set = false;
	_element_feedform_publish_is_set = false;
}


// -----------------------------------------------------------------------------
void Metrics::FromXml(const Xml::XmlNode& it)
{
	if (it.Exists("end_time"))
		SetEnd_time( atoi(std::string(it["end_time"]).c_str()) );
	if (it.Exists("active_users"))
		SetActive_users( atoi(std::string(it["active_users"]).c_str()) );
	if (it.Exists("api_calls"))
		SetApi_calls( atoi(std::string(it["api_calls"]).c_str()) );
	if (it.Exists("unique_api_calls"))
		SetUnique_api_calls( atoi(std::string(it["unique_api_calls"]).c_str()) );
	if (it.Exists("canvas_page_views"))
		SetCanvas_page_views( atoi(std::string(it["canvas_page_views"]).c_str()) );
	if (it.Exists("unique_canvas_page_views"))
		SetUnique_canvas_page_views( atoi(std::string(it["unique_canvas_page_views"]).c_str()) );
	if (it.Exists("canvas_http_request_time_avg"))
		SetCanvas_http_request_time_avg( atoi(std::string(it["canvas_http_request_time_avg"]).c_str()) );
	if (it.Exists("canvas_fbml_render_time_avg"))
		SetCanvas_fbml_render_time_avg( atoi(std::string(it["canvas_fbml_render_time_avg"]).c_str()) );
	if (it.Exists("unique_adds"))
		SetUnique_adds( atoi(std::string(it["unique_adds"]).c_str()) );
	if (it.Exists("unique_removes"))
		SetUnique_removes( atoi(std::string(it["unique_removes"]).c_str()) );
	if (it.Exists("unique_blocks"))
		SetUnique_blocks( atoi(std::string(it["unique_blocks"]).c_str()) );
	if (it.Exists("unique_unblocks"))
		SetUnique_unblocks( atoi(std::string(it["unique_unblocks"]).c_str()) );
	if (it.Exists("canvas_page_views_http_code_0"))
		SetCanvas_page_views_http_code_0( atoi(std::string(it["canvas_page_views_http_code_0"]).c_str()) );
	if (it.Exists("canvas_page_views_http_code_100"))
		SetCanvas_page_views_http_code_100( atoi(std::string(it["canvas_page_views_http_code_100"]).c_str()) );
	if (it.Exists("canvas_page_views_http_code_200"))
		SetCanvas_page_views_http_code_200( atoi(std::string(it["canvas_page_views_http_code_200"]).c_str()) );
	if (it.Exists("canvas_page_views_http_code_200ND"))
		SetCanvas_page_views_http_code_200ND( atoi(std::string(it["canvas_page_views_http_code_200ND"]).c_str()) );
	if (it.Exists("canvas_page_views_http_code_301"))
		SetCanvas_page_views_http_code_301( atoi(std::string(it["canvas_page_views_http_code_301"]).c_str()) );
	if (it.Exists("canvas_page_views_http_code_302"))
		SetCanvas_page_views_http_code_302( atoi(std::string(it["canvas_page_views_http_code_302"]).c_str()) );
	if (it.Exists("canvas_page_views_http_code_303"))
		SetCanvas_page_views_http_code_303( atoi(std::string(it["canvas_page_views_http_code_303"]).c_str()) );
	if (it.Exists("canvas_page_views_http_code_400"))
		SetCanvas_page_views_http_code_400( atoi(std::string(it["canvas_page_views_http_code_400"]).c_str()) );
	if (it.Exists("canvas_page_views_http_code_401"))
		SetCanvas_page_views_http_code_401( atoi(std::string(it["canvas_page_views_http_code_401"]).c_str()) );
	if (it.Exists("canvas_page_views_http_code_402"))
		SetCanvas_page_views_http_code_402( atoi(std::string(it["canvas_page_views_http_code_402"]).c_str()) );
	if (it.Exists("canvas_page_views_http_code_403"))
		SetCanvas_page_views_http_code_403( atoi(std::string(it["canvas_page_views_http_code_403"]).c_str()) );
	if (it.Exists("canvas_page_views_http_code_404"))
		SetCanvas_page_views_http_code_404( atoi(std::string(it["canvas_page_views_http_code_404"]).c_str()) );
	if (it.Exists("canvas_page_views_http_code_405"))
		SetCanvas_page_views_http_code_405( atoi(std::string(it["canvas_page_views_http_code_405"]).c_str()) );
	if (it.Exists("canvas_page_views_http_code_413"))
		SetCanvas_page_views_http_code_413( atoi(std::string(it["canvas_page_views_http_code_413"]).c_str()) );
	if (it.Exists("canvas_page_views_http_code_422"))
		SetCanvas_page_views_http_code_422( atoi(std::string(it["canvas_page_views_http_code_422"]).c_str()) );
	if (it.Exists("canvas_page_views_http_code_500"))
		SetCanvas_page_views_http_code_500( atoi(std::string(it["canvas_page_views_http_code_500"]).c_str()) );
	if (it.Exists("canvas_page_views_http_code_502"))
		SetCanvas_page_views_http_code_502( atoi(std::string(it["canvas_page_views_http_code_502"]).c_str()) );
	if (it.Exists("canvas_page_views_http_code_503"))
		SetCanvas_page_views_http_code_503( atoi(std::string(it["canvas_page_views_http_code_503"]).c_str()) );
	if (it.Exists("canvas_page_views_http_code_505"))
		SetCanvas_page_views_http_code_505( atoi(std::string(it["canvas_page_views_http_code_505"]).c_str()) );
	if (it.Exists("feedform_impression"))
		SetFeedform_impression( atoi(std::string(it["feedform_impression"]).c_str()) );
	if (it.Exists("feedform_publish"))
		SetFeedform_publish( atoi(std::string(it["feedform_publish"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Metrics::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	if (_element_end_time_is_set)
	{
		r = r + "<end_time>" + Utility::l2string(_element_end_time) + "</end_time>";
	}
	if (_element_active_users_is_set)
	{
		r = r + "<active_users>" + Utility::l2string(_element_active_users) + "</active_users>";
	}
	if (_element_api_calls_is_set)
	{
		r = r + "<api_calls>" + Utility::l2string(_element_api_calls) + "</api_calls>";
	}
	if (_element_unique_api_calls_is_set)
	{
		r = r + "<unique_api_calls>" + Utility::l2string(_element_unique_api_calls) + "</unique_api_calls>";
	}
	if (_element_canvas_page_views_is_set)
	{
		r = r + "<canvas_page_views>" + Utility::l2string(_element_canvas_page_views) + "</canvas_page_views>";
	}
	if (_element_unique_canvas_page_views_is_set)
	{
		r = r + "<unique_canvas_page_views>" + Utility::l2string(_element_unique_canvas_page_views) + "</unique_canvas_page_views>";
	}
	if (_element_canvas_http_request_time_avg_is_set)
	{
		r = r + "<canvas_http_request_time_avg>" + Utility::l2string(_element_canvas_http_request_time_avg) + "</canvas_http_request_time_avg>";
	}
	if (_element_canvas_fbml_render_time_avg_is_set)
	{
		r = r + "<canvas_fbml_render_time_avg>" + Utility::l2string(_element_canvas_fbml_render_time_avg) + "</canvas_fbml_render_time_avg>";
	}
	if (_element_unique_adds_is_set)
	{
		r = r + "<unique_adds>" + Utility::l2string(_element_unique_adds) + "</unique_adds>";
	}
	if (_element_unique_removes_is_set)
	{
		r = r + "<unique_removes>" + Utility::l2string(_element_unique_removes) + "</unique_removes>";
	}
	if (_element_unique_blocks_is_set)
	{
		r = r + "<unique_blocks>" + Utility::l2string(_element_unique_blocks) + "</unique_blocks>";
	}
	if (_element_unique_unblocks_is_set)
	{
		r = r + "<unique_unblocks>" + Utility::l2string(_element_unique_unblocks) + "</unique_unblocks>";
	}
	if (_element_canvas_page_views_http_code_0_is_set)
	{
		r = r + "<canvas_page_views_http_code_0>" + Utility::l2string(_element_canvas_page_views_http_code_0) + "</canvas_page_views_http_code_0>";
	}
	if (_element_canvas_page_views_http_code_100_is_set)
	{
		r = r + "<canvas_page_views_http_code_100>" + Utility::l2string(_element_canvas_page_views_http_code_100) + "</canvas_page_views_http_code_100>";
	}
	if (_element_canvas_page_views_http_code_200_is_set)
	{
		r = r + "<canvas_page_views_http_code_200>" + Utility::l2string(_element_canvas_page_views_http_code_200) + "</canvas_page_views_http_code_200>";
	}
	if (_element_canvas_page_views_http_code_200ND_is_set)
	{
		r = r + "<canvas_page_views_http_code_200ND>" + Utility::l2string(_element_canvas_page_views_http_code_200ND) + "</canvas_page_views_http_code_200ND>";
	}
	if (_element_canvas_page_views_http_code_301_is_set)
	{
		r = r + "<canvas_page_views_http_code_301>" + Utility::l2string(_element_canvas_page_views_http_code_301) + "</canvas_page_views_http_code_301>";
	}
	if (_element_canvas_page_views_http_code_302_is_set)
	{
		r = r + "<canvas_page_views_http_code_302>" + Utility::l2string(_element_canvas_page_views_http_code_302) + "</canvas_page_views_http_code_302>";
	}
	if (_element_canvas_page_views_http_code_303_is_set)
	{
		r = r + "<canvas_page_views_http_code_303>" + Utility::l2string(_element_canvas_page_views_http_code_303) + "</canvas_page_views_http_code_303>";
	}
	if (_element_canvas_page_views_http_code_400_is_set)
	{
		r = r + "<canvas_page_views_http_code_400>" + Utility::l2string(_element_canvas_page_views_http_code_400) + "</canvas_page_views_http_code_400>";
	}
	if (_element_canvas_page_views_http_code_401_is_set)
	{
		r = r + "<canvas_page_views_http_code_401>" + Utility::l2string(_element_canvas_page_views_http_code_401) + "</canvas_page_views_http_code_401>";
	}
	if (_element_canvas_page_views_http_code_402_is_set)
	{
		r = r + "<canvas_page_views_http_code_402>" + Utility::l2string(_element_canvas_page_views_http_code_402) + "</canvas_page_views_http_code_402>";
	}
	if (_element_canvas_page_views_http_code_403_is_set)
	{
		r = r + "<canvas_page_views_http_code_403>" + Utility::l2string(_element_canvas_page_views_http_code_403) + "</canvas_page_views_http_code_403>";
	}
	if (_element_canvas_page_views_http_code_404_is_set)
	{
		r = r + "<canvas_page_views_http_code_404>" + Utility::l2string(_element_canvas_page_views_http_code_404) + "</canvas_page_views_http_code_404>";
	}
	if (_element_canvas_page_views_http_code_405_is_set)
	{
		r = r + "<canvas_page_views_http_code_405>" + Utility::l2string(_element_canvas_page_views_http_code_405) + "</canvas_page_views_http_code_405>";
	}
	if (_element_canvas_page_views_http_code_413_is_set)
	{
		r = r + "<canvas_page_views_http_code_413>" + Utility::l2string(_element_canvas_page_views_http_code_413) + "</canvas_page_views_http_code_413>";
	}
	if (_element_canvas_page_views_http_code_422_is_set)
	{
		r = r + "<canvas_page_views_http_code_422>" + Utility::l2string(_element_canvas_page_views_http_code_422) + "</canvas_page_views_http_code_422>";
	}
	if (_element_canvas_page_views_http_code_500_is_set)
	{
		r = r + "<canvas_page_views_http_code_500>" + Utility::l2string(_element_canvas_page_views_http_code_500) + "</canvas_page_views_http_code_500>";
	}
	if (_element_canvas_page_views_http_code_502_is_set)
	{
		r = r + "<canvas_page_views_http_code_502>" + Utility::l2string(_element_canvas_page_views_http_code_502) + "</canvas_page_views_http_code_502>";
	}
	if (_element_canvas_page_views_http_code_503_is_set)
	{
		r = r + "<canvas_page_views_http_code_503>" + Utility::l2string(_element_canvas_page_views_http_code_503) + "</canvas_page_views_http_code_503>";
	}
	if (_element_canvas_page_views_http_code_505_is_set)
	{
		r = r + "<canvas_page_views_http_code_505>" + Utility::l2string(_element_canvas_page_views_http_code_505) + "</canvas_page_views_http_code_505>";
	}
	if (_element_feedform_impression_is_set)
	{
		r = r + "<feedform_impression>" + Utility::l2string(_element_feedform_impression) + "</feedform_impression>";
	}
	if (_element_feedform_publish_is_set)
	{
		r = r + "<feedform_publish>" + Utility::l2string(_element_feedform_publish) + "</feedform_publish>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Metrics::IsSet() const
{
	return End_timeIsSet() || Active_usersIsSet() || Api_callsIsSet() || Unique_api_callsIsSet() || Canvas_page_viewsIsSet() || Unique_canvas_page_viewsIsSet() || Canvas_http_request_time_avgIsSet() || Canvas_fbml_render_time_avgIsSet() || Unique_addsIsSet() || Unique_removesIsSet() || Unique_blocksIsSet() || Unique_unblocksIsSet() || Canvas_page_views_http_code_0IsSet() || Canvas_page_views_http_code_100IsSet() || Canvas_page_views_http_code_200IsSet() || Canvas_page_views_http_code_200NDIsSet() || Canvas_page_views_http_code_301IsSet() || Canvas_page_views_http_code_302IsSet() || Canvas_page_views_http_code_303IsSet() || Canvas_page_views_http_code_400IsSet() || Canvas_page_views_http_code_401IsSet() || Canvas_page_views_http_code_402IsSet() || Canvas_page_views_http_code_403IsSet() || Canvas_page_views_http_code_404IsSet() || Canvas_page_views_http_code_405IsSet() || Canvas_page_views_http_code_413IsSet() || Canvas_page_views_http_code_422IsSet() || Canvas_page_views_http_code_500IsSet() || Canvas_page_views_http_code_502IsSet() || Canvas_page_views_http_code_503IsSet() || Canvas_page_views_http_code_505IsSet() || Feedform_impressionIsSet() || Feedform_publishIsSet();
}


// -----------------------------------------------------------------------------
long Metrics::GetEnd_time() const
{
	return _element_end_time;
}


void Metrics::SetEnd_time(long end_time)
{
	_element_end_time = end_time;
	_element_end_time_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetActive_users() const
{
	return _element_active_users;
}


void Metrics::SetActive_users(int active_users)
{
	_element_active_users = active_users;
	_element_active_users_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetApi_calls() const
{
	return _element_api_calls;
}


void Metrics::SetApi_calls(int api_calls)
{
	_element_api_calls = api_calls;
	_element_api_calls_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetUnique_api_calls() const
{
	return _element_unique_api_calls;
}


void Metrics::SetUnique_api_calls(int unique_api_calls)
{
	_element_unique_api_calls = unique_api_calls;
	_element_unique_api_calls_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetCanvas_page_views() const
{
	return _element_canvas_page_views;
}


void Metrics::SetCanvas_page_views(int canvas_page_views)
{
	_element_canvas_page_views = canvas_page_views;
	_element_canvas_page_views_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetUnique_canvas_page_views() const
{
	return _element_unique_canvas_page_views;
}


void Metrics::SetUnique_canvas_page_views(int unique_canvas_page_views)
{
	_element_unique_canvas_page_views = unique_canvas_page_views;
	_element_unique_canvas_page_views_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetCanvas_http_request_time_avg() const
{
	return _element_canvas_http_request_time_avg;
}


void Metrics::SetCanvas_http_request_time_avg(int canvas_http_request_time_avg)
{
	_element_canvas_http_request_time_avg = canvas_http_request_time_avg;
	_element_canvas_http_request_time_avg_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetCanvas_fbml_render_time_avg() const
{
	return _element_canvas_fbml_render_time_avg;
}


void Metrics::SetCanvas_fbml_render_time_avg(int canvas_fbml_render_time_avg)
{
	_element_canvas_fbml_render_time_avg = canvas_fbml_render_time_avg;
	_element_canvas_fbml_render_time_avg_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetUnique_adds() const
{
	return _element_unique_adds;
}


void Metrics::SetUnique_adds(int unique_adds)
{
	_element_unique_adds = unique_adds;
	_element_unique_adds_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetUnique_removes() const
{
	return _element_unique_removes;
}


void Metrics::SetUnique_removes(int unique_removes)
{
	_element_unique_removes = unique_removes;
	_element_unique_removes_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetUnique_blocks() const
{
	return _element_unique_blocks;
}


void Metrics::SetUnique_blocks(int unique_blocks)
{
	_element_unique_blocks = unique_blocks;
	_element_unique_blocks_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetUnique_unblocks() const
{
	return _element_unique_unblocks;
}


void Metrics::SetUnique_unblocks(int unique_unblocks)
{
	_element_unique_unblocks = unique_unblocks;
	_element_unique_unblocks_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetCanvas_page_views_http_code_0() const
{
	return _element_canvas_page_views_http_code_0;
}


void Metrics::SetCanvas_page_views_http_code_0(int canvas_page_views_http_code_0)
{
	_element_canvas_page_views_http_code_0 = canvas_page_views_http_code_0;
	_element_canvas_page_views_http_code_0_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetCanvas_page_views_http_code_100() const
{
	return _element_canvas_page_views_http_code_100;
}


void Metrics::SetCanvas_page_views_http_code_100(int canvas_page_views_http_code_100)
{
	_element_canvas_page_views_http_code_100 = canvas_page_views_http_code_100;
	_element_canvas_page_views_http_code_100_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetCanvas_page_views_http_code_200() const
{
	return _element_canvas_page_views_http_code_200;
}


void Metrics::SetCanvas_page_views_http_code_200(int canvas_page_views_http_code_200)
{
	_element_canvas_page_views_http_code_200 = canvas_page_views_http_code_200;
	_element_canvas_page_views_http_code_200_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetCanvas_page_views_http_code_200ND() const
{
	return _element_canvas_page_views_http_code_200ND;
}


void Metrics::SetCanvas_page_views_http_code_200ND(int canvas_page_views_http_code_200ND)
{
	_element_canvas_page_views_http_code_200ND = canvas_page_views_http_code_200ND;
	_element_canvas_page_views_http_code_200ND_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetCanvas_page_views_http_code_301() const
{
	return _element_canvas_page_views_http_code_301;
}


void Metrics::SetCanvas_page_views_http_code_301(int canvas_page_views_http_code_301)
{
	_element_canvas_page_views_http_code_301 = canvas_page_views_http_code_301;
	_element_canvas_page_views_http_code_301_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetCanvas_page_views_http_code_302() const
{
	return _element_canvas_page_views_http_code_302;
}


void Metrics::SetCanvas_page_views_http_code_302(int canvas_page_views_http_code_302)
{
	_element_canvas_page_views_http_code_302 = canvas_page_views_http_code_302;
	_element_canvas_page_views_http_code_302_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetCanvas_page_views_http_code_303() const
{
	return _element_canvas_page_views_http_code_303;
}


void Metrics::SetCanvas_page_views_http_code_303(int canvas_page_views_http_code_303)
{
	_element_canvas_page_views_http_code_303 = canvas_page_views_http_code_303;
	_element_canvas_page_views_http_code_303_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetCanvas_page_views_http_code_400() const
{
	return _element_canvas_page_views_http_code_400;
}


void Metrics::SetCanvas_page_views_http_code_400(int canvas_page_views_http_code_400)
{
	_element_canvas_page_views_http_code_400 = canvas_page_views_http_code_400;
	_element_canvas_page_views_http_code_400_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetCanvas_page_views_http_code_401() const
{
	return _element_canvas_page_views_http_code_401;
}


void Metrics::SetCanvas_page_views_http_code_401(int canvas_page_views_http_code_401)
{
	_element_canvas_page_views_http_code_401 = canvas_page_views_http_code_401;
	_element_canvas_page_views_http_code_401_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetCanvas_page_views_http_code_402() const
{
	return _element_canvas_page_views_http_code_402;
}


void Metrics::SetCanvas_page_views_http_code_402(int canvas_page_views_http_code_402)
{
	_element_canvas_page_views_http_code_402 = canvas_page_views_http_code_402;
	_element_canvas_page_views_http_code_402_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetCanvas_page_views_http_code_403() const
{
	return _element_canvas_page_views_http_code_403;
}


void Metrics::SetCanvas_page_views_http_code_403(int canvas_page_views_http_code_403)
{
	_element_canvas_page_views_http_code_403 = canvas_page_views_http_code_403;
	_element_canvas_page_views_http_code_403_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetCanvas_page_views_http_code_404() const
{
	return _element_canvas_page_views_http_code_404;
}


void Metrics::SetCanvas_page_views_http_code_404(int canvas_page_views_http_code_404)
{
	_element_canvas_page_views_http_code_404 = canvas_page_views_http_code_404;
	_element_canvas_page_views_http_code_404_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetCanvas_page_views_http_code_405() const
{
	return _element_canvas_page_views_http_code_405;
}


void Metrics::SetCanvas_page_views_http_code_405(int canvas_page_views_http_code_405)
{
	_element_canvas_page_views_http_code_405 = canvas_page_views_http_code_405;
	_element_canvas_page_views_http_code_405_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetCanvas_page_views_http_code_413() const
{
	return _element_canvas_page_views_http_code_413;
}


void Metrics::SetCanvas_page_views_http_code_413(int canvas_page_views_http_code_413)
{
	_element_canvas_page_views_http_code_413 = canvas_page_views_http_code_413;
	_element_canvas_page_views_http_code_413_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetCanvas_page_views_http_code_422() const
{
	return _element_canvas_page_views_http_code_422;
}


void Metrics::SetCanvas_page_views_http_code_422(int canvas_page_views_http_code_422)
{
	_element_canvas_page_views_http_code_422 = canvas_page_views_http_code_422;
	_element_canvas_page_views_http_code_422_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetCanvas_page_views_http_code_500() const
{
	return _element_canvas_page_views_http_code_500;
}


void Metrics::SetCanvas_page_views_http_code_500(int canvas_page_views_http_code_500)
{
	_element_canvas_page_views_http_code_500 = canvas_page_views_http_code_500;
	_element_canvas_page_views_http_code_500_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetCanvas_page_views_http_code_502() const
{
	return _element_canvas_page_views_http_code_502;
}


void Metrics::SetCanvas_page_views_http_code_502(int canvas_page_views_http_code_502)
{
	_element_canvas_page_views_http_code_502 = canvas_page_views_http_code_502;
	_element_canvas_page_views_http_code_502_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetCanvas_page_views_http_code_503() const
{
	return _element_canvas_page_views_http_code_503;
}


void Metrics::SetCanvas_page_views_http_code_503(int canvas_page_views_http_code_503)
{
	_element_canvas_page_views_http_code_503 = canvas_page_views_http_code_503;
	_element_canvas_page_views_http_code_503_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetCanvas_page_views_http_code_505() const
{
	return _element_canvas_page_views_http_code_505;
}


void Metrics::SetCanvas_page_views_http_code_505(int canvas_page_views_http_code_505)
{
	_element_canvas_page_views_http_code_505 = canvas_page_views_http_code_505;
	_element_canvas_page_views_http_code_505_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetFeedform_impression() const
{
	return _element_feedform_impression;
}


void Metrics::SetFeedform_impression(int feedform_impression)
{
	_element_feedform_impression = feedform_impression;
	_element_feedform_impression_is_set = true;
}


// -----------------------------------------------------------------------------
int Metrics::GetFeedform_publish() const
{
	return _element_feedform_publish;
}


void Metrics::SetFeedform_publish(int feedform_publish)
{
	_element_feedform_publish = feedform_publish;
	_element_feedform_publish_is_set = true;
}


// -----------------------------------------------------------------------------
Short_story_template::Short_story_template()
: _element_template_title_is_set(false)
, _element_template_body_is_set(false)
{
}


// -----------------------------------------------------------------------------
Short_story_template::Short_story_template(const Xml::XmlNode& it)
: _element_template_title_is_set(false)
, _element_template_body_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Short_story_template::clear()
{
	_element_template_title.clear();
	_element_template_body.clear();
	_element_template_title_is_set = false;
	_element_template_body_is_set = false;
}


// -----------------------------------------------------------------------------
void Short_story_template::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("template_title"))
		throw Xml::XmlException("missing required node in element 'short_story_template': template_title");
	SetTemplate_title( it["template_title"] );
	if (!it.Exists("template_body"))
		throw Xml::XmlException("missing required node in element 'short_story_template': template_body");
	SetTemplate_body( it["template_body"] );
}


// -----------------------------------------------------------------------------
const std::string Short_story_template::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<template_title>" + _element_template_title + "</template_title>";
	r += "<template_body>" + _element_template_body + "</template_body>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Short_story_template::IsSet() const
{
	return Template_titleIsSet() || Template_bodyIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Short_story_template::GetTemplate_title() const
{
	return _element_template_title;
}


void Short_story_template::SetTemplate_title(const std::string& template_title)
{
	_element_template_title = template_title;
	_element_template_title_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Short_story_template::GetTemplate_body() const
{
	return _element_template_body;
}


void Short_story_template::SetTemplate_body(const std::string& template_body)
{
	_element_template_body = template_body;
	_element_template_body_is_set = true;
}


// -----------------------------------------------------------------------------
Full_story_template::Full_story_template()
: _element_template_title_is_set(false)
, _element_template_body_is_set(false)
{
}


// -----------------------------------------------------------------------------
Full_story_template::Full_story_template(const Xml::XmlNode& it)
: _element_template_title_is_set(false)
, _element_template_body_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Full_story_template::clear()
{
	_element_template_title.clear();
	_element_template_body.clear();
	_element_template_title_is_set = false;
	_element_template_body_is_set = false;
}


// -----------------------------------------------------------------------------
void Full_story_template::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("template_title"))
		throw Xml::XmlException("missing required node in element 'full_story_template': template_title");
	SetTemplate_title( it["template_title"] );
	if (!it.Exists("template_body"))
		throw Xml::XmlException("missing required node in element 'full_story_template': template_body");
	SetTemplate_body( it["template_body"] );
}


// -----------------------------------------------------------------------------
const std::string Full_story_template::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<template_title>" + _element_template_title + "</template_title>";
	r += "<template_body>" + _element_template_body + "</template_body>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Full_story_template::IsSet() const
{
	return Template_titleIsSet() || Template_bodyIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Full_story_template::GetTemplate_title() const
{
	return _element_template_title;
}


void Full_story_template::SetTemplate_title(const std::string& template_title)
{
	_element_template_title = template_title;
	_element_template_title_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Full_story_template::GetTemplate_body() const
{
	return _element_template_body;
}


void Full_story_template::SetTemplate_body(const std::string& template_body)
{
	_element_template_body = template_body;
	_element_template_body_is_set = true;
}


// -----------------------------------------------------------------------------
Action_link::Action_link()
: _element_text_is_set(false)
, _element_href_is_set(false)
{
}


// -----------------------------------------------------------------------------
Action_link::Action_link(const Xml::XmlNode& it)
: _element_text_is_set(false)
, _element_href_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Action_link::clear()
{
	_element_text.clear();
	_element_href.clear();
	_element_text_is_set = false;
	_element_href_is_set = false;
}


// -----------------------------------------------------------------------------
void Action_link::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("text"))
		throw Xml::XmlException("missing required node in element 'action_link': text");
	SetText( it["text"] );
	if (!it.Exists("href"))
		throw Xml::XmlException("missing required node in element 'action_link': href");
	SetHref( it["href"] );
}


// -----------------------------------------------------------------------------
const std::string Action_link::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<text>" + _element_text + "</text>";
	r += "<href>" + _element_href + "</href>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Action_link::IsSet() const
{
	return TextIsSet() || HrefIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Action_link::GetText() const
{
	return _element_text;
}


void Action_link::SetText(const std::string& text)
{
	_element_text = text;
	_element_text_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Action_link::GetHref() const
{
	return _element_href;
}


void Action_link::SetHref(const std::string& href)
{
	_element_href = href;
	_element_href_is_set = true;
}


// -----------------------------------------------------------------------------
Stream_action_link::Stream_action_link()
: _element_text_is_set(false)
, _element_href_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_action_link::Stream_action_link(const Xml::XmlNode& it)
: _element_text_is_set(false)
, _element_href_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_action_link::clear()
{
	_element_text.clear();
	_element_href.clear();
	_element_text_is_set = false;
	_element_href_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_action_link::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("text"))
		throw Xml::XmlException("missing required node in element 'stream_action_link': text");
	SetText( it["text"] );
	if (!it.Exists("href"))
		throw Xml::XmlException("missing required node in element 'stream_action_link': href");
	SetHref( it["href"] );
}


// -----------------------------------------------------------------------------
const std::string Stream_action_link::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<text>" + _element_text + "</text>";
	r += "<href>" + _element_href + "</href>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_action_link::IsSet() const
{
	return TextIsSet() || HrefIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Stream_action_link::GetText() const
{
	return _element_text;
}


void Stream_action_link::SetText(const std::string& text)
{
	_element_text = text;
	_element_text_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_action_link::GetHref() const
{
	return _element_href;
}


void Stream_action_link::SetHref(const std::string& href)
{
	_element_href = href;
	_element_href_is_set = true;
}


// -----------------------------------------------------------------------------
ActionLinkList::ActionLinkList()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
ActionLinkList::ActionLinkList(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void ActionLinkList::clear()
{
	while (!_element_stream_action_link.empty())
		_element_stream_action_link.erase( _element_stream_action_link.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void ActionLinkList::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "stream_action_link");
		while (n)
		{
			com_facebook_1_0_::Stream_action_link tmp(n);
			_element_stream_action_link.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string ActionLinkList::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Stream_action_link>::const_iterator it = _element_stream_action_link.begin(); it != _element_stream_action_link.end(); it++)
	{
		const com_facebook_1_0_::Stream_action_link& ref = *it;
		r += ref.ToString("stream_action_link");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool ActionLinkList::IsSet() const
{
	return Stream_action_linkIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Stream_action_link>& ActionLinkList::GetStream_action_link() const
{
	return _element_stream_action_link;
}


std::list<com_facebook_1_0_::Stream_action_link>& ActionLinkList::GetStream_action_link()
{
	return _element_stream_action_link;
}


void ActionLinkList::SetStream_action_link(const std::list<com_facebook_1_0_::Stream_action_link>& stream_action_link)
{
	_element_stream_action_link = stream_action_link;
}


// -----------------------------------------------------------------------------
bool ActionLinkList::Stream_action_linkIsSet() const
{
	return !_element_stream_action_link.empty();
}


// -----------------------------------------------------------------------------
bool ActionLinkList::GetList() const
{
	return _attribute_list;
}


void ActionLinkList::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Template_bundle::Template_bundle()
: _element_time_created_is_set(false)
, _element_template_bundle_id_is_set(false)
{
}


// -----------------------------------------------------------------------------
Template_bundle::Template_bundle(const Xml::XmlNode& it)
: _element_time_created_is_set(false)
, _element_template_bundle_id_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Template_bundle::clear()
{
	_element_one_line_story_templates.clear();
	_element_short_story_templates.clear();
	_element_full_story_template.clear();
	_element_action_links.clear();
	// simpleType:
	// _element_time_created.clear();
	// simpleType:
	// _element_template_bundle_id.clear();
	_element_time_created_is_set = false;
	_element_template_bundle_id_is_set = false;
}


// -----------------------------------------------------------------------------
void Template_bundle::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("one_line_story_templates"))
		throw Xml::XmlException("missing required node in element 'template_bundle': one_line_story_templates");
	{
		Xml::XmlNode n(it, "one_line_story_templates");
		if (n)
			_element_one_line_story_templates.FromXml( n );
	}
	if (!it.Exists("short_story_templates"))
		throw Xml::XmlException("missing required node in element 'template_bundle': short_story_templates");
	{
		Xml::XmlNode n(it, "short_story_templates");
		if (n)
			_element_short_story_templates.FromXml( n );
	}
	if (!it.Exists("full_story_template"))
		throw Xml::XmlException("missing required node in element 'template_bundle': full_story_template");
	{
		Xml::XmlNode n(it, "full_story_template");
		if (n)
			_element_full_story_template.FromXml( n );
	}
	if (!it.Exists("action_links"))
		throw Xml::XmlException("missing required node in element 'template_bundle': action_links");
	{
		Xml::XmlNode n(it, "action_links");
		if (n)
			_element_action_links.FromXml( n );
	}
	if (!it.Exists("time_created"))
		throw Xml::XmlException("missing required node in element 'template_bundle': time_created");
	SetTime_created( atoi(std::string(it["time_created"]).c_str()) );
	if (!it.Exists("template_bundle_id"))
		throw Xml::XmlException("missing required node in element 'template_bundle': template_bundle_id");
	SetTemplate_bundle_id( atoi(std::string(it["template_bundle_id"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Template_bundle::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += _element_one_line_story_templates.ToString("one_line_story_templates");
	r += _element_short_story_templates.ToString("short_story_templates");
	r += _element_full_story_template.ToString("full_story_template");
	r += _element_action_links.ToString("action_links");
	{
		r = r + "<time_created>" + Utility::l2string(_element_time_created) + "</time_created>";
	}
	{
		r = r + "<template_bundle_id>" + Utility::l2string(_element_template_bundle_id) + "</template_bundle_id>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Template_bundle::IsSet() const
{
	return One_line_story_templatesIsSet() || Short_story_templatesIsSet() || Full_story_templateIsSet() || Action_linksIsSet() || Time_createdIsSet() || Template_bundle_idIsSet();
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Template_bundle::One_line_story_templates_t& Template_bundle::GetOne_line_story_templates() const
{
	return _element_one_line_story_templates;
}


com_facebook_1_0_::Template_bundle::One_line_story_templates_t& Template_bundle::GetOne_line_story_templates()
{
	return _element_one_line_story_templates;
}


void Template_bundle::SetOne_line_story_templates(const com_facebook_1_0_::Template_bundle::One_line_story_templates_t& one_line_story_templates)
{
	_element_one_line_story_templates = one_line_story_templates;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Template_bundle::Short_story_templates_t& Template_bundle::GetShort_story_templates() const
{
	return _element_short_story_templates;
}


com_facebook_1_0_::Template_bundle::Short_story_templates_t& Template_bundle::GetShort_story_templates()
{
	return _element_short_story_templates;
}


void Template_bundle::SetShort_story_templates(const com_facebook_1_0_::Template_bundle::Short_story_templates_t& short_story_templates)
{
	_element_short_story_templates = short_story_templates;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Full_story_template& Template_bundle::GetFull_story_template() const
{
	return _element_full_story_template;
}


com_facebook_1_0_::Full_story_template& Template_bundle::GetFull_story_template()
{
	return _element_full_story_template;
}


void Template_bundle::SetFull_story_template(const com_facebook_1_0_::Full_story_template& full_story_template)
{
	_element_full_story_template = full_story_template;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::ActionLinkList& Template_bundle::GetAction_links() const
{
	return _element_action_links;
}


com_facebook_1_0_::ActionLinkList& Template_bundle::GetAction_links()
{
	return _element_action_links;
}


void Template_bundle::SetAction_links(const com_facebook_1_0_::ActionLinkList& action_links)
{
	_element_action_links = action_links;
}


// -----------------------------------------------------------------------------
long Template_bundle::GetTime_created() const
{
	return _element_time_created;
}


void Template_bundle::SetTime_created(long time_created)
{
	_element_time_created = time_created;
	_element_time_created_is_set = true;
}


// -----------------------------------------------------------------------------
long Template_bundle::GetTemplate_bundle_id() const
{
	return _element_template_bundle_id;
}


void Template_bundle::SetTemplate_bundle_id(long template_bundle_id)
{
	_element_template_bundle_id = template_bundle_id;
	_element_template_bundle_id_is_set = true;
}


// -----------------------------------------------------------------------------
bool Template_bundle::One_line_story_templatesIsSet() const
{
	return _element_one_line_story_templates.IsSet();
}


// -----------------------------------------------------------------------------
bool Template_bundle::Short_story_templatesIsSet() const
{
	return _element_short_story_templates.IsSet();
}


// -----------------------------------------------------------------------------
bool Template_bundle::Full_story_templateIsSet() const
{
	return _element_full_story_template.IsSet();
}


// -----------------------------------------------------------------------------
bool Template_bundle::Action_linksIsSet() const
{
	return _element_action_links.IsSet();
}


// -----------------------------------------------------------------------------
Template_bundle::One_line_story_templates_t::One_line_story_templates_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Template_bundle::One_line_story_templates_t::One_line_story_templates_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Template_bundle::One_line_story_templates_t::clear()
{
	while (!_element_one_line_story_template.empty())
		_element_one_line_story_template.erase( _element_one_line_story_template.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Template_bundle::One_line_story_templates_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "one_line_story_template");
		while (n)
		{
			_element_one_line_story_template.push_back( n.GetContent() );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Template_bundle::One_line_story_templates_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<std::string>::const_iterator it = _element_one_line_story_template.begin(); it != _element_one_line_story_template.end(); it++)
	{
		r += "<one_line_story_template>" + *it + "</one_line_story_template>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Template_bundle::One_line_story_templates_t::IsSet() const
{
	return One_line_story_templateIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<std::string>& Template_bundle::One_line_story_templates_t::GetOne_line_story_template() const
{
	return _element_one_line_story_template;
}


std::list<std::string>& Template_bundle::One_line_story_templates_t::GetOne_line_story_template()
{
	return _element_one_line_story_template;
}


void Template_bundle::One_line_story_templates_t::SetOne_line_story_template(const std::list<std::string>& one_line_story_template)
{
	_element_one_line_story_template = one_line_story_template;
}


// -----------------------------------------------------------------------------
bool Template_bundle::One_line_story_templates_t::One_line_story_templateIsSet() const
{
	return !_element_one_line_story_template.empty();
}


// -----------------------------------------------------------------------------
bool Template_bundle::One_line_story_templates_t::GetList() const
{
	return _attribute_list;
}


void Template_bundle::One_line_story_templates_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Template_bundle::Short_story_templates_t::Short_story_templates_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Template_bundle::Short_story_templates_t::Short_story_templates_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Template_bundle::Short_story_templates_t::clear()
{
	while (!_element_short_story_template.empty())
		_element_short_story_template.erase( _element_short_story_template.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Template_bundle::Short_story_templates_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "short_story_template");
		while (n)
		{
			com_facebook_1_0_::Short_story_template tmp(n);
			_element_short_story_template.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Template_bundle::Short_story_templates_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Short_story_template>::const_iterator it = _element_short_story_template.begin(); it != _element_short_story_template.end(); it++)
	{
		const com_facebook_1_0_::Short_story_template& ref = *it;
		r += ref.ToString("short_story_template");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Template_bundle::Short_story_templates_t::IsSet() const
{
	return Short_story_templateIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Short_story_template>& Template_bundle::Short_story_templates_t::GetShort_story_template() const
{
	return _element_short_story_template;
}


std::list<com_facebook_1_0_::Short_story_template>& Template_bundle::Short_story_templates_t::GetShort_story_template()
{
	return _element_short_story_template;
}


void Template_bundle::Short_story_templates_t::SetShort_story_template(const std::list<com_facebook_1_0_::Short_story_template>& short_story_template)
{
	_element_short_story_template = short_story_template;
}


// -----------------------------------------------------------------------------
bool Template_bundle::Short_story_templates_t::Short_story_templateIsSet() const
{
	return !_element_short_story_template.empty();
}


// -----------------------------------------------------------------------------
bool Template_bundle::Short_story_templates_t::GetList() const
{
	return _attribute_list;
}


void Template_bundle::Short_story_templates_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Feed_story::Feed_story()
: _element_actor_id_is_set(false)
, _element_post_id_is_set(false)
, _element_story_title_is_set(false)
, _element_story_body_is_set(false)
, _element_images_is_set(false)
, _element_flash_is_set(false)
, _element_mp3_is_set(false)
, _element_video_is_set(false)
, _element_time_published_is_set(false)
{
}


// -----------------------------------------------------------------------------
Feed_story::Feed_story(const Xml::XmlNode& it)
: _element_actor_id_is_set(false)
, _element_post_id_is_set(false)
, _element_story_title_is_set(false)
, _element_story_body_is_set(false)
, _element_images_is_set(false)
, _element_flash_is_set(false)
, _element_mp3_is_set(false)
, _element_video_is_set(false)
, _element_time_published_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Feed_story::clear()
{
	// simpleType:
	// _element_actor_id.clear();
	// simpleType:
	// _element_post_id.clear();
	_element_story_title.clear();
	_element_story_body.clear();
	_element_images.clear();
	_element_flash.clear();
	_element_mp3.clear();
	_element_video.clear();
	// simpleType:
	// _element_time_published.clear();
	_element_actor_id_is_set = false;
	_element_post_id_is_set = false;
	_element_story_title_is_set = false;
	_element_story_body_is_set = false;
	_element_images_is_set = false;
	_element_flash_is_set = false;
	_element_mp3_is_set = false;
	_element_video_is_set = false;
	_element_time_published_is_set = false;
}


// -----------------------------------------------------------------------------
void Feed_story::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("actor_id"))
		throw Xml::XmlException("missing required node in element 'feed_story': actor_id");
	SetActor_id( atoi(std::string(it["actor_id"]).c_str()) );
	if (!it.Exists("post_id"))
		throw Xml::XmlException("missing required node in element 'feed_story': post_id");
	SetPost_id( it["post_id"] );
	if (!it.Exists("story_title"))
		throw Xml::XmlException("missing required node in element 'feed_story': story_title");
	SetStory_title( it["story_title"] );
	if (it.Exists("story_body"))
		SetStory_body( it["story_body"] );
	if (it.Exists("images"))
		SetImages( it["images"] );
	if (it.Exists("flash"))
		SetFlash( it["flash"] );
	if (it.Exists("mp3"))
		SetMp3( it["mp3"] );
	if (it.Exists("video"))
		SetVideo( it["video"] );
	if (!it.Exists("time_published"))
		throw Xml::XmlException("missing required node in element 'feed_story': time_published");
	SetTime_published( atoi(std::string(it["time_published"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Feed_story::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<actor_id>" + Utility::l2string(_element_actor_id) + "</actor_id>";
	}
	r += "<post_id>" + _element_post_id + "</post_id>";
	r += "<story_title>" + _element_story_title + "</story_title>";
	if (_element_story_body_is_set)
		r += "<story_body>" + _element_story_body + "</story_body>";
	if (_element_images_is_set)
		r += "<images>" + _element_images + "</images>";
	if (_element_flash_is_set)
		r += "<flash>" + _element_flash + "</flash>";
	if (_element_mp3_is_set)
		r += "<mp3>" + _element_mp3 + "</mp3>";
	if (_element_video_is_set)
		r += "<video>" + _element_video + "</video>";
	{
		r = r + "<time_published>" + Utility::l2string(_element_time_published) + "</time_published>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Feed_story::IsSet() const
{
	return Actor_idIsSet() || Post_idIsSet() || Story_titleIsSet() || Story_bodyIsSet() || ImagesIsSet() || FlashIsSet() || Mp3IsSet() || VideoIsSet() || Time_publishedIsSet();
}


// -----------------------------------------------------------------------------
long Feed_story::GetActor_id() const
{
	return _element_actor_id;
}


void Feed_story::SetActor_id(long actor_id)
{
	_element_actor_id = actor_id;
	_element_actor_id_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Feed_story::GetPost_id() const
{
	return _element_post_id;
}


void Feed_story::SetPost_id(const std::string& post_id)
{
	_element_post_id = post_id;
	_element_post_id_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Feed_story::GetStory_title() const
{
	return _element_story_title;
}


void Feed_story::SetStory_title(const std::string& story_title)
{
	_element_story_title = story_title;
	_element_story_title_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Feed_story::GetStory_body() const
{
	return _element_story_body;
}


void Feed_story::SetStory_body(const std::string& story_body)
{
	_element_story_body = story_body;
	_element_story_body_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Feed_story::GetImages() const
{
	return _element_images;
}


void Feed_story::SetImages(const std::string& images)
{
	_element_images = images;
	_element_images_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Feed_story::GetFlash() const
{
	return _element_flash;
}


void Feed_story::SetFlash(const std::string& flash)
{
	_element_flash = flash;
	_element_flash_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Feed_story::GetMp3() const
{
	return _element_mp3;
}


void Feed_story::SetMp3(const std::string& mp3)
{
	_element_mp3 = mp3;
	_element_mp3_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Feed_story::GetVideo() const
{
	return _element_video;
}


void Feed_story::SetVideo(const std::string& video)
{
	_element_video = video;
	_element_video_is_set = true;
}


// -----------------------------------------------------------------------------
long Feed_story::GetTime_published() const
{
	return _element_time_published;
}


void Feed_story::SetTime_published(long time_published)
{
	_element_time_published = time_published;
	_element_time_published_is_set = true;
}


// -----------------------------------------------------------------------------
Info_item::Info_item()
: _element_label_is_set(false)
, _element_sublabel_is_set(false)
, _element_description_is_set(false)
, _element_link_is_set(false)
, _element_image_is_set(false)
, _element_meta_is_set(false)
{
}


// -----------------------------------------------------------------------------
Info_item::Info_item(const Xml::XmlNode& it)
: _element_label_is_set(false)
, _element_sublabel_is_set(false)
, _element_description_is_set(false)
, _element_link_is_set(false)
, _element_image_is_set(false)
, _element_meta_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Info_item::clear()
{
	_element_label.clear();
	_element_sublabel.clear();
	_element_description.clear();
	_element_link.clear();
	_element_image.clear();
	_element_meta.clear();
	_element_label_is_set = false;
	_element_sublabel_is_set = false;
	_element_description_is_set = false;
	_element_link_is_set = false;
	_element_image_is_set = false;
	_element_meta_is_set = false;
}


// -----------------------------------------------------------------------------
void Info_item::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("label"))
		throw Xml::XmlException("missing required node in element 'info_item': label");
	SetLabel( it["label"] );
	if (!it.Exists("sublabel"))
		throw Xml::XmlException("missing required node in element 'info_item': sublabel");
	SetSublabel( it["sublabel"] );
	if (!it.Exists("description"))
		throw Xml::XmlException("missing required node in element 'info_item': description");
	SetDescription( it["description"] );
	if (!it.Exists("link"))
		throw Xml::XmlException("missing required node in element 'info_item': link");
	SetLink( it["link"] );
	if (!it.Exists("image"))
		throw Xml::XmlException("missing required node in element 'info_item': image");
	SetImage( it["image"] );
	if (!it.Exists("meta"))
		throw Xml::XmlException("missing required node in element 'info_item': meta");
	SetMeta( it["meta"] );
}


// -----------------------------------------------------------------------------
const std::string Info_item::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<label>" + _element_label + "</label>";
	r += "<sublabel>" + _element_sublabel + "</sublabel>";
	r += "<description>" + _element_description + "</description>";
	r += "<link>" + _element_link + "</link>";
	r += "<image>" + _element_image + "</image>";
	r += "<meta>" + _element_meta + "</meta>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Info_item::IsSet() const
{
	return LabelIsSet() || SublabelIsSet() || DescriptionIsSet() || LinkIsSet() || ImageIsSet() || MetaIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Info_item::GetLabel() const
{
	return _element_label;
}


void Info_item::SetLabel(const std::string& label)
{
	_element_label = label;
	_element_label_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Info_item::GetSublabel() const
{
	return _element_sublabel;
}


void Info_item::SetSublabel(const std::string& sublabel)
{
	_element_sublabel = sublabel;
	_element_sublabel_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Info_item::GetDescription() const
{
	return _element_description;
}


void Info_item::SetDescription(const std::string& description)
{
	_element_description = description;
	_element_description_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Info_item::GetLink() const
{
	return _element_link;
}


void Info_item::SetLink(const std::string& link)
{
	_element_link = link;
	_element_link_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Info_item::GetImage() const
{
	return _element_image;
}


void Info_item::SetImage(const std::string& image)
{
	_element_image = image;
	_element_image_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Info_item::GetMeta() const
{
	return _element_meta;
}


void Info_item::SetMeta(const std::string& meta)
{
	_element_meta = meta;
	_element_meta_is_set = true;
}


// -----------------------------------------------------------------------------
Info_field::Info_field()
: _element_field_is_set(false)
{
}


// -----------------------------------------------------------------------------
Info_field::Info_field(const Xml::XmlNode& it)
: _element_field_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Info_field::clear()
{
	_element_field.clear();
	_element_items.clear();
	_element_field_is_set = false;
}


// -----------------------------------------------------------------------------
void Info_field::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("field"))
		throw Xml::XmlException("missing required node in element 'info_field': field");
	SetField( it["field"] );
	if (!it.Exists("items"))
		throw Xml::XmlException("missing required node in element 'info_field': items");
	{
		Xml::XmlNode n(it, "items");
		if (n)
			_element_items.FromXml( n );
	}
}


// -----------------------------------------------------------------------------
const std::string Info_field::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<field>" + _element_field + "</field>";
	r += _element_items.ToString("items");
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Info_field::IsSet() const
{
	return FieldIsSet() || ItemsIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Info_field::GetField() const
{
	return _element_field;
}


void Info_field::SetField(const std::string& field)
{
	_element_field = field;
	_element_field_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Info_field::Items_t& Info_field::GetItems() const
{
	return _element_items;
}


com_facebook_1_0_::Info_field::Items_t& Info_field::GetItems()
{
	return _element_items;
}


void Info_field::SetItems(const com_facebook_1_0_::Info_field::Items_t& items)
{
	_element_items = items;
}


// -----------------------------------------------------------------------------
bool Info_field::ItemsIsSet() const
{
	return _element_items.IsSet();
}


// -----------------------------------------------------------------------------
Info_field::Items_t::Items_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Info_field::Items_t::Items_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Info_field::Items_t::clear()
{
	while (!_element_info_item.empty())
		_element_info_item.erase( _element_info_item.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Info_field::Items_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "info_item");
		while (n)
		{
			com_facebook_1_0_::Info_item tmp(n);
			_element_info_item.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Info_field::Items_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Info_item>::const_iterator it = _element_info_item.begin(); it != _element_info_item.end(); it++)
	{
		const com_facebook_1_0_::Info_item& ref = *it;
		r += ref.ToString("info_item");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Info_field::Items_t::IsSet() const
{
	return Info_itemIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Info_item>& Info_field::Items_t::GetInfo_item() const
{
	return _element_info_item;
}


std::list<com_facebook_1_0_::Info_item>& Info_field::Items_t::GetInfo_item()
{
	return _element_info_item;
}


void Info_field::Items_t::SetInfo_item(const std::list<com_facebook_1_0_::Info_item>& info_item)
{
	_element_info_item = info_item;
}


// -----------------------------------------------------------------------------
bool Info_field::Items_t::Info_itemIsSet() const
{
	return !_element_info_item.empty();
}


// -----------------------------------------------------------------------------
bool Info_field::Items_t::GetList() const
{
	return _attribute_list;
}


void Info_field::Items_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
User_info::User_info()
: _element_type(0)
, _element_title_is_set(false)
, _element_type_is_set(false)
{
}


// -----------------------------------------------------------------------------
User_info::User_info(const Xml::XmlNode& it)
: _element_type(0)
, _element_title_is_set(false)
, _element_type_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void User_info::clear()
{
	_element_title.clear();
	_element_type = 0;
	_element_info_fields.clear();
	_element_title_is_set = false;
	_element_type_is_set = false;
}


// -----------------------------------------------------------------------------
void User_info::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("title"))
		throw Xml::XmlException("missing required node in element 'user_info': title");
	SetTitle( it["title"] );
	if (!it.Exists("type"))
		throw Xml::XmlException("missing required node in element 'user_info': type");
	SetType( atoi(std::string(it["type"]).c_str()) );
	if (!it.Exists("info_fields"))
		throw Xml::XmlException("missing required node in element 'user_info': info_fields");
	{
		Xml::XmlNode n(it, "info_fields");
		if (n)
			_element_info_fields.FromXml( n );
	}
}


// -----------------------------------------------------------------------------
const std::string User_info::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<title>" + _element_title + "</title>";
	{
		r = r + "<type>" + Utility::l2string(_element_type) + "</type>";
	}
	r += _element_info_fields.ToString("info_fields");
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool User_info::IsSet() const
{
	return TitleIsSet() || TypeIsSet() || Info_fieldsIsSet();
}


// -----------------------------------------------------------------------------
const std::string& User_info::GetTitle() const
{
	return _element_title;
}


void User_info::SetTitle(const std::string& title)
{
	_element_title = title;
	_element_title_is_set = true;
}


// -----------------------------------------------------------------------------
int User_info::GetType() const
{
	return _element_type;
}


void User_info::SetType(int type)
{
	_element_type = type;
	_element_type_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::User_info::Info_fields_t& User_info::GetInfo_fields() const
{
	return _element_info_fields;
}


com_facebook_1_0_::User_info::Info_fields_t& User_info::GetInfo_fields()
{
	return _element_info_fields;
}


void User_info::SetInfo_fields(const com_facebook_1_0_::User_info::Info_fields_t& info_fields)
{
	_element_info_fields = info_fields;
}


// -----------------------------------------------------------------------------
bool User_info::Info_fieldsIsSet() const
{
	return _element_info_fields.IsSet();
}


// -----------------------------------------------------------------------------
User_info::Info_fields_t::Info_fields_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
User_info::Info_fields_t::Info_fields_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void User_info::Info_fields_t::clear()
{
	while (!_element_info_field.empty())
		_element_info_field.erase( _element_info_field.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void User_info::Info_fields_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "info_field");
		while (n)
		{
			com_facebook_1_0_::Info_field tmp(n);
			_element_info_field.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string User_info::Info_fields_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Info_field>::const_iterator it = _element_info_field.begin(); it != _element_info_field.end(); it++)
	{
		const com_facebook_1_0_::Info_field& ref = *it;
		r += ref.ToString("info_field");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool User_info::Info_fields_t::IsSet() const
{
	return Info_fieldIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Info_field>& User_info::Info_fields_t::GetInfo_field() const
{
	return _element_info_field;
}


std::list<com_facebook_1_0_::Info_field>& User_info::Info_fields_t::GetInfo_field()
{
	return _element_info_field;
}


void User_info::Info_fields_t::SetInfo_field(const std::list<com_facebook_1_0_::Info_field>& info_field)
{
	_element_info_field = info_field;
}


// -----------------------------------------------------------------------------
bool User_info::Info_fields_t::Info_fieldIsSet() const
{
	return !_element_info_field.empty();
}


// -----------------------------------------------------------------------------
bool User_info::Info_fields_t::GetList() const
{
	return _attribute_list;
}


void User_info::Info_fields_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Custom_tag_parameter::Custom_tag_parameter()
: _element_name_is_set(false)
, _element_custom_tag_parameter_type_is_set(false)
, _element_description_is_set(false)
, _element_default_value_is_set(false)
{
}


// -----------------------------------------------------------------------------
Custom_tag_parameter::Custom_tag_parameter(const Xml::XmlNode& it)
: _element_name_is_set(false)
, _element_custom_tag_parameter_type_is_set(false)
, _element_description_is_set(false)
, _element_default_value_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Custom_tag_parameter::clear()
{
	_element_name.clear();
	_element_custom_tag_parameter_type.clear();
	_element_description.clear();
	_element_default_value.clear();
	_element_name_is_set = false;
	_element_custom_tag_parameter_type_is_set = false;
	_element_description_is_set = false;
	_element_default_value_is_set = false;
}


// -----------------------------------------------------------------------------
void Custom_tag_parameter::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("name"))
		throw Xml::XmlException("missing required node in element 'custom_tag_parameter': name");
	SetName( it["name"] );
	if (!it.Exists("custom_tag_parameter_type"))
		throw Xml::XmlException("missing required node in element 'custom_tag_parameter': custom_tag_parameter_type");
	SetCustom_tag_parameter_type( it["custom_tag_parameter_type"] );
	if (!it.Exists("description"))
		throw Xml::XmlException("missing required node in element 'custom_tag_parameter': description");
	SetDescription( it["description"] );
	if (!it.Exists("default_value"))
		throw Xml::XmlException("missing required node in element 'custom_tag_parameter': default_value");
	SetDefault_value( it["default_value"] );
}


// -----------------------------------------------------------------------------
const std::string Custom_tag_parameter::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<name>" + _element_name + "</name>";
	r += "<custom_tag_parameter_type>" + _element_custom_tag_parameter_type + "</custom_tag_parameter_type>";
	r += "<description>" + _element_description + "</description>";
	r += "<default_value>" + _element_default_value + "</default_value>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Custom_tag_parameter::IsSet() const
{
	return NameIsSet() || Custom_tag_parameter_typeIsSet() || DescriptionIsSet() || Default_valueIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Custom_tag_parameter::GetName() const
{
	return _element_name;
}


void Custom_tag_parameter::SetName(const std::string& name)
{
	_element_name = name;
	_element_name_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Custom_tag_parameter::GetCustom_tag_parameter_type() const
{
	return _element_custom_tag_parameter_type;
}


void Custom_tag_parameter::SetCustom_tag_parameter_type(const std::string& custom_tag_parameter_type)
{
	_element_custom_tag_parameter_type = custom_tag_parameter_type;
	_element_custom_tag_parameter_type_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Custom_tag_parameter::GetDescription() const
{
	return _element_description;
}


void Custom_tag_parameter::SetDescription(const std::string& description)
{
	_element_description = description;
	_element_description_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Custom_tag_parameter::GetDefault_value() const
{
	return _element_default_value;
}


void Custom_tag_parameter::SetDefault_value(const std::string& default_value)
{
	_element_default_value = default_value;
	_element_default_value_is_set = true;
}


// -----------------------------------------------------------------------------
Custom_tag::Custom_tag()
: _element_type(0)
, _element_name_is_set(false)
, _element_type_is_set(false)
, _element_summary_is_set(false)
, _element_description_is_set(false)
, _element_body_is_set(false)
, _element_open_tag_is_set(false)
, _element_close_tag_is_set(false)
{
}


// -----------------------------------------------------------------------------
Custom_tag::Custom_tag(const Xml::XmlNode& it)
: _element_type(0)
, _element_name_is_set(false)
, _element_type_is_set(false)
, _element_summary_is_set(false)
, _element_description_is_set(false)
, _element_body_is_set(false)
, _element_open_tag_is_set(false)
, _element_close_tag_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Custom_tag::clear()
{
	_element_name.clear();
	_element_type = 0;
	_element_summary.clear();
	_element_description.clear();
	_element_parameter.clear();
	_element_body.clear();
	_element_open_tag.clear();
	_element_close_tag.clear();
	_element_name_is_set = false;
	_element_type_is_set = false;
	_element_summary_is_set = false;
	_element_description_is_set = false;
	_element_body_is_set = false;
	_element_open_tag_is_set = false;
	_element_close_tag_is_set = false;
}


// -----------------------------------------------------------------------------
void Custom_tag::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("name"))
		throw Xml::XmlException("missing required node in element 'custom_tag': name");
	SetName( it["name"] );
	if (!it.Exists("type"))
		throw Xml::XmlException("missing required node in element 'custom_tag': type");
	SetType( atoi(std::string(it["type"]).c_str()) );
	if (!it.Exists("summary"))
		throw Xml::XmlException("missing required node in element 'custom_tag': summary");
	SetSummary( it["summary"] );
	if (!it.Exists("description"))
		throw Xml::XmlException("missing required node in element 'custom_tag': description");
	SetDescription( it["description"] );
	if (!it.Exists("parameter"))
		throw Xml::XmlException("missing required node in element 'custom_tag': parameter");
	{
		Xml::XmlNode n(it, "parameter");
		if (n)
			_element_parameter.FromXml( n );
	}
	if (!it.Exists("body"))
		throw Xml::XmlException("missing required node in element 'custom_tag': body");
	SetBody( it["body"] );
	if (!it.Exists("open_tag"))
		throw Xml::XmlException("missing required node in element 'custom_tag': open_tag");
	SetOpen_tag( it["open_tag"] );
	if (!it.Exists("close_tag"))
		throw Xml::XmlException("missing required node in element 'custom_tag': close_tag");
	SetClose_tag( it["close_tag"] );
}


// -----------------------------------------------------------------------------
const std::string Custom_tag::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<name>" + _element_name + "</name>";
	{
		r = r + "<type>" + Utility::l2string(_element_type) + "</type>";
	}
	r += "<summary>" + _element_summary + "</summary>";
	r += "<description>" + _element_description + "</description>";
	r += _element_parameter.ToString("parameter");
	r += "<body>" + _element_body + "</body>";
	r += "<open_tag>" + _element_open_tag + "</open_tag>";
	r += "<close_tag>" + _element_close_tag + "</close_tag>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Custom_tag::IsSet() const
{
	return NameIsSet() || TypeIsSet() || SummaryIsSet() || DescriptionIsSet() || ParameterIsSet() || BodyIsSet() || Open_tagIsSet() || Close_tagIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Custom_tag::GetName() const
{
	return _element_name;
}


void Custom_tag::SetName(const std::string& name)
{
	_element_name = name;
	_element_name_is_set = true;
}


// -----------------------------------------------------------------------------
int Custom_tag::GetType() const
{
	return _element_type;
}


void Custom_tag::SetType(int type)
{
	_element_type = type;
	_element_type_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Custom_tag::GetSummary() const
{
	return _element_summary;
}


void Custom_tag::SetSummary(const std::string& summary)
{
	_element_summary = summary;
	_element_summary_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Custom_tag::GetDescription() const
{
	return _element_description;
}


void Custom_tag::SetDescription(const std::string& description)
{
	_element_description = description;
	_element_description_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Custom_tag::Parameter_t& Custom_tag::GetParameter() const
{
	return _element_parameter;
}


com_facebook_1_0_::Custom_tag::Parameter_t& Custom_tag::GetParameter()
{
	return _element_parameter;
}


void Custom_tag::SetParameter(const com_facebook_1_0_::Custom_tag::Parameter_t& parameter)
{
	_element_parameter = parameter;
}


// -----------------------------------------------------------------------------
const std::string& Custom_tag::GetBody() const
{
	return _element_body;
}


void Custom_tag::SetBody(const std::string& body)
{
	_element_body = body;
	_element_body_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Custom_tag::GetOpen_tag() const
{
	return _element_open_tag;
}


void Custom_tag::SetOpen_tag(const std::string& open_tag)
{
	_element_open_tag = open_tag;
	_element_open_tag_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Custom_tag::GetClose_tag() const
{
	return _element_close_tag;
}


void Custom_tag::SetClose_tag(const std::string& close_tag)
{
	_element_close_tag = close_tag;
	_element_close_tag_is_set = true;
}


// -----------------------------------------------------------------------------
bool Custom_tag::ParameterIsSet() const
{
	return _element_parameter.IsSet();
}


// -----------------------------------------------------------------------------
Custom_tag::Parameter_t::Parameter_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Custom_tag::Parameter_t::Parameter_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Custom_tag::Parameter_t::clear()
{
	while (!_element_custom_tag_parameter.empty())
		_element_custom_tag_parameter.erase( _element_custom_tag_parameter.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Custom_tag::Parameter_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "custom_tag_parameter");
		while (n)
		{
			com_facebook_1_0_::Custom_tag_parameter tmp(n);
			_element_custom_tag_parameter.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Custom_tag::Parameter_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Custom_tag_parameter>::const_iterator it = _element_custom_tag_parameter.begin(); it != _element_custom_tag_parameter.end(); it++)
	{
		const com_facebook_1_0_::Custom_tag_parameter& ref = *it;
		r += ref.ToString("custom_tag_parameter");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Custom_tag::Parameter_t::IsSet() const
{
	return Custom_tag_parameterIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Custom_tag_parameter>& Custom_tag::Parameter_t::GetCustom_tag_parameter() const
{
	return _element_custom_tag_parameter;
}


std::list<com_facebook_1_0_::Custom_tag_parameter>& Custom_tag::Parameter_t::GetCustom_tag_parameter()
{
	return _element_custom_tag_parameter;
}


void Custom_tag::Parameter_t::SetCustom_tag_parameter(const std::list<com_facebook_1_0_::Custom_tag_parameter>& custom_tag_parameter)
{
	_element_custom_tag_parameter = custom_tag_parameter;
}


// -----------------------------------------------------------------------------
bool Custom_tag::Parameter_t::Custom_tag_parameterIsSet() const
{
	return !_element_custom_tag_parameter.empty();
}


// -----------------------------------------------------------------------------
bool Custom_tag::Parameter_t::GetList() const
{
	return _attribute_list;
}


void Custom_tag::Parameter_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Dashboard_bundle::Dashboard_bundle()
: _element_message_is_set(false)
{
}


// -----------------------------------------------------------------------------
Dashboard_bundle::Dashboard_bundle(const Xml::XmlNode& it)
: _element_message_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Dashboard_bundle::clear()
{
	_element_message.clear();
	_element_action_link.clear();
	_element_message_is_set = false;
}


// -----------------------------------------------------------------------------
void Dashboard_bundle::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("message"))
		throw Xml::XmlException("missing required node in element 'dashboard_bundle': message");
	SetMessage( it["message"] );
	if (!it.Exists("action_link"))
		throw Xml::XmlException("missing required node in element 'dashboard_bundle': action_link");
	{
		Xml::XmlNode n(it, "action_link");
		if (n)
			_element_action_link.FromXml( n );
	}
}


// -----------------------------------------------------------------------------
const std::string Dashboard_bundle::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<message>" + _element_message + "</message>";
	r += _element_action_link.ToString("action_link");
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Dashboard_bundle::IsSet() const
{
	return MessageIsSet() || Action_linkIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Dashboard_bundle::GetMessage() const
{
	return _element_message;
}


void Dashboard_bundle::SetMessage(const std::string& message)
{
	_element_message = message;
	_element_message_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Action_link& Dashboard_bundle::GetAction_link() const
{
	return _element_action_link;
}


com_facebook_1_0_::Action_link& Dashboard_bundle::GetAction_link()
{
	return _element_action_link;
}


void Dashboard_bundle::SetAction_link(const com_facebook_1_0_::Action_link& action_link)
{
	_element_action_link = action_link;
}


// -----------------------------------------------------------------------------
bool Dashboard_bundle::Action_linkIsSet() const
{
	return _element_action_link.IsSet();
}


// -----------------------------------------------------------------------------
Dashboard_activity::Dashboard_activity()
: _element_time(0)
, _element_image_is_set(false)
, _element_fbid_is_set(false)
, _element_time_is_set(false)
{
}


// -----------------------------------------------------------------------------
Dashboard_activity::Dashboard_activity(const Xml::XmlNode& it)
: _element_time(0)
, _element_image_is_set(false)
, _element_fbid_is_set(false)
, _element_time_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Dashboard_activity::clear()
{
	_element_image.clear();
	_element_activity.clear();
	// simpleType:
	// _element_fbid.clear();
	_element_time = 0;
	_element_image_is_set = false;
	_element_fbid_is_set = false;
	_element_time_is_set = false;
}


// -----------------------------------------------------------------------------
void Dashboard_activity::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("image"))
		throw Xml::XmlException("missing required node in element 'dashboard_activity': image");
	SetImage( it["image"] );
	if (!it.Exists("activity"))
		throw Xml::XmlException("missing required node in element 'dashboard_activity': activity");
	{
		Xml::XmlNode n(it, "activity");
		if (n)
			_element_activity.FromXml( n );
	}
	if (!it.Exists("fbid"))
		throw Xml::XmlException("missing required node in element 'dashboard_activity': fbid");
	SetFbid( atoi(std::string(it["fbid"]).c_str()) );
	if (!it.Exists("time"))
		throw Xml::XmlException("missing required node in element 'dashboard_activity': time");
	SetTime( atoi(std::string(it["time"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Dashboard_activity::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<image>" + _element_image + "</image>";
	r += _element_activity.ToString("activity");
	{
		r = r + "<fbid>" + Utility::l2string(_element_fbid) + "</fbid>";
	}
	{
		r = r + "<time>" + Utility::l2string(_element_time) + "</time>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Dashboard_activity::IsSet() const
{
	return ImageIsSet() || ActivityIsSet() || FbidIsSet() || TimeIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Dashboard_activity::GetImage() const
{
	return _element_image;
}


void Dashboard_activity::SetImage(const std::string& image)
{
	_element_image = image;
	_element_image_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Dashboard_activity::Activity_t& Dashboard_activity::GetActivity() const
{
	return _element_activity;
}


com_facebook_1_0_::Dashboard_activity::Activity_t& Dashboard_activity::GetActivity()
{
	return _element_activity;
}


void Dashboard_activity::SetActivity(const com_facebook_1_0_::Dashboard_activity::Activity_t& activity)
{
	_element_activity = activity;
}


// -----------------------------------------------------------------------------
long Dashboard_activity::GetFbid() const
{
	return _element_fbid;
}


void Dashboard_activity::SetFbid(long fbid)
{
	_element_fbid = fbid;
	_element_fbid_is_set = true;
}


// -----------------------------------------------------------------------------
int Dashboard_activity::GetTime() const
{
	return _element_time;
}


void Dashboard_activity::SetTime(int time)
{
	_element_time = time;
	_element_time_is_set = true;
}


// -----------------------------------------------------------------------------
bool Dashboard_activity::ActivityIsSet() const
{
	return _element_activity.IsSet();
}


// -----------------------------------------------------------------------------
Dashboard_activity::Activity_t::Activity_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Dashboard_activity::Activity_t::Activity_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Dashboard_activity::Activity_t::clear()
{
	while (!_element_dashboard_bundle.empty())
		_element_dashboard_bundle.erase( _element_dashboard_bundle.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Dashboard_activity::Activity_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "dashboard_bundle");
		while (n)
		{
			com_facebook_1_0_::Dashboard_bundle tmp(n);
			_element_dashboard_bundle.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Dashboard_activity::Activity_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Dashboard_bundle>::const_iterator it = _element_dashboard_bundle.begin(); it != _element_dashboard_bundle.end(); it++)
	{
		const com_facebook_1_0_::Dashboard_bundle& ref = *it;
		r += ref.ToString("dashboard_bundle");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Dashboard_activity::Activity_t::IsSet() const
{
	return Dashboard_bundleIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Dashboard_bundle>& Dashboard_activity::Activity_t::GetDashboard_bundle() const
{
	return _element_dashboard_bundle;
}


std::list<com_facebook_1_0_::Dashboard_bundle>& Dashboard_activity::Activity_t::GetDashboard_bundle()
{
	return _element_dashboard_bundle;
}


void Dashboard_activity::Activity_t::SetDashboard_bundle(const std::list<com_facebook_1_0_::Dashboard_bundle>& dashboard_bundle)
{
	_element_dashboard_bundle = dashboard_bundle;
}


// -----------------------------------------------------------------------------
bool Dashboard_activity::Activity_t::Dashboard_bundleIsSet() const
{
	return !_element_dashboard_bundle.empty();
}


// -----------------------------------------------------------------------------
bool Dashboard_activity::Activity_t::GetList() const
{
	return _attribute_list;
}


void Dashboard_activity::Activity_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Dashboard_news::Dashboard_news()
: _element_time(0)
, _element_image_is_set(false)
, _element_fbid_is_set(false)
, _element_time_is_set(false)
{
}


// -----------------------------------------------------------------------------
Dashboard_news::Dashboard_news(const Xml::XmlNode& it)
: _element_time(0)
, _element_image_is_set(false)
, _element_fbid_is_set(false)
, _element_time_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Dashboard_news::clear()
{
	_element_image.clear();
	_element_news.clear();
	// simpleType:
	// _element_fbid.clear();
	_element_time = 0;
	_element_image_is_set = false;
	_element_fbid_is_set = false;
	_element_time_is_set = false;
}


// -----------------------------------------------------------------------------
void Dashboard_news::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("image"))
		throw Xml::XmlException("missing required node in element 'dashboard_news': image");
	SetImage( it["image"] );
	if (!it.Exists("news"))
		throw Xml::XmlException("missing required node in element 'dashboard_news': news");
	{
		Xml::XmlNode n(it, "news");
		if (n)
			_element_news.FromXml( n );
	}
	if (!it.Exists("fbid"))
		throw Xml::XmlException("missing required node in element 'dashboard_news': fbid");
	SetFbid( atoi(std::string(it["fbid"]).c_str()) );
	if (!it.Exists("time"))
		throw Xml::XmlException("missing required node in element 'dashboard_news': time");
	SetTime( atoi(std::string(it["time"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Dashboard_news::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<image>" + _element_image + "</image>";
	r += _element_news.ToString("news");
	{
		r = r + "<fbid>" + Utility::l2string(_element_fbid) + "</fbid>";
	}
	{
		r = r + "<time>" + Utility::l2string(_element_time) + "</time>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Dashboard_news::IsSet() const
{
	return ImageIsSet() || NewsIsSet() || FbidIsSet() || TimeIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Dashboard_news::GetImage() const
{
	return _element_image;
}


void Dashboard_news::SetImage(const std::string& image)
{
	_element_image = image;
	_element_image_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Dashboard_news::News_t& Dashboard_news::GetNews() const
{
	return _element_news;
}


com_facebook_1_0_::Dashboard_news::News_t& Dashboard_news::GetNews()
{
	return _element_news;
}


void Dashboard_news::SetNews(const com_facebook_1_0_::Dashboard_news::News_t& news)
{
	_element_news = news;
}


// -----------------------------------------------------------------------------
long Dashboard_news::GetFbid() const
{
	return _element_fbid;
}


void Dashboard_news::SetFbid(long fbid)
{
	_element_fbid = fbid;
	_element_fbid_is_set = true;
}


// -----------------------------------------------------------------------------
int Dashboard_news::GetTime() const
{
	return _element_time;
}


void Dashboard_news::SetTime(int time)
{
	_element_time = time;
	_element_time_is_set = true;
}


// -----------------------------------------------------------------------------
bool Dashboard_news::NewsIsSet() const
{
	return _element_news.IsSet();
}


// -----------------------------------------------------------------------------
Dashboard_news::News_t::News_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Dashboard_news::News_t::News_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Dashboard_news::News_t::clear()
{
	while (!_element_dashboard_bundle.empty())
		_element_dashboard_bundle.erase( _element_dashboard_bundle.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Dashboard_news::News_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "dashboard_bundle");
		while (n)
		{
			com_facebook_1_0_::Dashboard_bundle tmp(n);
			_element_dashboard_bundle.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Dashboard_news::News_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Dashboard_bundle>::const_iterator it = _element_dashboard_bundle.begin(); it != _element_dashboard_bundle.end(); it++)
	{
		const com_facebook_1_0_::Dashboard_bundle& ref = *it;
		r += ref.ToString("dashboard_bundle");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Dashboard_news::News_t::IsSet() const
{
	return Dashboard_bundleIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Dashboard_bundle>& Dashboard_news::News_t::GetDashboard_bundle() const
{
	return _element_dashboard_bundle;
}


std::list<com_facebook_1_0_::Dashboard_bundle>& Dashboard_news::News_t::GetDashboard_bundle()
{
	return _element_dashboard_bundle;
}


void Dashboard_news::News_t::SetDashboard_bundle(const std::list<com_facebook_1_0_::Dashboard_bundle>& dashboard_bundle)
{
	_element_dashboard_bundle = dashboard_bundle;
}


// -----------------------------------------------------------------------------
bool Dashboard_news::News_t::Dashboard_bundleIsSet() const
{
	return !_element_dashboard_bundle.empty();
}


// -----------------------------------------------------------------------------
bool Dashboard_news::News_t::GetList() const
{
	return _attribute_list;
}


void Dashboard_news::News_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Privacy::Privacy()
: _element_description_is_set(false)
, _element_value_is_set(false)
, _element_friends_is_set(false)
{
}


// -----------------------------------------------------------------------------
Privacy::Privacy(const Xml::XmlNode& it)
: _element_description_is_set(false)
, _element_value_is_set(false)
, _element_friends_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Privacy::clear()
{
	_element_description.clear();
	_element_value.clear();
	_element_friends.clear();
	_element_networks.clear();
	_element_allow.clear();
	_element_deny.clear();
	_element_description_is_set = false;
	_element_value_is_set = false;
	_element_friends_is_set = false;
}


// -----------------------------------------------------------------------------
void Privacy::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("description"))
		throw Xml::XmlException("missing required node in element 'privacy': description");
	SetDescription( it["description"] );
	if (!it.Exists("value"))
		throw Xml::XmlException("missing required node in element 'privacy': value");
	SetValue( it["value"] );
	if (!it.Exists("friends"))
		throw Xml::XmlException("missing required node in element 'privacy': friends");
	SetFriends( it["friends"] );
	if (!it.Exists("networks"))
		throw Xml::XmlException("missing required node in element 'privacy': networks");
	{
		Xml::XmlNode n(it, "networks");
		if (n)
			_element_networks.FromXml( n );
	}
	if (!it.Exists("allow"))
		throw Xml::XmlException("missing required node in element 'privacy': allow");
	{
		Xml::XmlNode n(it, "allow");
		if (n)
			_element_allow.FromXml( n );
	}
	if (!it.Exists("deny"))
		throw Xml::XmlException("missing required node in element 'privacy': deny");
	{
		Xml::XmlNode n(it, "deny");
		if (n)
			_element_deny.FromXml( n );
	}
}


// -----------------------------------------------------------------------------
const std::string Privacy::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<description>" + _element_description + "</description>";
	r += "<value>" + _element_value + "</value>";
	r += "<friends>" + _element_friends + "</friends>";
	r += _element_networks.ToString("networks");
	r += _element_allow.ToString("allow");
	r += _element_deny.ToString("deny");
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Privacy::IsSet() const
{
	return DescriptionIsSet() || ValueIsSet() || FriendsIsSet() || NetworksIsSet() || AllowIsSet() || DenyIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Privacy::GetDescription() const
{
	return _element_description;
}


void Privacy::SetDescription(const std::string& description)
{
	_element_description = description;
	_element_description_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Privacy::GetValue() const
{
	return _element_value;
}


void Privacy::SetValue(const std::string& value)
{
	_element_value = value;
	_element_value_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Privacy::GetFriends() const
{
	return _element_friends;
}


void Privacy::SetFriends(const std::string& friends)
{
	_element_friends = friends;
	_element_friends_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Privacy::Networks_t& Privacy::GetNetworks() const
{
	return _element_networks;
}


com_facebook_1_0_::Privacy::Networks_t& Privacy::GetNetworks()
{
	return _element_networks;
}


void Privacy::SetNetworks(const com_facebook_1_0_::Privacy::Networks_t& networks)
{
	_element_networks = networks;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Privacy::Allow_t& Privacy::GetAllow() const
{
	return _element_allow;
}


com_facebook_1_0_::Privacy::Allow_t& Privacy::GetAllow()
{
	return _element_allow;
}


void Privacy::SetAllow(const com_facebook_1_0_::Privacy::Allow_t& allow)
{
	_element_allow = allow;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Privacy::Deny_t& Privacy::GetDeny() const
{
	return _element_deny;
}


com_facebook_1_0_::Privacy::Deny_t& Privacy::GetDeny()
{
	return _element_deny;
}


void Privacy::SetDeny(const com_facebook_1_0_::Privacy::Deny_t& deny)
{
	_element_deny = deny;
}


// -----------------------------------------------------------------------------
bool Privacy::NetworksIsSet() const
{
	return _element_networks.IsSet();
}


// -----------------------------------------------------------------------------
bool Privacy::AllowIsSet() const
{
	return _element_allow.IsSet();
}


// -----------------------------------------------------------------------------
bool Privacy::DenyIsSet() const
{
	return _element_deny.IsSet();
}


// -----------------------------------------------------------------------------
Privacy::Networks_t::Networks_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Privacy::Networks_t::Networks_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Privacy::Networks_t::clear()
{
	while (!_element_networks_elt.empty())
		_element_networks_elt.erase( _element_networks_elt.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Privacy::Networks_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "networks_elt");
		while (n)
		{
			_element_networks_elt.push_back( n.GetContent() );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Privacy::Networks_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<std::string>::const_iterator it = _element_networks_elt.begin(); it != _element_networks_elt.end(); it++)
	{
		r += "<networks_elt>" + *it + "</networks_elt>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Privacy::Networks_t::IsSet() const
{
	return Networks_eltIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<std::string>& Privacy::Networks_t::GetNetworks_elt() const
{
	return _element_networks_elt;
}


std::list<std::string>& Privacy::Networks_t::GetNetworks_elt()
{
	return _element_networks_elt;
}


void Privacy::Networks_t::SetNetworks_elt(const std::list<std::string>& networks_elt)
{
	_element_networks_elt = networks_elt;
}


// -----------------------------------------------------------------------------
bool Privacy::Networks_t::Networks_eltIsSet() const
{
	return !_element_networks_elt.empty();
}


// -----------------------------------------------------------------------------
bool Privacy::Networks_t::GetList() const
{
	return _attribute_list;
}


void Privacy::Networks_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Privacy::Allow_t::Allow_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Privacy::Allow_t::Allow_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Privacy::Allow_t::clear()
{
	while (!_element_allow_elt.empty())
		_element_allow_elt.erase( _element_allow_elt.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Privacy::Allow_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "allow_elt");
		while (n)
		{
			_element_allow_elt.push_back( n.GetContent() );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Privacy::Allow_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<std::string>::const_iterator it = _element_allow_elt.begin(); it != _element_allow_elt.end(); it++)
	{
		r += "<allow_elt>" + *it + "</allow_elt>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Privacy::Allow_t::IsSet() const
{
	return Allow_eltIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<std::string>& Privacy::Allow_t::GetAllow_elt() const
{
	return _element_allow_elt;
}


std::list<std::string>& Privacy::Allow_t::GetAllow_elt()
{
	return _element_allow_elt;
}


void Privacy::Allow_t::SetAllow_elt(const std::list<std::string>& allow_elt)
{
	_element_allow_elt = allow_elt;
}


// -----------------------------------------------------------------------------
bool Privacy::Allow_t::Allow_eltIsSet() const
{
	return !_element_allow_elt.empty();
}


// -----------------------------------------------------------------------------
bool Privacy::Allow_t::GetList() const
{
	return _attribute_list;
}


void Privacy::Allow_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Privacy::Deny_t::Deny_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Privacy::Deny_t::Deny_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Privacy::Deny_t::clear()
{
	while (!_element_deny_elt.empty())
		_element_deny_elt.erase( _element_deny_elt.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Privacy::Deny_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "deny_elt");
		while (n)
		{
			_element_deny_elt.push_back( n.GetContent() );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Privacy::Deny_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<std::string>::const_iterator it = _element_deny_elt.begin(); it != _element_deny_elt.end(); it++)
	{
		r += "<deny_elt>" + *it + "</deny_elt>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Privacy::Deny_t::IsSet() const
{
	return Deny_eltIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<std::string>& Privacy::Deny_t::GetDeny_elt() const
{
	return _element_deny_elt;
}


std::list<std::string>& Privacy::Deny_t::GetDeny_elt()
{
	return _element_deny_elt;
}


void Privacy::Deny_t::SetDeny_elt(const std::list<std::string>& deny_elt)
{
	_element_deny_elt = deny_elt;
}


// -----------------------------------------------------------------------------
bool Privacy::Deny_t::Deny_eltIsSet() const
{
	return !_element_deny_elt.empty();
}


// -----------------------------------------------------------------------------
bool Privacy::Deny_t::GetList() const
{
	return _attribute_list;
}


void Privacy::Deny_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Stream_comments::Stream_comments()
: _element_count(0)
, _element_can_remove_is_set(false)
, _element_can_post_is_set(false)
, _element_count_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_comments::Stream_comments(const Xml::XmlNode& it)
: _element_count(0)
, _element_can_remove_is_set(false)
, _element_can_post_is_set(false)
, _element_count_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_comments::clear()
{
	_element_can_remove = false;
	_element_can_post = false;
	_element_count = 0;
	_element_comment_list.clear();
	_element_can_remove_is_set = false;
	_element_can_post_is_set = false;
	_element_count_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_comments::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("can_remove"))
		throw Xml::XmlException("missing required node in element 'stream_comments': can_remove");
	SetCan_remove( atoi(std::string(it["can_remove"]).c_str()) );
	if (!it.Exists("can_post"))
		throw Xml::XmlException("missing required node in element 'stream_comments': can_post");
	SetCan_post( atoi(std::string(it["can_post"]).c_str()) );
	if (!it.Exists("count"))
		throw Xml::XmlException("missing required node in element 'stream_comments': count");
	SetCount( atoi(std::string(it["count"]).c_str()) );
	if (!it.Exists("comment_list"))
		throw Xml::XmlException("missing required node in element 'stream_comments': comment_list");
	{
		Xml::XmlNode n(it, "comment_list");
		if (n)
			_element_comment_list.FromXml( n );
	}
}


// -----------------------------------------------------------------------------
const std::string Stream_comments::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<can_remove>" + Utility::l2string(_element_can_remove) + "</can_remove>";
	}
	{
		r = r + "<can_post>" + Utility::l2string(_element_can_post) + "</can_post>";
	}
	{
		r = r + "<count>" + Utility::l2string(_element_count) + "</count>";
	}
	r += _element_comment_list.ToString("comment_list");
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_comments::IsSet() const
{
	return Can_removeIsSet() || Can_postIsSet() || CountIsSet() || Comment_listIsSet();
}


// -----------------------------------------------------------------------------
bool Stream_comments::GetCan_remove() const
{
	return _element_can_remove;
}


void Stream_comments::SetCan_remove(bool can_remove)
{
	_element_can_remove = can_remove;
	_element_can_remove_is_set = true;
}


// -----------------------------------------------------------------------------
bool Stream_comments::GetCan_post() const
{
	return _element_can_post;
}


void Stream_comments::SetCan_post(bool can_post)
{
	_element_can_post = can_post;
	_element_can_post_is_set = true;
}


// -----------------------------------------------------------------------------
int Stream_comments::GetCount() const
{
	return _element_count;
}


void Stream_comments::SetCount(int count)
{
	_element_count = count;
	_element_count_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Stream_comments::Comment_list_t& Stream_comments::GetComment_list() const
{
	return _element_comment_list;
}


com_facebook_1_0_::Stream_comments::Comment_list_t& Stream_comments::GetComment_list()
{
	return _element_comment_list;
}


void Stream_comments::SetComment_list(const com_facebook_1_0_::Stream_comments::Comment_list_t& comment_list)
{
	_element_comment_list = comment_list;
}


// -----------------------------------------------------------------------------
bool Stream_comments::Comment_listIsSet() const
{
	return _element_comment_list.IsSet();
}


// -----------------------------------------------------------------------------
Stream_comments::Comment_list_t::Comment_list_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_comments::Comment_list_t::Comment_list_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_comments::Comment_list_t::clear()
{
	while (!_element_comment.empty())
		_element_comment.erase( _element_comment.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_comments::Comment_list_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "comment");
		while (n)
		{
			com_facebook_1_0_::Comment tmp(n);
			_element_comment.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Stream_comments::Comment_list_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Comment>::const_iterator it = _element_comment.begin(); it != _element_comment.end(); it++)
	{
		const com_facebook_1_0_::Comment& ref = *it;
		r += ref.ToString("comment");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_comments::Comment_list_t::IsSet() const
{
	return CommentIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Comment>& Stream_comments::Comment_list_t::GetComment() const
{
	return _element_comment;
}


std::list<com_facebook_1_0_::Comment>& Stream_comments::Comment_list_t::GetComment()
{
	return _element_comment;
}


void Stream_comments::Comment_list_t::SetComment(const std::list<com_facebook_1_0_::Comment>& comment)
{
	_element_comment = comment;
}


// -----------------------------------------------------------------------------
bool Stream_comments::Comment_list_t::CommentIsSet() const
{
	return !_element_comment.empty();
}


// -----------------------------------------------------------------------------
bool Stream_comments::Comment_list_t::GetList() const
{
	return _attribute_list;
}


void Stream_comments::Comment_list_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Stream_likes::Stream_likes()
: _element_count(0)
, _element_href_is_set(false)
, _element_count_is_set(false)
, _element_user_likes_is_set(false)
, _element_can_like_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_likes::Stream_likes(const Xml::XmlNode& it)
: _element_count(0)
, _element_href_is_set(false)
, _element_count_is_set(false)
, _element_user_likes_is_set(false)
, _element_can_like_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_likes::clear()
{
	_element_href.clear();
	_element_count = 0;
	_element_sample.clear();
	_element_friends.clear();
	_element_user_likes = false;
	_element_can_like = false;
	_element_href_is_set = false;
	_element_count_is_set = false;
	_element_user_likes_is_set = false;
	_element_can_like_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_likes::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("href"))
		throw Xml::XmlException("missing required node in element 'stream_likes': href");
	SetHref( it["href"] );
	if (!it.Exists("count"))
		throw Xml::XmlException("missing required node in element 'stream_likes': count");
	SetCount( atoi(std::string(it["count"]).c_str()) );
	if (!it.Exists("sample"))
		throw Xml::XmlException("missing required node in element 'stream_likes': sample");
	{
		Xml::XmlNode n(it, "sample");
		if (n)
			_element_sample.FromXml( n );
	}
	if (!it.Exists("friends"))
		throw Xml::XmlException("missing required node in element 'stream_likes': friends");
	{
		Xml::XmlNode n(it, "friends");
		if (n)
			_element_friends.FromXml( n );
	}
	if (!it.Exists("user_likes"))
		throw Xml::XmlException("missing required node in element 'stream_likes': user_likes");
	SetUser_likes( atoi(std::string(it["user_likes"]).c_str()) );
	if (!it.Exists("can_like"))
		throw Xml::XmlException("missing required node in element 'stream_likes': can_like");
	SetCan_like( atoi(std::string(it["can_like"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Stream_likes::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<href>" + _element_href + "</href>";
	{
		r = r + "<count>" + Utility::l2string(_element_count) + "</count>";
	}
	r += _element_sample.ToString("sample");
	r += _element_friends.ToString("friends");
	{
		r = r + "<user_likes>" + Utility::l2string(_element_user_likes) + "</user_likes>";
	}
	{
		r = r + "<can_like>" + Utility::l2string(_element_can_like) + "</can_like>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_likes::IsSet() const
{
	return HrefIsSet() || CountIsSet() || SampleIsSet() || FriendsIsSet() || User_likesIsSet() || Can_likeIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Stream_likes::GetHref() const
{
	return _element_href;
}


void Stream_likes::SetHref(const std::string& href)
{
	_element_href = href;
	_element_href_is_set = true;
}


// -----------------------------------------------------------------------------
int Stream_likes::GetCount() const
{
	return _element_count;
}


void Stream_likes::SetCount(int count)
{
	_element_count = count;
	_element_count_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Stream_likes::Sample_t& Stream_likes::GetSample() const
{
	return _element_sample;
}


com_facebook_1_0_::Stream_likes::Sample_t& Stream_likes::GetSample()
{
	return _element_sample;
}


void Stream_likes::SetSample(const com_facebook_1_0_::Stream_likes::Sample_t& sample)
{
	_element_sample = sample;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Stream_likes::Friends_t& Stream_likes::GetFriends() const
{
	return _element_friends;
}


com_facebook_1_0_::Stream_likes::Friends_t& Stream_likes::GetFriends()
{
	return _element_friends;
}


void Stream_likes::SetFriends(const com_facebook_1_0_::Stream_likes::Friends_t& friends)
{
	_element_friends = friends;
}


// -----------------------------------------------------------------------------
bool Stream_likes::GetUser_likes() const
{
	return _element_user_likes;
}


void Stream_likes::SetUser_likes(bool user_likes)
{
	_element_user_likes = user_likes;
	_element_user_likes_is_set = true;
}


// -----------------------------------------------------------------------------
bool Stream_likes::GetCan_like() const
{
	return _element_can_like;
}


void Stream_likes::SetCan_like(bool can_like)
{
	_element_can_like = can_like;
	_element_can_like_is_set = true;
}


// -----------------------------------------------------------------------------
bool Stream_likes::SampleIsSet() const
{
	return _element_sample.IsSet();
}


// -----------------------------------------------------------------------------
bool Stream_likes::FriendsIsSet() const
{
	return _element_friends.IsSet();
}


// -----------------------------------------------------------------------------
Stream_likes::Sample_t::Sample_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_likes::Sample_t::Sample_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_likes::Sample_t::clear()
{
	while (!_element_uid.empty())
		_element_uid.erase( _element_uid.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_likes::Sample_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "uid");
		while (n)
		{
			_element_uid.push_back( atoi(n.GetContent().c_str()) );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Stream_likes::Sample_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<long>::const_iterator it = _element_uid.begin(); it != _element_uid.end(); it++)
	{
			r = r + "<uid>" + Utility::l2string(*it) + "</uid>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_likes::Sample_t::IsSet() const
{
	return UidIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<long>& Stream_likes::Sample_t::GetUid() const
{
	return _element_uid;
}


std::list<long>& Stream_likes::Sample_t::GetUid()
{
	return _element_uid;
}


void Stream_likes::Sample_t::SetUid(const std::list<long>& uid)
{
	_element_uid = uid;
}


// -----------------------------------------------------------------------------
bool Stream_likes::Sample_t::UidIsSet() const
{
	return !_element_uid.empty();
}


// -----------------------------------------------------------------------------
bool Stream_likes::Sample_t::GetList() const
{
	return _attribute_list;
}


void Stream_likes::Sample_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Stream_likes::Friends_t::Friends_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_likes::Friends_t::Friends_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_likes::Friends_t::clear()
{
	while (!_element_uid.empty())
		_element_uid.erase( _element_uid.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_likes::Friends_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "uid");
		while (n)
		{
			_element_uid.push_back( atoi(n.GetContent().c_str()) );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Stream_likes::Friends_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<long>::const_iterator it = _element_uid.begin(); it != _element_uid.end(); it++)
	{
			r = r + "<uid>" + Utility::l2string(*it) + "</uid>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_likes::Friends_t::IsSet() const
{
	return UidIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<long>& Stream_likes::Friends_t::GetUid() const
{
	return _element_uid;
}


std::list<long>& Stream_likes::Friends_t::GetUid()
{
	return _element_uid;
}


void Stream_likes::Friends_t::SetUid(const std::list<long>& uid)
{
	_element_uid = uid;
}


// -----------------------------------------------------------------------------
bool Stream_likes::Friends_t::UidIsSet() const
{
	return !_element_uid.empty();
}


// -----------------------------------------------------------------------------
bool Stream_likes::Friends_t::GetList() const
{
	return _attribute_list;
}


void Stream_likes::Friends_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Stream_video::Stream_video()
: _element_display_url_is_set(false)
, _element_source_url_is_set(false)
, _element_owner_is_set(false)
, _element_permalink_is_set(false)
, _element_preview_img_is_set(false)
, _element_source_type_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_video::Stream_video(const Xml::XmlNode& it)
: _element_display_url_is_set(false)
, _element_source_url_is_set(false)
, _element_owner_is_set(false)
, _element_permalink_is_set(false)
, _element_preview_img_is_set(false)
, _element_source_type_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_video::clear()
{
	_element_display_url.clear();
	_element_source_url.clear();
	// simpleType:
	// _element_owner.clear();
	_element_permalink.clear();
	_element_preview_img.clear();
	_element_source_type.clear();
	_element_display_url_is_set = false;
	_element_source_url_is_set = false;
	_element_owner_is_set = false;
	_element_permalink_is_set = false;
	_element_preview_img_is_set = false;
	_element_source_type_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_video::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("display_url"))
		throw Xml::XmlException("missing required node in element 'stream_video': display_url");
	SetDisplay_url( it["display_url"] );
	if (!it.Exists("source_url"))
		throw Xml::XmlException("missing required node in element 'stream_video': source_url");
	SetSource_url( it["source_url"] );
	if (!it.Exists("owner"))
		throw Xml::XmlException("missing required node in element 'stream_video': owner");
	SetOwner( atoi(std::string(it["owner"]).c_str()) );
	if (!it.Exists("permalink"))
		throw Xml::XmlException("missing required node in element 'stream_video': permalink");
	SetPermalink( it["permalink"] );
	if (!it.Exists("preview_img"))
		throw Xml::XmlException("missing required node in element 'stream_video': preview_img");
	SetPreview_img( it["preview_img"] );
	if (!it.Exists("source_type"))
		throw Xml::XmlException("missing required node in element 'stream_video': source_type");
	SetSource_type( it["source_type"] );
}


// -----------------------------------------------------------------------------
const std::string Stream_video::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<display_url>" + _element_display_url + "</display_url>";
	r += "<source_url>" + _element_source_url + "</source_url>";
	{
		r = r + "<owner>" + Utility::l2string(_element_owner) + "</owner>";
	}
	r += "<permalink>" + _element_permalink + "</permalink>";
	r += "<preview_img>" + _element_preview_img + "</preview_img>";
	r += "<source_type>" + _element_source_type + "</source_type>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_video::IsSet() const
{
	return Display_urlIsSet() || Source_urlIsSet() || OwnerIsSet() || PermalinkIsSet() || Preview_imgIsSet() || Source_typeIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Stream_video::GetDisplay_url() const
{
	return _element_display_url;
}


void Stream_video::SetDisplay_url(const std::string& display_url)
{
	_element_display_url = display_url;
	_element_display_url_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_video::GetSource_url() const
{
	return _element_source_url;
}


void Stream_video::SetSource_url(const std::string& source_url)
{
	_element_source_url = source_url;
	_element_source_url_is_set = true;
}


// -----------------------------------------------------------------------------
long Stream_video::GetOwner() const
{
	return _element_owner;
}


void Stream_video::SetOwner(long owner)
{
	_element_owner = owner;
	_element_owner_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_video::GetPermalink() const
{
	return _element_permalink;
}


void Stream_video::SetPermalink(const std::string& permalink)
{
	_element_permalink = permalink;
	_element_permalink_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_video::GetPreview_img() const
{
	return _element_preview_img;
}


void Stream_video::SetPreview_img(const std::string& preview_img)
{
	_element_preview_img = preview_img;
	_element_preview_img_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_video::GetSource_type() const
{
	return _element_source_type;
}


void Stream_video::SetSource_type(const std::string& source_type)
{
	_element_source_type = source_type;
	_element_source_type_is_set = true;
}


// -----------------------------------------------------------------------------
Stream_photo::Stream_photo()
: _element_index(0)
, _element_width(0)
, _element_height(0)
, _element_aid_is_set(false)
, _element_pid_is_set(false)
, _element_owner_is_set(false)
, _element_index_is_set(false)
, _element_width_is_set(false)
, _element_height_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_photo::Stream_photo(const Xml::XmlNode& it)
: _element_index(0)
, _element_width(0)
, _element_height(0)
, _element_aid_is_set(false)
, _element_pid_is_set(false)
, _element_owner_is_set(false)
, _element_index_is_set(false)
, _element_width_is_set(false)
, _element_height_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_photo::clear()
{
	// simpleType:
	// _element_aid.clear();
	// simpleType:
	// _element_pid.clear();
	// simpleType:
	// _element_owner.clear();
	_element_index = 0;
	_element_width = 0;
	_element_height = 0;
	_element_aid_is_set = false;
	_element_pid_is_set = false;
	_element_owner_is_set = false;
	_element_index_is_set = false;
	_element_width_is_set = false;
	_element_height_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_photo::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("aid"))
		throw Xml::XmlException("missing required node in element 'stream_photo': aid");
	SetAid( it["aid"] );
	if (!it.Exists("pid"))
		throw Xml::XmlException("missing required node in element 'stream_photo': pid");
	SetPid( it["pid"] );
	if (!it.Exists("owner"))
		throw Xml::XmlException("missing required node in element 'stream_photo': owner");
	SetOwner( atoi(std::string(it["owner"]).c_str()) );
	if (!it.Exists("index"))
		throw Xml::XmlException("missing required node in element 'stream_photo': index");
	SetIndex( atoi(std::string(it["index"]).c_str()) );
	if (!it.Exists("width"))
		throw Xml::XmlException("missing required node in element 'stream_photo': width");
	SetWidth( atoi(std::string(it["width"]).c_str()) );
	if (!it.Exists("height"))
		throw Xml::XmlException("missing required node in element 'stream_photo': height");
	SetHeight( atoi(std::string(it["height"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Stream_photo::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<aid>" + _element_aid + "</aid>";
	r += "<pid>" + _element_pid + "</pid>";
	{
		r = r + "<owner>" + Utility::l2string(_element_owner) + "</owner>";
	}
	{
		r = r + "<index>" + Utility::l2string(_element_index) + "</index>";
	}
	{
		r = r + "<width>" + Utility::l2string(_element_width) + "</width>";
	}
	{
		r = r + "<height>" + Utility::l2string(_element_height) + "</height>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_photo::IsSet() const
{
	return AidIsSet() || PidIsSet() || OwnerIsSet() || IndexIsSet() || WidthIsSet() || HeightIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Stream_photo::GetAid() const
{
	return _element_aid;
}


void Stream_photo::SetAid(const std::string& aid)
{
	_element_aid = aid;
	_element_aid_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_photo::GetPid() const
{
	return _element_pid;
}


void Stream_photo::SetPid(const std::string& pid)
{
	_element_pid = pid;
	_element_pid_is_set = true;
}


// -----------------------------------------------------------------------------
long Stream_photo::GetOwner() const
{
	return _element_owner;
}


void Stream_photo::SetOwner(long owner)
{
	_element_owner = owner;
	_element_owner_is_set = true;
}


// -----------------------------------------------------------------------------
int Stream_photo::GetIndex() const
{
	return _element_index;
}


void Stream_photo::SetIndex(int index)
{
	_element_index = index;
	_element_index_is_set = true;
}


// -----------------------------------------------------------------------------
int Stream_photo::GetWidth() const
{
	return _element_width;
}


void Stream_photo::SetWidth(int width)
{
	_element_width = width;
	_element_width_is_set = true;
}


// -----------------------------------------------------------------------------
int Stream_photo::GetHeight() const
{
	return _element_height;
}


void Stream_photo::SetHeight(int height)
{
	_element_height = height;
	_element_height_is_set = true;
}


// -----------------------------------------------------------------------------
Stream_swf::Stream_swf()
: _element_width(0)
, _element_height(0)
, _element_source_url_is_set(false)
, _element_preview_img_is_set(false)
, _element_flash_vars_is_set(false)
, _element_width_is_set(false)
, _element_height_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_swf::Stream_swf(const Xml::XmlNode& it)
: _element_width(0)
, _element_height(0)
, _element_source_url_is_set(false)
, _element_preview_img_is_set(false)
, _element_flash_vars_is_set(false)
, _element_width_is_set(false)
, _element_height_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_swf::clear()
{
	_element_source_url.clear();
	_element_preview_img.clear();
	_element_flash_vars.clear();
	_element_width = 0;
	_element_height = 0;
	_element_source_url_is_set = false;
	_element_preview_img_is_set = false;
	_element_flash_vars_is_set = false;
	_element_width_is_set = false;
	_element_height_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_swf::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("source_url"))
		throw Xml::XmlException("missing required node in element 'stream_swf': source_url");
	SetSource_url( it["source_url"] );
	if (!it.Exists("preview_img"))
		throw Xml::XmlException("missing required node in element 'stream_swf': preview_img");
	SetPreview_img( it["preview_img"] );
	if (!it.Exists("flash_vars"))
		throw Xml::XmlException("missing required node in element 'stream_swf': flash_vars");
	SetFlash_vars( it["flash_vars"] );
	if (!it.Exists("width"))
		throw Xml::XmlException("missing required node in element 'stream_swf': width");
	SetWidth( atoi(std::string(it["width"]).c_str()) );
	if (!it.Exists("height"))
		throw Xml::XmlException("missing required node in element 'stream_swf': height");
	SetHeight( atoi(std::string(it["height"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Stream_swf::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<source_url>" + _element_source_url + "</source_url>";
	r += "<preview_img>" + _element_preview_img + "</preview_img>";
	r += "<flash_vars>" + _element_flash_vars + "</flash_vars>";
	{
		r = r + "<width>" + Utility::l2string(_element_width) + "</width>";
	}
	{
		r = r + "<height>" + Utility::l2string(_element_height) + "</height>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_swf::IsSet() const
{
	return Source_urlIsSet() || Preview_imgIsSet() || Flash_varsIsSet() || WidthIsSet() || HeightIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Stream_swf::GetSource_url() const
{
	return _element_source_url;
}


void Stream_swf::SetSource_url(const std::string& source_url)
{
	_element_source_url = source_url;
	_element_source_url_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_swf::GetPreview_img() const
{
	return _element_preview_img;
}


void Stream_swf::SetPreview_img(const std::string& preview_img)
{
	_element_preview_img = preview_img;
	_element_preview_img_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_swf::GetFlash_vars() const
{
	return _element_flash_vars;
}


void Stream_swf::SetFlash_vars(const std::string& flash_vars)
{
	_element_flash_vars = flash_vars;
	_element_flash_vars_is_set = true;
}


// -----------------------------------------------------------------------------
int Stream_swf::GetWidth() const
{
	return _element_width;
}


void Stream_swf::SetWidth(int width)
{
	_element_width = width;
	_element_width_is_set = true;
}


// -----------------------------------------------------------------------------
int Stream_swf::GetHeight() const
{
	return _element_height;
}


void Stream_swf::SetHeight(int height)
{
	_element_height = height;
	_element_height_is_set = true;
}


// -----------------------------------------------------------------------------
Stream_music::Stream_music()
: _element_source_url_is_set(false)
, _element_title_is_set(false)
, _element_artist_is_set(false)
, _element_album_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_music::Stream_music(const Xml::XmlNode& it)
: _element_source_url_is_set(false)
, _element_title_is_set(false)
, _element_artist_is_set(false)
, _element_album_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_music::clear()
{
	_element_source_url.clear();
	_element_title.clear();
	_element_artist.clear();
	_element_album.clear();
	_element_source_url_is_set = false;
	_element_title_is_set = false;
	_element_artist_is_set = false;
	_element_album_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_music::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("source_url"))
		throw Xml::XmlException("missing required node in element 'stream_music': source_url");
	SetSource_url( it["source_url"] );
	if (!it.Exists("title"))
		throw Xml::XmlException("missing required node in element 'stream_music': title");
	SetTitle( it["title"] );
	if (!it.Exists("artist"))
		throw Xml::XmlException("missing required node in element 'stream_music': artist");
	SetArtist( it["artist"] );
	if (!it.Exists("album"))
		throw Xml::XmlException("missing required node in element 'stream_music': album");
	SetAlbum( it["album"] );
}


// -----------------------------------------------------------------------------
const std::string Stream_music::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<source_url>" + _element_source_url + "</source_url>";
	r += "<title>" + _element_title + "</title>";
	r += "<artist>" + _element_artist + "</artist>";
	r += "<album>" + _element_album + "</album>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_music::IsSet() const
{
	return Source_urlIsSet() || TitleIsSet() || ArtistIsSet() || AlbumIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Stream_music::GetSource_url() const
{
	return _element_source_url;
}


void Stream_music::SetSource_url(const std::string& source_url)
{
	_element_source_url = source_url;
	_element_source_url_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_music::GetTitle() const
{
	return _element_title;
}


void Stream_music::SetTitle(const std::string& title)
{
	_element_title = title;
	_element_title_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_music::GetArtist() const
{
	return _element_artist;
}


void Stream_music::SetArtist(const std::string& artist)
{
	_element_artist = artist;
	_element_artist_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_music::GetAlbum() const
{
	return _element_album;
}


void Stream_music::SetAlbum(const std::string& album)
{
	_element_album = album;
	_element_album_is_set = true;
}


// -----------------------------------------------------------------------------
Stream_media::Stream_media()
: _element_href_is_set(false)
, _element_alt_is_set(false)
, _element_type_is_set(false)
, _element_src_is_set(false)
, _element_obj_is_set(false)
, _element_data_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_media::Stream_media(const Xml::XmlNode& it)
: _element_href_is_set(false)
, _element_alt_is_set(false)
, _element_type_is_set(false)
, _element_src_is_set(false)
, _element_obj_is_set(false)
, _element_data_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_media::clear()
{
	_element_href.clear();
	_element_alt.clear();
	_element_type.clear();
	_element_src.clear();
	_element_video.clear();
	_element_obj.clear();
	_element_music.clear();
	_element_data.clear();
	_element_photo.clear();
	_element_swf.clear();
	_element_href_is_set = false;
	_element_alt_is_set = false;
	_element_type_is_set = false;
	_element_src_is_set = false;
	_element_obj_is_set = false;
	_element_data_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_media::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("href"))
		throw Xml::XmlException("missing required node in element 'stream_media': href");
	SetHref( it["href"] );
	if (!it.Exists("alt"))
		throw Xml::XmlException("missing required node in element 'stream_media': alt");
	SetAlt( it["alt"] );
	if (!it.Exists("type"))
		throw Xml::XmlException("missing required node in element 'stream_media': type");
	SetType( it["type"] );
	if (!it.Exists("src"))
		throw Xml::XmlException("missing required node in element 'stream_media': src");
	SetSrc( it["src"] );
	if (!it.Exists("video"))
		throw Xml::XmlException("missing required node in element 'stream_media': video");
	{
		Xml::XmlNode n(it, "video");
		if (n)
			_element_video.FromXml( n );
	}
	if (!it.Exists("obj"))
		throw Xml::XmlException("missing required node in element 'stream_media': obj");
	SetObj( it["obj"] );
	if (!it.Exists("music"))
		throw Xml::XmlException("missing required node in element 'stream_media': music");
	{
		Xml::XmlNode n(it, "music");
		if (n)
			_element_music.FromXml( n );
	}
	if (!it.Exists("data"))
		throw Xml::XmlException("missing required node in element 'stream_media': data");
	SetData( it["data"] );
	if (!it.Exists("photo"))
		throw Xml::XmlException("missing required node in element 'stream_media': photo");
	{
		Xml::XmlNode n(it, "photo");
		if (n)
			_element_photo.FromXml( n );
	}
	if (!it.Exists("swf"))
		throw Xml::XmlException("missing required node in element 'stream_media': swf");
	{
		Xml::XmlNode n(it, "swf");
		if (n)
			_element_swf.FromXml( n );
	}
}


// -----------------------------------------------------------------------------
const std::string Stream_media::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<href>" + _element_href + "</href>";
	r += "<alt>" + _element_alt + "</alt>";
	r += "<type>" + _element_type + "</type>";
	r += "<src>" + _element_src + "</src>";
	r += _element_video.ToString("video");
	r += "<obj>" + _element_obj + "</obj>";
	r += _element_music.ToString("music");
	r += "<data>" + _element_data + "</data>";
	r += _element_photo.ToString("photo");
	r += _element_swf.ToString("swf");
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_media::IsSet() const
{
	return HrefIsSet() || AltIsSet() || TypeIsSet() || SrcIsSet() || VideoIsSet() || ObjIsSet() || MusicIsSet() || DataIsSet() || PhotoIsSet() || SwfIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Stream_media::GetHref() const
{
	return _element_href;
}


void Stream_media::SetHref(const std::string& href)
{
	_element_href = href;
	_element_href_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_media::GetAlt() const
{
	return _element_alt;
}


void Stream_media::SetAlt(const std::string& alt)
{
	_element_alt = alt;
	_element_alt_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_media::GetType() const
{
	return _element_type;
}


void Stream_media::SetType(const std::string& type)
{
	_element_type = type;
	_element_type_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_media::GetSrc() const
{
	return _element_src;
}


void Stream_media::SetSrc(const std::string& src)
{
	_element_src = src;
	_element_src_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Stream_video& Stream_media::GetVideo() const
{
	return _element_video;
}


com_facebook_1_0_::Stream_video& Stream_media::GetVideo()
{
	return _element_video;
}


void Stream_media::SetVideo(const com_facebook_1_0_::Stream_video& video)
{
	_element_video = video;
}


// -----------------------------------------------------------------------------
const std::string& Stream_media::GetObj() const
{
	return _element_obj;
}


void Stream_media::SetObj(const std::string& obj)
{
	_element_obj = obj;
	_element_obj_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Stream_music& Stream_media::GetMusic() const
{
	return _element_music;
}


com_facebook_1_0_::Stream_music& Stream_media::GetMusic()
{
	return _element_music;
}


void Stream_media::SetMusic(const com_facebook_1_0_::Stream_music& music)
{
	_element_music = music;
}


// -----------------------------------------------------------------------------
const std::string& Stream_media::GetData() const
{
	return _element_data;
}


void Stream_media::SetData(const std::string& data)
{
	_element_data = data;
	_element_data_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Stream_photo& Stream_media::GetPhoto() const
{
	return _element_photo;
}


com_facebook_1_0_::Stream_photo& Stream_media::GetPhoto()
{
	return _element_photo;
}


void Stream_media::SetPhoto(const com_facebook_1_0_::Stream_photo& photo)
{
	_element_photo = photo;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Stream_swf& Stream_media::GetSwf() const
{
	return _element_swf;
}


com_facebook_1_0_::Stream_swf& Stream_media::GetSwf()
{
	return _element_swf;
}


void Stream_media::SetSwf(const com_facebook_1_0_::Stream_swf& swf)
{
	_element_swf = swf;
}


// -----------------------------------------------------------------------------
bool Stream_media::VideoIsSet() const
{
	return _element_video.IsSet();
}


// -----------------------------------------------------------------------------
bool Stream_media::MusicIsSet() const
{
	return _element_music.IsSet();
}


// -----------------------------------------------------------------------------
bool Stream_media::PhotoIsSet() const
{
	return _element_photo.IsSet();
}


// -----------------------------------------------------------------------------
bool Stream_media::SwfIsSet() const
{
	return _element_swf.IsSet();
}


// -----------------------------------------------------------------------------
Stream_property::Stream_property()
: _element_name_is_set(false)
, _element_text_is_set(false)
, _element_href_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_property::Stream_property(const Xml::XmlNode& it)
: _element_name_is_set(false)
, _element_text_is_set(false)
, _element_href_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_property::clear()
{
	_element_name.clear();
	_element_text.clear();
	_element_href.clear();
	_element_name_is_set = false;
	_element_text_is_set = false;
	_element_href_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_property::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("name"))
		throw Xml::XmlException("missing required node in element 'stream_property': name");
	SetName( it["name"] );
	if (!it.Exists("text"))
		throw Xml::XmlException("missing required node in element 'stream_property': text");
	SetText( it["text"] );
	if (!it.Exists("href"))
		throw Xml::XmlException("missing required node in element 'stream_property': href");
	SetHref( it["href"] );
}


// -----------------------------------------------------------------------------
const std::string Stream_property::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<name>" + _element_name + "</name>";
	r += "<text>" + _element_text + "</text>";
	r += "<href>" + _element_href + "</href>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_property::IsSet() const
{
	return NameIsSet() || TextIsSet() || HrefIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Stream_property::GetName() const
{
	return _element_name;
}


void Stream_property::SetName(const std::string& name)
{
	_element_name = name;
	_element_name_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_property::GetText() const
{
	return _element_text;
}


void Stream_property::SetText(const std::string& text)
{
	_element_text = text;
	_element_text_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_property::GetHref() const
{
	return _element_href;
}


void Stream_property::SetHref(const std::string& href)
{
	_element_href = href;
	_element_href_is_set = true;
}


// -----------------------------------------------------------------------------
Stream_attachment::Stream_attachment()
: _element_name_is_set(false)
, _element_href_is_set(false)
, _element_caption_is_set(false)
, _element_description_is_set(false)
, _element_icon_is_set(false)
, _element_fb_object_type_is_set(false)
, _element_fb_object_id_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_attachment::Stream_attachment(const Xml::XmlNode& it)
: _element_name_is_set(false)
, _element_href_is_set(false)
, _element_caption_is_set(false)
, _element_description_is_set(false)
, _element_icon_is_set(false)
, _element_fb_object_type_is_set(false)
, _element_fb_object_id_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_attachment::clear()
{
	_element_media.clear();
	_element_name.clear();
	_element_href.clear();
	_element_caption.clear();
	_element_description.clear();
	_element_properties.clear();
	_element_icon.clear();
	_element_fb_object_type.clear();
	_element_fb_object_id.clear();
	_element_name_is_set = false;
	_element_href_is_set = false;
	_element_caption_is_set = false;
	_element_description_is_set = false;
	_element_icon_is_set = false;
	_element_fb_object_type_is_set = false;
	_element_fb_object_id_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_attachment::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("media"))
		throw Xml::XmlException("missing required node in element 'stream_attachment': media");
	{
		Xml::XmlNode n(it, "media");
		if (n)
			_element_media.FromXml( n );
	}
	if (!it.Exists("name"))
		throw Xml::XmlException("missing required node in element 'stream_attachment': name");
	SetName( it["name"] );
	if (!it.Exists("href"))
		throw Xml::XmlException("missing required node in element 'stream_attachment': href");
	SetHref( it["href"] );
	if (!it.Exists("caption"))
		throw Xml::XmlException("missing required node in element 'stream_attachment': caption");
	SetCaption( it["caption"] );
	if (!it.Exists("description"))
		throw Xml::XmlException("missing required node in element 'stream_attachment': description");
	SetDescription( it["description"] );
	if (!it.Exists("properties"))
		throw Xml::XmlException("missing required node in element 'stream_attachment': properties");
	{
		Xml::XmlNode n(it, "properties");
		if (n)
			_element_properties.FromXml( n );
	}
	if (!it.Exists("icon"))
		throw Xml::XmlException("missing required node in element 'stream_attachment': icon");
	SetIcon( it["icon"] );
	if (!it.Exists("fb_object_type"))
		throw Xml::XmlException("missing required node in element 'stream_attachment': fb_object_type");
	SetFb_object_type( it["fb_object_type"] );
	if (!it.Exists("fb_object_id"))
		throw Xml::XmlException("missing required node in element 'stream_attachment': fb_object_id");
	SetFb_object_id( it["fb_object_id"] );
}


// -----------------------------------------------------------------------------
const std::string Stream_attachment::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += _element_media.ToString("media");
	r += "<name>" + _element_name + "</name>";
	r += "<href>" + _element_href + "</href>";
	r += "<caption>" + _element_caption + "</caption>";
	r += "<description>" + _element_description + "</description>";
	r += _element_properties.ToString("properties");
	r += "<icon>" + _element_icon + "</icon>";
	r += "<fb_object_type>" + _element_fb_object_type + "</fb_object_type>";
	r += "<fb_object_id>" + _element_fb_object_id + "</fb_object_id>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_attachment::IsSet() const
{
	return MediaIsSet() || NameIsSet() || HrefIsSet() || CaptionIsSet() || DescriptionIsSet() || PropertiesIsSet() || IconIsSet() || Fb_object_typeIsSet() || Fb_object_idIsSet();
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Stream_attachment::Media_t& Stream_attachment::GetMedia() const
{
	return _element_media;
}


com_facebook_1_0_::Stream_attachment::Media_t& Stream_attachment::GetMedia()
{
	return _element_media;
}


void Stream_attachment::SetMedia(const com_facebook_1_0_::Stream_attachment::Media_t& media)
{
	_element_media = media;
}


// -----------------------------------------------------------------------------
const std::string& Stream_attachment::GetName() const
{
	return _element_name;
}


void Stream_attachment::SetName(const std::string& name)
{
	_element_name = name;
	_element_name_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_attachment::GetHref() const
{
	return _element_href;
}


void Stream_attachment::SetHref(const std::string& href)
{
	_element_href = href;
	_element_href_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_attachment::GetCaption() const
{
	return _element_caption;
}


void Stream_attachment::SetCaption(const std::string& caption)
{
	_element_caption = caption;
	_element_caption_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_attachment::GetDescription() const
{
	return _element_description;
}


void Stream_attachment::SetDescription(const std::string& description)
{
	_element_description = description;
	_element_description_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Stream_attachment::Properties_t& Stream_attachment::GetProperties() const
{
	return _element_properties;
}


com_facebook_1_0_::Stream_attachment::Properties_t& Stream_attachment::GetProperties()
{
	return _element_properties;
}


void Stream_attachment::SetProperties(const com_facebook_1_0_::Stream_attachment::Properties_t& properties)
{
	_element_properties = properties;
}


// -----------------------------------------------------------------------------
const std::string& Stream_attachment::GetIcon() const
{
	return _element_icon;
}


void Stream_attachment::SetIcon(const std::string& icon)
{
	_element_icon = icon;
	_element_icon_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_attachment::GetFb_object_type() const
{
	return _element_fb_object_type;
}


void Stream_attachment::SetFb_object_type(const std::string& fb_object_type)
{
	_element_fb_object_type = fb_object_type;
	_element_fb_object_type_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_attachment::GetFb_object_id() const
{
	return _element_fb_object_id;
}


void Stream_attachment::SetFb_object_id(const std::string& fb_object_id)
{
	_element_fb_object_id = fb_object_id;
	_element_fb_object_id_is_set = true;
}


// -----------------------------------------------------------------------------
bool Stream_attachment::MediaIsSet() const
{
	return _element_media.IsSet();
}


// -----------------------------------------------------------------------------
bool Stream_attachment::PropertiesIsSet() const
{
	return _element_properties.IsSet();
}


// -----------------------------------------------------------------------------
Stream_attachment::Media_t::Media_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_attachment::Media_t::Media_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_attachment::Media_t::clear()
{
	while (!_element_stream_media.empty())
		_element_stream_media.erase( _element_stream_media.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_attachment::Media_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "stream_media");
		while (n)
		{
			com_facebook_1_0_::Stream_media tmp(n);
			_element_stream_media.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Stream_attachment::Media_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Stream_media>::const_iterator it = _element_stream_media.begin(); it != _element_stream_media.end(); it++)
	{
		const com_facebook_1_0_::Stream_media& ref = *it;
		r += ref.ToString("stream_media");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_attachment::Media_t::IsSet() const
{
	return Stream_mediaIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Stream_media>& Stream_attachment::Media_t::GetStream_media() const
{
	return _element_stream_media;
}


std::list<com_facebook_1_0_::Stream_media>& Stream_attachment::Media_t::GetStream_media()
{
	return _element_stream_media;
}


void Stream_attachment::Media_t::SetStream_media(const std::list<com_facebook_1_0_::Stream_media>& stream_media)
{
	_element_stream_media = stream_media;
}


// -----------------------------------------------------------------------------
bool Stream_attachment::Media_t::Stream_mediaIsSet() const
{
	return !_element_stream_media.empty();
}


// -----------------------------------------------------------------------------
bool Stream_attachment::Media_t::GetList() const
{
	return _attribute_list;
}


void Stream_attachment::Media_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Stream_attachment::Properties_t::Properties_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_attachment::Properties_t::Properties_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_attachment::Properties_t::clear()
{
	while (!_element_stream_property.empty())
		_element_stream_property.erase( _element_stream_property.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_attachment::Properties_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "stream_property");
		while (n)
		{
			com_facebook_1_0_::Stream_property tmp(n);
			_element_stream_property.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Stream_attachment::Properties_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Stream_property>::const_iterator it = _element_stream_property.begin(); it != _element_stream_property.end(); it++)
	{
		const com_facebook_1_0_::Stream_property& ref = *it;
		r += ref.ToString("stream_property");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_attachment::Properties_t::IsSet() const
{
	return Stream_propertyIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Stream_property>& Stream_attachment::Properties_t::GetStream_property() const
{
	return _element_stream_property;
}


std::list<com_facebook_1_0_::Stream_property>& Stream_attachment::Properties_t::GetStream_property()
{
	return _element_stream_property;
}


void Stream_attachment::Properties_t::SetStream_property(const std::list<com_facebook_1_0_::Stream_property>& stream_property)
{
	_element_stream_property = stream_property;
}


// -----------------------------------------------------------------------------
bool Stream_attachment::Properties_t::Stream_propertyIsSet() const
{
	return !_element_stream_property.empty();
}


// -----------------------------------------------------------------------------
bool Stream_attachment::Properties_t::GetList() const
{
	return _attribute_list;
}


void Stream_attachment::Properties_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Stream_app_data::Stream_app_data()
: _element_tbid(0)
, _element_tbid_is_set(false)
, _element_attachment_data_is_set(false)
, _element_images_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_app_data::Stream_app_data(const Xml::XmlNode& it)
: _element_tbid(0)
, _element_tbid_is_set(false)
, _element_attachment_data_is_set(false)
, _element_images_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_app_data::clear()
{
	_element_tbid = 0;
	_element_attachment_data.clear();
	_element_images.clear();
	_element_tbid_is_set = false;
	_element_attachment_data_is_set = false;
	_element_images_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_app_data::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("tbid"))
		throw Xml::XmlException("missing required node in element 'stream_app_data': tbid");
	SetTbid( atoi(std::string(it["tbid"]).c_str()) );
	if (!it.Exists("attachment_data"))
		throw Xml::XmlException("missing required node in element 'stream_app_data': attachment_data");
	SetAttachment_data( it["attachment_data"] );
	if (!it.Exists("images"))
		throw Xml::XmlException("missing required node in element 'stream_app_data': images");
	SetImages( it["images"] );
}


// -----------------------------------------------------------------------------
const std::string Stream_app_data::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<tbid>" + Utility::l2string(_element_tbid) + "</tbid>";
	}
	r += "<attachment_data>" + _element_attachment_data + "</attachment_data>";
	r += "<images>" + _element_images + "</images>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_app_data::IsSet() const
{
	return TbidIsSet() || Attachment_dataIsSet() || ImagesIsSet();
}


// -----------------------------------------------------------------------------
long Stream_app_data::GetTbid() const
{
	return _element_tbid;
}


void Stream_app_data::SetTbid(long tbid)
{
	_element_tbid = tbid;
	_element_tbid_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_app_data::GetAttachment_data() const
{
	return _element_attachment_data;
}


void Stream_app_data::SetAttachment_data(const std::string& attachment_data)
{
	_element_attachment_data = attachment_data;
	_element_attachment_data_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_app_data::GetImages() const
{
	return _element_images;
}


void Stream_app_data::SetImages(const std::string& images)
{
	_element_images = images;
	_element_images_is_set = true;
}


// -----------------------------------------------------------------------------
Stream_post::Stream_post()
: _element_app_id(0)
, _element_post_id_is_set(false)
, _element_viewer_id_is_set(false)
, _element_view_is_set(false)
, _element_source_id_is_set(false)
, _element_type_is_set(false)
, _element_app_id_is_set(false)
, _element_attribution_is_set(false)
, _element_actor_id_is_set(false)
, _element_target_id_is_set(false)
, _element_message_is_set(false)
, _element_updated_time_is_set(false)
, _element_created_time_is_set(false)
, _element_is_hidden_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_post::Stream_post(const Xml::XmlNode& it)
: _element_app_id(0)
, _element_post_id_is_set(false)
, _element_viewer_id_is_set(false)
, _element_view_is_set(false)
, _element_source_id_is_set(false)
, _element_type_is_set(false)
, _element_app_id_is_set(false)
, _element_attribution_is_set(false)
, _element_actor_id_is_set(false)
, _element_target_id_is_set(false)
, _element_message_is_set(false)
, _element_updated_time_is_set(false)
, _element_created_time_is_set(false)
, _element_is_hidden_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_post::clear()
{
	// simpleType:
	// _element_post_id.clear();
	// simpleType:
	// _element_viewer_id.clear();
	_element_view.clear();
	// simpleType:
	// _element_source_id.clear();
	_element_type.clear();
	_element_app_id = 0;
	_element_attribution.clear();
	// simpleType:
	// _element_actor_id.clear();
	// simpleType:
	// _element_target_id.clear();
	_element_message.clear();
	_element_attachment.clear();
	_element_app_data.clear();
	_element_action_links.clear();
	_element_comments.clear();
	_element_likes.clear();
	_element_privacy.clear();
	// simpleType:
	// _element_updated_time.clear();
	// simpleType:
	// _element_created_time.clear();
	_element_tagged_ids.clear();
	_element_is_hidden = false;
	_element_post_id_is_set = false;
	_element_viewer_id_is_set = false;
	_element_view_is_set = false;
	_element_source_id_is_set = false;
	_element_type_is_set = false;
	_element_app_id_is_set = false;
	_element_attribution_is_set = false;
	_element_actor_id_is_set = false;
	_element_target_id_is_set = false;
	_element_message_is_set = false;
	_element_updated_time_is_set = false;
	_element_created_time_is_set = false;
	_element_is_hidden_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_post::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("post_id"))
		throw Xml::XmlException("missing required node in element 'stream_post': post_id");
	SetPost_id( it["post_id"] );
	if (!it.Exists("viewer_id"))
		throw Xml::XmlException("missing required node in element 'stream_post': viewer_id");
	SetViewer_id( atoi(std::string(it["viewer_id"]).c_str()) );
	if (!it.Exists("view"))
		throw Xml::XmlException("missing required node in element 'stream_post': view");
	SetView( it["view"] );
	if (!it.Exists("source_id"))
		throw Xml::XmlException("missing required node in element 'stream_post': source_id");
	SetSource_id( atoi(std::string(it["source_id"]).c_str()) );
	if (!it.Exists("type"))
		throw Xml::XmlException("missing required node in element 'stream_post': type");
	SetType( it["type"] );
	if (!it.Exists("app_id"))
		throw Xml::XmlException("missing required node in element 'stream_post': app_id");
	SetApp_id( atoi(std::string(it["app_id"]).c_str()) );
	if (!it.Exists("attribution"))
		throw Xml::XmlException("missing required node in element 'stream_post': attribution");
	SetAttribution( it["attribution"] );
	if (!it.Exists("actor_id"))
		throw Xml::XmlException("missing required node in element 'stream_post': actor_id");
	SetActor_id( atoi(std::string(it["actor_id"]).c_str()) );
	if (!it.Exists("target_id"))
		throw Xml::XmlException("missing required node in element 'stream_post': target_id");
	SetTarget_id( atoi(std::string(it["target_id"]).c_str()) );
	if (!it.Exists("message"))
		throw Xml::XmlException("missing required node in element 'stream_post': message");
	SetMessage( it["message"] );
	if (!it.Exists("attachment"))
		throw Xml::XmlException("missing required node in element 'stream_post': attachment");
	{
		Xml::XmlNode n(it, "attachment");
		if (n)
			_element_attachment.FromXml( n );
	}
	if (!it.Exists("app_data"))
		throw Xml::XmlException("missing required node in element 'stream_post': app_data");
	{
		Xml::XmlNode n(it, "app_data");
		if (n)
			_element_app_data.FromXml( n );
	}
	if (!it.Exists("action_links"))
		throw Xml::XmlException("missing required node in element 'stream_post': action_links");
	{
		Xml::XmlNode n(it, "action_links");
		if (n)
			_element_action_links.FromXml( n );
	}
	if (!it.Exists("comments"))
		throw Xml::XmlException("missing required node in element 'stream_post': comments");
	{
		Xml::XmlNode n(it, "comments");
		if (n)
			_element_comments.FromXml( n );
	}
	if (!it.Exists("likes"))
		throw Xml::XmlException("missing required node in element 'stream_post': likes");
	{
		Xml::XmlNode n(it, "likes");
		if (n)
			_element_likes.FromXml( n );
	}
	if (!it.Exists("privacy"))
		throw Xml::XmlException("missing required node in element 'stream_post': privacy");
	{
		Xml::XmlNode n(it, "privacy");
		if (n)
			_element_privacy.FromXml( n );
	}
	if (!it.Exists("updated_time"))
		throw Xml::XmlException("missing required node in element 'stream_post': updated_time");
	SetUpdated_time( atoi(std::string(it["updated_time"]).c_str()) );
	if (!it.Exists("created_time"))
		throw Xml::XmlException("missing required node in element 'stream_post': created_time");
	SetCreated_time( atoi(std::string(it["created_time"]).c_str()) );
	if (!it.Exists("tagged_ids"))
		throw Xml::XmlException("missing required node in element 'stream_post': tagged_ids");
	{
		Xml::XmlNode n(it, "tagged_ids");
		if (n)
			_element_tagged_ids.FromXml( n );
	}
	if (!it.Exists("is_hidden"))
		throw Xml::XmlException("missing required node in element 'stream_post': is_hidden");
	SetIs_hidden( atoi(std::string(it["is_hidden"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Stream_post::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<post_id>" + _element_post_id + "</post_id>";
	{
		r = r + "<viewer_id>" + Utility::l2string(_element_viewer_id) + "</viewer_id>";
	}
	r += "<view>" + _element_view + "</view>";
	{
		r = r + "<source_id>" + Utility::l2string(_element_source_id) + "</source_id>";
	}
	r += "<type>" + _element_type + "</type>";
	{
		r = r + "<app_id>" + Utility::l2string(_element_app_id) + "</app_id>";
	}
	r += "<attribution>" + _element_attribution + "</attribution>";
	{
		r = r + "<actor_id>" + Utility::l2string(_element_actor_id) + "</actor_id>";
	}
	{
		r = r + "<target_id>" + Utility::l2string(_element_target_id) + "</target_id>";
	}
	r += "<message>" + _element_message + "</message>";
	r += _element_attachment.ToString("attachment");
	r += _element_app_data.ToString("app_data");
	r += _element_action_links.ToString("action_links");
	r += _element_comments.ToString("comments");
	r += _element_likes.ToString("likes");
	r += _element_privacy.ToString("privacy");
	{
		r = r + "<updated_time>" + Utility::l2string(_element_updated_time) + "</updated_time>";
	}
	{
		r = r + "<created_time>" + Utility::l2string(_element_created_time) + "</created_time>";
	}
	r += _element_tagged_ids.ToString("tagged_ids");
	{
		r = r + "<is_hidden>" + Utility::l2string(_element_is_hidden) + "</is_hidden>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_post::IsSet() const
{
	return Post_idIsSet() || Viewer_idIsSet() || ViewIsSet() || Source_idIsSet() || TypeIsSet() || App_idIsSet() || AttributionIsSet() || Actor_idIsSet() || Target_idIsSet() || MessageIsSet() || AttachmentIsSet() || App_dataIsSet() || Action_linksIsSet() || CommentsIsSet() || LikesIsSet() || PrivacyIsSet() || Updated_timeIsSet() || Created_timeIsSet() || Tagged_idsIsSet() || Is_hiddenIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Stream_post::GetPost_id() const
{
	return _element_post_id;
}


void Stream_post::SetPost_id(const std::string& post_id)
{
	_element_post_id = post_id;
	_element_post_id_is_set = true;
}


// -----------------------------------------------------------------------------
long Stream_post::GetViewer_id() const
{
	return _element_viewer_id;
}


void Stream_post::SetViewer_id(long viewer_id)
{
	_element_viewer_id = viewer_id;
	_element_viewer_id_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_post::GetView() const
{
	return _element_view;
}


void Stream_post::SetView(const std::string& view)
{
	_element_view = view;
	_element_view_is_set = true;
}


// -----------------------------------------------------------------------------
long Stream_post::GetSource_id() const
{
	return _element_source_id;
}


void Stream_post::SetSource_id(long source_id)
{
	_element_source_id = source_id;
	_element_source_id_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_post::GetType() const
{
	return _element_type;
}


void Stream_post::SetType(const std::string& type)
{
	_element_type = type;
	_element_type_is_set = true;
}


// -----------------------------------------------------------------------------
long Stream_post::GetApp_id() const
{
	return _element_app_id;
}


void Stream_post::SetApp_id(long app_id)
{
	_element_app_id = app_id;
	_element_app_id_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_post::GetAttribution() const
{
	return _element_attribution;
}


void Stream_post::SetAttribution(const std::string& attribution)
{
	_element_attribution = attribution;
	_element_attribution_is_set = true;
}


// -----------------------------------------------------------------------------
long Stream_post::GetActor_id() const
{
	return _element_actor_id;
}


void Stream_post::SetActor_id(long actor_id)
{
	_element_actor_id = actor_id;
	_element_actor_id_is_set = true;
}


// -----------------------------------------------------------------------------
long Stream_post::GetTarget_id() const
{
	return _element_target_id;
}


void Stream_post::SetTarget_id(long target_id)
{
	_element_target_id = target_id;
	_element_target_id_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_post::GetMessage() const
{
	return _element_message;
}


void Stream_post::SetMessage(const std::string& message)
{
	_element_message = message;
	_element_message_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Stream_attachment& Stream_post::GetAttachment() const
{
	return _element_attachment;
}


com_facebook_1_0_::Stream_attachment& Stream_post::GetAttachment()
{
	return _element_attachment;
}


void Stream_post::SetAttachment(const com_facebook_1_0_::Stream_attachment& attachment)
{
	_element_attachment = attachment;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Stream_app_data& Stream_post::GetApp_data() const
{
	return _element_app_data;
}


com_facebook_1_0_::Stream_app_data& Stream_post::GetApp_data()
{
	return _element_app_data;
}


void Stream_post::SetApp_data(const com_facebook_1_0_::Stream_app_data& app_data)
{
	_element_app_data = app_data;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::ActionLinkList& Stream_post::GetAction_links() const
{
	return _element_action_links;
}


com_facebook_1_0_::ActionLinkList& Stream_post::GetAction_links()
{
	return _element_action_links;
}


void Stream_post::SetAction_links(const com_facebook_1_0_::ActionLinkList& action_links)
{
	_element_action_links = action_links;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Stream_comments& Stream_post::GetComments() const
{
	return _element_comments;
}


com_facebook_1_0_::Stream_comments& Stream_post::GetComments()
{
	return _element_comments;
}


void Stream_post::SetComments(const com_facebook_1_0_::Stream_comments& comments)
{
	_element_comments = comments;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Stream_likes& Stream_post::GetLikes() const
{
	return _element_likes;
}


com_facebook_1_0_::Stream_likes& Stream_post::GetLikes()
{
	return _element_likes;
}


void Stream_post::SetLikes(const com_facebook_1_0_::Stream_likes& likes)
{
	_element_likes = likes;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Privacy& Stream_post::GetPrivacy() const
{
	return _element_privacy;
}


com_facebook_1_0_::Privacy& Stream_post::GetPrivacy()
{
	return _element_privacy;
}


void Stream_post::SetPrivacy(const com_facebook_1_0_::Privacy& privacy)
{
	_element_privacy = privacy;
}


// -----------------------------------------------------------------------------
long Stream_post::GetUpdated_time() const
{
	return _element_updated_time;
}


void Stream_post::SetUpdated_time(long updated_time)
{
	_element_updated_time = updated_time;
	_element_updated_time_is_set = true;
}


// -----------------------------------------------------------------------------
long Stream_post::GetCreated_time() const
{
	return _element_created_time;
}


void Stream_post::SetCreated_time(long created_time)
{
	_element_created_time = created_time;
	_element_created_time_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Stream_post::Tagged_ids_t& Stream_post::GetTagged_ids() const
{
	return _element_tagged_ids;
}


com_facebook_1_0_::Stream_post::Tagged_ids_t& Stream_post::GetTagged_ids()
{
	return _element_tagged_ids;
}


void Stream_post::SetTagged_ids(const com_facebook_1_0_::Stream_post::Tagged_ids_t& tagged_ids)
{
	_element_tagged_ids = tagged_ids;
}


// -----------------------------------------------------------------------------
bool Stream_post::GetIs_hidden() const
{
	return _element_is_hidden;
}


void Stream_post::SetIs_hidden(bool is_hidden)
{
	_element_is_hidden = is_hidden;
	_element_is_hidden_is_set = true;
}


// -----------------------------------------------------------------------------
bool Stream_post::AttachmentIsSet() const
{
	return _element_attachment.IsSet();
}


// -----------------------------------------------------------------------------
bool Stream_post::App_dataIsSet() const
{
	return _element_app_data.IsSet();
}


// -----------------------------------------------------------------------------
bool Stream_post::Action_linksIsSet() const
{
	return _element_action_links.IsSet();
}


// -----------------------------------------------------------------------------
bool Stream_post::CommentsIsSet() const
{
	return _element_comments.IsSet();
}


// -----------------------------------------------------------------------------
bool Stream_post::LikesIsSet() const
{
	return _element_likes.IsSet();
}


// -----------------------------------------------------------------------------
bool Stream_post::PrivacyIsSet() const
{
	return _element_privacy.IsSet();
}


// -----------------------------------------------------------------------------
bool Stream_post::Tagged_idsIsSet() const
{
	return _element_tagged_ids.IsSet();
}


// -----------------------------------------------------------------------------
Stream_post::Tagged_ids_t::Tagged_ids_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_post::Tagged_ids_t::Tagged_ids_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_post::Tagged_ids_t::clear()
{
	while (!_element_id.empty())
		_element_id.erase( _element_id.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_post::Tagged_ids_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "id");
		while (n)
		{
			_element_id.push_back( atoi(n.GetContent().c_str()) );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Stream_post::Tagged_ids_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<long>::const_iterator it = _element_id.begin(); it != _element_id.end(); it++)
	{
			r = r + "<id>" + Utility::l2string(*it) + "</id>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_post::Tagged_ids_t::IsSet() const
{
	return IdIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<long>& Stream_post::Tagged_ids_t::GetId() const
{
	return _element_id;
}


std::list<long>& Stream_post::Tagged_ids_t::GetId()
{
	return _element_id;
}


void Stream_post::Tagged_ids_t::SetId(const std::list<long>& id)
{
	_element_id = id;
}


// -----------------------------------------------------------------------------
bool Stream_post::Tagged_ids_t::IdIsSet() const
{
	return !_element_id.empty();
}


// -----------------------------------------------------------------------------
bool Stream_post::Tagged_ids_t::GetList() const
{
	return _attribute_list;
}


void Stream_post::Tagged_ids_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Photo_feedback::Photo_feedback()
: _element_pid_is_set(false)
{
}


// -----------------------------------------------------------------------------
Photo_feedback::Photo_feedback(const Xml::XmlNode& it)
: _element_pid_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Photo_feedback::clear()
{
	// simpleType:
	// _element_pid.clear();
	_element_comments.clear();
	_element_likes.clear();
	_element_pid_is_set = false;
}


// -----------------------------------------------------------------------------
void Photo_feedback::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("pid"))
		throw Xml::XmlException("missing required node in element 'photo_feedback': pid");
	SetPid( it["pid"] );
	if (!it.Exists("comments"))
		throw Xml::XmlException("missing required node in element 'photo_feedback': comments");
	{
		Xml::XmlNode n(it, "comments");
		if (n)
			_element_comments.FromXml( n );
	}
	if (!it.Exists("likes"))
		throw Xml::XmlException("missing required node in element 'photo_feedback': likes");
	{
		Xml::XmlNode n(it, "likes");
		if (n)
			_element_likes.FromXml( n );
	}
}


// -----------------------------------------------------------------------------
const std::string Photo_feedback::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<pid>" + _element_pid + "</pid>";
	r += _element_comments.ToString("comments");
	r += _element_likes.ToString("likes");
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Photo_feedback::IsSet() const
{
	return PidIsSet() || CommentsIsSet() || LikesIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Photo_feedback::GetPid() const
{
	return _element_pid;
}


void Photo_feedback::SetPid(const std::string& pid)
{
	_element_pid = pid;
	_element_pid_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Stream_comments& Photo_feedback::GetComments() const
{
	return _element_comments;
}


com_facebook_1_0_::Stream_comments& Photo_feedback::GetComments()
{
	return _element_comments;
}


void Photo_feedback::SetComments(const com_facebook_1_0_::Stream_comments& comments)
{
	_element_comments = comments;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Stream_likes& Photo_feedback::GetLikes() const
{
	return _element_likes;
}


com_facebook_1_0_::Stream_likes& Photo_feedback::GetLikes()
{
	return _element_likes;
}


void Photo_feedback::SetLikes(const com_facebook_1_0_::Stream_likes& likes)
{
	_element_likes = likes;
}


// -----------------------------------------------------------------------------
bool Photo_feedback::CommentsIsSet() const
{
	return _element_comments.IsSet();
}


// -----------------------------------------------------------------------------
bool Photo_feedback::LikesIsSet() const
{
	return _element_likes.IsSet();
}


// -----------------------------------------------------------------------------
Connection::Connection()
: _element_source_id(0)
, _element_target_id(0)
, _element_source_id_is_set(false)
, _element_target_id_is_set(false)
, _element_is_following_is_set(false)
{
}


// -----------------------------------------------------------------------------
Connection::Connection(const Xml::XmlNode& it)
: _element_source_id(0)
, _element_target_id(0)
, _element_source_id_is_set(false)
, _element_target_id_is_set(false)
, _element_is_following_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Connection::clear()
{
	_element_source_id = 0;
	_element_target_id = 0;
	_element_is_following = false;
	_element_source_id_is_set = false;
	_element_target_id_is_set = false;
	_element_is_following_is_set = false;
}


// -----------------------------------------------------------------------------
void Connection::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("source_id"))
		throw Xml::XmlException("missing required node in element 'connection': source_id");
	SetSource_id( atoi(std::string(it["source_id"]).c_str()) );
	if (!it.Exists("target_id"))
		throw Xml::XmlException("missing required node in element 'connection': target_id");
	SetTarget_id( atoi(std::string(it["target_id"]).c_str()) );
	if (!it.Exists("is_following"))
		throw Xml::XmlException("missing required node in element 'connection': is_following");
	SetIs_following( atoi(std::string(it["is_following"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Connection::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<source_id>" + Utility::l2string(_element_source_id) + "</source_id>";
	}
	{
		r = r + "<target_id>" + Utility::l2string(_element_target_id) + "</target_id>";
	}
	{
		r = r + "<is_following>" + Utility::l2string(_element_is_following) + "</is_following>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Connection::IsSet() const
{
	return Source_idIsSet() || Target_idIsSet() || Is_followingIsSet();
}


// -----------------------------------------------------------------------------
long Connection::GetSource_id() const
{
	return _element_source_id;
}


void Connection::SetSource_id(long source_id)
{
	_element_source_id = source_id;
	_element_source_id_is_set = true;
}


// -----------------------------------------------------------------------------
long Connection::GetTarget_id() const
{
	return _element_target_id;
}


void Connection::SetTarget_id(long target_id)
{
	_element_target_id = target_id;
	_element_target_id_is_set = true;
}


// -----------------------------------------------------------------------------
bool Connection::GetIs_following() const
{
	return _element_is_following;
}


void Connection::SetIs_following(bool is_following)
{
	_element_is_following = is_following;
	_element_is_following_is_set = true;
}


// -----------------------------------------------------------------------------
Stream_data::Stream_data()
{
}


// -----------------------------------------------------------------------------
Stream_data::Stream_data(const Xml::XmlNode& it)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_data::clear()
{
	_element_posts.clear();
	_element_profiles.clear();
	_element_albums.clear();
	_element_photo_tags.clear();
	_element_photo_feedback.clear();
	_element_connections.clear();
}


// -----------------------------------------------------------------------------
void Stream_data::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("posts"))
		throw Xml::XmlException("missing required node in element 'stream_data': posts");
	{
		Xml::XmlNode n(it, "posts");
		if (n)
			_element_posts.FromXml( n );
	}
	if (!it.Exists("profiles"))
		throw Xml::XmlException("missing required node in element 'stream_data': profiles");
	{
		Xml::XmlNode n(it, "profiles");
		if (n)
			_element_profiles.FromXml( n );
	}
	if (!it.Exists("albums"))
		throw Xml::XmlException("missing required node in element 'stream_data': albums");
	{
		Xml::XmlNode n(it, "albums");
		if (n)
			_element_albums.FromXml( n );
	}
	if (!it.Exists("photo_tags"))
		throw Xml::XmlException("missing required node in element 'stream_data': photo_tags");
	{
		Xml::XmlNode n(it, "photo_tags");
		if (n)
			_element_photo_tags.FromXml( n );
	}
	if (!it.Exists("photo_feedback"))
		throw Xml::XmlException("missing required node in element 'stream_data': photo_feedback");
	{
		Xml::XmlNode n(it, "photo_feedback");
		if (n)
			_element_photo_feedback.FromXml( n );
	}
	if (!it.Exists("connections"))
		throw Xml::XmlException("missing required node in element 'stream_data': connections");
	{
		Xml::XmlNode n(it, "connections");
		if (n)
			_element_connections.FromXml( n );
	}
}


// -----------------------------------------------------------------------------
const std::string Stream_data::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += _element_posts.ToString("posts");
	r += _element_profiles.ToString("profiles");
	r += _element_albums.ToString("albums");
	r += _element_photo_tags.ToString("photo_tags");
	r += _element_photo_feedback.ToString("photo_feedback");
	r += _element_connections.ToString("connections");
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_data::IsSet() const
{
	return PostsIsSet() || ProfilesIsSet() || AlbumsIsSet() || Photo_tagsIsSet() || Photo_feedbackIsSet() || ConnectionsIsSet();
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Stream_data::Posts_t& Stream_data::GetPosts() const
{
	return _element_posts;
}


com_facebook_1_0_::Stream_data::Posts_t& Stream_data::GetPosts()
{
	return _element_posts;
}


void Stream_data::SetPosts(const com_facebook_1_0_::Stream_data::Posts_t& posts)
{
	_element_posts = posts;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Stream_data::Profiles_t& Stream_data::GetProfiles() const
{
	return _element_profiles;
}


com_facebook_1_0_::Stream_data::Profiles_t& Stream_data::GetProfiles()
{
	return _element_profiles;
}


void Stream_data::SetProfiles(const com_facebook_1_0_::Stream_data::Profiles_t& profiles)
{
	_element_profiles = profiles;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Stream_data::Albums_t& Stream_data::GetAlbums() const
{
	return _element_albums;
}


com_facebook_1_0_::Stream_data::Albums_t& Stream_data::GetAlbums()
{
	return _element_albums;
}


void Stream_data::SetAlbums(const com_facebook_1_0_::Stream_data::Albums_t& albums)
{
	_element_albums = albums;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Stream_data::Photo_tags_t& Stream_data::GetPhoto_tags() const
{
	return _element_photo_tags;
}


com_facebook_1_0_::Stream_data::Photo_tags_t& Stream_data::GetPhoto_tags()
{
	return _element_photo_tags;
}


void Stream_data::SetPhoto_tags(const com_facebook_1_0_::Stream_data::Photo_tags_t& photo_tags)
{
	_element_photo_tags = photo_tags;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Stream_data::Photo_feedback_t& Stream_data::GetPhoto_feedback() const
{
	return _element_photo_feedback;
}


com_facebook_1_0_::Stream_data::Photo_feedback_t& Stream_data::GetPhoto_feedback()
{
	return _element_photo_feedback;
}


void Stream_data::SetPhoto_feedback(const com_facebook_1_0_::Stream_data::Photo_feedback_t& photo_feedback)
{
	_element_photo_feedback = photo_feedback;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Stream_data::Connections_t& Stream_data::GetConnections() const
{
	return _element_connections;
}


com_facebook_1_0_::Stream_data::Connections_t& Stream_data::GetConnections()
{
	return _element_connections;
}


void Stream_data::SetConnections(const com_facebook_1_0_::Stream_data::Connections_t& connections)
{
	_element_connections = connections;
}


// -----------------------------------------------------------------------------
bool Stream_data::PostsIsSet() const
{
	return _element_posts.IsSet();
}


// -----------------------------------------------------------------------------
bool Stream_data::ProfilesIsSet() const
{
	return _element_profiles.IsSet();
}


// -----------------------------------------------------------------------------
bool Stream_data::AlbumsIsSet() const
{
	return _element_albums.IsSet();
}


// -----------------------------------------------------------------------------
bool Stream_data::Photo_tagsIsSet() const
{
	return _element_photo_tags.IsSet();
}


// -----------------------------------------------------------------------------
bool Stream_data::Photo_feedbackIsSet() const
{
	return _element_photo_feedback.IsSet();
}


// -----------------------------------------------------------------------------
bool Stream_data::ConnectionsIsSet() const
{
	return _element_connections.IsSet();
}


// -----------------------------------------------------------------------------
Stream_data::Posts_t::Posts_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_data::Posts_t::Posts_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_data::Posts_t::clear()
{
	while (!_element_stream_post.empty())
		_element_stream_post.erase( _element_stream_post.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_data::Posts_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "stream_post");
		while (n)
		{
			com_facebook_1_0_::Stream_post tmp(n);
			_element_stream_post.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Stream_data::Posts_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Stream_post>::const_iterator it = _element_stream_post.begin(); it != _element_stream_post.end(); it++)
	{
		const com_facebook_1_0_::Stream_post& ref = *it;
		r += ref.ToString("stream_post");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_data::Posts_t::IsSet() const
{
	return Stream_postIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Stream_post>& Stream_data::Posts_t::GetStream_post() const
{
	return _element_stream_post;
}


std::list<com_facebook_1_0_::Stream_post>& Stream_data::Posts_t::GetStream_post()
{
	return _element_stream_post;
}


void Stream_data::Posts_t::SetStream_post(const std::list<com_facebook_1_0_::Stream_post>& stream_post)
{
	_element_stream_post = stream_post;
}


// -----------------------------------------------------------------------------
bool Stream_data::Posts_t::Stream_postIsSet() const
{
	return !_element_stream_post.empty();
}


// -----------------------------------------------------------------------------
bool Stream_data::Posts_t::GetList() const
{
	return _attribute_list;
}


void Stream_data::Posts_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Stream_data::Profiles_t::Profiles_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_data::Profiles_t::Profiles_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_data::Profiles_t::clear()
{
	while (!_element_profile.empty())
		_element_profile.erase( _element_profile.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_data::Profiles_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "profile");
		while (n)
		{
			com_facebook_1_0_::Profile tmp(n);
			_element_profile.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Stream_data::Profiles_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Profile>::const_iterator it = _element_profile.begin(); it != _element_profile.end(); it++)
	{
		const com_facebook_1_0_::Profile& ref = *it;
		r += ref.ToString("profile");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_data::Profiles_t::IsSet() const
{
	return ProfileIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Profile>& Stream_data::Profiles_t::GetProfile() const
{
	return _element_profile;
}


std::list<com_facebook_1_0_::Profile>& Stream_data::Profiles_t::GetProfile()
{
	return _element_profile;
}


void Stream_data::Profiles_t::SetProfile(const std::list<com_facebook_1_0_::Profile>& profile)
{
	_element_profile = profile;
}


// -----------------------------------------------------------------------------
bool Stream_data::Profiles_t::ProfileIsSet() const
{
	return !_element_profile.empty();
}


// -----------------------------------------------------------------------------
bool Stream_data::Profiles_t::GetList() const
{
	return _attribute_list;
}


void Stream_data::Profiles_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Stream_data::Albums_t::Albums_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_data::Albums_t::Albums_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_data::Albums_t::clear()
{
	while (!_element_album.empty())
		_element_album.erase( _element_album.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_data::Albums_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "album");
		while (n)
		{
			com_facebook_1_0_::Album tmp(n);
			_element_album.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Stream_data::Albums_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Album>::const_iterator it = _element_album.begin(); it != _element_album.end(); it++)
	{
		const com_facebook_1_0_::Album& ref = *it;
		r += ref.ToString("album");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_data::Albums_t::IsSet() const
{
	return AlbumIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Album>& Stream_data::Albums_t::GetAlbum() const
{
	return _element_album;
}


std::list<com_facebook_1_0_::Album>& Stream_data::Albums_t::GetAlbum()
{
	return _element_album;
}


void Stream_data::Albums_t::SetAlbum(const std::list<com_facebook_1_0_::Album>& album)
{
	_element_album = album;
}


// -----------------------------------------------------------------------------
bool Stream_data::Albums_t::AlbumIsSet() const
{
	return !_element_album.empty();
}


// -----------------------------------------------------------------------------
bool Stream_data::Albums_t::GetList() const
{
	return _attribute_list;
}


void Stream_data::Albums_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Stream_data::Photo_tags_t::Photo_tags_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_data::Photo_tags_t::Photo_tags_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_data::Photo_tags_t::clear()
{
	while (!_element_photo_tag.empty())
		_element_photo_tag.erase( _element_photo_tag.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_data::Photo_tags_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "photo_tag");
		while (n)
		{
			com_facebook_1_0_::Photo_tag tmp(n);
			_element_photo_tag.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Stream_data::Photo_tags_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Photo_tag>::const_iterator it = _element_photo_tag.begin(); it != _element_photo_tag.end(); it++)
	{
		const com_facebook_1_0_::Photo_tag& ref = *it;
		r += ref.ToString("photo_tag");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_data::Photo_tags_t::IsSet() const
{
	return Photo_tagIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Photo_tag>& Stream_data::Photo_tags_t::GetPhoto_tag() const
{
	return _element_photo_tag;
}


std::list<com_facebook_1_0_::Photo_tag>& Stream_data::Photo_tags_t::GetPhoto_tag()
{
	return _element_photo_tag;
}


void Stream_data::Photo_tags_t::SetPhoto_tag(const std::list<com_facebook_1_0_::Photo_tag>& photo_tag)
{
	_element_photo_tag = photo_tag;
}


// -----------------------------------------------------------------------------
bool Stream_data::Photo_tags_t::Photo_tagIsSet() const
{
	return !_element_photo_tag.empty();
}


// -----------------------------------------------------------------------------
bool Stream_data::Photo_tags_t::GetList() const
{
	return _attribute_list;
}


void Stream_data::Photo_tags_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Stream_data::Photo_feedback_t::Photo_feedback_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_data::Photo_feedback_t::Photo_feedback_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_data::Photo_feedback_t::clear()
{
	while (!_element_photo_feedback.empty())
		_element_photo_feedback.erase( _element_photo_feedback.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_data::Photo_feedback_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "photo_feedback");
		while (n)
		{
			com_facebook_1_0_::Photo_feedback tmp(n);
			_element_photo_feedback.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Stream_data::Photo_feedback_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Photo_feedback>::const_iterator it = _element_photo_feedback.begin(); it != _element_photo_feedback.end(); it++)
	{
		const com_facebook_1_0_::Photo_feedback& ref = *it;
		r += ref.ToString("photo_feedback");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_data::Photo_feedback_t::IsSet() const
{
	return Photo_feedbackIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Photo_feedback>& Stream_data::Photo_feedback_t::GetPhoto_feedback() const
{
	return _element_photo_feedback;
}


std::list<com_facebook_1_0_::Photo_feedback>& Stream_data::Photo_feedback_t::GetPhoto_feedback()
{
	return _element_photo_feedback;
}


void Stream_data::Photo_feedback_t::SetPhoto_feedback(const std::list<com_facebook_1_0_::Photo_feedback>& photo_feedback)
{
	_element_photo_feedback = photo_feedback;
}


// -----------------------------------------------------------------------------
bool Stream_data::Photo_feedback_t::Photo_feedbackIsSet() const
{
	return !_element_photo_feedback.empty();
}


// -----------------------------------------------------------------------------
bool Stream_data::Photo_feedback_t::GetList() const
{
	return _attribute_list;
}


void Stream_data::Photo_feedback_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Stream_data::Connections_t::Connections_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_data::Connections_t::Connections_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_data::Connections_t::clear()
{
	while (!_element_connection.empty())
		_element_connection.erase( _element_connection.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_data::Connections_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "connection");
		while (n)
		{
			com_facebook_1_0_::Connection tmp(n);
			_element_connection.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Stream_data::Connections_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Connection>::const_iterator it = _element_connection.begin(); it != _element_connection.end(); it++)
	{
		const com_facebook_1_0_::Connection& ref = *it;
		r += ref.ToString("connection");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_data::Connections_t::IsSet() const
{
	return ConnectionIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Connection>& Stream_data::Connections_t::GetConnection() const
{
	return _element_connection;
}


std::list<com_facebook_1_0_::Connection>& Stream_data::Connections_t::GetConnection()
{
	return _element_connection;
}


void Stream_data::Connections_t::SetConnection(const std::list<com_facebook_1_0_::Connection>& connection)
{
	_element_connection = connection;
}


// -----------------------------------------------------------------------------
bool Stream_data::Connections_t::ConnectionIsSet() const
{
	return !_element_connection.empty();
}


// -----------------------------------------------------------------------------
bool Stream_data::Connections_t::GetList() const
{
	return _attribute_list;
}


void Stream_data::Connections_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Stream_filter::Stream_filter()
: _element_rank(0)
, _element_value(0)
, _element_uid_is_set(false)
, _element_filter_key_is_set(false)
, _element_name_is_set(false)
, _element_rank_is_set(false)
, _element_icon_url_is_set(false)
, _element_is_visible_is_set(false)
, _element_type_is_set(false)
, _element_value_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_filter::Stream_filter(const Xml::XmlNode& it)
: _element_rank(0)
, _element_value(0)
, _element_uid_is_set(false)
, _element_filter_key_is_set(false)
, _element_name_is_set(false)
, _element_rank_is_set(false)
, _element_icon_url_is_set(false)
, _element_is_visible_is_set(false)
, _element_type_is_set(false)
, _element_value_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_filter::clear()
{
	// simpleType:
	// _element_uid.clear();
	_element_filter_key.clear();
	_element_name.clear();
	_element_rank = 0;
	_element_icon_url.clear();
	_element_is_visible = false;
	_element_type.clear();
	_element_value = 0;
	_element_uid_is_set = false;
	_element_filter_key_is_set = false;
	_element_name_is_set = false;
	_element_rank_is_set = false;
	_element_icon_url_is_set = false;
	_element_is_visible_is_set = false;
	_element_type_is_set = false;
	_element_value_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_filter::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("uid"))
		throw Xml::XmlException("missing required node in element 'stream_filter': uid");
	SetUid( atoi(std::string(it["uid"]).c_str()) );
	if (!it.Exists("filter_key"))
		throw Xml::XmlException("missing required node in element 'stream_filter': filter_key");
	SetFilter_key( it["filter_key"] );
	if (!it.Exists("name"))
		throw Xml::XmlException("missing required node in element 'stream_filter': name");
	SetName( it["name"] );
	if (!it.Exists("rank"))
		throw Xml::XmlException("missing required node in element 'stream_filter': rank");
	SetRank( atoi(std::string(it["rank"]).c_str()) );
	if (!it.Exists("icon_url"))
		throw Xml::XmlException("missing required node in element 'stream_filter': icon_url");
	SetIcon_url( it["icon_url"] );
	if (!it.Exists("is_visible"))
		throw Xml::XmlException("missing required node in element 'stream_filter': is_visible");
	SetIs_visible( atoi(std::string(it["is_visible"]).c_str()) );
	if (!it.Exists("type"))
		throw Xml::XmlException("missing required node in element 'stream_filter': type");
	SetType( it["type"] );
	if (!it.Exists("value"))
		throw Xml::XmlException("missing required node in element 'stream_filter': value");
	SetValue( atoi(std::string(it["value"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Stream_filter::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<uid>" + Utility::l2string(_element_uid) + "</uid>";
	}
	r += "<filter_key>" + _element_filter_key + "</filter_key>";
	r += "<name>" + _element_name + "</name>";
	{
		r = r + "<rank>" + Utility::l2string(_element_rank) + "</rank>";
	}
	r += "<icon_url>" + _element_icon_url + "</icon_url>";
	{
		r = r + "<is_visible>" + Utility::l2string(_element_is_visible) + "</is_visible>";
	}
	r += "<type>" + _element_type + "</type>";
	{
		r = r + "<value>" + Utility::l2string(_element_value) + "</value>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_filter::IsSet() const
{
	return UidIsSet() || Filter_keyIsSet() || NameIsSet() || RankIsSet() || Icon_urlIsSet() || Is_visibleIsSet() || TypeIsSet() || ValueIsSet();
}


// -----------------------------------------------------------------------------
long Stream_filter::GetUid() const
{
	return _element_uid;
}


void Stream_filter::SetUid(long uid)
{
	_element_uid = uid;
	_element_uid_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_filter::GetFilter_key() const
{
	return _element_filter_key;
}


void Stream_filter::SetFilter_key(const std::string& filter_key)
{
	_element_filter_key = filter_key;
	_element_filter_key_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_filter::GetName() const
{
	return _element_name;
}


void Stream_filter::SetName(const std::string& name)
{
	_element_name = name;
	_element_name_is_set = true;
}


// -----------------------------------------------------------------------------
int Stream_filter::GetRank() const
{
	return _element_rank;
}


void Stream_filter::SetRank(int rank)
{
	_element_rank = rank;
	_element_rank_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_filter::GetIcon_url() const
{
	return _element_icon_url;
}


void Stream_filter::SetIcon_url(const std::string& icon_url)
{
	_element_icon_url = icon_url;
	_element_icon_url_is_set = true;
}


// -----------------------------------------------------------------------------
bool Stream_filter::GetIs_visible() const
{
	return _element_is_visible;
}


void Stream_filter::SetIs_visible(bool is_visible)
{
	_element_is_visible = is_visible;
	_element_is_visible_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Stream_filter::GetType() const
{
	return _element_type;
}


void Stream_filter::SetType(const std::string& type)
{
	_element_type = type;
	_element_type_is_set = true;
}


// -----------------------------------------------------------------------------
long Stream_filter::GetValue() const
{
	return _element_value;
}


void Stream_filter::SetValue(long value)
{
	_element_value = value;
	_element_value_is_set = true;
}


// -----------------------------------------------------------------------------
Link_stat::Link_stat()
: _element_share_count(0)
, _element_like_count(0)
, _element_comment_count(0)
, _element_total_count(0)
, _element_click_count(0)
, _element_url_is_set(false)
, _element_share_count_is_set(false)
, _element_like_count_is_set(false)
, _element_comment_count_is_set(false)
, _element_total_count_is_set(false)
, _element_click_count_is_set(false)
, _element_normalized_url_is_set(false)
{
}


// -----------------------------------------------------------------------------
Link_stat::Link_stat(const Xml::XmlNode& it)
: _element_share_count(0)
, _element_like_count(0)
, _element_comment_count(0)
, _element_total_count(0)
, _element_click_count(0)
, _element_url_is_set(false)
, _element_share_count_is_set(false)
, _element_like_count_is_set(false)
, _element_comment_count_is_set(false)
, _element_total_count_is_set(false)
, _element_click_count_is_set(false)
, _element_normalized_url_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Link_stat::clear()
{
	_element_url.clear();
	_element_share_count = 0;
	_element_like_count = 0;
	_element_comment_count = 0;
	_element_total_count = 0;
	_element_click_count = 0;
	_element_normalized_url.clear();
	_element_url_is_set = false;
	_element_share_count_is_set = false;
	_element_like_count_is_set = false;
	_element_comment_count_is_set = false;
	_element_total_count_is_set = false;
	_element_click_count_is_set = false;
	_element_normalized_url_is_set = false;
}


// -----------------------------------------------------------------------------
void Link_stat::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("url"))
		throw Xml::XmlException("missing required node in element 'link_stat': url");
	SetUrl( it["url"] );
	if (!it.Exists("share_count"))
		throw Xml::XmlException("missing required node in element 'link_stat': share_count");
	SetShare_count( atoi(std::string(it["share_count"]).c_str()) );
	if (!it.Exists("like_count"))
		throw Xml::XmlException("missing required node in element 'link_stat': like_count");
	SetLike_count( atoi(std::string(it["like_count"]).c_str()) );
	if (!it.Exists("comment_count"))
		throw Xml::XmlException("missing required node in element 'link_stat': comment_count");
	SetComment_count( atoi(std::string(it["comment_count"]).c_str()) );
	if (!it.Exists("total_count"))
		throw Xml::XmlException("missing required node in element 'link_stat': total_count");
	SetTotal_count( atoi(std::string(it["total_count"]).c_str()) );
	if (!it.Exists("click_count"))
		throw Xml::XmlException("missing required node in element 'link_stat': click_count");
	SetClick_count( atoi(std::string(it["click_count"]).c_str()) );
	if (!it.Exists("normalized_url"))
		throw Xml::XmlException("missing required node in element 'link_stat': normalized_url");
	SetNormalized_url( it["normalized_url"] );
}


// -----------------------------------------------------------------------------
const std::string Link_stat::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<url>" + _element_url + "</url>";
	{
		r = r + "<share_count>" + Utility::l2string(_element_share_count) + "</share_count>";
	}
	{
		r = r + "<like_count>" + Utility::l2string(_element_like_count) + "</like_count>";
	}
	{
		r = r + "<comment_count>" + Utility::l2string(_element_comment_count) + "</comment_count>";
	}
	{
		r = r + "<total_count>" + Utility::l2string(_element_total_count) + "</total_count>";
	}
	{
		r = r + "<click_count>" + Utility::l2string(_element_click_count) + "</click_count>";
	}
	r += "<normalized_url>" + _element_normalized_url + "</normalized_url>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Link_stat::IsSet() const
{
	return UrlIsSet() || Share_countIsSet() || Like_countIsSet() || Comment_countIsSet() || Total_countIsSet() || Click_countIsSet() || Normalized_urlIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Link_stat::GetUrl() const
{
	return _element_url;
}


void Link_stat::SetUrl(const std::string& url)
{
	_element_url = url;
	_element_url_is_set = true;
}


// -----------------------------------------------------------------------------
long Link_stat::GetShare_count() const
{
	return _element_share_count;
}


void Link_stat::SetShare_count(long share_count)
{
	_element_share_count = share_count;
	_element_share_count_is_set = true;
}


// -----------------------------------------------------------------------------
long Link_stat::GetLike_count() const
{
	return _element_like_count;
}


void Link_stat::SetLike_count(long like_count)
{
	_element_like_count = like_count;
	_element_like_count_is_set = true;
}


// -----------------------------------------------------------------------------
long Link_stat::GetComment_count() const
{
	return _element_comment_count;
}


void Link_stat::SetComment_count(long comment_count)
{
	_element_comment_count = comment_count;
	_element_comment_count_is_set = true;
}


// -----------------------------------------------------------------------------
long Link_stat::GetTotal_count() const
{
	return _element_total_count;
}


void Link_stat::SetTotal_count(long total_count)
{
	_element_total_count = total_count;
	_element_total_count_is_set = true;
}


// -----------------------------------------------------------------------------
long Link_stat::GetClick_count() const
{
	return _element_click_count;
}


void Link_stat::SetClick_count(long click_count)
{
	_element_click_count = click_count;
	_element_click_count_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Link_stat::GetNormalized_url() const
{
	return _element_normalized_url;
}


void Link_stat::SetNormalized_url(const std::string& normalized_url)
{
	_element_normalized_url = normalized_url;
	_element_normalized_url_is_set = true;
}


// -----------------------------------------------------------------------------
Fql_result::Fql_result()
: _element_name_is_set(false)
, _element_fql_result_set_is_set(false)
{
}


// -----------------------------------------------------------------------------
Fql_result::Fql_result(const Xml::XmlNode& it)
: _element_name_is_set(false)
, _element_fql_result_set_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Fql_result::clear()
{
	_element_name.clear();
	_element_fql_result_set.clear();
	_element_name_is_set = false;
	_element_fql_result_set_is_set = false;
}


// -----------------------------------------------------------------------------
void Fql_result::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("name"))
		throw Xml::XmlException("missing required node in element 'fql_result': name");
	SetName( it["name"] );
	if (!it.Exists("fql_result_set"))
		throw Xml::XmlException("missing required node in element 'fql_result': fql_result_set");
	SetFql_result_set( it["fql_result_set"] );
}


// -----------------------------------------------------------------------------
const std::string Fql_result::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<name>" + _element_name + "</name>";
	r += "<fql_result_set>" + _element_fql_result_set + "</fql_result_set>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Fql_result::IsSet() const
{
	return NameIsSet() || Fql_result_setIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Fql_result::GetName() const
{
	return _element_name;
}


void Fql_result::SetName(const std::string& name)
{
	_element_name = name;
	_element_name_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Fql_result::GetFql_result_set() const
{
	return _element_fql_result_set;
}


void Fql_result::SetFql_result_set(const std::string& fql_result_set)
{
	_element_fql_result_set = fql_result_set;
	_element_fql_result_set_is_set = true;
}


// -----------------------------------------------------------------------------
Translation::Translation()
: _element_is_translatable(0)
, _element_native_string_is_set(false)
, _element_description_is_set(false)
, _element_native_hash_is_set(false)
, _element_translation_is_set(false)
, _element_locale_is_set(false)
, _element_approval_status_is_set(false)
, _element_pre_hash_string_is_set(false)
, _element_best_string_is_set(false)
, _element_is_translatable_is_set(false)
{
}


// -----------------------------------------------------------------------------
Translation::Translation(const Xml::XmlNode& it)
: _element_is_translatable(0)
, _element_native_string_is_set(false)
, _element_description_is_set(false)
, _element_native_hash_is_set(false)
, _element_translation_is_set(false)
, _element_locale_is_set(false)
, _element_approval_status_is_set(false)
, _element_pre_hash_string_is_set(false)
, _element_best_string_is_set(false)
, _element_is_translatable_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Translation::clear()
{
	_element_native_string.clear();
	_element_description.clear();
	_element_native_hash.clear();
	_element_translation.clear();
	_element_locale.clear();
	_element_approval_status.clear();
	_element_pre_hash_string.clear();
	_element_best_string.clear();
	_element_is_translatable = 0;
	_element_native_string_is_set = false;
	_element_description_is_set = false;
	_element_native_hash_is_set = false;
	_element_translation_is_set = false;
	_element_locale_is_set = false;
	_element_approval_status_is_set = false;
	_element_pre_hash_string_is_set = false;
	_element_best_string_is_set = false;
	_element_is_translatable_is_set = false;
}


// -----------------------------------------------------------------------------
void Translation::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("native_string"))
		throw Xml::XmlException("missing required node in element 'translation': native_string");
	SetNative_string( it["native_string"] );
	if (!it.Exists("description"))
		throw Xml::XmlException("missing required node in element 'translation': description");
	SetDescription( it["description"] );
	if (!it.Exists("native_hash"))
		throw Xml::XmlException("missing required node in element 'translation': native_hash");
	SetNative_hash( it["native_hash"] );
	if (!it.Exists("translation"))
		throw Xml::XmlException("missing required node in element 'translation': translation");
	SetTranslation( it["translation"] );
	if (!it.Exists("locale"))
		throw Xml::XmlException("missing required node in element 'translation': locale");
	SetLocale( it["locale"] );
	if (!it.Exists("approval_status"))
		throw Xml::XmlException("missing required node in element 'translation': approval_status");
	SetApproval_status( it["approval_status"] );
	if (!it.Exists("pre_hash_string"))
		throw Xml::XmlException("missing required node in element 'translation': pre_hash_string");
	SetPre_hash_string( it["pre_hash_string"] );
	if (!it.Exists("best_string"))
		throw Xml::XmlException("missing required node in element 'translation': best_string");
	SetBest_string( it["best_string"] );
	if (!it.Exists("is_translatable"))
		throw Xml::XmlException("missing required node in element 'translation': is_translatable");
	SetIs_translatable( atoi(std::string(it["is_translatable"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Translation::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<native_string>" + _element_native_string + "</native_string>";
	r += "<description>" + _element_description + "</description>";
	r += "<native_hash>" + _element_native_hash + "</native_hash>";
	r += "<translation>" + _element_translation + "</translation>";
	r += "<locale>" + _element_locale + "</locale>";
	r += "<approval_status>" + _element_approval_status + "</approval_status>";
	r += "<pre_hash_string>" + _element_pre_hash_string + "</pre_hash_string>";
	r += "<best_string>" + _element_best_string + "</best_string>";
	{
		r = r + "<is_translatable>" + Utility::l2string(_element_is_translatable) + "</is_translatable>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Translation::IsSet() const
{
	return Native_stringIsSet() || DescriptionIsSet() || Native_hashIsSet() || TranslationIsSet() || LocaleIsSet() || Approval_statusIsSet() || Pre_hash_stringIsSet() || Best_stringIsSet() || Is_translatableIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Translation::GetNative_string() const
{
	return _element_native_string;
}


void Translation::SetNative_string(const std::string& native_string)
{
	_element_native_string = native_string;
	_element_native_string_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Translation::GetDescription() const
{
	return _element_description;
}


void Translation::SetDescription(const std::string& description)
{
	_element_description = description;
	_element_description_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Translation::GetNative_hash() const
{
	return _element_native_hash;
}


void Translation::SetNative_hash(const std::string& native_hash)
{
	_element_native_hash = native_hash;
	_element_native_hash_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Translation::GetTranslation() const
{
	return _element_translation;
}


void Translation::SetTranslation(const std::string& translation)
{
	_element_translation = translation;
	_element_translation_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Translation::GetLocale() const
{
	return _element_locale;
}


void Translation::SetLocale(const std::string& locale)
{
	_element_locale = locale;
	_element_locale_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Translation::GetApproval_status() const
{
	return _element_approval_status;
}


void Translation::SetApproval_status(const std::string& approval_status)
{
	_element_approval_status = approval_status;
	_element_approval_status_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Translation::GetPre_hash_string() const
{
	return _element_pre_hash_string;
}


void Translation::SetPre_hash_string(const std::string& pre_hash_string)
{
	_element_pre_hash_string = pre_hash_string;
	_element_pre_hash_string_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Translation::GetBest_string() const
{
	return _element_best_string;
}


void Translation::SetBest_string(const std::string& best_string)
{
	_element_best_string = best_string;
	_element_best_string_is_set = true;
}


// -----------------------------------------------------------------------------
int Translation::GetIs_translatable() const
{
	return _element_is_translatable;
}


void Translation::SetIs_translatable(int is_translatable)
{
	_element_is_translatable = is_translatable;
	_element_is_translatable_is_set = true;
}


// -----------------------------------------------------------------------------
Translation_info::Translation_info()
: _element_translation_is_set(false)
, _element_status_is_set(false)
, _element_description_is_set(false)
{
}


// -----------------------------------------------------------------------------
Translation_info::Translation_info(const Xml::XmlNode& it)
: _element_translation_is_set(false)
, _element_status_is_set(false)
, _element_description_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Translation_info::clear()
{
	_element_translation.clear();
	_element_status.clear();
	_element_description.clear();
	_element_translation_is_set = false;
	_element_status_is_set = false;
	_element_description_is_set = false;
}


// -----------------------------------------------------------------------------
void Translation_info::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("translation"))
		throw Xml::XmlException("missing required node in element 'translation_info': translation");
	SetTranslation( it["translation"] );
	if (!it.Exists("status"))
		throw Xml::XmlException("missing required node in element 'translation_info': status");
	SetStatus( it["status"] );
	if (!it.Exists("description"))
		throw Xml::XmlException("missing required node in element 'translation_info': description");
	SetDescription( it["description"] );
}


// -----------------------------------------------------------------------------
const std::string Translation_info::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<translation>" + _element_translation + "</translation>";
	r += "<status>" + _element_status + "</status>";
	r += "<description>" + _element_description + "</description>";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Translation_info::IsSet() const
{
	return TranslationIsSet() || StatusIsSet() || DescriptionIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Translation_info::GetTranslation() const
{
	return _element_translation;
}


void Translation_info::SetTranslation(const std::string& translation)
{
	_element_translation = translation;
	_element_translation_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Translation_info::GetStatus() const
{
	return _element_status;
}


void Translation_info::SetStatus(const std::string& status)
{
	_element_status = status;
	_element_status_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Translation_info::GetDescription() const
{
	return _element_description;
}


void Translation_info::SetDescription(const std::string& description)
{
	_element_description = description;
	_element_description_is_set = true;
}


// -----------------------------------------------------------------------------
Locale_string::Locale_string()
: _element_native_string_is_set(false)
{
}


// -----------------------------------------------------------------------------
Locale_string::Locale_string(const Xml::XmlNode& it)
: _element_native_string_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Locale_string::clear()
{
	_element_native_string.clear();
	_element_translations.clear();
	_element_native_string_is_set = false;
}


// -----------------------------------------------------------------------------
void Locale_string::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("native_string"))
		throw Xml::XmlException("missing required node in element 'locale_string': native_string");
	SetNative_string( it["native_string"] );
	if (!it.Exists("translations"))
		throw Xml::XmlException("missing required node in element 'locale_string': translations");
	{
		Xml::XmlNode n(it, "translations");
		if (n)
			_element_translations.FromXml( n );
	}
}


// -----------------------------------------------------------------------------
const std::string Locale_string::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<native_string>" + _element_native_string + "</native_string>";
	r += _element_translations.ToString("translations");
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Locale_string::IsSet() const
{
	return Native_stringIsSet() || TranslationsIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Locale_string::GetNative_string() const
{
	return _element_native_string;
}


void Locale_string::SetNative_string(const std::string& native_string)
{
	_element_native_string = native_string;
	_element_native_string_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Locale_string::Translations_t& Locale_string::GetTranslations() const
{
	return _element_translations;
}


com_facebook_1_0_::Locale_string::Translations_t& Locale_string::GetTranslations()
{
	return _element_translations;
}


void Locale_string::SetTranslations(const com_facebook_1_0_::Locale_string::Translations_t& translations)
{
	_element_translations = translations;
}


// -----------------------------------------------------------------------------
bool Locale_string::TranslationsIsSet() const
{
	return _element_translations.IsSet();
}


// -----------------------------------------------------------------------------
Locale_string::Translations_t::Translations_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Locale_string::Translations_t::Translations_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Locale_string::Translations_t::clear()
{
	while (!_element_translation_info.empty())
		_element_translation_info.erase( _element_translation_info.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Locale_string::Translations_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "translation_info");
		while (n)
		{
			com_facebook_1_0_::Translation_info tmp(n);
			_element_translation_info.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Locale_string::Translations_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Translation_info>::const_iterator it = _element_translation_info.begin(); it != _element_translation_info.end(); it++)
	{
		const com_facebook_1_0_::Translation_info& ref = *it;
		r += ref.ToString("translation_info");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Locale_string::Translations_t::IsSet() const
{
	return Translation_infoIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Translation_info>& Locale_string::Translations_t::GetTranslation_info() const
{
	return _element_translation_info;
}


std::list<com_facebook_1_0_::Translation_info>& Locale_string::Translations_t::GetTranslation_info()
{
	return _element_translation_info;
}


void Locale_string::Translations_t::SetTranslation_info(const std::list<com_facebook_1_0_::Translation_info>& translation_info)
{
	_element_translation_info = translation_info;
}


// -----------------------------------------------------------------------------
bool Locale_string::Translations_t::Translation_infoIsSet() const
{
	return !_element_translation_info.empty();
}


// -----------------------------------------------------------------------------
bool Locale_string::Translations_t::GetList() const
{
	return _attribute_list;
}


void Locale_string::Translations_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Locale_data::Locale_data()
: _element_locale_is_set(false)
{
}


// -----------------------------------------------------------------------------
Locale_data::Locale_data(const Xml::XmlNode& it)
: _element_locale_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Locale_data::clear()
{
	_element_locale.clear();
	_element_strings.clear();
	_element_locale_is_set = false;
}


// -----------------------------------------------------------------------------
void Locale_data::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("locale"))
		throw Xml::XmlException("missing required node in element 'locale_data': locale");
	SetLocale( it["locale"] );
	if (!it.Exists("strings"))
		throw Xml::XmlException("missing required node in element 'locale_data': strings");
	{
		Xml::XmlNode n(it, "strings");
		if (n)
			_element_strings.FromXml( n );
	}
}


// -----------------------------------------------------------------------------
const std::string Locale_data::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<locale>" + _element_locale + "</locale>";
	r += _element_strings.ToString("strings");
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Locale_data::IsSet() const
{
	return LocaleIsSet() || StringsIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Locale_data::GetLocale() const
{
	return _element_locale;
}


void Locale_data::SetLocale(const std::string& locale)
{
	_element_locale = locale;
	_element_locale_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Locale_data::Strings_t& Locale_data::GetStrings() const
{
	return _element_strings;
}


com_facebook_1_0_::Locale_data::Strings_t& Locale_data::GetStrings()
{
	return _element_strings;
}


void Locale_data::SetStrings(const com_facebook_1_0_::Locale_data::Strings_t& strings)
{
	_element_strings = strings;
}


// -----------------------------------------------------------------------------
bool Locale_data::StringsIsSet() const
{
	return _element_strings.IsSet();
}


// -----------------------------------------------------------------------------
Locale_data::Strings_t::Strings_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Locale_data::Strings_t::Strings_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Locale_data::Strings_t::clear()
{
	while (!_element_locale_string.empty())
		_element_locale_string.erase( _element_locale_string.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Locale_data::Strings_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "locale_string");
		while (n)
		{
			com_facebook_1_0_::Locale_string tmp(n);
			_element_locale_string.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Locale_data::Strings_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Locale_string>::const_iterator it = _element_locale_string.begin(); it != _element_locale_string.end(); it++)
	{
		const com_facebook_1_0_::Locale_string& ref = *it;
		r += ref.ToString("locale_string");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Locale_data::Strings_t::IsSet() const
{
	return Locale_stringIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Locale_string>& Locale_data::Strings_t::GetLocale_string() const
{
	return _element_locale_string;
}


std::list<com_facebook_1_0_::Locale_string>& Locale_data::Strings_t::GetLocale_string()
{
	return _element_locale_string;
}


void Locale_data::Strings_t::SetLocale_string(const std::list<com_facebook_1_0_::Locale_string>& locale_string)
{
	_element_locale_string = locale_string;
}


// -----------------------------------------------------------------------------
bool Locale_data::Strings_t::Locale_stringIsSet() const
{
	return !_element_locale_string.empty();
}


// -----------------------------------------------------------------------------
bool Locale_data::Strings_t::GetList() const
{
	return _attribute_list;
}


void Locale_data::Strings_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Message::Message()
: _element_message_id_is_set(false)
, _element_author_id_is_set(false)
, _element_body_is_set(false)
, _element_created_time_is_set(false)
{
}


// -----------------------------------------------------------------------------
Message::Message(const Xml::XmlNode& it)
: _element_message_id_is_set(false)
, _element_author_id_is_set(false)
, _element_body_is_set(false)
, _element_created_time_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Message::clear()
{
	// simpleType:
	// _element_message_id.clear();
	// simpleType:
	// _element_author_id.clear();
	_element_body.clear();
	// simpleType:
	// _element_created_time.clear();
	_element_attachment.clear();
	_element_message_id_is_set = false;
	_element_author_id_is_set = false;
	_element_body_is_set = false;
	_element_created_time_is_set = false;
}


// -----------------------------------------------------------------------------
void Message::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("message_id"))
		throw Xml::XmlException("missing required node in element 'message': message_id");
	SetMessage_id( it["message_id"] );
	if (!it.Exists("author_id"))
		throw Xml::XmlException("missing required node in element 'message': author_id");
	SetAuthor_id( atoi(std::string(it["author_id"]).c_str()) );
	if (!it.Exists("body"))
		throw Xml::XmlException("missing required node in element 'message': body");
	SetBody( it["body"] );
	if (!it.Exists("created_time"))
		throw Xml::XmlException("missing required node in element 'message': created_time");
	SetCreated_time( atoi(std::string(it["created_time"]).c_str()) );
	if (!it.Exists("attachment"))
		throw Xml::XmlException("missing required node in element 'message': attachment");
	{
		Xml::XmlNode n(it, "attachment");
		if (n)
			_element_attachment.FromXml( n );
	}
}


// -----------------------------------------------------------------------------
const std::string Message::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	r += "<message_id>" + _element_message_id + "</message_id>";
	{
		r = r + "<author_id>" + Utility::l2string(_element_author_id) + "</author_id>";
	}
	r += "<body>" + _element_body + "</body>";
	{
		r = r + "<created_time>" + Utility::l2string(_element_created_time) + "</created_time>";
	}
	r += _element_attachment.ToString("attachment");
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Message::IsSet() const
{
	return Message_idIsSet() || Author_idIsSet() || BodyIsSet() || Created_timeIsSet() || AttachmentIsSet();
}


// -----------------------------------------------------------------------------
const std::string& Message::GetMessage_id() const
{
	return _element_message_id;
}


void Message::SetMessage_id(const std::string& message_id)
{
	_element_message_id = message_id;
	_element_message_id_is_set = true;
}


// -----------------------------------------------------------------------------
long Message::GetAuthor_id() const
{
	return _element_author_id;
}


void Message::SetAuthor_id(long author_id)
{
	_element_author_id = author_id;
	_element_author_id_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Message::GetBody() const
{
	return _element_body;
}


void Message::SetBody(const std::string& body)
{
	_element_body = body;
	_element_body_is_set = true;
}


// -----------------------------------------------------------------------------
long Message::GetCreated_time() const
{
	return _element_created_time;
}


void Message::SetCreated_time(long created_time)
{
	_element_created_time = created_time;
	_element_created_time_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Stream_attachment& Message::GetAttachment() const
{
	return _element_attachment;
}


com_facebook_1_0_::Stream_attachment& Message::GetAttachment()
{
	return _element_attachment;
}


void Message::SetAttachment(const com_facebook_1_0_::Stream_attachment& attachment)
{
	_element_attachment = attachment;
}


// -----------------------------------------------------------------------------
bool Message::AttachmentIsSet() const
{
	return _element_attachment.IsSet();
}


// -----------------------------------------------------------------------------
Thread::Thread()
: _element_message_count(0)
, _element_thread_id_is_set(false)
, _element_subject_is_set(false)
, _element_updated_time_is_set(false)
, _element_parent_message_id_is_set(false)
, _element_parent_thread_id_is_set(false)
, _element_message_count_is_set(false)
, _element_snippet_is_set(false)
, _element_snippet_author_is_set(false)
, _element_object_id_is_set(false)
, _element_unread_is_set(false)
{
}


// -----------------------------------------------------------------------------
Thread::Thread(const Xml::XmlNode& it)
: _element_message_count(0)
, _element_thread_id_is_set(false)
, _element_subject_is_set(false)
, _element_updated_time_is_set(false)
, _element_parent_message_id_is_set(false)
, _element_parent_thread_id_is_set(false)
, _element_message_count_is_set(false)
, _element_snippet_is_set(false)
, _element_snippet_author_is_set(false)
, _element_object_id_is_set(false)
, _element_unread_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Thread::clear()
{
	// simpleType:
	// _element_thread_id.clear();
	_element_subject.clear();
	_element_recipients.clear();
	// simpleType:
	// _element_updated_time.clear();
	// simpleType:
	// _element_parent_message_id.clear();
	// simpleType:
	// _element_parent_thread_id.clear();
	_element_message_count = 0;
	_element_snippet.clear();
	// simpleType:
	// _element_snippet_author.clear();
	// simpleType:
	// _element_object_id.clear();
	_element_unread = false;
	_element_messages.clear();
	_element_thread_id_is_set = false;
	_element_subject_is_set = false;
	_element_updated_time_is_set = false;
	_element_parent_message_id_is_set = false;
	_element_parent_thread_id_is_set = false;
	_element_message_count_is_set = false;
	_element_snippet_is_set = false;
	_element_snippet_author_is_set = false;
	_element_object_id_is_set = false;
	_element_unread_is_set = false;
}


// -----------------------------------------------------------------------------
void Thread::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("thread_id"))
		throw Xml::XmlException("missing required node in element 'thread': thread_id");
	SetThread_id( atoi(std::string(it["thread_id"]).c_str()) );
	if (!it.Exists("subject"))
		throw Xml::XmlException("missing required node in element 'thread': subject");
	SetSubject( it["subject"] );
	if (!it.Exists("recipients"))
		throw Xml::XmlException("missing required node in element 'thread': recipients");
	{
		Xml::XmlNode n(it, "recipients");
		if (n)
			_element_recipients.FromXml( n );
	}
	if (!it.Exists("updated_time"))
		throw Xml::XmlException("missing required node in element 'thread': updated_time");
	SetUpdated_time( atoi(std::string(it["updated_time"]).c_str()) );
	if (!it.Exists("parent_message_id"))
		throw Xml::XmlException("missing required node in element 'thread': parent_message_id");
	SetParent_message_id( it["parent_message_id"] );
	if (!it.Exists("parent_thread_id"))
		throw Xml::XmlException("missing required node in element 'thread': parent_thread_id");
	SetParent_thread_id( atoi(std::string(it["parent_thread_id"]).c_str()) );
	if (!it.Exists("message_count"))
		throw Xml::XmlException("missing required node in element 'thread': message_count");
	SetMessage_count( atoi(std::string(it["message_count"]).c_str()) );
	if (!it.Exists("snippet"))
		throw Xml::XmlException("missing required node in element 'thread': snippet");
	SetSnippet( it["snippet"] );
	if (!it.Exists("snippet_author"))
		throw Xml::XmlException("missing required node in element 'thread': snippet_author");
	SetSnippet_author( atoi(std::string(it["snippet_author"]).c_str()) );
	if (!it.Exists("object_id"))
		throw Xml::XmlException("missing required node in element 'thread': object_id");
	SetObject_id( atoi(std::string(it["object_id"]).c_str()) );
	if (!it.Exists("unread"))
		throw Xml::XmlException("missing required node in element 'thread': unread");
	SetUnread( atoi(std::string(it["unread"]).c_str()) );
	if (!it.Exists("messages"))
		throw Xml::XmlException("missing required node in element 'thread': messages");
	{
		Xml::XmlNode n(it, "messages");
		if (n)
			_element_messages.FromXml( n );
	}
}


// -----------------------------------------------------------------------------
const std::string Thread::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<thread_id>" + Utility::l2string(_element_thread_id) + "</thread_id>";
	}
	r += "<subject>" + _element_subject + "</subject>";
	r += _element_recipients.ToString("recipients");
	{
		r = r + "<updated_time>" + Utility::l2string(_element_updated_time) + "</updated_time>";
	}
	r += "<parent_message_id>" + _element_parent_message_id + "</parent_message_id>";
	{
		r = r + "<parent_thread_id>" + Utility::l2string(_element_parent_thread_id) + "</parent_thread_id>";
	}
	{
		r = r + "<message_count>" + Utility::l2string(_element_message_count) + "</message_count>";
	}
	r += "<snippet>" + _element_snippet + "</snippet>";
	{
		r = r + "<snippet_author>" + Utility::l2string(_element_snippet_author) + "</snippet_author>";
	}
	{
		r = r + "<object_id>" + Utility::l2string(_element_object_id) + "</object_id>";
	}
	{
		r = r + "<unread>" + Utility::l2string(_element_unread) + "</unread>";
	}
	r += _element_messages.ToString("messages");
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Thread::IsSet() const
{
	return Thread_idIsSet() || SubjectIsSet() || RecipientsIsSet() || Updated_timeIsSet() || Parent_message_idIsSet() || Parent_thread_idIsSet() || Message_countIsSet() || SnippetIsSet() || Snippet_authorIsSet() || Object_idIsSet() || UnreadIsSet() || MessagesIsSet();
}


// -----------------------------------------------------------------------------
long Thread::GetThread_id() const
{
	return _element_thread_id;
}


void Thread::SetThread_id(long thread_id)
{
	_element_thread_id = thread_id;
	_element_thread_id_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Thread::GetSubject() const
{
	return _element_subject;
}


void Thread::SetSubject(const std::string& subject)
{
	_element_subject = subject;
	_element_subject_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Thread::Recipients_t& Thread::GetRecipients() const
{
	return _element_recipients;
}


com_facebook_1_0_::Thread::Recipients_t& Thread::GetRecipients()
{
	return _element_recipients;
}


void Thread::SetRecipients(const com_facebook_1_0_::Thread::Recipients_t& recipients)
{
	_element_recipients = recipients;
}


// -----------------------------------------------------------------------------
long Thread::GetUpdated_time() const
{
	return _element_updated_time;
}


void Thread::SetUpdated_time(long updated_time)
{
	_element_updated_time = updated_time;
	_element_updated_time_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Thread::GetParent_message_id() const
{
	return _element_parent_message_id;
}


void Thread::SetParent_message_id(const std::string& parent_message_id)
{
	_element_parent_message_id = parent_message_id;
	_element_parent_message_id_is_set = true;
}


// -----------------------------------------------------------------------------
long Thread::GetParent_thread_id() const
{
	return _element_parent_thread_id;
}


void Thread::SetParent_thread_id(long parent_thread_id)
{
	_element_parent_thread_id = parent_thread_id;
	_element_parent_thread_id_is_set = true;
}


// -----------------------------------------------------------------------------
int Thread::GetMessage_count() const
{
	return _element_message_count;
}


void Thread::SetMessage_count(int message_count)
{
	_element_message_count = message_count;
	_element_message_count_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Thread::GetSnippet() const
{
	return _element_snippet;
}


void Thread::SetSnippet(const std::string& snippet)
{
	_element_snippet = snippet;
	_element_snippet_is_set = true;
}


// -----------------------------------------------------------------------------
long Thread::GetSnippet_author() const
{
	return _element_snippet_author;
}


void Thread::SetSnippet_author(long snippet_author)
{
	_element_snippet_author = snippet_author;
	_element_snippet_author_is_set = true;
}


// -----------------------------------------------------------------------------
long Thread::GetObject_id() const
{
	return _element_object_id;
}


void Thread::SetObject_id(long object_id)
{
	_element_object_id = object_id;
	_element_object_id_is_set = true;
}


// -----------------------------------------------------------------------------
bool Thread::GetUnread() const
{
	return _element_unread;
}


void Thread::SetUnread(bool unread)
{
	_element_unread = unread;
	_element_unread_is_set = true;
}


// -----------------------------------------------------------------------------
const com_facebook_1_0_::Thread::Messages_t& Thread::GetMessages() const
{
	return _element_messages;
}


com_facebook_1_0_::Thread::Messages_t& Thread::GetMessages()
{
	return _element_messages;
}


void Thread::SetMessages(const com_facebook_1_0_::Thread::Messages_t& messages)
{
	_element_messages = messages;
}


// -----------------------------------------------------------------------------
bool Thread::RecipientsIsSet() const
{
	return _element_recipients.IsSet();
}


// -----------------------------------------------------------------------------
bool Thread::MessagesIsSet() const
{
	return _element_messages.IsSet();
}


// -----------------------------------------------------------------------------
Thread::Recipients_t::Recipients_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Thread::Recipients_t::Recipients_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Thread::Recipients_t::clear()
{
	while (!_element_uid.empty())
		_element_uid.erase( _element_uid.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Thread::Recipients_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "uid");
		while (n)
		{
			_element_uid.push_back( atoi(n.GetContent().c_str()) );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Thread::Recipients_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<long>::const_iterator it = _element_uid.begin(); it != _element_uid.end(); it++)
	{
			r = r + "<uid>" + Utility::l2string(*it) + "</uid>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Thread::Recipients_t::IsSet() const
{
	return UidIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<long>& Thread::Recipients_t::GetUid() const
{
	return _element_uid;
}


std::list<long>& Thread::Recipients_t::GetUid()
{
	return _element_uid;
}


void Thread::Recipients_t::SetUid(const std::list<long>& uid)
{
	_element_uid = uid;
}


// -----------------------------------------------------------------------------
bool Thread::Recipients_t::UidIsSet() const
{
	return !_element_uid.empty();
}


// -----------------------------------------------------------------------------
bool Thread::Recipients_t::GetList() const
{
	return _attribute_list;
}


void Thread::Recipients_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Thread::Messages_t::Messages_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Thread::Messages_t::Messages_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Thread::Messages_t::clear()
{
	while (!_element_message.empty())
		_element_message.erase( _element_message.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Thread::Messages_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "message");
		while (n)
		{
			com_facebook_1_0_::Message tmp(n);
			_element_message.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Thread::Messages_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Message>::const_iterator it = _element_message.begin(); it != _element_message.end(); it++)
	{
		const com_facebook_1_0_::Message& ref = *it;
		r += ref.ToString("message");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Thread::Messages_t::IsSet() const
{
	return MessageIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Message>& Thread::Messages_t::GetMessage() const
{
	return _element_message;
}


std::list<com_facebook_1_0_::Message>& Thread::Messages_t::GetMessage()
{
	return _element_message;
}


void Thread::Messages_t::SetMessage(const std::list<com_facebook_1_0_::Message>& message)
{
	_element_message = message;
}


// -----------------------------------------------------------------------------
bool Thread::Messages_t::MessageIsSet() const
{
	return !_element_message.empty();
}


// -----------------------------------------------------------------------------
bool Thread::Messages_t::GetList() const
{
	return _attribute_list;
}


void Thread::Messages_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Mailbox_folder::Mailbox_folder()
: _element_folder_id(0)
, _element_unread_count(0)
, _element_total_count(0)
, _element_folder_id_is_set(false)
, _element_name_is_set(false)
, _element_unread_count_is_set(false)
, _element_total_count_is_set(false)
, _element_viewer_id_is_set(false)
{
}


// -----------------------------------------------------------------------------
Mailbox_folder::Mailbox_folder(const Xml::XmlNode& it)
: _element_folder_id(0)
, _element_unread_count(0)
, _element_total_count(0)
, _element_folder_id_is_set(false)
, _element_name_is_set(false)
, _element_unread_count_is_set(false)
, _element_total_count_is_set(false)
, _element_viewer_id_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Mailbox_folder::clear()
{
	_element_folder_id = 0;
	_element_name.clear();
	_element_unread_count = 0;
	_element_total_count = 0;
	// simpleType:
	// _element_viewer_id.clear();
	_element_folder_id_is_set = false;
	_element_name_is_set = false;
	_element_unread_count_is_set = false;
	_element_total_count_is_set = false;
	_element_viewer_id_is_set = false;
}


// -----------------------------------------------------------------------------
void Mailbox_folder::FromXml(const Xml::XmlNode& it)
{
	if (!it.Exists("folder_id"))
		throw Xml::XmlException("missing required node in element 'mailbox_folder': folder_id");
	SetFolder_id( atoi(std::string(it["folder_id"]).c_str()) );
	if (!it.Exists("name"))
		throw Xml::XmlException("missing required node in element 'mailbox_folder': name");
	SetName( it["name"] );
	if (!it.Exists("unread_count"))
		throw Xml::XmlException("missing required node in element 'mailbox_folder': unread_count");
	SetUnread_count( atoi(std::string(it["unread_count"]).c_str()) );
	if (!it.Exists("total_count"))
		throw Xml::XmlException("missing required node in element 'mailbox_folder': total_count");
	SetTotal_count( atoi(std::string(it["total_count"]).c_str()) );
	if (!it.Exists("viewer_id"))
		throw Xml::XmlException("missing required node in element 'mailbox_folder': viewer_id");
	SetViewer_id( atoi(std::string(it["viewer_id"]).c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Mailbox_folder::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	{
		r = r + "<folder_id>" + Utility::l2string(_element_folder_id) + "</folder_id>";
	}
	r += "<name>" + _element_name + "</name>";
	{
		r = r + "<unread_count>" + Utility::l2string(_element_unread_count) + "</unread_count>";
	}
	{
		r = r + "<total_count>" + Utility::l2string(_element_total_count) + "</total_count>";
	}
	{
		r = r + "<viewer_id>" + Utility::l2string(_element_viewer_id) + "</viewer_id>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Mailbox_folder::IsSet() const
{
	return Folder_idIsSet() || NameIsSet() || Unread_countIsSet() || Total_countIsSet() || Viewer_idIsSet();
}


// -----------------------------------------------------------------------------
int Mailbox_folder::GetFolder_id() const
{
	return _element_folder_id;
}


void Mailbox_folder::SetFolder_id(int folder_id)
{
	_element_folder_id = folder_id;
	_element_folder_id_is_set = true;
}


// -----------------------------------------------------------------------------
const std::string& Mailbox_folder::GetName() const
{
	return _element_name;
}


void Mailbox_folder::SetName(const std::string& name)
{
	_element_name = name;
	_element_name_is_set = true;
}


// -----------------------------------------------------------------------------
int Mailbox_folder::GetUnread_count() const
{
	return _element_unread_count;
}


void Mailbox_folder::SetUnread_count(int unread_count)
{
	_element_unread_count = unread_count;
	_element_unread_count_is_set = true;
}


// -----------------------------------------------------------------------------
int Mailbox_folder::GetTotal_count() const
{
	return _element_total_count;
}


void Mailbox_folder::SetTotal_count(int total_count)
{
	_element_total_count = total_count;
	_element_total_count_is_set = true;
}


// -----------------------------------------------------------------------------
long Mailbox_folder::GetViewer_id() const
{
	return _element_viewer_id;
}


void Mailbox_folder::SetViewer_id(long viewer_id)
{
	_element_viewer_id = viewer_id;
	_element_viewer_id_is_set = true;
}


// -----------------------------------------------------------------------------
Connect_registerUsers_response_t::Connect_registerUsers_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Connect_registerUsers_response_t::Connect_registerUsers_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Connect_registerUsers_response_t::clear()
{
	while (!_element_connect_registerUsers_response_elt.empty())
		_element_connect_registerUsers_response_elt.erase( _element_connect_registerUsers_response_elt.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Connect_registerUsers_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "connect_registerUsers_response_elt");
		while (n)
		{
			_element_connect_registerUsers_response_elt.push_back( n.GetContent() );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Connect_registerUsers_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<std::string>::const_iterator it = _element_connect_registerUsers_response_elt.begin(); it != _element_connect_registerUsers_response_elt.end(); it++)
	{
		r += "<connect_registerUsers_response_elt>" + *it + "</connect_registerUsers_response_elt>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Connect_registerUsers_response_t::IsSet() const
{
	return Connect_registerUsers_response_eltIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<std::string>& Connect_registerUsers_response_t::GetConnect_registerUsers_response_elt() const
{
	return _element_connect_registerUsers_response_elt;
}


std::list<std::string>& Connect_registerUsers_response_t::GetConnect_registerUsers_response_elt()
{
	return _element_connect_registerUsers_response_elt;
}


void Connect_registerUsers_response_t::SetConnect_registerUsers_response_elt(const std::list<std::string>& connect_registerUsers_response_elt)
{
	_element_connect_registerUsers_response_elt = connect_registerUsers_response_elt;
}


// -----------------------------------------------------------------------------
bool Connect_registerUsers_response_t::Connect_registerUsers_response_eltIsSet() const
{
	return !_element_connect_registerUsers_response_elt.empty();
}


// -----------------------------------------------------------------------------
bool Connect_registerUsers_response_t::GetList() const
{
	return _attribute_list;
}


void Connect_registerUsers_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Connect_unregisterUsers_response_t::Connect_unregisterUsers_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Connect_unregisterUsers_response_t::Connect_unregisterUsers_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Connect_unregisterUsers_response_t::clear()
{
	while (!_element_connect_unregisterUsers_response_elt.empty())
		_element_connect_unregisterUsers_response_elt.erase( _element_connect_unregisterUsers_response_elt.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Connect_unregisterUsers_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "connect_unregisterUsers_response_elt");
		while (n)
		{
			_element_connect_unregisterUsers_response_elt.push_back( n.GetContent() );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Connect_unregisterUsers_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<std::string>::const_iterator it = _element_connect_unregisterUsers_response_elt.begin(); it != _element_connect_unregisterUsers_response_elt.end(); it++)
	{
		r += "<connect_unregisterUsers_response_elt>" + *it + "</connect_unregisterUsers_response_elt>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Connect_unregisterUsers_response_t::IsSet() const
{
	return Connect_unregisterUsers_response_eltIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<std::string>& Connect_unregisterUsers_response_t::GetConnect_unregisterUsers_response_elt() const
{
	return _element_connect_unregisterUsers_response_elt;
}


std::list<std::string>& Connect_unregisterUsers_response_t::GetConnect_unregisterUsers_response_elt()
{
	return _element_connect_unregisterUsers_response_elt;
}


void Connect_unregisterUsers_response_t::SetConnect_unregisterUsers_response_elt(const std::list<std::string>& connect_unregisterUsers_response_elt)
{
	_element_connect_unregisterUsers_response_elt = connect_unregisterUsers_response_elt;
}


// -----------------------------------------------------------------------------
bool Connect_unregisterUsers_response_t::Connect_unregisterUsers_response_eltIsSet() const
{
	return !_element_connect_unregisterUsers_response_elt.empty();
}


// -----------------------------------------------------------------------------
bool Connect_unregisterUsers_response_t::GetList() const
{
	return _attribute_list;
}


void Connect_unregisterUsers_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Events_get_response_t::Events_get_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Events_get_response_t::Events_get_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Events_get_response_t::clear()
{
	while (!_element_event.empty())
		_element_event.erase( _element_event.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Events_get_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "event");
		while (n)
		{
			com_facebook_1_0_::Event tmp(n);
			_element_event.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Events_get_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Event>::const_iterator it = _element_event.begin(); it != _element_event.end(); it++)
	{
		const com_facebook_1_0_::Event& ref = *it;
		r += ref.ToString("event");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Events_get_response_t::IsSet() const
{
	return EventIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Event>& Events_get_response_t::GetEvent() const
{
	return _element_event;
}


std::list<com_facebook_1_0_::Event>& Events_get_response_t::GetEvent()
{
	return _element_event;
}


void Events_get_response_t::SetEvent(const std::list<com_facebook_1_0_::Event>& event)
{
	_element_event = event;
}


// -----------------------------------------------------------------------------
bool Events_get_response_t::EventIsSet() const
{
	return !_element_event.empty();
}


// -----------------------------------------------------------------------------
bool Events_get_response_t::GetList() const
{
	return _attribute_list;
}


void Events_get_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Notes_get_response_t::Notes_get_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Notes_get_response_t::Notes_get_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Notes_get_response_t::clear()
{
	while (!_element_note.empty())
		_element_note.erase( _element_note.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Notes_get_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "note");
		while (n)
		{
			com_facebook_1_0_::Note tmp(n);
			_element_note.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Notes_get_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Note>::const_iterator it = _element_note.begin(); it != _element_note.end(); it++)
	{
		const com_facebook_1_0_::Note& ref = *it;
		r += ref.ToString("note");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Notes_get_response_t::IsSet() const
{
	return NoteIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Note>& Notes_get_response_t::GetNote() const
{
	return _element_note;
}


std::list<com_facebook_1_0_::Note>& Notes_get_response_t::GetNote()
{
	return _element_note;
}


void Notes_get_response_t::SetNote(const std::list<com_facebook_1_0_::Note>& note)
{
	_element_note = note;
}


// -----------------------------------------------------------------------------
bool Notes_get_response_t::NoteIsSet() const
{
	return !_element_note.empty();
}


// -----------------------------------------------------------------------------
bool Notes_get_response_t::GetList() const
{
	return _attribute_list;
}


void Notes_get_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Status_get_response_t::Status_get_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Status_get_response_t::Status_get_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Status_get_response_t::clear()
{
	while (!_element_user_status.empty())
		_element_user_status.erase( _element_user_status.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Status_get_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "user_status");
		while (n)
		{
			com_facebook_1_0_::User_status tmp(n);
			_element_user_status.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Status_get_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::User_status>::const_iterator it = _element_user_status.begin(); it != _element_user_status.end(); it++)
	{
		const com_facebook_1_0_::User_status& ref = *it;
		r += ref.ToString("user_status");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Status_get_response_t::IsSet() const
{
	return User_statusIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::User_status>& Status_get_response_t::GetUser_status() const
{
	return _element_user_status;
}


std::list<com_facebook_1_0_::User_status>& Status_get_response_t::GetUser_status()
{
	return _element_user_status;
}


void Status_get_response_t::SetUser_status(const std::list<com_facebook_1_0_::User_status>& user_status)
{
	_element_user_status = user_status;
}


// -----------------------------------------------------------------------------
bool Status_get_response_t::User_statusIsSet() const
{
	return !_element_user_status.empty();
}


// -----------------------------------------------------------------------------
bool Status_get_response_t::GetList() const
{
	return _attribute_list;
}


void Status_get_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Stream_getFilters_response_t::Stream_getFilters_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_getFilters_response_t::Stream_getFilters_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_getFilters_response_t::clear()
{
	while (!_element_stream_filter.empty())
		_element_stream_filter.erase( _element_stream_filter.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_getFilters_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "stream_filter");
		while (n)
		{
			com_facebook_1_0_::Stream_filter tmp(n);
			_element_stream_filter.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Stream_getFilters_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Stream_filter>::const_iterator it = _element_stream_filter.begin(); it != _element_stream_filter.end(); it++)
	{
		const com_facebook_1_0_::Stream_filter& ref = *it;
		r += ref.ToString("stream_filter");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_getFilters_response_t::IsSet() const
{
	return Stream_filterIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Stream_filter>& Stream_getFilters_response_t::GetStream_filter() const
{
	return _element_stream_filter;
}


std::list<com_facebook_1_0_::Stream_filter>& Stream_getFilters_response_t::GetStream_filter()
{
	return _element_stream_filter;
}


void Stream_getFilters_response_t::SetStream_filter(const std::list<com_facebook_1_0_::Stream_filter>& stream_filter)
{
	_element_stream_filter = stream_filter;
}


// -----------------------------------------------------------------------------
bool Stream_getFilters_response_t::Stream_filterIsSet() const
{
	return !_element_stream_filter.empty();
}


// -----------------------------------------------------------------------------
bool Stream_getFilters_response_t::GetList() const
{
	return _attribute_list;
}


void Stream_getFilters_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Stream_getComments_response_t::Stream_getComments_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Stream_getComments_response_t::Stream_getComments_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Stream_getComments_response_t::clear()
{
	while (!_element_comment.empty())
		_element_comment.erase( _element_comment.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Stream_getComments_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "comment");
		while (n)
		{
			com_facebook_1_0_::Comment tmp(n);
			_element_comment.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Stream_getComments_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Comment>::const_iterator it = _element_comment.begin(); it != _element_comment.end(); it++)
	{
		const com_facebook_1_0_::Comment& ref = *it;
		r += ref.ToString("comment");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Stream_getComments_response_t::IsSet() const
{
	return CommentIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Comment>& Stream_getComments_response_t::GetComment() const
{
	return _element_comment;
}


std::list<com_facebook_1_0_::Comment>& Stream_getComments_response_t::GetComment()
{
	return _element_comment;
}


void Stream_getComments_response_t::SetComment(const std::list<com_facebook_1_0_::Comment>& comment)
{
	_element_comment = comment;
}


// -----------------------------------------------------------------------------
bool Stream_getComments_response_t::CommentIsSet() const
{
	return !_element_comment.empty();
}


// -----------------------------------------------------------------------------
bool Stream_getComments_response_t::GetList() const
{
	return _attribute_list;
}


void Stream_getComments_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Links_get_response_t::Links_get_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Links_get_response_t::Links_get_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Links_get_response_t::clear()
{
	while (!_element_link.empty())
		_element_link.erase( _element_link.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Links_get_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "link");
		while (n)
		{
			com_facebook_1_0_::Link tmp(n);
			_element_link.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Links_get_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Link>::const_iterator it = _element_link.begin(); it != _element_link.end(); it++)
	{
		const com_facebook_1_0_::Link& ref = *it;
		r += ref.ToString("link");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Links_get_response_t::IsSet() const
{
	return LinkIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Link>& Links_get_response_t::GetLink() const
{
	return _element_link;
}


std::list<com_facebook_1_0_::Link>& Links_get_response_t::GetLink()
{
	return _element_link;
}


void Links_get_response_t::SetLink(const std::list<com_facebook_1_0_::Link>& link)
{
	_element_link = link;
}


// -----------------------------------------------------------------------------
bool Links_get_response_t::LinkIsSet() const
{
	return !_element_link.empty();
}


// -----------------------------------------------------------------------------
bool Links_get_response_t::GetList() const
{
	return _attribute_list;
}


void Links_get_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Links_getStats_response_t::Links_getStats_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Links_getStats_response_t::Links_getStats_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Links_getStats_response_t::clear()
{
	while (!_element_link_stat.empty())
		_element_link_stat.erase( _element_link_stat.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Links_getStats_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "link_stat");
		while (n)
		{
			com_facebook_1_0_::Link_stat tmp(n);
			_element_link_stat.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Links_getStats_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Link_stat>::const_iterator it = _element_link_stat.begin(); it != _element_link_stat.end(); it++)
	{
		const com_facebook_1_0_::Link_stat& ref = *it;
		r += ref.ToString("link_stat");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Links_getStats_response_t::IsSet() const
{
	return Link_statIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Link_stat>& Links_getStats_response_t::GetLink_stat() const
{
	return _element_link_stat;
}


std::list<com_facebook_1_0_::Link_stat>& Links_getStats_response_t::GetLink_stat()
{
	return _element_link_stat;
}


void Links_getStats_response_t::SetLink_stat(const std::list<com_facebook_1_0_::Link_stat>& link_stat)
{
	_element_link_stat = link_stat;
}


// -----------------------------------------------------------------------------
bool Links_getStats_response_t::Link_statIsSet() const
{
	return !_element_link_stat.empty();
}


// -----------------------------------------------------------------------------
bool Links_getStats_response_t::GetList() const
{
	return _attribute_list;
}


void Links_getStats_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Comments_get_response_t::Comments_get_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Comments_get_response_t::Comments_get_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Comments_get_response_t::clear()
{
	while (!_element_comment.empty())
		_element_comment.erase( _element_comment.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Comments_get_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "comment");
		while (n)
		{
			com_facebook_1_0_::Comment tmp(n);
			_element_comment.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Comments_get_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Comment>::const_iterator it = _element_comment.begin(); it != _element_comment.end(); it++)
	{
		const com_facebook_1_0_::Comment& ref = *it;
		r += ref.ToString("comment");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Comments_get_response_t::IsSet() const
{
	return CommentIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Comment>& Comments_get_response_t::GetComment() const
{
	return _element_comment;
}


std::list<com_facebook_1_0_::Comment>& Comments_get_response_t::GetComment()
{
	return _element_comment;
}


void Comments_get_response_t::SetComment(const std::list<com_facebook_1_0_::Comment>& comment)
{
	_element_comment = comment;
}


// -----------------------------------------------------------------------------
bool Comments_get_response_t::CommentIsSet() const
{
	return !_element_comment.empty();
}


// -----------------------------------------------------------------------------
bool Comments_get_response_t::GetList() const
{
	return _attribute_list;
}


void Comments_get_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Fbml_getCustomTags_response_t::Fbml_getCustomTags_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Fbml_getCustomTags_response_t::Fbml_getCustomTags_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Fbml_getCustomTags_response_t::clear()
{
	while (!_element_custom_tag.empty())
		_element_custom_tag.erase( _element_custom_tag.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Fbml_getCustomTags_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "custom_tag");
		while (n)
		{
			com_facebook_1_0_::Custom_tag tmp(n);
			_element_custom_tag.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Fbml_getCustomTags_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Custom_tag>::const_iterator it = _element_custom_tag.begin(); it != _element_custom_tag.end(); it++)
	{
		const com_facebook_1_0_::Custom_tag& ref = *it;
		r += ref.ToString("custom_tag");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Fbml_getCustomTags_response_t::IsSet() const
{
	return Custom_tagIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Custom_tag>& Fbml_getCustomTags_response_t::GetCustom_tag() const
{
	return _element_custom_tag;
}


std::list<com_facebook_1_0_::Custom_tag>& Fbml_getCustomTags_response_t::GetCustom_tag()
{
	return _element_custom_tag;
}


void Fbml_getCustomTags_response_t::SetCustom_tag(const std::list<com_facebook_1_0_::Custom_tag>& custom_tag)
{
	_element_custom_tag = custom_tag;
}


// -----------------------------------------------------------------------------
bool Fbml_getCustomTags_response_t::Custom_tagIsSet() const
{
	return !_element_custom_tag.empty();
}


// -----------------------------------------------------------------------------
bool Fbml_getCustomTags_response_t::GetList() const
{
	return _attribute_list;
}


void Fbml_getCustomTags_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Friends_areFriends_response_t::Friends_areFriends_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Friends_areFriends_response_t::Friends_areFriends_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Friends_areFriends_response_t::clear()
{
	while (!_element_friend_info.empty())
		_element_friend_info.erase( _element_friend_info.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Friends_areFriends_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "friend_info");
		while (n)
		{
			com_facebook_1_0_::Friend_info tmp(n);
			_element_friend_info.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Friends_areFriends_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Friend_info>::const_iterator it = _element_friend_info.begin(); it != _element_friend_info.end(); it++)
	{
		const com_facebook_1_0_::Friend_info& ref = *it;
		r += ref.ToString("friend_info");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Friends_areFriends_response_t::IsSet() const
{
	return Friend_infoIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Friend_info>& Friends_areFriends_response_t::GetFriend_info() const
{
	return _element_friend_info;
}


std::list<com_facebook_1_0_::Friend_info>& Friends_areFriends_response_t::GetFriend_info()
{
	return _element_friend_info;
}


void Friends_areFriends_response_t::SetFriend_info(const std::list<com_facebook_1_0_::Friend_info>& friend_info)
{
	_element_friend_info = friend_info;
}


// -----------------------------------------------------------------------------
bool Friends_areFriends_response_t::Friend_infoIsSet() const
{
	return !_element_friend_info.empty();
}


// -----------------------------------------------------------------------------
bool Friends_areFriends_response_t::GetList() const
{
	return _attribute_list;
}


void Friends_areFriends_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Friends_get_response_t::Friends_get_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Friends_get_response_t::Friends_get_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Friends_get_response_t::clear()
{
	while (!_element_uid.empty())
		_element_uid.erase( _element_uid.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Friends_get_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "uid");
		while (n)
		{
			_element_uid.push_back( atoi(n.GetContent().c_str()) );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Friends_get_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<long>::const_iterator it = _element_uid.begin(); it != _element_uid.end(); it++)
	{
			r = r + "<uid>" + Utility::l2string(*it) + "</uid>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Friends_get_response_t::IsSet() const
{
	return UidIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<long>& Friends_get_response_t::GetUid() const
{
	return _element_uid;
}


std::list<long>& Friends_get_response_t::GetUid()
{
	return _element_uid;
}


void Friends_get_response_t::SetUid(const std::list<long>& uid)
{
	_element_uid = uid;
}


// -----------------------------------------------------------------------------
bool Friends_get_response_t::UidIsSet() const
{
	return !_element_uid.empty();
}


// -----------------------------------------------------------------------------
bool Friends_get_response_t::GetList() const
{
	return _attribute_list;
}


void Friends_get_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Friends_getMutualFriends_response_t::Friends_getMutualFriends_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Friends_getMutualFriends_response_t::Friends_getMutualFriends_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Friends_getMutualFriends_response_t::clear()
{
	while (!_element_uid.empty())
		_element_uid.erase( _element_uid.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Friends_getMutualFriends_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "uid");
		while (n)
		{
			_element_uid.push_back( atoi(n.GetContent().c_str()) );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Friends_getMutualFriends_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<long>::const_iterator it = _element_uid.begin(); it != _element_uid.end(); it++)
	{
			r = r + "<uid>" + Utility::l2string(*it) + "</uid>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Friends_getMutualFriends_response_t::IsSet() const
{
	return UidIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<long>& Friends_getMutualFriends_response_t::GetUid() const
{
	return _element_uid;
}


std::list<long>& Friends_getMutualFriends_response_t::GetUid()
{
	return _element_uid;
}


void Friends_getMutualFriends_response_t::SetUid(const std::list<long>& uid)
{
	_element_uid = uid;
}


// -----------------------------------------------------------------------------
bool Friends_getMutualFriends_response_t::UidIsSet() const
{
	return !_element_uid.empty();
}


// -----------------------------------------------------------------------------
bool Friends_getMutualFriends_response_t::GetList() const
{
	return _attribute_list;
}


void Friends_getMutualFriends_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Friends_getAppUsers_response_t::Friends_getAppUsers_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Friends_getAppUsers_response_t::Friends_getAppUsers_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Friends_getAppUsers_response_t::clear()
{
	while (!_element_uid.empty())
		_element_uid.erase( _element_uid.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Friends_getAppUsers_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "uid");
		while (n)
		{
			_element_uid.push_back( atoi(n.GetContent().c_str()) );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Friends_getAppUsers_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<long>::const_iterator it = _element_uid.begin(); it != _element_uid.end(); it++)
	{
			r = r + "<uid>" + Utility::l2string(*it) + "</uid>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Friends_getAppUsers_response_t::IsSet() const
{
	return UidIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<long>& Friends_getAppUsers_response_t::GetUid() const
{
	return _element_uid;
}


std::list<long>& Friends_getAppUsers_response_t::GetUid()
{
	return _element_uid;
}


void Friends_getAppUsers_response_t::SetUid(const std::list<long>& uid)
{
	_element_uid = uid;
}


// -----------------------------------------------------------------------------
bool Friends_getAppUsers_response_t::UidIsSet() const
{
	return !_element_uid.empty();
}


// -----------------------------------------------------------------------------
bool Friends_getAppUsers_response_t::GetList() const
{
	return _attribute_list;
}


void Friends_getAppUsers_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Friends_getLists_response_t::Friends_getLists_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Friends_getLists_response_t::Friends_getLists_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Friends_getLists_response_t::clear()
{
	while (!_element_friendlist.empty())
		_element_friendlist.erase( _element_friendlist.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Friends_getLists_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "friendlist");
		while (n)
		{
			com_facebook_1_0_::Friendlist tmp(n);
			_element_friendlist.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Friends_getLists_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Friendlist>::const_iterator it = _element_friendlist.begin(); it != _element_friendlist.end(); it++)
	{
		const com_facebook_1_0_::Friendlist& ref = *it;
		r += ref.ToString("friendlist");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Friends_getLists_response_t::IsSet() const
{
	return FriendlistIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Friendlist>& Friends_getLists_response_t::GetFriendlist() const
{
	return _element_friendlist;
}


std::list<com_facebook_1_0_::Friendlist>& Friends_getLists_response_t::GetFriendlist()
{
	return _element_friendlist;
}


void Friends_getLists_response_t::SetFriendlist(const std::list<com_facebook_1_0_::Friendlist>& friendlist)
{
	_element_friendlist = friendlist;
}


// -----------------------------------------------------------------------------
bool Friends_getLists_response_t::FriendlistIsSet() const
{
	return !_element_friendlist.empty();
}


// -----------------------------------------------------------------------------
bool Friends_getLists_response_t::GetList() const
{
	return _attribute_list;
}


void Friends_getLists_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Groups_get_response_t::Groups_get_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Groups_get_response_t::Groups_get_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Groups_get_response_t::clear()
{
	while (!_element_group.empty())
		_element_group.erase( _element_group.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Groups_get_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "group");
		while (n)
		{
			com_facebook_1_0_::Group tmp(n);
			_element_group.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Groups_get_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Group>::const_iterator it = _element_group.begin(); it != _element_group.end(); it++)
	{
		const com_facebook_1_0_::Group& ref = *it;
		r += ref.ToString("group");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Groups_get_response_t::IsSet() const
{
	return GroupIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Group>& Groups_get_response_t::GetGroup() const
{
	return _element_group;
}


std::list<com_facebook_1_0_::Group>& Groups_get_response_t::GetGroup()
{
	return _element_group;
}


void Groups_get_response_t::SetGroup(const std::list<com_facebook_1_0_::Group>& group)
{
	_element_group = group;
}


// -----------------------------------------------------------------------------
bool Groups_get_response_t::GroupIsSet() const
{
	return !_element_group.empty();
}


// -----------------------------------------------------------------------------
bool Groups_get_response_t::GetList() const
{
	return _attribute_list;
}


void Groups_get_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Intl_getTranslations_response_t::Intl_getTranslations_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Intl_getTranslations_response_t::Intl_getTranslations_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Intl_getTranslations_response_t::clear()
{
	while (!_element_locale_data.empty())
		_element_locale_data.erase( _element_locale_data.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Intl_getTranslations_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "locale_data");
		while (n)
		{
			com_facebook_1_0_::Locale_data tmp(n);
			_element_locale_data.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Intl_getTranslations_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Locale_data>::const_iterator it = _element_locale_data.begin(); it != _element_locale_data.end(); it++)
	{
		const com_facebook_1_0_::Locale_data& ref = *it;
		r += ref.ToString("locale_data");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Intl_getTranslations_response_t::IsSet() const
{
	return Locale_dataIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Locale_data>& Intl_getTranslations_response_t::GetLocale_data() const
{
	return _element_locale_data;
}


std::list<com_facebook_1_0_::Locale_data>& Intl_getTranslations_response_t::GetLocale_data()
{
	return _element_locale_data;
}


void Intl_getTranslations_response_t::SetLocale_data(const std::list<com_facebook_1_0_::Locale_data>& locale_data)
{
	_element_locale_data = locale_data;
}


// -----------------------------------------------------------------------------
bool Intl_getTranslations_response_t::Locale_dataIsSet() const
{
	return !_element_locale_data.empty();
}


// -----------------------------------------------------------------------------
bool Intl_getTranslations_response_t::GetList() const
{
	return _attribute_list;
}


void Intl_getTranslations_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Privacy_canSee_response_t::Privacy_canSee_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Privacy_canSee_response_t::Privacy_canSee_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Privacy_canSee_response_t::clear()
{
	while (!_element_privacy_canSee_response_elt.empty())
		_element_privacy_canSee_response_elt.erase( _element_privacy_canSee_response_elt.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Privacy_canSee_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "privacy_canSee_response_elt");
		while (n)
		{
			_element_privacy_canSee_response_elt.push_back( atoi(n.GetContent().c_str()) );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Privacy_canSee_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<bool>::const_iterator it = _element_privacy_canSee_response_elt.begin(); it != _element_privacy_canSee_response_elt.end(); it++)
	{
		{
			r = r + "<privacy_canSee_response_elt>" + Utility::l2string(*it) + "</privacy_canSee_response_elt>";
		}
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Privacy_canSee_response_t::IsSet() const
{
	return Privacy_canSee_response_eltIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<bool>& Privacy_canSee_response_t::GetPrivacy_canSee_response_elt() const
{
	return _element_privacy_canSee_response_elt;
}


std::list<bool>& Privacy_canSee_response_t::GetPrivacy_canSee_response_elt()
{
	return _element_privacy_canSee_response_elt;
}


void Privacy_canSee_response_t::SetPrivacy_canSee_response_elt(const std::list<bool>& privacy_canSee_response_elt)
{
	_element_privacy_canSee_response_elt = privacy_canSee_response_elt;
}


// -----------------------------------------------------------------------------
bool Privacy_canSee_response_t::Privacy_canSee_response_eltIsSet() const
{
	return !_element_privacy_canSee_response_elt.empty();
}


// -----------------------------------------------------------------------------
bool Privacy_canSee_response_t::GetList() const
{
	return _attribute_list;
}


void Privacy_canSee_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Data_getCookies_response_t::Data_getCookies_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Data_getCookies_response_t::Data_getCookies_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Data_getCookies_response_t::clear()
{
	while (!_element_cookie.empty())
		_element_cookie.erase( _element_cookie.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Data_getCookies_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "cookie");
		while (n)
		{
			com_facebook_1_0_::Cookie tmp(n);
			_element_cookie.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Data_getCookies_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Cookie>::const_iterator it = _element_cookie.begin(); it != _element_cookie.end(); it++)
	{
		const com_facebook_1_0_::Cookie& ref = *it;
		r += ref.ToString("cookie");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Data_getCookies_response_t::IsSet() const
{
	return CookieIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Cookie>& Data_getCookies_response_t::GetCookie() const
{
	return _element_cookie;
}


std::list<com_facebook_1_0_::Cookie>& Data_getCookies_response_t::GetCookie()
{
	return _element_cookie;
}


void Data_getCookies_response_t::SetCookie(const std::list<com_facebook_1_0_::Cookie>& cookie)
{
	_element_cookie = cookie;
}


// -----------------------------------------------------------------------------
bool Data_getCookies_response_t::CookieIsSet() const
{
	return !_element_cookie.empty();
}


// -----------------------------------------------------------------------------
bool Data_getCookies_response_t::GetList() const
{
	return _attribute_list;
}


void Data_getCookies_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Permissions_checkGrantedApiAccess_response_t::Permissions_checkGrantedApiAccess_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Permissions_checkGrantedApiAccess_response_t::Permissions_checkGrantedApiAccess_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Permissions_checkGrantedApiAccess_response_t::clear()
{
	while (!_element_permissions_checkGrantedApiAccess_response_elt.empty())
		_element_permissions_checkGrantedApiAccess_response_elt.erase( _element_permissions_checkGrantedApiAccess_response_elt.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Permissions_checkGrantedApiAccess_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "permissions_checkGrantedApiAccess_response_elt");
		while (n)
		{
			_element_permissions_checkGrantedApiAccess_response_elt.push_back( n.GetContent() );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Permissions_checkGrantedApiAccess_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<std::string>::const_iterator it = _element_permissions_checkGrantedApiAccess_response_elt.begin(); it != _element_permissions_checkGrantedApiAccess_response_elt.end(); it++)
	{
		r += "<permissions_checkGrantedApiAccess_response_elt>" + *it + "</permissions_checkGrantedApiAccess_response_elt>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Permissions_checkGrantedApiAccess_response_t::IsSet() const
{
	return Permissions_checkGrantedApiAccess_response_eltIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<std::string>& Permissions_checkGrantedApiAccess_response_t::GetPermissions_checkGrantedApiAccess_response_elt() const
{
	return _element_permissions_checkGrantedApiAccess_response_elt;
}


std::list<std::string>& Permissions_checkGrantedApiAccess_response_t::GetPermissions_checkGrantedApiAccess_response_elt()
{
	return _element_permissions_checkGrantedApiAccess_response_elt;
}


void Permissions_checkGrantedApiAccess_response_t::SetPermissions_checkGrantedApiAccess_response_elt(const std::list<std::string>& permissions_checkGrantedApiAccess_response_elt)
{
	_element_permissions_checkGrantedApiAccess_response_elt = permissions_checkGrantedApiAccess_response_elt;
}


// -----------------------------------------------------------------------------
bool Permissions_checkGrantedApiAccess_response_t::Permissions_checkGrantedApiAccess_response_eltIsSet() const
{
	return !_element_permissions_checkGrantedApiAccess_response_elt.empty();
}


// -----------------------------------------------------------------------------
bool Permissions_checkGrantedApiAccess_response_t::GetList() const
{
	return _attribute_list;
}


void Permissions_checkGrantedApiAccess_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Permissions_checkAvailableApiAccess_response_t::Permissions_checkAvailableApiAccess_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Permissions_checkAvailableApiAccess_response_t::Permissions_checkAvailableApiAccess_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Permissions_checkAvailableApiAccess_response_t::clear()
{
	while (!_element_permissions_checkAvailableApiAccess_response_elt.empty())
		_element_permissions_checkAvailableApiAccess_response_elt.erase( _element_permissions_checkAvailableApiAccess_response_elt.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Permissions_checkAvailableApiAccess_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "permissions_checkAvailableApiAccess_response_elt");
		while (n)
		{
			_element_permissions_checkAvailableApiAccess_response_elt.push_back( n.GetContent() );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Permissions_checkAvailableApiAccess_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<std::string>::const_iterator it = _element_permissions_checkAvailableApiAccess_response_elt.begin(); it != _element_permissions_checkAvailableApiAccess_response_elt.end(); it++)
	{
		r += "<permissions_checkAvailableApiAccess_response_elt>" + *it + "</permissions_checkAvailableApiAccess_response_elt>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Permissions_checkAvailableApiAccess_response_t::IsSet() const
{
	return Permissions_checkAvailableApiAccess_response_eltIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<std::string>& Permissions_checkAvailableApiAccess_response_t::GetPermissions_checkAvailableApiAccess_response_elt() const
{
	return _element_permissions_checkAvailableApiAccess_response_elt;
}


std::list<std::string>& Permissions_checkAvailableApiAccess_response_t::GetPermissions_checkAvailableApiAccess_response_elt()
{
	return _element_permissions_checkAvailableApiAccess_response_elt;
}


void Permissions_checkAvailableApiAccess_response_t::SetPermissions_checkAvailableApiAccess_response_elt(const std::list<std::string>& permissions_checkAvailableApiAccess_response_elt)
{
	_element_permissions_checkAvailableApiAccess_response_elt = permissions_checkAvailableApiAccess_response_elt;
}


// -----------------------------------------------------------------------------
bool Permissions_checkAvailableApiAccess_response_t::Permissions_checkAvailableApiAccess_response_eltIsSet() const
{
	return !_element_permissions_checkAvailableApiAccess_response_elt.empty();
}


// -----------------------------------------------------------------------------
bool Permissions_checkAvailableApiAccess_response_t::GetList() const
{
	return _attribute_list;
}


void Permissions_checkAvailableApiAccess_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Fql_query_response_t::Fql_query_response_t()
{
}


// -----------------------------------------------------------------------------
Fql_query_response_t::Fql_query_response_t(const Xml::XmlNode& it)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Fql_query_response_t::clear()
{
}


// -----------------------------------------------------------------------------
void Fql_query_response_t::FromXml(const Xml::XmlNode& it)
{
}


// -----------------------------------------------------------------------------
const std::string Fql_query_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name + ">";
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Fql_query_response_t::IsSet() const
{
;
}


// -----------------------------------------------------------------------------
Fql_multiquery_response_t::Fql_multiquery_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Fql_multiquery_response_t::Fql_multiquery_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Fql_multiquery_response_t::clear()
{
	while (!_element_fql_result.empty())
		_element_fql_result.erase( _element_fql_result.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Fql_multiquery_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "fql_result");
		while (n)
		{
			com_facebook_1_0_::Fql_result tmp(n);
			_element_fql_result.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Fql_multiquery_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Fql_result>::const_iterator it = _element_fql_result.begin(); it != _element_fql_result.end(); it++)
	{
		const com_facebook_1_0_::Fql_result& ref = *it;
		r += ref.ToString("fql_result");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Fql_multiquery_response_t::IsSet() const
{
	return Fql_resultIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Fql_result>& Fql_multiquery_response_t::GetFql_result() const
{
	return _element_fql_result;
}


std::list<com_facebook_1_0_::Fql_result>& Fql_multiquery_response_t::GetFql_result()
{
	return _element_fql_result;
}


void Fql_multiquery_response_t::SetFql_result(const std::list<com_facebook_1_0_::Fql_result>& fql_result)
{
	_element_fql_result = fql_result;
}


// -----------------------------------------------------------------------------
bool Fql_multiquery_response_t::Fql_resultIsSet() const
{
	return !_element_fql_result.empty();
}


// -----------------------------------------------------------------------------
bool Fql_multiquery_response_t::GetList() const
{
	return _attribute_list;
}


void Fql_multiquery_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Batch_run_response_t::Batch_run_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Batch_run_response_t::Batch_run_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Batch_run_response_t::clear()
{
	while (!_element_batch_run_response_elt.empty())
		_element_batch_run_response_elt.erase( _element_batch_run_response_elt.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Batch_run_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "batch_run_response_elt");
		while (n)
		{
			_element_batch_run_response_elt.push_back( n.GetContent() );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Batch_run_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<std::string>::const_iterator it = _element_batch_run_response_elt.begin(); it != _element_batch_run_response_elt.end(); it++)
	{
		r += "<batch_run_response_elt>" + *it + "</batch_run_response_elt>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Batch_run_response_t::IsSet() const
{
	return Batch_run_response_eltIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<std::string>& Batch_run_response_t::GetBatch_run_response_elt() const
{
	return _element_batch_run_response_elt;
}


std::list<std::string>& Batch_run_response_t::GetBatch_run_response_elt()
{
	return _element_batch_run_response_elt;
}


void Batch_run_response_t::SetBatch_run_response_elt(const std::list<std::string>& batch_run_response_elt)
{
	_element_batch_run_response_elt = batch_run_response_elt;
}


// -----------------------------------------------------------------------------
bool Batch_run_response_t::Batch_run_response_eltIsSet() const
{
	return !_element_batch_run_response_elt.empty();
}


// -----------------------------------------------------------------------------
bool Batch_run_response_t::GetList() const
{
	return _attribute_list;
}


void Batch_run_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Message_getThreadsInFolder_response_t::Message_getThreadsInFolder_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Message_getThreadsInFolder_response_t::Message_getThreadsInFolder_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Message_getThreadsInFolder_response_t::clear()
{
	while (!_element_thread.empty())
		_element_thread.erase( _element_thread.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Message_getThreadsInFolder_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "thread");
		while (n)
		{
			com_facebook_1_0_::Thread tmp(n);
			_element_thread.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Message_getThreadsInFolder_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Thread>::const_iterator it = _element_thread.begin(); it != _element_thread.end(); it++)
	{
		const com_facebook_1_0_::Thread& ref = *it;
		r += ref.ToString("thread");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Message_getThreadsInFolder_response_t::IsSet() const
{
	return ThreadIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Thread>& Message_getThreadsInFolder_response_t::GetThread() const
{
	return _element_thread;
}


std::list<com_facebook_1_0_::Thread>& Message_getThreadsInFolder_response_t::GetThread()
{
	return _element_thread;
}


void Message_getThreadsInFolder_response_t::SetThread(const std::list<com_facebook_1_0_::Thread>& thread)
{
	_element_thread = thread;
}


// -----------------------------------------------------------------------------
bool Message_getThreadsInFolder_response_t::ThreadIsSet() const
{
	return !_element_thread.empty();
}


// -----------------------------------------------------------------------------
bool Message_getThreadsInFolder_response_t::GetList() const
{
	return _attribute_list;
}


void Message_getThreadsInFolder_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Photos_get_response_t::Photos_get_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Photos_get_response_t::Photos_get_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Photos_get_response_t::clear()
{
	while (!_element_photo.empty())
		_element_photo.erase( _element_photo.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Photos_get_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "photo");
		while (n)
		{
			com_facebook_1_0_::Photo tmp(n);
			_element_photo.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Photos_get_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Photo>::const_iterator it = _element_photo.begin(); it != _element_photo.end(); it++)
	{
		const com_facebook_1_0_::Photo& ref = *it;
		r += ref.ToString("photo");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Photos_get_response_t::IsSet() const
{
	return PhotoIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Photo>& Photos_get_response_t::GetPhoto() const
{
	return _element_photo;
}


std::list<com_facebook_1_0_::Photo>& Photos_get_response_t::GetPhoto()
{
	return _element_photo;
}


void Photos_get_response_t::SetPhoto(const std::list<com_facebook_1_0_::Photo>& photo)
{
	_element_photo = photo;
}


// -----------------------------------------------------------------------------
bool Photos_get_response_t::PhotoIsSet() const
{
	return !_element_photo.empty();
}


// -----------------------------------------------------------------------------
bool Photos_get_response_t::GetList() const
{
	return _attribute_list;
}


void Photos_get_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Photos_getAlbums_response_t::Photos_getAlbums_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Photos_getAlbums_response_t::Photos_getAlbums_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Photos_getAlbums_response_t::clear()
{
	while (!_element_album.empty())
		_element_album.erase( _element_album.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Photos_getAlbums_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "album");
		while (n)
		{
			com_facebook_1_0_::Album tmp(n);
			_element_album.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Photos_getAlbums_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Album>::const_iterator it = _element_album.begin(); it != _element_album.end(); it++)
	{
		const com_facebook_1_0_::Album& ref = *it;
		r += ref.ToString("album");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Photos_getAlbums_response_t::IsSet() const
{
	return AlbumIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Album>& Photos_getAlbums_response_t::GetAlbum() const
{
	return _element_album;
}


std::list<com_facebook_1_0_::Album>& Photos_getAlbums_response_t::GetAlbum()
{
	return _element_album;
}


void Photos_getAlbums_response_t::SetAlbum(const std::list<com_facebook_1_0_::Album>& album)
{
	_element_album = album;
}


// -----------------------------------------------------------------------------
bool Photos_getAlbums_response_t::AlbumIsSet() const
{
	return !_element_album.empty();
}


// -----------------------------------------------------------------------------
bool Photos_getAlbums_response_t::GetList() const
{
	return _attribute_list;
}


void Photos_getAlbums_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Photos_getTags_response_t::Photos_getTags_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Photos_getTags_response_t::Photos_getTags_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Photos_getTags_response_t::clear()
{
	while (!_element_photo_tag.empty())
		_element_photo_tag.erase( _element_photo_tag.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Photos_getTags_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "photo_tag");
		while (n)
		{
			com_facebook_1_0_::Photo_tag tmp(n);
			_element_photo_tag.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Photos_getTags_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Photo_tag>::const_iterator it = _element_photo_tag.begin(); it != _element_photo_tag.end(); it++)
	{
		const com_facebook_1_0_::Photo_tag& ref = *it;
		r += ref.ToString("photo_tag");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Photos_getTags_response_t::IsSet() const
{
	return Photo_tagIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Photo_tag>& Photos_getTags_response_t::GetPhoto_tag() const
{
	return _element_photo_tag;
}


std::list<com_facebook_1_0_::Photo_tag>& Photos_getTags_response_t::GetPhoto_tag()
{
	return _element_photo_tag;
}


void Photos_getTags_response_t::SetPhoto_tag(const std::list<com_facebook_1_0_::Photo_tag>& photo_tag)
{
	_element_photo_tag = photo_tag;
}


// -----------------------------------------------------------------------------
bool Photos_getTags_response_t::Photo_tagIsSet() const
{
	return !_element_photo_tag.empty();
}


// -----------------------------------------------------------------------------
bool Photos_getTags_response_t::GetList() const
{
	return _attribute_list;
}


void Photos_getTags_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Profile_getInfo_response_t::Profile_getInfo_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Profile_getInfo_response_t::Profile_getInfo_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Profile_getInfo_response_t::clear()
{
	while (!_element_user_info.empty())
		_element_user_info.erase( _element_user_info.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Profile_getInfo_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "user_info");
		while (n)
		{
			com_facebook_1_0_::User_info tmp(n);
			_element_user_info.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Profile_getInfo_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::User_info>::const_iterator it = _element_user_info.begin(); it != _element_user_info.end(); it++)
	{
		const com_facebook_1_0_::User_info& ref = *it;
		r += ref.ToString("user_info");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Profile_getInfo_response_t::IsSet() const
{
	return User_infoIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::User_info>& Profile_getInfo_response_t::GetUser_info() const
{
	return _element_user_info;
}


std::list<com_facebook_1_0_::User_info>& Profile_getInfo_response_t::GetUser_info()
{
	return _element_user_info;
}


void Profile_getInfo_response_t::SetUser_info(const std::list<com_facebook_1_0_::User_info>& user_info)
{
	_element_user_info = user_info;
}


// -----------------------------------------------------------------------------
bool Profile_getInfo_response_t::User_infoIsSet() const
{
	return !_element_user_info.empty();
}


// -----------------------------------------------------------------------------
bool Profile_getInfo_response_t::GetList() const
{
	return _attribute_list;
}


void Profile_getInfo_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Profile_getInfoOptions_response_t::Profile_getInfoOptions_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Profile_getInfoOptions_response_t::Profile_getInfoOptions_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Profile_getInfoOptions_response_t::clear()
{
	while (!_element_info_item.empty())
		_element_info_item.erase( _element_info_item.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Profile_getInfoOptions_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "info_item");
		while (n)
		{
			com_facebook_1_0_::Info_item tmp(n);
			_element_info_item.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Profile_getInfoOptions_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Info_item>::const_iterator it = _element_info_item.begin(); it != _element_info_item.end(); it++)
	{
		const com_facebook_1_0_::Info_item& ref = *it;
		r += ref.ToString("info_item");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Profile_getInfoOptions_response_t::IsSet() const
{
	return Info_itemIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Info_item>& Profile_getInfoOptions_response_t::GetInfo_item() const
{
	return _element_info_item;
}


std::list<com_facebook_1_0_::Info_item>& Profile_getInfoOptions_response_t::GetInfo_item()
{
	return _element_info_item;
}


void Profile_getInfoOptions_response_t::SetInfo_item(const std::list<com_facebook_1_0_::Info_item>& info_item)
{
	_element_info_item = info_item;
}


// -----------------------------------------------------------------------------
bool Profile_getInfoOptions_response_t::Info_itemIsSet() const
{
	return !_element_info_item.empty();
}


// -----------------------------------------------------------------------------
bool Profile_getInfoOptions_response_t::GetList() const
{
	return _attribute_list;
}


void Profile_getInfoOptions_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Update_decodeIDs_response_t::Update_decodeIDs_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Update_decodeIDs_response_t::Update_decodeIDs_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Update_decodeIDs_response_t::clear()
{
	while (!_element_id_map.empty())
		_element_id_map.erase( _element_id_map.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Update_decodeIDs_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "id_map");
		while (n)
		{
			com_facebook_1_0_::Id_map tmp(n);
			_element_id_map.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Update_decodeIDs_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Id_map>::const_iterator it = _element_id_map.begin(); it != _element_id_map.end(); it++)
	{
		const com_facebook_1_0_::Id_map& ref = *it;
		r += ref.ToString("id_map");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Update_decodeIDs_response_t::IsSet() const
{
	return Id_mapIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Id_map>& Update_decodeIDs_response_t::GetId_map() const
{
	return _element_id_map;
}


std::list<com_facebook_1_0_::Id_map>& Update_decodeIDs_response_t::GetId_map()
{
	return _element_id_map;
}


void Update_decodeIDs_response_t::SetId_map(const std::list<com_facebook_1_0_::Id_map>& id_map)
{
	_element_id_map = id_map;
}


// -----------------------------------------------------------------------------
bool Update_decodeIDs_response_t::Id_mapIsSet() const
{
	return !_element_id_map.empty();
}


// -----------------------------------------------------------------------------
bool Update_decodeIDs_response_t::GetList() const
{
	return _attribute_list;
}


void Update_decodeIDs_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Users_getInfo_response_t::Users_getInfo_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Users_getInfo_response_t::Users_getInfo_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Users_getInfo_response_t::clear()
{
	while (!_element_user.empty())
		_element_user.erase( _element_user.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Users_getInfo_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "user");
		while (n)
		{
			com_facebook_1_0_::User tmp(n);
			_element_user.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Users_getInfo_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::User>::const_iterator it = _element_user.begin(); it != _element_user.end(); it++)
	{
		const com_facebook_1_0_::User& ref = *it;
		r += ref.ToString("user");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Users_getInfo_response_t::IsSet() const
{
	return UserIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::User>& Users_getInfo_response_t::GetUser() const
{
	return _element_user;
}


std::list<com_facebook_1_0_::User>& Users_getInfo_response_t::GetUser()
{
	return _element_user;
}


void Users_getInfo_response_t::SetUser(const std::list<com_facebook_1_0_::User>& user)
{
	_element_user = user;
}


// -----------------------------------------------------------------------------
bool Users_getInfo_response_t::UserIsSet() const
{
	return !_element_user.empty();
}


// -----------------------------------------------------------------------------
bool Users_getInfo_response_t::GetList() const
{
	return _attribute_list;
}


void Users_getInfo_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Users_getStandardInfo_response_t::Users_getStandardInfo_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Users_getStandardInfo_response_t::Users_getStandardInfo_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Users_getStandardInfo_response_t::clear()
{
	while (!_element_user.empty())
		_element_user.erase( _element_user.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Users_getStandardInfo_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "user");
		while (n)
		{
			com_facebook_1_0_::User tmp(n);
			_element_user.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Users_getStandardInfo_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::User>::const_iterator it = _element_user.begin(); it != _element_user.end(); it++)
	{
		const com_facebook_1_0_::User& ref = *it;
		r += ref.ToString("user");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Users_getStandardInfo_response_t::IsSet() const
{
	return UserIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::User>& Users_getStandardInfo_response_t::GetUser() const
{
	return _element_user;
}


std::list<com_facebook_1_0_::User>& Users_getStandardInfo_response_t::GetUser()
{
	return _element_user;
}


void Users_getStandardInfo_response_t::SetUser(const std::list<com_facebook_1_0_::User>& user)
{
	_element_user = user;
}


// -----------------------------------------------------------------------------
bool Users_getStandardInfo_response_t::UserIsSet() const
{
	return !_element_user.empty();
}


// -----------------------------------------------------------------------------
bool Users_getStandardInfo_response_t::GetList() const
{
	return _attribute_list;
}


void Users_getStandardInfo_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Pages_getInfo_response_t::Pages_getInfo_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Pages_getInfo_response_t::Pages_getInfo_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Pages_getInfo_response_t::clear()
{
	while (!_element_page.empty())
		_element_page.erase( _element_page.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Pages_getInfo_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "page");
		while (n)
		{
			com_facebook_1_0_::Page tmp(n);
			_element_page.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Pages_getInfo_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Page>::const_iterator it = _element_page.begin(); it != _element_page.end(); it++)
	{
		const com_facebook_1_0_::Page& ref = *it;
		r += ref.ToString("page");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Pages_getInfo_response_t::IsSet() const
{
	return PageIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Page>& Pages_getInfo_response_t::GetPage() const
{
	return _element_page;
}


std::list<com_facebook_1_0_::Page>& Pages_getInfo_response_t::GetPage()
{
	return _element_page;
}


void Pages_getInfo_response_t::SetPage(const std::list<com_facebook_1_0_::Page>& page)
{
	_element_page = page;
}


// -----------------------------------------------------------------------------
bool Pages_getInfo_response_t::PageIsSet() const
{
	return !_element_page.empty();
}


// -----------------------------------------------------------------------------
bool Pages_getInfo_response_t::GetList() const
{
	return _attribute_list;
}


void Pages_getInfo_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Data_getUserPreferences_response_t::Data_getUserPreferences_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Data_getUserPreferences_response_t::Data_getUserPreferences_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Data_getUserPreferences_response_t::clear()
{
	while (!_element_preference.empty())
		_element_preference.erase( _element_preference.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Data_getUserPreferences_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "preference");
		while (n)
		{
			com_facebook_1_0_::Preference tmp(n);
			_element_preference.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Data_getUserPreferences_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Preference>::const_iterator it = _element_preference.begin(); it != _element_preference.end(); it++)
	{
		const com_facebook_1_0_::Preference& ref = *it;
		r += ref.ToString("preference");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Data_getUserPreferences_response_t::IsSet() const
{
	return PreferenceIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Preference>& Data_getUserPreferences_response_t::GetPreference() const
{
	return _element_preference;
}


std::list<com_facebook_1_0_::Preference>& Data_getUserPreferences_response_t::GetPreference()
{
	return _element_preference;
}


void Data_getUserPreferences_response_t::SetPreference(const std::list<com_facebook_1_0_::Preference>& preference)
{
	_element_preference = preference;
}


// -----------------------------------------------------------------------------
bool Data_getUserPreferences_response_t::PreferenceIsSet() const
{
	return !_element_preference.empty();
}


// -----------------------------------------------------------------------------
bool Data_getUserPreferences_response_t::GetList() const
{
	return _attribute_list;
}


void Data_getUserPreferences_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Data_getObjectTypes_response_t::Data_getObjectTypes_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Data_getObjectTypes_response_t::Data_getObjectTypes_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Data_getObjectTypes_response_t::clear()
{
	while (!_element_object_type_info.empty())
		_element_object_type_info.erase( _element_object_type_info.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Data_getObjectTypes_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "object_type_info");
		while (n)
		{
			com_facebook_1_0_::Object_type_info tmp(n);
			_element_object_type_info.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Data_getObjectTypes_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Object_type_info>::const_iterator it = _element_object_type_info.begin(); it != _element_object_type_info.end(); it++)
	{
		const com_facebook_1_0_::Object_type_info& ref = *it;
		r += ref.ToString("object_type_info");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Data_getObjectTypes_response_t::IsSet() const
{
	return Object_type_infoIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Object_type_info>& Data_getObjectTypes_response_t::GetObject_type_info() const
{
	return _element_object_type_info;
}


std::list<com_facebook_1_0_::Object_type_info>& Data_getObjectTypes_response_t::GetObject_type_info()
{
	return _element_object_type_info;
}


void Data_getObjectTypes_response_t::SetObject_type_info(const std::list<com_facebook_1_0_::Object_type_info>& object_type_info)
{
	_element_object_type_info = object_type_info;
}


// -----------------------------------------------------------------------------
bool Data_getObjectTypes_response_t::Object_type_infoIsSet() const
{
	return !_element_object_type_info.empty();
}


// -----------------------------------------------------------------------------
bool Data_getObjectTypes_response_t::GetList() const
{
	return _attribute_list;
}


void Data_getObjectTypes_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Data_getObjectType_response_t::Data_getObjectType_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Data_getObjectType_response_t::Data_getObjectType_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Data_getObjectType_response_t::clear()
{
	while (!_element_object_property_info.empty())
		_element_object_property_info.erase( _element_object_property_info.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Data_getObjectType_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "object_property_info");
		while (n)
		{
			com_facebook_1_0_::Object_property_info tmp(n);
			_element_object_property_info.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Data_getObjectType_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Object_property_info>::const_iterator it = _element_object_property_info.begin(); it != _element_object_property_info.end(); it++)
	{
		const com_facebook_1_0_::Object_property_info& ref = *it;
		r += ref.ToString("object_property_info");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Data_getObjectType_response_t::IsSet() const
{
	return Object_property_infoIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Object_property_info>& Data_getObjectType_response_t::GetObject_property_info() const
{
	return _element_object_property_info;
}


std::list<com_facebook_1_0_::Object_property_info>& Data_getObjectType_response_t::GetObject_property_info()
{
	return _element_object_property_info;
}


void Data_getObjectType_response_t::SetObject_property_info(const std::list<com_facebook_1_0_::Object_property_info>& object_property_info)
{
	_element_object_property_info = object_property_info;
}


// -----------------------------------------------------------------------------
bool Data_getObjectType_response_t::Object_property_infoIsSet() const
{
	return !_element_object_property_info.empty();
}


// -----------------------------------------------------------------------------
bool Data_getObjectType_response_t::GetList() const
{
	return _attribute_list;
}


void Data_getObjectType_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Data_getObjects_response_t::Data_getObjects_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Data_getObjects_response_t::Data_getObjects_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Data_getObjects_response_t::clear()
{
	while (!_element_data_getObjects_response_elt.empty())
		_element_data_getObjects_response_elt.erase( _element_data_getObjects_response_elt.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Data_getObjects_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "data_getObjects_response_elt");
		while (n)
		{
			com_facebook_1_0_::Container tmp(n);
			_element_data_getObjects_response_elt.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Data_getObjects_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Container>::const_iterator it = _element_data_getObjects_response_elt.begin(); it != _element_data_getObjects_response_elt.end(); it++)
	{
		const com_facebook_1_0_::Container& ref = *it;
		r += ref.ToString("data_getObjects_response_elt");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Data_getObjects_response_t::IsSet() const
{
	return Data_getObjects_response_eltIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Container>& Data_getObjects_response_t::GetData_getObjects_response_elt() const
{
	return _element_data_getObjects_response_elt;
}


std::list<com_facebook_1_0_::Container>& Data_getObjects_response_t::GetData_getObjects_response_elt()
{
	return _element_data_getObjects_response_elt;
}


void Data_getObjects_response_t::SetData_getObjects_response_elt(const std::list<com_facebook_1_0_::Container>& data_getObjects_response_elt)
{
	_element_data_getObjects_response_elt = data_getObjects_response_elt;
}


// -----------------------------------------------------------------------------
bool Data_getObjects_response_t::Data_getObjects_response_eltIsSet() const
{
	return !_element_data_getObjects_response_elt.empty();
}


// -----------------------------------------------------------------------------
bool Data_getObjects_response_t::GetList() const
{
	return _attribute_list;
}


void Data_getObjects_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Data_getAssociationDefinitions_response_t::Data_getAssociationDefinitions_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Data_getAssociationDefinitions_response_t::Data_getAssociationDefinitions_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Data_getAssociationDefinitions_response_t::clear()
{
	while (!_element_object_assoc_info.empty())
		_element_object_assoc_info.erase( _element_object_assoc_info.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Data_getAssociationDefinitions_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "object_assoc_info");
		while (n)
		{
			com_facebook_1_0_::Object_assoc_info tmp(n);
			_element_object_assoc_info.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Data_getAssociationDefinitions_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Object_assoc_info>::const_iterator it = _element_object_assoc_info.begin(); it != _element_object_assoc_info.end(); it++)
	{
		const com_facebook_1_0_::Object_assoc_info& ref = *it;
		r += ref.ToString("object_assoc_info");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Data_getAssociationDefinitions_response_t::IsSet() const
{
	return Object_assoc_infoIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Object_assoc_info>& Data_getAssociationDefinitions_response_t::GetObject_assoc_info() const
{
	return _element_object_assoc_info;
}


std::list<com_facebook_1_0_::Object_assoc_info>& Data_getAssociationDefinitions_response_t::GetObject_assoc_info()
{
	return _element_object_assoc_info;
}


void Data_getAssociationDefinitions_response_t::SetObject_assoc_info(const std::list<com_facebook_1_0_::Object_assoc_info>& object_assoc_info)
{
	_element_object_assoc_info = object_assoc_info;
}


// -----------------------------------------------------------------------------
bool Data_getAssociationDefinitions_response_t::Object_assoc_infoIsSet() const
{
	return !_element_object_assoc_info.empty();
}


// -----------------------------------------------------------------------------
bool Data_getAssociationDefinitions_response_t::GetList() const
{
	return _attribute_list;
}


void Data_getAssociationDefinitions_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Data_getAssociatedObjects_response_t::Data_getAssociatedObjects_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Data_getAssociatedObjects_response_t::Data_getAssociatedObjects_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Data_getAssociatedObjects_response_t::clear()
{
	while (!_element_object_association.empty())
		_element_object_association.erase( _element_object_association.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Data_getAssociatedObjects_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "object_association");
		while (n)
		{
			com_facebook_1_0_::Object_association tmp(n);
			_element_object_association.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Data_getAssociatedObjects_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Object_association>::const_iterator it = _element_object_association.begin(); it != _element_object_association.end(); it++)
	{
		const com_facebook_1_0_::Object_association& ref = *it;
		r += ref.ToString("object_association");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Data_getAssociatedObjects_response_t::IsSet() const
{
	return Object_associationIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Object_association>& Data_getAssociatedObjects_response_t::GetObject_association() const
{
	return _element_object_association;
}


std::list<com_facebook_1_0_::Object_association>& Data_getAssociatedObjects_response_t::GetObject_association()
{
	return _element_object_association;
}


void Data_getAssociatedObjects_response_t::SetObject_association(const std::list<com_facebook_1_0_::Object_association>& object_association)
{
	_element_object_association = object_association;
}


// -----------------------------------------------------------------------------
bool Data_getAssociatedObjects_response_t::Object_associationIsSet() const
{
	return !_element_object_association.empty();
}


// -----------------------------------------------------------------------------
bool Data_getAssociatedObjects_response_t::GetList() const
{
	return _attribute_list;
}


void Data_getAssociatedObjects_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Data_getAssociatedObjectCounts_response_t::Data_getAssociatedObjectCounts_response_t()
: _element_data_getAssociatedObjectCounts_response_elt(0)
, _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Data_getAssociatedObjectCounts_response_t::Data_getAssociatedObjectCounts_response_t(const Xml::XmlNode& it)
: _element_data_getAssociatedObjectCounts_response_elt(0)
, _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Data_getAssociatedObjectCounts_response_t::clear()
{
	while (!_element_data_getAssociatedObjectCounts_response_elt.empty())
		_element_data_getAssociatedObjectCounts_response_elt.erase( _element_data_getAssociatedObjectCounts_response_elt.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Data_getAssociatedObjectCounts_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "data_getAssociatedObjectCounts_response_elt");
		while (n)
		{
			_element_data_getAssociatedObjectCounts_response_elt.push_back( atoi(n.GetContent().c_str()) );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Data_getAssociatedObjectCounts_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<int>::const_iterator it = _element_data_getAssociatedObjectCounts_response_elt.begin(); it != _element_data_getAssociatedObjectCounts_response_elt.end(); it++)
	{
		{
			r = r + "<data_getAssociatedObjectCounts_response_elt>" + Utility::l2string(*it) + "</data_getAssociatedObjectCounts_response_elt>";
		}
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Data_getAssociatedObjectCounts_response_t::IsSet() const
{
	return Data_getAssociatedObjectCounts_response_eltIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<int>& Data_getAssociatedObjectCounts_response_t::GetData_getAssociatedObjectCounts_response_elt() const
{
	return _element_data_getAssociatedObjectCounts_response_elt;
}


std::list<int>& Data_getAssociatedObjectCounts_response_t::GetData_getAssociatedObjectCounts_response_elt()
{
	return _element_data_getAssociatedObjectCounts_response_elt;
}


void Data_getAssociatedObjectCounts_response_t::SetData_getAssociatedObjectCounts_response_elt(const std::list<int>& data_getAssociatedObjectCounts_response_elt)
{
	_element_data_getAssociatedObjectCounts_response_elt = data_getAssociatedObjectCounts_response_elt;
}


// -----------------------------------------------------------------------------
bool Data_getAssociatedObjectCounts_response_t::Data_getAssociatedObjectCounts_response_eltIsSet() const
{
	return !_element_data_getAssociatedObjectCounts_response_elt.empty();
}


// -----------------------------------------------------------------------------
bool Data_getAssociatedObjectCounts_response_t::GetList() const
{
	return _attribute_list;
}


void Data_getAssociatedObjectCounts_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Data_getAssociations_response_t::Data_getAssociations_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Data_getAssociations_response_t::Data_getAssociations_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Data_getAssociations_response_t::clear()
{
	while (!_element_object_association.empty())
		_element_object_association.erase( _element_object_association.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Data_getAssociations_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "object_association");
		while (n)
		{
			com_facebook_1_0_::Object_association tmp(n);
			_element_object_association.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Data_getAssociations_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Object_association>::const_iterator it = _element_object_association.begin(); it != _element_object_association.end(); it++)
	{
		const com_facebook_1_0_::Object_association& ref = *it;
		r += ref.ToString("object_association");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Data_getAssociations_response_t::IsSet() const
{
	return Object_associationIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Object_association>& Data_getAssociations_response_t::GetObject_association() const
{
	return _element_object_association;
}


std::list<com_facebook_1_0_::Object_association>& Data_getAssociations_response_t::GetObject_association()
{
	return _element_object_association;
}


void Data_getAssociations_response_t::SetObject_association(const std::list<com_facebook_1_0_::Object_association>& object_association)
{
	_element_object_association = object_association;
}


// -----------------------------------------------------------------------------
bool Data_getAssociations_response_t::Object_associationIsSet() const
{
	return !_element_object_association.empty();
}


// -----------------------------------------------------------------------------
bool Data_getAssociations_response_t::GetList() const
{
	return _attribute_list;
}


void Data_getAssociations_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Admin_getBannedUsers_response_t::Admin_getBannedUsers_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Admin_getBannedUsers_response_t::Admin_getBannedUsers_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Admin_getBannedUsers_response_t::clear()
{
	while (!_element_uid.empty())
		_element_uid.erase( _element_uid.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Admin_getBannedUsers_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "uid");
		while (n)
		{
			_element_uid.push_back( atoi(n.GetContent().c_str()) );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Admin_getBannedUsers_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<long>::const_iterator it = _element_uid.begin(); it != _element_uid.end(); it++)
	{
			r = r + "<uid>" + Utility::l2string(*it) + "</uid>";
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Admin_getBannedUsers_response_t::IsSet() const
{
	return UidIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<long>& Admin_getBannedUsers_response_t::GetUid() const
{
	return _element_uid;
}


std::list<long>& Admin_getBannedUsers_response_t::GetUid()
{
	return _element_uid;
}


void Admin_getBannedUsers_response_t::SetUid(const std::list<long>& uid)
{
	_element_uid = uid;
}


// -----------------------------------------------------------------------------
bool Admin_getBannedUsers_response_t::UidIsSet() const
{
	return !_element_uid.empty();
}


// -----------------------------------------------------------------------------
bool Admin_getBannedUsers_response_t::GetList() const
{
	return _attribute_list;
}


void Admin_getBannedUsers_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Feed_getRegisteredTemplateBundles_response_t::Feed_getRegisteredTemplateBundles_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Feed_getRegisteredTemplateBundles_response_t::Feed_getRegisteredTemplateBundles_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Feed_getRegisteredTemplateBundles_response_t::clear()
{
	while (!_element_template_bundle.empty())
		_element_template_bundle.erase( _element_template_bundle.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Feed_getRegisteredTemplateBundles_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "template_bundle");
		while (n)
		{
			com_facebook_1_0_::Template_bundle tmp(n);
			_element_template_bundle.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Feed_getRegisteredTemplateBundles_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Template_bundle>::const_iterator it = _element_template_bundle.begin(); it != _element_template_bundle.end(); it++)
	{
		const com_facebook_1_0_::Template_bundle& ref = *it;
		r += ref.ToString("template_bundle");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Feed_getRegisteredTemplateBundles_response_t::IsSet() const
{
	return Template_bundleIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Template_bundle>& Feed_getRegisteredTemplateBundles_response_t::GetTemplate_bundle() const
{
	return _element_template_bundle;
}


std::list<com_facebook_1_0_::Template_bundle>& Feed_getRegisteredTemplateBundles_response_t::GetTemplate_bundle()
{
	return _element_template_bundle;
}


void Feed_getRegisteredTemplateBundles_response_t::SetTemplate_bundle(const std::list<com_facebook_1_0_::Template_bundle>& template_bundle)
{
	_element_template_bundle = template_bundle;
}


// -----------------------------------------------------------------------------
bool Feed_getRegisteredTemplateBundles_response_t::Template_bundleIsSet() const
{
	return !_element_template_bundle.empty();
}


// -----------------------------------------------------------------------------
bool Feed_getRegisteredTemplateBundles_response_t::GetList() const
{
	return _attribute_list;
}


void Feed_getRegisteredTemplateBundles_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Feed_getAppFriendStories_response_t::Feed_getAppFriendStories_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Feed_getAppFriendStories_response_t::Feed_getAppFriendStories_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Feed_getAppFriendStories_response_t::clear()
{
	while (!_element_feed_story.empty())
		_element_feed_story.erase( _element_feed_story.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Feed_getAppFriendStories_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "feed_story");
		while (n)
		{
			com_facebook_1_0_::Feed_story tmp(n);
			_element_feed_story.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Feed_getAppFriendStories_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Feed_story>::const_iterator it = _element_feed_story.begin(); it != _element_feed_story.end(); it++)
	{
		const com_facebook_1_0_::Feed_story& ref = *it;
		r += ref.ToString("feed_story");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Feed_getAppFriendStories_response_t::IsSet() const
{
	return Feed_storyIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Feed_story>& Feed_getAppFriendStories_response_t::GetFeed_story() const
{
	return _element_feed_story;
}


std::list<com_facebook_1_0_::Feed_story>& Feed_getAppFriendStories_response_t::GetFeed_story()
{
	return _element_feed_story;
}


void Feed_getAppFriendStories_response_t::SetFeed_story(const std::list<com_facebook_1_0_::Feed_story>& feed_story)
{
	_element_feed_story = feed_story;
}


// -----------------------------------------------------------------------------
bool Feed_getAppFriendStories_response_t::Feed_storyIsSet() const
{
	return !_element_feed_story.empty();
}


// -----------------------------------------------------------------------------
bool Feed_getAppFriendStories_response_t::GetList() const
{
	return _attribute_list;
}


void Feed_getAppFriendStories_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


// -----------------------------------------------------------------------------
Admin_getMetrics_response_t::Admin_getMetrics_response_t()
: _attribute_list(false)
, _attribute_list_is_set(false)
{
}


// -----------------------------------------------------------------------------
Admin_getMetrics_response_t::Admin_getMetrics_response_t(const Xml::XmlNode& it)
: _attribute_list(false)
, _attribute_list_is_set(false)
{
	FromXml(it);
}


// -----------------------------------------------------------------------------
void Admin_getMetrics_response_t::clear()
{
	while (!_element_metrics.empty())
		_element_metrics.erase( _element_metrics.begin() );
	_attribute_list = false;
	_attribute_list_is_set = false;
}


// -----------------------------------------------------------------------------
void Admin_getMetrics_response_t::FromXml(const Xml::XmlNode& it)
{
	{
		Xml::XmlNode n(it, "metrics");
		while (n)
		{
			com_facebook_1_0_::Metrics tmp(n);
			_element_metrics.push_back( tmp );
			++n;
		}
	}
	if (it.PropertyExists("list"))
		SetList( atoi(it.GetProperty("list").c_str()) );
}


// -----------------------------------------------------------------------------
const std::string Admin_getMetrics_response_t::ToString(const std::string& name) const
{
	std::string r;
	if (!name.empty())
		r += "<" + name;
	if (ListIsSet())
	{
		r = r + " list='" + Utility::l2string(GetList()) + "'";
	}
	r += ">";
	for (std::list<com_facebook_1_0_::Metrics>::const_iterator it = _element_metrics.begin(); it != _element_metrics.end(); it++)
	{
		const com_facebook_1_0_::Metrics& ref = *it;
		r += ref.ToString("metrics");
	}
	if (!name.empty())
		r += "</" + name + ">";
	return r;
}


// -----------------------------------------------------------------------------
bool Admin_getMetrics_response_t::IsSet() const
{
	return MetricsIsSet() || ListIsSet();
}


// -----------------------------------------------------------------------------
const std::list<com_facebook_1_0_::Metrics>& Admin_getMetrics_response_t::GetMetrics() const
{
	return _element_metrics;
}


std::list<com_facebook_1_0_::Metrics>& Admin_getMetrics_response_t::GetMetrics()
{
	return _element_metrics;
}


void Admin_getMetrics_response_t::SetMetrics(const std::list<com_facebook_1_0_::Metrics>& metrics)
{
	_element_metrics = metrics;
}


// -----------------------------------------------------------------------------
bool Admin_getMetrics_response_t::MetricsIsSet() const
{
	return !_element_metrics.empty();
}


// -----------------------------------------------------------------------------
bool Admin_getMetrics_response_t::GetList() const
{
	return _attribute_list;
}


void Admin_getMetrics_response_t::SetList(bool list)
{
	_attribute_list = list;
	_attribute_list_is_set = true;
}


} // namespace com_facebook_1_0_

